diff --git a/books/bookvol10.3.pamphlet b/books/bookvol10.3.pamphlet
index 9454583..e496cbf 100644
--- a/books/bookvol10.3.pamphlet
+++ b/books/bookvol10.3.pamphlet
@@ -17368,6 +17368,134 @@ CartesianTensor(minix, dim, R): Exports == Implementation where
 
 \end{chunk}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{domain CELL Cell}
+
+\begin{chunk}{Cell.input}
+)set break resume
+)sys rm -f Cell.output
+)spool Cell.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1
+)show Cell
+--E 1
+
+)spool
+)lisp (bye)
+\end{chunk}
+\begin{chunk}{Cell.help}
+====================================================================
+Cell examples
+====================================================================
+
+See Also:
+o )show Cell
+
+\end{chunk}
+
+\pagehead{Cell}{CELL}
+\pagepic{ps/v103cell.eps}{CELL}{1.00}
+{\bf See}\\
+
+{\bf Exports:}\\
+\begin{tabular}{lll}
+\cross{CELL}{coerce} &
+\cross{CELL}{mainVariableOf} &
+\cross{CELL}{samplePoint}\\
+\cross{CELL}{variablesOf} &
+\cross{CELL}{dimension} &
+\cross{CELL}{hasDimension?} \\
+\cross{CELL}{makeCell} &
+\cross{CELL}{makeCell} &
+\cross{CELL}{projection}
+\end{tabular}
+
+\begin{chunk}{domain CELL Cell}
+)abbrev domain CELL Cell
+Cell(TheField) : PUB == PRIV where
+  TheField : RealClosedField
+
+  ThePols ==> Polynomial(TheField)
+
+  O           ==> OutputForm
+  B           ==> Boolean
+  Z           ==> Integer
+  N           ==> NonNegativeInteger
+  BUP         ==> SparseUnivariatePolynomial(TheField)
+  SCELL       ==> SimpleCell(TheField,BUP)
+
+  PUB == CoercibleTo(O) with
+
+     samplePoint : % -> List(TheField)
+
+     dimension : % -> N
+
+     hasDimension? :  (%,Symbol) -> B
+
+     makeCell : List(SCELL) -> %
+
+     makeCell : (SCELL,%) -> %
+
+     mainVariableOf : % -> Symbol
+
+     variablesOf : % -> List Symbol
+
+     projection : % -> Union(%,"failed")
+
+  PRIV == add
+
+    Rep := List(SCELL)
+
+    coerce(c:%):O == 
+      paren [sc::O for sc in c]
+
+    projection(cell) ==
+      null cell => error "projection: should not appear"
+      r := rest(cell)
+      null r => "failed"
+      r
+
+    makeCell(l:List(SCELL)) == l
+
+    makeCell(scell,toAdd) == cons(scell,toAdd)
+
+    mainVariableOf(cell) == 
+      null(cell) => 
+        error "Should not appear"
+      variableOf(first(cell))
+
+    variablesOf(cell) ==
+      null(cell) => []
+      cons(mainVariableOf(cell),variablesOf(rest(cell)::%))
+
+    dimension(cell) ==
+      null(cell) => 0
+      hasDimension?(first(cell)) => 1+dimension(rest(cell))
+      dimension(rest(cell))
+
+    hasDimension?(cell,var) ==
+      null(cell) => 
+        error "Should not appear"
+      sc : SCELL := first(cell)
+      v := variableOf(sc)
+      v = var => hasDimension?(sc)
+      v < var => false
+      v > var => true
+      error "Caca Prout"
+
+    samplePoint(cell) ==
+      null(cell) => []
+      cons(samplePoint(first(cell)),samplePoint(rest(cell)))
+
+\end{chunk}
+\begin{chunk}{CELL.dotabb}
+"CELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CELL"]
+"SCELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SCELL"]
+"CELL" -> "SCELL"
+\end{chunk}
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{domain CHAR Character}
 
 \begin{chunk}{Character.input}
@@ -118072,6 +118200,167 @@ SimpleAlgebraicExtension(R:CommutativeRing,
 
 \end{chunk}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{domain SCELL SimpleCell}
+This domain is made to work with one-dimensional semi-algebraic cells
+ie either an algebraic point, either an interval. The point is specified as 
+specification of an algebraic value.
+
+\begin{chunk}{SimpleCell.input}
+)set break resume
+)sys rm -f SimpleCell.output
+)spool SimpleCell.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1
+)show SimpleCell
+--E 1
+
+)spool
+)lisp (bye)
+\end{chunk}
+\begin{chunk}{SimpleCell.help}
+====================================================================
+SimpleCell examples
+====================================================================
+
+This domain is made to work with one-dimensional semi-algebraic cells
+ie either an algebraic point, either an interval. The point is
+specified as specification of an algebraic value.
+
+See Also:
+o )show SimpleCell
+
+\end{chunk}
+
+\pagehead{SimpleCell}{SCELL}
+\pagepic{ps/v103simplecell.eps}{SCELL}{1.00}
+{\bf See}\\
+
+{\bf Exports:}\\
+\begin{tabular}{lll}
+\cross{SCELL}{coerce} &
+\cross{SCELL}{hasDimension?} &
+\cross{SCELL}{samplePoint} \\
+\cross{SCELL}{stablePol} &
+\cross{SCELL}{variableOf} &
+\cross{SCELL}{allSimpleCells} \\
+\cross{SCELL}{allSimpleCells} &
+\cross{SCELL}{pointToCell} &
+\cross{SCELL}{separe}
+\end{tabular}
+
+\begin{chunk}{domain SCELL SimpleCell}
+)abbrev domain SCELL SimpleCell
+SimpleCell(TheField,ThePols) : PUB == PRIV where
+  TheField : RealClosedField
+  ThePols : UnivariatePolynomialCategory(TheField)
+  O           ==> OutputForm
+  B           ==> Boolean
+  Z           ==> Integer
+  N           ==> NonNegativeInteger
+  VARS ==> RealPolynomialUtilitiesPackage(TheField,ThePols)
+  LF ==> List(TheField)
+
+  PUB == CoercibleTo(O) with
+     allSimpleCells : (ThePols,Symbol) -> List %
+
+     allSimpleCells : (List(ThePols),Symbol) -> List %
+
+     hasDimension? : % -> B
+
+     samplePoint : % -> TheField
+
+     stablePol : % -> ThePols
+
+     variableOf : % -> Symbol
+
+     separe : (LF,TheField,TheField) -> LF
+
+     pointToCell : (TheField,B,Symbol) -> %
+
+  PRIV == add
+
+     Rep := Record(samplePoint:TheField,
+                   hasDim:B,
+                   varOf:Symbol)
+
+     samplePoint(c) == c.samplePoint
+
+     stablePol(c) == error "Prout"
+
+     hasDimension?(c) == c.hasDim
+
+     variableOf(c) == c.varOf
+
+     coerce(c:%):O ==
+       o : O := ((c.varOf)::O) = ((c.samplePoint)::O)
+       brace [o,(c.hasDim)::O]
+
+     separe(liste,gauche,droite) ==
+       milieu : TheField := (gauche + droite) / (2::TheField)
+       liste = [] => [milieu]
+       #liste = 1 => [gauche,first(liste),droite]
+       nbe := first(liste)
+       lg :List(TheField) := []
+       ld :List(TheField) := rest(liste)
+       sg := sign(milieu-nbe)
+       while sg > 0 repeat
+         lg := cons(nbe,lg)
+         ld = [] => return(separe(reverse(lg),gauche,milieu))
+         nbe := first(ld)
+         sg := sign(milieu-nbe)
+         ld := rest(ld)
+       sg < 0 =>
+         append(separe(reverse(lg),gauche,milieu),
+                rest(separe(cons(nbe,ld),milieu,droite)))
+       newDroite := (gauche+milieu)/(2::TheField)
+       null lg =>
+           newGauche := (milieu+droite)/(2::TheField)
+           while newGauche >= first(ld) repeat
+             newGauche := (milieu+newGauche)/(2::TheField)
+           append([gauche,milieu],separe(ld,newGauche,droite))
+       while newDroite <= first(lg) repeat
+         newDroite := (newDroite+milieu)/(2::TheField)
+       newGauche := (milieu+droite)/(2::TheField)
+       null ld => append(separe(reverse(lg),gauche,newDroite),[milieu,droite])
+       while newGauche >= first(ld) repeat
+         newGauche := (milieu+newGauche)/(2::TheField)
+       append(separe(reverse(lg),gauche,newDroite),
+              cons(milieu,separe(ld,newGauche,droite)))
+
+     pointToCell(sp,hasDim?,varName) ==
+       [sp,hasDim?,varName]$Rep
+
+     allSimpleCells(p:ThePols,var:Symbol) ==
+       allSimpleCells([p],var)
+
+     PACK ==> CylindricalAlgebraicDecompositionUtilities(TheField,ThePols)
+     allSimpleCells(lp:List(ThePols),var:Symbol) ==
+       lp1 := gcdBasis(lp)$PACK
+       null(lp1) => [pointToCell(0,true,var)]
+       b := ("max" / [ boundOfCauchy(p)$VARS for p in lp1 ])::TheField
+       l := "append" / [allRootsOf(makeSUP(unitCanonical(p))) for p in lp1]
+       l := sort(l)
+       l1 := separe(l,-b,b)
+       res : List(%) := [pointToCell(first(l1),true,var)]
+       l1 := rest(l1)
+       while not(null(l1)) repeat
+         res := cons(pointToCell(first(l1),false,var),res)
+         l1 := rest(l1)
+         l1 = [] => return(error "Liste vide")
+         res := cons(pointToCell(first(l1),true,var),res)
+         l1 := rest(l1)
+       reverse! res
+
+\end{chunk}
+\begin{chunk}{SCELL.dotabb}
+"SCELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SCELL"]
+"ALIST" [color="#88FF44",href="bookvol10.3.pdf#nameddest=ALIST"]
+"SCELL" -> "ALIST"
+\end{chunk}
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{domain SFORT SimpleFortranProgram}
 
 \begin{chunk}{SimpleFortranProgram.input}
@@ -155341,6 +155630,7 @@ Note that this code is not included in the generated catdef.spad file.
 
 \getchunk{domain CARD CardinalNumber}
 \getchunk{domain CARTEN CartesianTensor}
+\getchunk{domain CELL Cell}
 \getchunk{domain CHAR Character}
 \getchunk{domain CCLASS CharacterClass}
 \getchunk{domain CLIF CliffordAlgebra}
@@ -155630,6 +155920,7 @@ Note that this code is not included in the generated catdef.spad file.
 \getchunk{domain SEX SExpression}
 \getchunk{domain SEXOF SExpressionOf}
 \getchunk{domain SAE SimpleAlgebraicExtension}
+\getchunk{domain SCELL SimpleCell}
 \getchunk{domain SFORT SimpleFortranProgram}
 \getchunk{domain SINT SingleInteger}
 \getchunk{domain SAOS SingletonAsOrderedSet}
diff --git a/books/bookvol10.4.pamphlet b/books/bookvol10.4.pamphlet
index 057850e..1b5716f 100644
--- a/books/bookvol10.4.pamphlet
+++ b/books/bookvol10.4.pamphlet
@@ -12701,6 +12701,290 @@ CyclotomicPolynomialPackage: public == private where
 
 \end{chunk}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{package CAD CylindricalAlgebraicDecompositionPackage}
+\begin{chunk}{CylindricalAlgebraicDecompositionPackage.input}
+)set break resume
+)sys rm -f CylindricalAlgebraicDecompositionPackage.output
+)spool CylindricalAlgebraicDecompositionPackage.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1
+)show CylindricalAlgebraicDecompositionPackage
+--E 1
+
+)spool
+)lisp (bye)
+\end{chunk}
+\begin{chunk}{CylindricalAlgebraicDecompositionPackage.help}
+====================================================================
+CylindricalAlgebraicDecompositionPackage examples
+====================================================================
+
+See Also:
+o )show CylindricalAlgebraicDecompositionPackage
+
+\end{chunk}
+\pagehead{CylindricalAlgebraicDecompositionPackage}{CAD}
+\pagepic{ps/v104cylindricalalgebraicdecompositionpackage.eps}{CAD}{1.00}
+
+{\bf Exports:}\\
+\begin{tabular}{lll}
+\cross{CAD}{coefficientSet} &
+\cross{CAD}{cylindricalDecomposition} &
+\cross{CAD}{cylindricalDecomposition} \\
+\cross{CAD}{discriminantSet} &
+\cross{CAD}{principalSubResultantSet} &
+\cross{CAD}{projectionSet} \\
+\cross{CAD}{resultantSet} &
+\cross{CAD}{specialise}
+\end{tabular}
+
+\begin{chunk}{package CAD CylindricalAlgebraicDecompositionPackage}
+)abbrev package CAD CylindricalAlgebraicDecompositionPackage
+
+CylindricalAlgebraicDecompositionPackage(TheField) : PUB == PRIV where
+
+  TheField : RealClosedField
+
+  ThePols ==> Polynomial(TheField)
+  P ==> ThePols
+  BUP ==> SparseUnivariatePolynomial(TheField)
+  RUP ==> SparseUnivariatePolynomial(ThePols)
+
+  Z           ==> Integer
+  N           ==> NonNegativeInteger
+
+  CELL ==> Cell(TheField)
+  SCELL ==> SimpleCell(TheField,BUP)
+
+  PUB == with
+
+      cylindricalDecomposition: List P -> List CELL
+
+      cylindricalDecomposition: (List(P),List(Symbol)) -> List CELL
+
+      projectionSet: (List RUP) -> List P
+
+      coefficientSet: RUP -> List P
+
+      discriminantSet : List RUP -> List(P)
+
+      resultantSet :  List RUP -> List P 
+
+      principalSubResultantSet : (RUP,RUP) -> List P
+
+      specialise : (List(ThePols),CELL) -> List(BUP)
+
+  PRIV == add
+
+     cylindricalDecomposition(lpols) ==
+       lv : List(Symbol) := []
+       for pol in lpols repeat
+         ground?(pol) => "next pol"
+         lv := removeDuplicates(append(variables(pol),lv))
+       lv := reverse(sort(lv))
+       cylindricalDecomposition(lpols,lv)
+
+     cylindricalDecomposition(lpols,lvars) ==
+       lvars = [] => error("CAD: cylindricalDecomposition: empty list of vars")
+       mv := first(lvars)
+       lv := rest(lvars)
+       lv = [] =>
+         lp1 := [ univariate(pol) for pol in lpols ]
+         scells := allSimpleCells(lp1,mv)$SCELL
+         [ makeCell([scell]) for scell in scells ]
+       lpols1 := projectionSet [univariate(pol,mv) for pol in lpols]
+       previousCad := cylindricalDecomposition(lpols1,lv)
+       res : List(CELL) := []
+       for cell in previousCad repeat
+         lspec := specialise(lpols,cell)
+         scells := allSimpleCells(lspec,mv)
+         res := append(res,[makeCell(scell,cell) for scell in scells])
+       res
+
+     PACK1 ==> CylindricalAlgebraicDecompositionUtilities(ThePols,RUP)
+     PACK2 ==> CylindricalAlgebraicDecompositionUtilities(TheField,BUP)
+
+     specialise(lpols,cell) ==
+       lpols = [] => error("CAD: specialise: empty list of pols")
+       sp := samplePoint(cell)
+       vl := variablesOf(cell)
+       res : List(BUP) := []
+       for pol in lpols repeat
+         p1 := univariate(eval(pol,vl,sp))
+         degree(p1) = 0 => "next pol"
+         res := cons(p1,res)
+       res
+
+     coefficientSet(pol) ==
+       res : List(ThePols) := []
+       for c in coefficients(pol) repeat
+         ground?(c) => return(res)
+         res := cons(c,res)
+       res
+
+     SUBRES ==> SubResultantPackage(ThePols,RUP)
+     discriminantSet(lpols) ==
+       res : List(ThePols) := []
+       for p in lpols repeat
+         v := subresultantVector(p,differentiate(p))$SUBRES
+         not(zero?(degree(v.0))) => return(error "Bad discriminant")
+         d : ThePols :=  leadingCoefficient(v.0)
+         zero?(d) => return(error "Non Square Free polynomial")
+         if not(ground? d) then res := cons(d,res)
+       res
+
+     principalSubResultantSet(p,q) ==
+        if degree(p) < degree(q)
+        then (p,q) := (q,p)
+        if degree(p) = degree(q)
+        then (p,q) := (q,pseudoRemainder(p, q))
+        v := subresultantVector(p,q)$SUBRES
+        [coefficient(v.i,i) for i in 0..(((#v)-2)::N)]
+
+     resultantSet(lpols) ==
+       res : List(ThePols) := []
+       laux := lpols
+       for p in lpols repeat
+         laux := rest(laux)
+         for q in laux repeat
+           r : ThePols :=  first(principalSubResultantSet(p,q))
+           zero?(r) => return(error "Non relatively prime polynomials")
+           if not(ground? r) then res := cons(r,res)
+       res
+
+     projectionSet(lpols) ==
+       res : List(ThePols) := []
+       for p in lpols repeat
+         c := content(p)
+         ground?(c) => "next p"
+         res := cons(c,res)
+       lp1 := [primitivePart p for p in lpols]
+       f : ((RUP,RUP) -> Boolean) := (degree(#1) <= degree(#2))
+       lp1 := sort(f,lp1)
+       lsqfrb := squareFreeBasis(lp1)$PACK1
+       lsqfrb := sort(f,lsqfrb)
+       for p in lp1 repeat
+         res := append(res,coefficientSet(p))
+       res := append(res,discriminantSet(lsqfrb))
+       append(res,resultantSet(lsqfrb))
+
+\end{chunk}
+\begin{chunk}{CAD.dotabb}
+"CAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CAD"]
+"CELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CELL"]
+"CAD" -> "CELL"
+\end{chunk}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\section{package CADU CylindricalAlgebraicDecompositionUtilities}
+Test are some standard tools which are needed to compute with univariate
+polynomials. 
+
+A gcd basis for a set of polynomials is a set of pairwise relatively prime 
+polynomials which all divide the original set and whose product is the
+same than the product of the original set.
+
+A square free basis for a list of polynomials is just a list
+of square free polynomials which are pairwise relatively primes and have
+the same roots than the original polynomials.
+
+\begin{chunk}{CylindricalAlgebraicDecompositionUtilities.input}
+)set break resume
+)sys rm -f CylindricalAlgebraicDecompositionUtilities.output
+)spool CylindricalAlgebraicDecompositionUtilities.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 1
+)show CylindricalAlgebraicDecompositionUtilities
+--E 1
+
+)spool
+)lisp (bye)
+\end{chunk}
+\begin{chunk}{CylindricalAlgebraicDecompositionUtilities.help}
+====================================================================
+CylindricalAlgebraicDecompositionUtilities examples
+====================================================================
+
+Test are some standard tools which are needed to compute with univariate
+polynomials. 
+
+A gcd basis for a set of polynomials is a set of pairwise relatively prime 
+polynomials which all divide the original set and whose product is the
+same than the product of the original set.
+
+A square free basis for a list of polynomials is just a list
+of square free polynomials which are pairwise relatively primes and have
+the same roots than the original polynomials.
+
+See Also:
+o )show CylindricalAlgebraicDecompositionUtilities
+
+\end{chunk}
+\pagehead{CylindricalAlgebraicDecompositionUtilities}{CADU}
+\pagepic{ps/v104cylindricalalgebraicdecompositionutilities.eps}{CADU}{1.00}
+
+{\bf Exports:}\\
+\begin{tabular}{lll}
+\cross{CADU}{gcdBasis} &
+\cross{CADU}{gcdBasisAdd} &
+\cross{CADU}{squareFreeBasis}
+\end{tabular}
+
+\begin{chunk}{package CADU CylindricalAlgebraicDecompositionUtilities}
+)abbrev package CADU CylindricalAlgebraicDecompositionUtilities
+CylindricalAlgebraicDecompositionUtilities(R,P) : PUB == PRIV where
+
+  R : GcdDomain
+  P : UnivariatePolynomialCategory(R)
+
+  PUB == with
+      squareFreeBasis : List(P) -> List(P)
+        ++ 
+      gcdBasis : List(P) -> List(P)
+        ++ decompose a list of polynomials into pairwise relatively 
+        ++ prime polynomials
+      gcdBasisAdd : (P,List(P)) -> List(P)
+        ++ add one polynomial to list of pairwise relatively prime polynomials
+
+  PRIV == add
+
+     squareFreeBasis(lpols) ==
+       lpols = [] => []
+       pol := first(lpols)
+       sqpol := unitCanonical(squareFreePart(pol))
+       gcdBasis(cons(sqpol,squareFreeBasis(rest(lpols))))
+         
+     gcdBasisAdd(p,lpols) ==
+       (degree(p) = 0) => lpols
+       null lpols => [unitCanonical p]
+       p1 := first(lpols)
+       g := gcd(p,p1)
+       (degree(g) = 0) => cons(p1,gcdBasisAdd(p,rest lpols))
+       p := (p exquo g)::P
+       p1 := (p1 exquo g)::P
+       basis := gcdBasisAdd(p,rest(lpols))
+       if degree(p1) > 0 then basis := cons(p1,basis)
+       gcdBasisAdd(g,basis)
+       
+
+     gcdBasis(lpols) ==
+       (#lpols <= 1) => lpols
+       basis := gcdBasis(rest lpols)
+       gcdBasisAdd(first(lpols),basis)
+
+\end{chunk}
+\begin{chunk}{CADU.dotabb}
+"CADU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CADU"]
+"PFECAT" [color="#4488FF",href="bookvol10.2.pdf#nameddest=PFECAT"]
+"CADU" -> "PFECAT"
+
+\end{chunk}
 \chapter{Chapter D}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{package DFINTTLS DefiniteIntegrationTools}
@@ -12732,7 +13016,7 @@ o )show DefiniteIntegrationTools
 
 \end{chunk}
 \pagehead{DefiniteIntegrationTools}{DFINTTLS}
-\pagepic{ps/v104definiteintegrationtools.ps}{DFINTTLS}{1.00}
+\pagepic{ps/v104definiteintegrationtools.eps}{DFINTTLS}{1.00}
 
 {\bf Exports:}\\
 \begin{tabular}{lll}
@@ -174434,6 +174718,8 @@ ZeroDimensionalSolvePackage(R,ls,ls2): Exports == Implementation where
 \getchunk{package CYCLES CycleIndicators}
 \getchunk{package CSTTOOLS CyclicStreamTools}
 \getchunk{package CYCLOTOM CyclotomicPolynomialPackage}
+\getchunk{package CAD CylindricalAlgebraicDecompositionPackage}
+\getchunk{package CADU CylindricalAlgebraicDecompositionUtilities}
 
 \getchunk{package DFINTTLS DefiniteIntegrationTools}
 \getchunk{package DEGRED DegreeReductionPackage}
diff --git a/books/bookvol10.pamphlet b/books/bookvol10.pamphlet
index 96aa078..587f03a 100644
--- a/books/bookvol10.pamphlet
+++ b/books/bookvol10.pamphlet
@@ -5932,7 +5932,8 @@ LAYER11=\
   ${OUT}/ASP1.o     ${OUT}/ASP10.o    ${OUT}/ASP24.o    ${OUT}/ASP4.o     \
   ${OUT}/ASP50.o    ${OUT}/ASP6.o     ${OUT}/ASP73.o    ${OUT}/AXSERV.o   \
   ${OUT}/BALFACT.o  ${OUT}/BEZOUT.o   ${OUT}/BINARY.o   ${OUT}/BINFILE.o  \
-  ${OUT}/BOUNDZRO.o ${OUT}/BPADICRT.o ${OUT}/BRILL.o    ${OUT}/CDEN.o     \
+  ${OUT}/BOUNDZRO.o ${OUT}/BPADICRT.o ${OUT}/BRILL.o    ${OUT}/CADU.o     \
+  ${OUT}/CDEN.o     \
   ${OUT}/CHVAR.o    ${OUT}/COMMUPC.o  ${OUT}/CONTFRAC.o ${OUT}/CVMP.o     \
   ${OUT}/CYCLOTOM.o ${OUT}/CYCLES.o   ${OUT}/DDFACT.o   ${OUT}/DECIMAL.o  \
   ${OUT}/DIOPS.o    ${OUT}/DIOPS-.o   ${OUT}/DIRPROD.o  ${OUT}/DISPLAY.o  \
@@ -6214,6 +6215,21 @@ LAYER11=\
 /*"BRILL" -> {"OM"; "TRANFUN"; "TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"}*/
 /*"BRILL" -> {"ELEMFUN"; "PI"}*/
 
+"CADU" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CADU"]
+/*"CADU" -> {"GCDDOM"; "INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"} */
+/*"CADU" -> {"CABMON"; "ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"} */
+/*"CADU" -> {"KOERCE"; "SGROUP"; "MONOID"; "LMODULE"; "BMODULE"} */
+/*"CADU" -> {"RMODULE"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LORER"; "UPOLYC"}*/
+/*"CADU" -> {"POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARZ"; "CHARNZ"}*/
+/*"CADU" -> {"FRETRCT"; "RETRACT"; "EVALAB"; "IEVALAB"; "FLINEXP"} */
+/*"CADU" -> {"LINEXP"; "ORDSET"; "KONVERT"; "PATMAB"}*/
+"CADU" -> "PFECAT"
+/*"CADU" -> {"UFD"; "ELTAB"; "DIFRING"; "DIFEXT"; "STEP"; "EUCDOM"}*/
+/*"CADU" -> {"PID"; "FIELD"; "DIVRING"; "INT"; "LIST"; "ILIST"}*/
+/*"CADU" -> {"NNI"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"}*/
+/*"CADU" -> {"AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"}*/
+/*"CADU" -> {"FLAGG"; "ELAGG"; "OM"}*/
+
 "CDEN" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CDEN"]
 /*"CDEN" -> {"INTDOM"; "COMRING"; "RING"; "RNG"; "ABELGRP"; "CABMON"}*/
 /*"CDEN" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE"; "SGROUP"}*/
@@ -11011,7 +11027,8 @@ LAYER16=\
   ${OUT}/QUATCAT.o  ${OUT}/QUATCAT-.o ${OUT}/RECLOS.o   ${OUT}/REP1.o     \
   ${OUT}/RESULT.o   ${OUT}/RFFACT.o   ${OUT}/RMATRIX.o  ${OUT}/ROMAN.o    \
   ${OUT}/ROUTINE.o  ${OUT}/RPOLCAT.o  ${OUT}/RPOLCAT-.o ${OUT}/RULECOLD.o \
-  ${OUT}/SAOS.o     ${OUT}/SEGBIND.o  ${OUT}/SET.o      ${OUT}/SPECOUT.o  \
+  ${OUT}/SAOS.o     ${OUT}/SCELL.o  \
+  ${OUT}/SEGBIND.o  ${OUT}/SET.o      ${OUT}/SPECOUT.o  \
   ${OUT}/SQMATRIX.o ${OUT}/SWITCH.o   ${OUT}/SYMS.o     ${OUT}/SYMTAB.o   \
   ${OUT}/SYSSOLP.o  ${OUT}/UTSCAT.o   ${OUT}/UTSCAT-.o  ${OUT}/VARIABLE.o \
   layer16done
@@ -12831,6 +12848,26 @@ LAYER16=\
 /*"SAOS" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"}*/
 /*"SAOS" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"}*/
 
+"SCELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SCELL"]
+/* "SCELL" -> {"KOERCE"; "RCFIELD"; "CHARZ"; "RING"; "RNG"; "ABELGRP"} */
+/* "SCELL" -> {"CABMON"; "ABELMON"' "ABELSG"; "SETCAT"; "BASTYPE"} */
+/* "SCELL" -> {"SGROUP"; "MONOID"; "LMODULE"; "ORDRING"; "OAGROUP"} */
+/* "SCELL" -> {"OCAMON"; "OAMON"; "OASGP"; "COMRING"; "BMODULE"} */
+/* "SCELL" -> {"RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"; "INTDOM"} */
+/* "SCELL" -> {"ALGEBRA"; "MODULE"; "ENTIRER"; "LORER"; "UFD"; "DIVRING"} */
+/* "SCELL" -> {"FRETRCT"; "RETRACT"; "RADCAT"; "UPOLYC"; "POLYCAT"; "FAMR"} */
+/* "SCELL" -> {"AMR"; "CHARZ"; "EVALAB"; "IEVALAB"; "FLINEXP"; "LINEXP"} */
+/* "SCELL" -> {"KONVERT"; "PATMAB"; "PFECAT"; "ELTAB"; "DIFRING"; "DIFEXT"} */
+/* "SCELL" -> {"STEP"; "SYMBOL"; "INT"; "REF"} */
+"SCELL" -> "ALIST"
+/* "SCELL" -> {"LIST"; "STRING"; "CHAR"; "SINT"; "OUTFORM"; "PRIMARR"} */
+/* "SCELL" -> {"A1AGG-"; "ISTRING"; "SRAGG-"; "FLAGG-"; "LNAGG-"} */
+/* "SCELL" -> {"BOOLEAN"; "ILIST"; "LSAGG"; "STAGG"; "URAGG"; "RCAGG"} */
+/* "SCELL" -> {"HOAGG"; "AGG"; "TYPE"; "LNAGG"; "IXAGG"; "ELTAGG"; "CLAGG"} */
+/* "SCELL" -> {"FLAGG"; "ELAGG"; "OM"; "PI"; "NNI"; "LSAGG-"; "STAGG-"} */
+/* "SCELL" -> {"ELAGG-"; "URAGG-"; "RCAGG-"; "IXAGG-"; "CLAGG-"; "HOAGG-"} */
+/* "SCELL" -> {"ORDSET-"; "AGG-"; "ELTAGG-"; "SETCAT-""; "BASTYPE-"}*/
+
 "SEGBIND" [color="#88FF44",href="bookvol10.3.pdf#nameddest=SEGBIND"]
 /*"SEGBIND" -> {"TYPE"; "SETCAT"; "BASTYPE"; "KOERCE"; "SYMBOL"; "INT"}*/
 /*"SEGBIND" -> "REF"*/
@@ -13002,7 +13039,7 @@ LAYER17=\
   ${OUT}/ALGSC.o    ${OUT}/AN.o       ${OUT}/APPRULE.o  ${OUT}/ASP19.o    \
   ${OUT}/ASP20.o    ${OUT}/ASP31.o    ${OUT}/ASP35.o    ${OUT}/ASP41.o    \
   ${OUT}/ASP42.o    ${OUT}/ASP74.o    ${OUT}/ASP77.o    ${OUT}/ASP80.o    \
-  ${OUT}/CDFMAT.o   ${OUT}/CDFVEC.o   \
+  ${OUT}/CDFMAT.o   ${OUT}/CDFVEC.o   ${OUT}/CELL.o \
   ${OUT}/CINTSLPE.o ${OUT}/COMBF.o    ${OUT}/COMPFACT.o ${OUT}/COMPLEX.o  \
   ${OUT}/COMPLPAT.o ${OUT}/CMPLXRT.o  ${OUT}/CPMATCH.o  ${OUT}/CRFP.o     \
   ${OUT}/CTRIGMNP.o ${OUT}/D01WGTS.o  ${OUT}/D02AGNT.o  ${OUT}/D03EEFA.o  \
@@ -13452,6 +13489,20 @@ LAYER17=\
 /*"CDFVEC" -> {"TRIGCAT"; "ATRIG"; "HYPCAT"; "AHYP"; "ELEMFUN"; "PFECAT"}*/
 /*"CDFVEC" -> {"OM"; "SPFCAT"; "INS"; "OINTDOM"; "CFCAT"}*/
 
+"CELL" [color="#88FF44",href="bookvol10.3.pdf#nameddest=CELL"]
+"CELL" -> "SCELL"
+/* "CELL" -> {"KOERCE"; "RCFIELD"; "CHARZ"; "RING"; "RNG"} */
+/* "CELL" -> {"ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"} */
+/* "CELL" -> {"BASTYPE"; "SGROUP"; "MONOID"; "LMODULE"; "ORDRING"} */
+/* "CELL" -> {"OAGROUP"; "OCAMON"; "OAMON"; "OASGP"; "ORDSET"} */
+/* "CELL" -> {"COMRING"; "BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"} */
+/* "CELL" -> {"PID"; "GCDDOM"; "INTDOM"; "ALGEBRA"; "MODULE"} */
+/* "CELL" -> {"ENTIRER"; "LORER"; "UFD"; "DIVRING"; "FRETRCT"} */
+/* "CELL" -> {"RETRACT"; "RADCAT"; "INT"; "LIST"; "ILIST"} */
+/* "CELL" -> {"NNI"; "SYMBOL"; "REF"; "ALIST"; "STRING"; "CHAR"} */
+/* "CELL" -> {"SINT"; "OUTFORM"; "PRIMARR"; "A1AGG-"; "ISTRING"} */
+/* "CELL" -> {"SRAGG-"; "FLAGG-"; "LNAGG-"; "BOOLEAN"} */
+
 "CINTSLPE" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CINTSLPE"]
 /*"CINTSLPE" -> {"INS"; "UFD"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
 /*"CINTSLPE" -> {"RNG"; "ABELGRP"; "CABMON"; "ABELMON"; "ABELSG"; "SETCAT"}*/
@@ -15766,10 +15817,11 @@ LAYER17=\
 \end{chunk}
 \subsection{Layer18}
 Depends on: ACFS EXPRSOL FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL 
-Used in next layer: EXPRSOL SFRTCAT
+Used in next layer: EXPRSOL SFRTCAT CELL
 \begin{chunk}{layer18}
 
 LAYER18=\
+  ${OUT}/CAD.o \
   ${OUT}/DEFINTEF.o ${OUT}/DEFINTRF.o ${OUT}/DFINTTLS.o ${OUT}/EFULS.o    \
   ${OUT}/ESCONT.o   ${OUT}/EXPR.o     ${OUT}/EXPRSOL.o  ${OUT}/EXPR2UPS.o \
   ${OUT}/FACTEXT.o  \
@@ -15789,7 +15841,26 @@ LAYER18=\
 \end{chunk}
 \begin{chunk}{layerpic}
 /* layer 18 */
-/* depends on: ACFS FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL */
+/* depends on: ACFS FDIVCAT RSETCAT UFPS ULSCCAT UTSSOL CELL */
+
+"CAD" [color="#FF4488",href="bookvol10.4.pdf#nameddest=CAD"]
+"CAD" -> "CELL"
+/*"CAD" -> {"POLY"; "SUP"; "INT"; "NNI"; "SCELL"; "RCFIELD" } */
+/*"CAD" -> {"CHARZ"; "RING"; "RNG"; "ABELGRP"; "CABMON" } */
+/*"CAD" -> {"ABELMON"; "ABELSG"; "SETCAT"; "BASTYPE"; "KOERCE" } */
+/*"CAD" -> {"SGROUP"; "MONOID"; "LMODULE"; "ORDRING"; "OAGROUP" } */
+/*"CAD" -> {"OCAMON"; "OAMON"; "OASGP"; "ORDSET"; "COMRING"} */
+/*"CAD" -> {"BMODULE"; "RMODULE"; "FIELD"; "EUCDOM"; "PID"; "GCDDOM"} */
+/*"CAD" -> {"INTDOM"; "ALGEBRA"; "MODULE"; "ENTIRER"; "LORER"; "UFD"} */
+/*"CAD" -> {"DIVRING"; "FRETRCT"; "RETRACT"; "RADCAT"; "LIST"; "INT"} */
+/*"CAD" -> {"LSAGG"; "STAGG"; "URAGG"; "RCAGG"; "HOAGG"; "AGG" } */
+/*"CAD" -> {"TYPE"; "EVALAB"; "IEVALAB"; "LNAGG"; "IXAGG"; "ELTAGG" } */
+/*"CAD" -> {"ELTAB"; "CLAGG"; "KONVERT"; "FLAGG"; "ELAGG"; "OM" } */
+/*"CAD" -> {"PATMAB"; "LIST"; "LSAGG-"; "STAGG-"; "ELAGG-" } */
+/*"CAD" -> {"FLAGG-"; "POLYCAT"; "PDRING"; "FAMR"; "AMR"; "CHARNZ" } */
+/*"CAD" -> {"FLINEXP"; "LINEXP"; " PFECAT"; "CADU"; "SUBRESP " } */
+/*"CAD" -> {"PRIMARR"; "UPOLYC"; "DIFRING"; "DIFEXT"; "STEP"; "SINT" } */
+/*"CAD" -> {"A1AGG" } */
 
 "DEFINTEF" [color="#FF4488",href="bookvol10.4.pdf#nameddest=DEFINTEF"]
 /*"DEFINTEF" -> {"EUCDOM"; "PID"; "GCDDOM"; "INTDOM"; "COMRING"; "RING"}*/
@@ -17989,6 +18060,7 @@ REGRESS= \
  CardinalNumber.regress \
  CartesianTensor.regress \
  CartesianTensorFunctions2.regress \
+ Cell.regress \
  CentralAttribute.regress \
  ChangeOfVariable.regress \
  Character.regress \
@@ -18033,6 +18105,8 @@ REGRESS= \
  CycleIndicators.regress \
  CyclicStreamTools.regress \
  CyclotomicPolynomialPackage.regress \
+ CylindricalAlgebraicDecompositionPackage.regress \
+ CylindricalAlgebraicDecompositionUtilities.regress \
  dasum.regress \
  daxpy.regress \
  dcabs1.regress \
@@ -18846,6 +18920,7 @@ REGRESS= \
  ShallowlyMutableAttribute.regress \
  SimpleAlgebraicExtension.regress \
  SimpleAlgebraicExtensionAlgFactor.regress \
+ SimpleCell.regess \
  SimpleFortranProgram.regress \
  SingleInteger.regress \
  SingletonAsOrderedSet.regress \
diff --git a/books/bookvol5.pamphlet b/books/bookvol5.pamphlet
index c017e6b..f79bdfc 100644
--- a/books/bookvol5.pamphlet
+++ b/books/bookvol5.pamphlet
@@ -24243,6 +24243,7 @@ otherwise the new algebra won't be loaded by the interpreter when needed.
    (|CardinalNumber| . CARD)
    (|CartesianTensor| . CARTEN)
    (|CartesianTensorFunctions2| . CARTEN2)
+   (|Cell| .  CELL)
    (|Character| . CHAR)
    (|CharacterClass| . CCLASS)
    (|CharacteristicPolynomialPackage| . CHARPOL)
@@ -24261,6 +24262,8 @@ otherwise the new algebra won't be loaded by the interpreter when needed.
    (|CoordinateSystems| . COORDSYS)
    (|CRApackage| . CRAPACK)
    (|CycleIndicators| . CYCLES)
+   (|CylindricalAlgebraicDecompositionPackage| . CAD)
+   (|CylindricalAlgebraicDecompositionUtilities| . CADU)
    (|Database| . DBASE)
    (|DataList| . DLIST)
    (|DecimalExpansion| . DECIMAL)
@@ -24561,6 +24564,7 @@ otherwise the new algebra won't be loaded by the interpreter when needed.
    (|SegmentFunctions2| . SEG2)
    (|Set| . SET)
    (|SimpleAlgebraicExtensionAlgFactor| . SAEFACT)
+   (|SimpleCell| . SCELL)
    (|SimplifyAlgebraicNumberConvertPackage| . SIMPAN)
    (|SingleInteger| . SINT)
    (|SmithNormalForm| . SMITH)
diff --git a/books/bookvolbib.pamphlet b/books/bookvolbib.pamphlet
index cc291b7..9c3290b 100644
--- a/books/bookvolbib.pamphlet
+++ b/books/bookvolbib.pamphlet
@@ -85,7 +85,7 @@ IBM Research Report, RC3062 Sept 1970
 
 \bibitem[Broadbery 95]{BGDW95} Broadbery, P. A.; G{\'o}mez-D{\'\i}az, T.;
 Watt, S. M.\\
-``On the implementation of dynamic evaluation''\\
+``On the Implementation of Dynamic Evaluation''\\
 In Levelt [Lev95] pages 77-84 ISBN 0-89791-699-9 LCCN QA76.95 I59 1995
 ACM order number 505950\\
 \verb|pdf.aminer.org/000/449/014/on_the_implementation_of_dynamic_evaluation.pdf|
@@ -111,7 +111,7 @@ to form new processes to explore alternative branches in parallel.
 \end{adjustwidth}
 
 \bibitem[Boehm 89]{Boe89} Boehm, Hans-J.\\
-``Type inference in the presence of type abstraction''\\
+``Type Inference in the Presence of Type Abstraction''\\
 ACM SIGPLAN Notices, 24(7) pp192-206 July 1989 CODEN SINODQ ISSN 0362-1340\\
 \verb|www.acm.org/pubs/citations/proceedings/pldi/73141/p192-boehm|
 %\verb|axiom-developer.org/axiom-website/papers/Boe89.pdf|
@@ -237,7 +237,7 @@ algebra systems.
 \end{adjustwidth}
 
 \bibitem[Bronstein 92]{Bro92} Bronstein, M.\\
-``Linear Ordinary Differential Equations: breaking through the order 2 barrier''\\
+``Linear Ordinary Differential Equations: Breaking Through the Order 2 Barrier''\\
 \verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/issac92.ps.gz|
 %\verb|axiom-developer.org/axiom-website/papers/Bro92.pdf|
 
@@ -270,7 +270,7 @@ LCCN QA76.95 I59 1993 ACM order number 505930
 \verb|arxiv.org/PS_cache/nlin/pdf/0408/0408058v1.pdf|
 
 \bibitem[Bronstein 93]{BS93} Bronstein, Manuel; Salvy, Bruno\\ 
-``Full partial fraction decomposition of rational functions''\\
+``Full Partial Fraction Decomposition of Rational Functions''\\
 In Bronstein [Bro93] pp157-160 ISBN 0-89791-604-2 LCCN QA76.95 I59 1993\\
 \verb|www.acm.org/pubs/citations/proceedings/issac/164081/p157-bronstein|
 
@@ -296,6 +296,7 @@ Elektronik, 43(15) pp107-110, July 1994, CODEN EKRKAR ISSN 0013-5658
 
 \bibitem[Bronstein 97a]{Bro97a} Bronstein, Manuel; Weil, Jacques-Arthur\\
 ``On Symmetric Powers of Differential Operators''\\
+ISSAC'97 pp 156-163 ACM NY (1997)
 \verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/mb_papers.html|
 %\verb|axiom-developer.org/axiom-website/papers/Bro97a.pdf|
 
@@ -345,7 +346,6 @@ Two volumes
 
 \bibitem[Buhl 05]{Buh05} Buhl, Soren L.\\
 ``Some Reflections on Integrating a Computer Algebra System in R''\\
-\verb|www.math.auc.dk/~slb/kurser/software/RCompAlg.pdf|
 
 \bibitem[Burge 91]{Bur91} Burge, W.H.\\
 ``Scratchpad and the Rogers-Ramanujan identities''\\
@@ -379,9 +379,10 @@ Scratchpad''\\
 Rapports de recherche 1586, Institut National de Recherche en
 Informatique et en Automatique, Le Chesnay, France, January 1992, 12pp
 
-\bibitem[Caprotti]{CCR} Caprotti, Olga; Cohen, Arjeh M.; Riem, Manfred\\
+\bibitem[Caprotti 00]{CCR00} Caprotti, Olga; Cohen, Arjeh M.; Riem, Manfred\\
 ``Java Phrasebooks for Computer Algebra and Automated Deduction''\\
 \verb|www.sigsam.org/bulletin/articles/132/paper8.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/CCR00.pdf|
 
 \bibitem[Capriotti 99]{CC99} Capriotti, O.; Carlisle, D.\\
 ``OpenMath and MathML: Semantic Mark Up for Mathematics''\\
@@ -597,6 +598,7 @@ Downer's Grove, IL, USA and Oxford, UK, August 1993\\
 
 \bibitem[Davenport (a)]{DFxx} Davenport, James; Faure, Christ\'ele\\
 ``The Unknown in Computer Algebra''
+\verb|axiom-wiki.newsynthesis.org/public/refs/TheUnknownInComputerAlgebra.pdf|
 %\verb|axiom-developer.org/axiom-website/papers/DFxx.pdf|
 
 \begin{adjustwidth}{2.5em}{0pt}
@@ -720,7 +722,7 @@ automated coerion algorithm in Axiom.
 ``Automated coercion for Axiom''\\
 In Dooley [Doo99], pp229-235
 ISBN 1-58113-073-2 LCCN QA76.95.I57 1999 ACM Press\\
-\verb|www.acm.org/pubs/contents/proceedings/issac/309831|
+\verb|www.acm.org/citation.cfm?id=309944|
 
 \bibitem[Dominguez 01]{DR01} Dom\'inguez, C\'esar; Rubio, Julio\\
 ``Modeling Inheritance as Coercion in a Symbolic Computation System''
@@ -744,12 +746,23 @@ fragment.
 Grant citation GR/L48256 Nov 1, 1997-Feb 28, 2001\\
 \verb|www.cs.st-andrews.ac.uk/research/output/detail?output=ML97.php|
 
-\bibitem[Dunstan 01]{DGKM01} Dunstan, Martin; Gottliebsen, Hanne; 
-Kelsey, Tom; Martin, Ursula\\
-``Computer Algebra meets Automated Theorem Proving: A Maple-PVS Interface''
+\bibitem[Adams 01]{DGKM01} Adams, Andrew; Dunstan, Martin; Gottliebsen, Hanne;
+Kelsey, Tom; Martin, Ursula; Owre, Sam\\
+``Computer Algebra meets Automated Theorem Proving: Integrating Maple and PVS''
 TPHOLS 2001, Edinburgh\\
-\verb|www.cs-st-andrews.ac.uk/~tom/pub/tphols.ps|\\
-\verb|www.cs-st-andrews.ac.uk/~tom/pub/dunstanetal.ps|
+\verb|www.csl.sri.com/~owre/papers/tphols01/tphols01.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/DGKM01.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+We describe an interface between version 6 of the Maple computer
+algebra system with the PVS automated theorem prover. The interface is
+designed to allow Maple users access to the robust and checkable proof
+environment of PVS. We also extend this environment by the provision
+of a library of proof strategies for use in real analysis. We
+demonstrate examples using the interface and the real analysis
+library. These examples provide proofs which are both illustrative and
+applicable to genuine symbolic computation problems.
+\end{adjustwidth}
 
 \bibitem[Duval 92]{DJ92} Duval D.; Jung, F.\\
 ``Examples of problem solving using computer algebra''\\
@@ -769,6 +782,16 @@ Journal of Pure and Applied Algebra, no99, 1995, pp. 267--295.
 \bibitem[Erocal 10]{ES10} Er\"ocal, Burcin; Stein, William\\
 ``The Sage Project''\\
 \verb|wstein.org/papers/icms/icms_2010.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/ES10.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+Sage is a free, open source, self-contained distribution of
+mathematical software, including a large library that provides a
+unified interface to the components of this distribution. This library
+also builds on the components of Sage to implement novel algorithms
+covering a broad range of mathematical functionality from algebraic
+combinatorics to number theory and arithmetic geometry.
+\end{adjustwidth}
 
 \subsection{F} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
@@ -781,6 +804,7 @@ In Watanabe and Nagata [WN90], pp60-67 ISBN 0-89791-401-5 LCCN QA76.95.I57 1990
 ``An incremental approach to building a mathematical expert out of software''\\
 4/19/2005\hfill\\
 \verb|www.cs.berkeley.edu/~fateman/papers/axiom.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/Fat05.pdf|
 
 \bibitem[Fateman 06]{Fat06} Fateman, R. J.\\
 ``Building Algebra Systems by Overloading Lisp''\\
@@ -819,10 +843,11 @@ Automatique Sept. 2000 No. 4001
 %\verb|axiom-developer.org/axiom-website/papers/FDN00b.pdf|
 
 \begin{adjustwidth}{2.5em}{0pt}
-One of the main strengths of computer algebra is being able to solve a family
-of problems with one computation. In order to express not only one problem
-but a family of problems, one introduces some symbols which are in fact the
-parameters common to all the problems of the family.
+One of the main strengths of computer algebra is being able to solve a
+family of problems with one computation. In order to express not only
+one problem but a family of problems, one introduces some symbols
+which are in fact the parameters common to all the problems of the
+family.
 
 The user must be able to understand in which way these parameters
 affect the result when he looks at the answer. Otherwise it may lead
@@ -894,6 +919,20 @@ CODEN JSYCEH ISSN 0747-7171
 \verb|pid=1-s2.0-S0747717188800488-main.pdf|
 %\verb|axiom-developer.org/axiom-website/papers/GM88.pdf|
 
+\begin{adjustwidth}{2.5em}{0pt}
+Buchberger's algorithm calculates Groebner bases of polynomial
+ideals. Its efficiency depends strongly on practical criteria for
+detecting superfluous reductions. Buchberger recommends two
+criteria. The more important one is interpreted in this paper as a
+criterion for detecting redundant elements in a basis of a module of
+syzygies. We present a method for obtaining a reduced, nearly minimal
+basis of that module. The simple procedure for detecting (redundant
+syzygies and )superfluous reductions is incorporated now in our
+installation of Buchberger's algorithm in SCRATCHPAD II and REDUCE
+3.3. The paper concludes with statistics stressing the good
+computational properties of these installations.
+\end{adjustwidth}
+
 \bibitem[Geddes 92]{GCL92} Geddes, Keith; Czapor, O.; Stephen R.; 
 Labahn, George\\
 ``Algorithms For Computer Algebra''\\
@@ -1086,6 +1125,7 @@ implemented in a symbolic manipulation system.
 
 \bibitem[Boyle 88]{Boyl88} Boyle, Ann\\
 ``Future Directions for Research in Symbolic Computation''\\
+Soc. for Industrial and Applied Mathematics, Philadelphia (1990)
 \verb|www.eecis.udel.edu/~caviness/wsreport.pdf|
 %\verb|axiom-developer.org/axiom-website/Boyl88.pdf|
 
@@ -1270,7 +1310,6 @@ Oxford, UK, 1994\\
 ``Formal Methods and Computer Algebra: A Larch Specification of AXIOM 
 Categories and Functors''\\
 Ph.D. Thesis, University of St Andrews, 1999\\
-\verb|www.cs.st-andrews.ac.uk/research/publications/Kel00.php|
 
 \bibitem[Kelsey 00a]{Kel00a} Kelsey, Tom\\
 ``Formal specification of computer algebra''\\
@@ -1388,8 +1427,9 @@ In Anonymous [Ano91], pp287-299 (vol. 1) 2 vols.
 \bibitem[Lecerf 96]{Le96} Lecerf, Gr\'egoire\\
 ``Dynamic Evaluation and Real Closure Implementation in Axiom''\\
 June 29, 1996 \\
-\verb|www.math.uvsq.fr/~lecerf/software/drc/drc.ps|
-
+\verb|lecerf.perso.math.cnrs.fr/software/drc/drc.ps|
+%\verb|axiom-developer.org/axiom-website/papers/Le96.ps|
+TPDHERE
 \bibitem[Lecerf 96a]{Le96a} Lecerf, Gr\'egoire\\
 ``The Dynamic Real Closure implemented in Axiom''\\
 \verb|lecerf.perso.math.cnrs.fr/software/drc/drc.ps|
@@ -1425,6 +1465,18 @@ This paper proposes a non-intrusive automatic parallelization
 framework for typeful and property-aware computer algebra systems.
 \end{adjustwidth}
 
+\bibitem[Ligatsikas 96]{Liga96} Ligatsikas, Zenon; Rioboo, Renaud;
+Roy, Marie Francoise\\
+``Generic computation of the real closure of an ordered field''\\
+Math. and Computers in Simulation 42 pp 541-549 (1996)\\
+%\verb|axiom-developer.org/axiom-website/papers/Liga96.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+This paper describes a generalization of the real closure computation
+of an ordered field (Rioboo, 1991) enabling to use different technques
+to code a single real algebraic number.
+\end{adjustwidth}
+
 \bibitem[Linton 93]{Lin93} Linton, Steve\\
 ``Vector Enumeration Programs, version 3.04''\\
 \verb|www.cs.st-andrews.ac.uk/~sal/nme/nme_toc.html#SEC1|
@@ -2333,6 +2385,19 @@ problems of elementary algebra and geometry.
 ``On the Theories of Triangular Sets''\\
 Journal of Symbolic Computation 1999 Vol 28 pp105-124
 
+\bibitem[Aubry 96]{Aub96} Aubry, Philippe; Maza, Marc Moreno\\
+``Triangular Sets for Solving Polynomial Systems: a Comparison of Four Methods''\\
+\verb|www.lip6.fr/lip6/reports/1997/lip6.1997.009.ps.gz|
+%\verb|axiom-developer.org/axiom-website/papers/Aub96.ps|
+
+\begin{adjustwidth}{2.5em}{0pt}
+Four methods for solving polynomial systems by means of triangular
+sets are presented and implemented in a unified way. These methods are
+those of Wu, Lazard, Kalkbrener, and Wang. They are compared on
+various examples with emphasis on efficiency, conciseness and
+legibility of the outputs.
+\end{adjustwidth}
+
 \subsection{B} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 \bibitem[Bailey 66]{Bai66} Bailey P B\\
@@ -2437,6 +2502,11 @@ J. Reine Angew. Math., v. 234, (1969), pp. 45-64
 ``Note on Irreducibility Testing''\\
 Mathematics of Computation, vol. 35, num. 35, Oct. 1980, 1379-1381
 
+\bibitem[Bronstein 98a]{Bro98a} Bronstein, M.; Grabmeier, J.; Weispfenning, V. (eds)\\
+``Symbolic Rewriting Techniques''\\
+Progress in Computer Science and Applied Logic 15, Birkhauser-Verlag, Basel 
+ISBN 3-7643-5901-3 (1998)
+
 \bibitem[Bronstein 88]{Bro88} Bronstein, Manual\\
 ``The Transcendental Risch Differential Equation''\\
 J. Symbolic Computation (1990) 9, pp49-60 Feb 1988\\
@@ -2512,8 +2582,60 @@ a particular integrand along the way.
 \bibitem[Bronstein 98b]{Bro98b} Bronstein, Manuel\\
 ``Symbolic Integration Tutorial''\\
 INRIA Sophia Antipolis ISSAC 1998 Rostock
+\verb|www-sop.inria.fr/cafe/Manuel.Bronstein/publications/issac98.pdf|
 %\verb|axiom-developer.org/axiom-website/papers/Bro98b.pdf|
 
+\bibitem[Brown 99]{Brow99} Brown, Christopher W.\\
+``Solution Formula Construction for Truth Invariant CADs''\\
+Ph.D Thesis, Univ. Delaware (1999)
+\verb|www.usna.edu/Users/cs/wcbrown/reearch/thesis.ps.gz|
+%\verb|axiom-developer.org/axiom-website/papers/Brow99.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+The CAD-based quantifier elimination algorithm takes a formula from
+the elementary theory of real closed fields as input, and constructs a
+CAD of the space of the formula's unquantified variables. This
+decomposition is truth invariant with respect to the input formula,
+meaning that the formula is either identically true or identically
+false in each cell of the decomposition. The method determines the
+truth of the input formula for each cell of the CAD, and then uses the
+CAD to construct a solution formula -- a quantifier free formula that
+is equivalent to the input formula. This final phase of the algorithm,
+the solution formula construction phase, is the focus of this thesis.
+
+An optimal solution formula construction algorithm would be {\sl
+complete} -- i.e. applicable to any truth-invariant CAD, would be {\sl
+efficient}, and would produce {\sl simple} solution formulas. Prior to
+this thesis, no method was available with even two of these three
+properties. Several algorithms are presented, all addressing problems
+related to solution formula construction. In combination, these
+provide an efficient and complete method for constructing solution
+formulas that are simple in a variety of ways.
+
+Algorithms presented in this thesis have been implemented using the
+SACLIB library, and integrated into QEPCAD, a SACLIB-based
+implementation of quantifier elimination by CAD. Example computations
+based on these implementations are discussed.
+\end{adjustwidth}
+
+\bibitem[Brown 02]{Brow02} Brown, Christopher W.\\
+``QEPCAD B -- A program for computing with semi-algebraic sets using CADs''\\
+%\verb|axiom-developer.org/axiom-website/papers/Brow02.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+This report introduces QEPCAD B, a program for computing with real
+algebraic sets using cylindrical algebraic decomposition (CAD). QEPCAD
+B both extends and improves upon the QEPCAD system for quantifier
+elimination by partial cylindrical algebraic decomposition written by
+Hoon Hong in the early 1990s. This paper briefly discusses some of the
+improvements in the implementation of CAD and quantifier elimination
+vis CAD, and provides somewhat more detail on extensions to the system
+that go beyond quantifier elimination. The author is responsible for
+most of the extended features of QEPCAD B, but improvements to the
+basic CAD implementation and to the SACLIB library on which QEPCAD is
+based are the results of many people's work.
+\end{adjustwidth}
+
 \subsection{C} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 \bibitem[Carlson 65]{Car65} Carlson B C\\
@@ -2541,6 +2663,20 @@ Math. Comput. 51 267--280. (1988)
 Paris 1829 (reprinted Oeuvres, II S\'erie, Tome IX,
 Gauthier-Villars, Paris, 1891).
 
+\bibitem[Ch\`eze 07]{Chez07} Ch\'eze, Guillaume; Lecerf, Gr\'egoire\\
+``Lifting and recombination techniques for absolute factorization''\\
+Journal of Complexity, VOl 23 Issue 3 June 2007 pp 380-420
+\verb|www.sciencedirect.com/science/article/pii/S0885064X07000465|
+%\verb|axiom-developer.org/axiom-website/papers/Chez07.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+In the vein of recent algorithmic advances in polynomial factorization
+based on lifting and recombination techniques, we present new faster
+algorithms for computing the absolute factorization of a bivariate
+polynomial. The running time of our probabilistic algorithm is less
+than quadratic in the dense size of the polynomial to be factored.
+\end{adjustwidth}
+
 \bibitem[Childs 79]{CSDDN79} Childs B; Scott M; Daniel J W; Denman E; 
 Nelson P (eds)\\
 ``Codes for Boundary-value Problems in Ordinary Differential Equations''\\
@@ -2786,6 +2922,24 @@ according to the approach of sketch theory.
 
 \subsection{F} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+\bibitem[Fateman 08]{Fat08} Fateman, Richard\\
+``Revisiting numeric/symbolic indefinite integration of rational functions, and extensions''\\
+\verb|www.eecs.berkeley.edu/~fateman/papers/integ.pdf|
+%\verb|axiom-developer.org/axiom-website/papers/Fat08.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+We know we can solve this problem: Given any rational function
+$f(x)=p(x)/q(x)$, where $p$ and $q$ are univariate polynomials over
+the rationals, compute its {\sl indefinite} integral, using if
+necessary, algebraic numbers. But in many circumstances an approximate
+result is more likely to be of use. Furthermore, it is plausible that
+it would be more useful to solve the problem to allow definite
+integration, or introduce additional parameters so that we can solve
+multiple definite integrations.  How can a computer algebra system
+best answer the more useful questions?  Finally, what if the integrand
+is not a ratio of polynomials, but something more challenging?
+\end{adjustwidth}
+
 \bibitem[Fletcher 01]{Fl01} Fletcher, John P.\\
 ``Symbolic processing of Clifford Numbers in C++''\\
 Paper 25, AGACSE 2001.
@@ -3381,6 +3535,7 @@ J. Res. Natl. Inst. Stand. Technol. (NIST) V105 No4 July-Aug 2000 pp589-590
 typewriter-like devices''\\
 Interactive Systems for Experimental and Applied Mathematics
 M. Klerer and J. Reinfelds, eds., Academic Press, New York 1968, pp79-90
+%\verb|axiom-developer.org/axiom-website/papers/Mil68.pdf|
 
 \bibitem[Minc 79]{Min79} Henryk Minc\\
 ``Evaluation of Permanents''\\
@@ -4619,7 +4774,8 @@ condition generator for Larch/Aldor.
 \bibitem[Dunstan 00]{Dun00} Dunstan, Martin; Kelsey, Tom; Martin, Ursula;
 Linton, Steve\\
 ``Formal Methods for Extensions to CAS''\\
-FM 99, Toulouse, France, Sept 20-24, 1999, p1758-1777
+FME'99, Toulouse, France, Sept 20-24, 1999, pp 1758-1777
+\verb|tom.host.cs.st-andrews.ac.uk/pub/fm99.ps|
 %\verb|axiom-developer.org/axiom-website/papers/Dun00.pdf|
 
 \begin{adjustwidth}{2.5em}{0pt}
@@ -4678,6 +4834,22 @@ validation test for that example.
 Addison-Wesley ISBN 0-321-14306-X
 %\verb|axiom-developer.org/axiom-website/papers/Lamp02.pdf|
 
+\bibitem[Martin 97]{Mart97} Martin, U.; Shand, D.\\
+``Investigating some Embedded Verification Techniques for Computer Algebra Systems''\\
+\verb|www.risc.jku.at/conferences/Theorema/papers/shand.ps.gz|
+%\verb|axiom-developer.org/axiom-website/papers/Mart97.ps|
+
+\begin{adjustwidth}{2.5em}{0pt}
+This paper reports some preliminary ideas on a collaborative project
+between St. Andrews University in the UK and NAG Ltd. The project aims
+to use embedded verification techniques to improve the reliability and
+mathematical soundness of computer algebra systems. We give some
+history of attempts to integrate computer algebra systems and
+automated theorem provers and discuss possible advantages and
+disadvantages of these approaches. We also discuss some possible case
+studies.
+\end{adjustwidth}
+
 \bibitem[Mason 86]{Mason86} Mason, Ian A.\\
 ``The Semantics of Destructive Lisp''\\
 Center for the Study of Language and Information ISBN 0-937073-06-7
@@ -5249,6 +5421,28 @@ formulae the method has gained practical applications, e.g. in the
 context of computing threshold conditions in epidemic modeling.
 \end{adjustwidth}{2.5em}{0pt}
 
+\bibitem[Ulmer 03]{Ulm03} Ulmer, Felix\\
+``Liouvillian solutions of third order differential equations''\\
+J. Symbolic COmputations 36 pp 855-889 (2003)
+\verb|www.sciencedirect.com/science/article/pii/S0747717103000658|
+%\verb|axiom-developer.org/axiom-website/papers/Ulm03.pdf|
+
+\begin{adjustwidth}{2.5em}{0pt}
+The Kovacic algorithm and its improvements give explicit formulae for
+the Liouvillian solutions of second order linear differential
+equations. Algorithms for third order differential equations also
+exist, but the tools they use are more sophisticated and the
+computations more involved. In this paper we refine parts of the
+algorithm to find Liouvillian solutions of third order equations. We
+show that,except for four finite groups and a reduction to the second
+order case, it is possible to give a formula in the imprimitve
+case. We also give necessary conditions and several simplifications
+for the computation of the minimal polynomial for the remaining finite
+set of finite groups (or any known finite group) by extracting
+ramification information from the character table. Several examples
+have been constructed, illustrating the possibilities and limitations.
+\end{adjustwidth}
+
 \subsection{Expression Simplification} %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 \bibitem[Carette 04]{Car04} Carette, Jacques\\
@@ -5872,7 +6066,7 @@ an integral arising in analyzing the entropy of certain processes.
 
 \bibitem[Raab 13]{Raab13} Raab, Clemens G.\\
 ``Generalization of Risch's Algorithm to Special Functions''\\
-\verb|arxiv.org/pdf/1305.1481.pdf|
+\verb|arxiv.org/pdf/1305.1481|
 %\verb|axiom-developer.org/axiom-website/papers/Raab13.pdf|
 
 \begin{adjustwidth}{2.5em}{0pt}
diff --git a/books/ps/v103cell.eps b/books/ps/v103cell.eps
new file mode 100644
index 0000000..5aafbcb
--- /dev/null
+++ b/books/ps/v103cell.eps
@@ -0,0 +1,278 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: graphviz version 2.26.3 (20100126.1600)
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 104 152
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 104 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 68 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 41 translate
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+65 112 lineto
+65 -5 lineto
+closepath fill
+1 setlinewidth
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+65 112 lineto
+65 -5 lineto
+closepath stroke
+% CELL
+gsave
+[ /Rect [ 3 72 57 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.3.pdf#nameddest=CELL) >>
+  /Subtype /Link
+/ANN pdfmark
+0.27273 0.73333 1 nodecolor
+newpath 57 108 moveto
+3 108 lineto
+3 72 lineto
+57 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.27273 0.73333 1 nodecolor
+newpath 57 108 moveto
+3 108 lineto
+3 72 lineto
+57 72 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+12 86.4 moveto 36 (CELL) alignedtext
+grestore
+% SCELL
+gsave
+[ /Rect [ 0 0 60 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.3.pdf#nameddest=SCELL) >>
+  /Subtype /Link
+/ANN pdfmark
+0.27273 0.73333 1 nodecolor
+newpath 60 36 moveto
+0 36 lineto
+0 0 lineto
+60 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.27273 0.73333 1 nodecolor
+newpath 60 36 moveto
+0 36 lineto
+0 0 lineto
+60 0 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+7.5 14.4 moveto 45 (SCELL) alignedtext
+grestore
+% CELL->SCELL
+gsave
+1 setlinewidth
+0 0 0 edgecolor
+newpath 30 71.83 moveto
+30 64.13 30 54.97 30 46.42 curveto
+stroke
+0 0 0 edgecolor
+newpath 33.5 46.41 moveto
+30 36.41 lineto
+26.5 46.41 lineto
+closepath fill
+1 setlinewidth
+solid
+0 0 0 edgecolor
+newpath 33.5 46.41 moveto
+30 36.41 lineto
+26.5 46.41 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/books/ps/v103simplecell.eps b/books/ps/v103simplecell.eps
new file mode 100644
index 0000000..1b4ee39
--- /dev/null
+++ b/books/ps/v103simplecell.eps
@@ -0,0 +1,278 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: graphviz version 2.26.3 (20100126.1600)
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 104 152
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 104 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 68 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 41 translate
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+65 112 lineto
+65 -5 lineto
+closepath fill
+1 setlinewidth
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+65 112 lineto
+65 -5 lineto
+closepath stroke
+% SCELL
+gsave
+[ /Rect [ 0 72 60 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.3.pdf#nameddest=SCELL) >>
+  /Subtype /Link
+/ANN pdfmark
+0.27273 0.73333 1 nodecolor
+newpath 60 108 moveto
+0 108 lineto
+0 72 lineto
+60 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.27273 0.73333 1 nodecolor
+newpath 60 108 moveto
+0 108 lineto
+0 72 lineto
+60 72 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+7.5 86.4 moveto 45 (SCELL) alignedtext
+grestore
+% ALIST
+gsave
+[ /Rect [ 2 0 58 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.3.pdf#nameddest=ALIST) >>
+  /Subtype /Link
+/ANN pdfmark
+0.27273 0.73333 1 nodecolor
+newpath 58 36 moveto
+2 36 lineto
+2 0 lineto
+58 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.27273 0.73333 1 nodecolor
+newpath 58 36 moveto
+2 36 lineto
+2 0 lineto
+58 0 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+9.5 14.4 moveto 41 (ALIST) alignedtext
+grestore
+% SCELL->ALIST
+gsave
+1 setlinewidth
+0 0 0 edgecolor
+newpath 30 71.83 moveto
+30 64.13 30 54.97 30 46.42 curveto
+stroke
+0 0 0 edgecolor
+newpath 33.5 46.41 moveto
+30 36.41 lineto
+26.5 46.41 lineto
+closepath fill
+1 setlinewidth
+solid
+0 0 0 edgecolor
+newpath 33.5 46.41 moveto
+30 36.41 lineto
+26.5 46.41 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/books/ps/v104cylindricalalgebraicdecompositionpackage.eps b/books/ps/v104cylindricalalgebraicdecompositionpackage.eps
new file mode 100644
index 0000000..d57c1ec
--- /dev/null
+++ b/books/ps/v104cylindricalalgebraicdecompositionpackage.eps
@@ -0,0 +1,278 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: graphviz version 2.26.3 (20100126.1600)
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 98 152
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 98 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 62 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 41 translate
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+59 112 lineto
+59 -5 lineto
+closepath fill
+1 setlinewidth
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+59 112 lineto
+59 -5 lineto
+closepath stroke
+% CAD
+gsave
+[ /Rect [ 0 72 54 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.4.pdf#nameddest=CAD) >>
+  /Subtype /Link
+/ANN pdfmark
+0.93939 0.73333 1 nodecolor
+newpath 54 108 moveto
+0 108 lineto
+0 72 lineto
+54 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.93939 0.73333 1 nodecolor
+newpath 54 108 moveto
+0 108 lineto
+0 72 lineto
+54 72 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+11.5 86.4 moveto 31 (CAD) alignedtext
+grestore
+% CELL
+gsave
+[ /Rect [ 0 0 54 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.3.pdf#nameddest=CELL) >>
+  /Subtype /Link
+/ANN pdfmark
+0.27273 0.73333 1 nodecolor
+newpath 54 36 moveto
+0 36 lineto
+0 0 lineto
+54 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.27273 0.73333 1 nodecolor
+newpath 54 36 moveto
+0 36 lineto
+0 0 lineto
+54 0 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+9 14.4 moveto 36 (CELL) alignedtext
+grestore
+% CAD->CELL
+gsave
+1 setlinewidth
+0 0 0 edgecolor
+newpath 27 71.83 moveto
+27 64.13 27 54.97 27 46.42 curveto
+stroke
+0 0 0 edgecolor
+newpath 30.5 46.41 moveto
+27 36.41 lineto
+23.5 46.41 lineto
+closepath fill
+1 setlinewidth
+solid
+0 0 0 edgecolor
+newpath 30.5 46.41 moveto
+27 36.41 lineto
+23.5 46.41 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/books/ps/v104cylindricalalgebraicdecompositionutilities.eps b/books/ps/v104cylindricalalgebraicdecompositionutilities.eps
new file mode 100644
index 0000000..1f3150a
--- /dev/null
+++ b/books/ps/v104cylindricalalgebraicdecompositionutilities.eps
@@ -0,0 +1,278 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: graphviz version 2.26.3 (20100126.1600)
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 114 152
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 114 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 78 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 41 translate
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+75 112 lineto
+75 -5 lineto
+closepath fill
+1 setlinewidth
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+75 112 lineto
+75 -5 lineto
+closepath stroke
+% CADU
+gsave
+[ /Rect [ 6 72 64 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.4.pdf#nameddest=CADU) >>
+  /Subtype /Link
+/ANN pdfmark
+0.93939 0.73333 1 nodecolor
+newpath 64 108 moveto
+6 108 lineto
+6 72 lineto
+64 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.93939 0.73333 1 nodecolor
+newpath 64 108 moveto
+6 108 lineto
+6 72 lineto
+64 72 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+14 86.4 moveto 42 (CADU) alignedtext
+grestore
+% PFECAT
+gsave
+[ /Rect [ 0 0 70 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.2.pdf#nameddest=PFECAT) >>
+  /Subtype /Link
+/ANN pdfmark
+0.60606 0.73333 1 nodecolor
+newpath 70 36 moveto
+0 36 lineto
+0 0 lineto
+70 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.60606 0.73333 1 nodecolor
+newpath 70 36 moveto
+0 36 lineto
+0 0 lineto
+70 0 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+7.5 14.4 moveto 55 (PFECAT) alignedtext
+grestore
+% CADU->PFECAT
+gsave
+1 setlinewidth
+0 0 0 edgecolor
+newpath 35 71.83 moveto
+35 64.13 35 54.97 35 46.42 curveto
+stroke
+0 0 0 edgecolor
+newpath 38.5 46.41 moveto
+35 36.41 lineto
+31.5 46.41 lineto
+closepath fill
+1 setlinewidth
+solid
+0 0 0 edgecolor
+newpath 38.5 46.41 moveto
+35 36.41 lineto
+31.5 46.41 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/books/ps/v104definiteintegrationtools.eps b/books/ps/v104definiteintegrationtools.eps
new file mode 100644
index 0000000..4675cbb
--- /dev/null
+++ b/books/ps/v104definiteintegrationtools.eps
@@ -0,0 +1,278 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: graphviz version 2.26.3 (20100126.1600)
+%%Title: pic
+%%Pages: 1
+%%BoundingBox: 36 36 130 152
+%%EndComments
+save
+%%BeginProlog
+/DotDict 200 dict def
+DotDict begin
+
+/setupLatin1 {
+mark
+/EncodingVector 256 array def
+ EncodingVector 0
+
+ISOLatin1Encoding 0 255 getinterval putinterval
+EncodingVector 45 /hyphen put
+
+% Set up ISO Latin 1 character encoding
+/starnetISO {
+        dup dup findfont dup length dict begin
+        { 1 index /FID ne { def }{ pop pop } ifelse
+        } forall
+        /Encoding EncodingVector def
+        currentdict end definefont
+} def
+/Times-Roman starnetISO def
+/Times-Italic starnetISO def
+/Times-Bold starnetISO def
+/Times-BoldItalic starnetISO def
+/Helvetica starnetISO def
+/Helvetica-Oblique starnetISO def
+/Helvetica-Bold starnetISO def
+/Helvetica-BoldOblique starnetISO def
+/Courier starnetISO def
+/Courier-Oblique starnetISO def
+/Courier-Bold starnetISO def
+/Courier-BoldOblique starnetISO def
+cleartomark
+} bind def
+
+%%BeginResource: procset graphviz 0 0
+/coord-font-family /Times-Roman def
+/default-font-family /Times-Roman def
+/coordfont coord-font-family findfont 8 scalefont def
+
+/InvScaleFactor 1.0 def
+/set_scale {
+       dup 1 exch div /InvScaleFactor exch def
+       scale
+} bind def
+
+% styles
+/solid { [] 0 setdash } bind def
+/dashed { [9 InvScaleFactor mul dup ] 0 setdash } bind def
+/dotted { [1 InvScaleFactor mul 6 InvScaleFactor mul] 0 setdash } bind def
+/invis {/fill {newpath} def /stroke {newpath} def /show {pop newpath} def} bind def
+/bold { 2 setlinewidth } bind def
+/filled { } bind def
+/unfilled { } bind def
+/rounded { } bind def
+/diagonals { } bind def
+
+% hooks for setting color 
+/nodecolor { sethsbcolor } bind def
+/edgecolor { sethsbcolor } bind def
+/graphcolor { sethsbcolor } bind def
+/nopcolor {pop pop pop} bind def
+
+/beginpage {	% i j npages
+	/npages exch def
+	/j exch def
+	/i exch def
+	/str 10 string def
+	npages 1 gt {
+		gsave
+			coordfont setfont
+			0 0 moveto
+			(\() show i str cvs show (,) show j str cvs show (\)) show
+		grestore
+	} if
+} bind def
+
+/set_font {
+	findfont exch
+	scalefont setfont
+} def
+
+% draw text fitted to its expected width
+/alignedtext {			% width text
+	/text exch def
+	/width exch def
+	gsave
+		width 0 gt {
+			[] 0 setdash
+			text stringwidth pop width exch sub text length div 0 text ashow
+		} if
+	grestore
+} def
+
+/boxprim {				% xcorner ycorner xsize ysize
+		4 2 roll
+		moveto
+		2 copy
+		exch 0 rlineto
+		0 exch rlineto
+		pop neg 0 rlineto
+		closepath
+} bind def
+
+/ellipse_path {
+	/ry exch def
+	/rx exch def
+	/y exch def
+	/x exch def
+	matrix currentmatrix
+	newpath
+	x y translate
+	rx ry scale
+	0 0 1 0 360 arc
+	setmatrix
+} bind def
+
+/endpage { showpage } bind def
+/showpage { } def
+
+/layercolorseq
+	[	% layer color sequence - darkest to lightest
+		[0 0 0]
+		[.2 .8 .8]
+		[.4 .8 .8]
+		[.6 .8 .8]
+		[.8 .8 .8]
+	]
+def
+
+/layerlen layercolorseq length def
+
+/setlayer {/maxlayer exch def /curlayer exch def
+	layercolorseq curlayer 1 sub layerlen mod get
+	aload pop sethsbcolor
+	/nodecolor {nopcolor} def
+	/edgecolor {nopcolor} def
+	/graphcolor {nopcolor} def
+} bind def
+
+/onlayer { curlayer ne {invis} if } def
+
+/onlayers {
+	/myupper exch def
+	/mylower exch def
+	curlayer mylower lt
+	curlayer myupper gt
+	or
+	{invis} if
+} def
+
+/curlayer 0 def
+
+%%EndResource
+%%EndProlog
+%%BeginSetup
+14 default-font-family set_font
+1 setmiterlimit
+% /arrowlength 10 def
+% /arrowwidth 5 def
+
+% make sure pdfmark is harmless for PS-interpreters other than Distiller
+/pdfmark where {pop} {userdict /pdfmark /cleartomark load put} ifelse
+% make '<<' and '>>' safe on PS Level 1 devices
+/languagelevel where {pop languagelevel}{1} ifelse
+2 lt {
+    userdict (<<) cvn ([) cvn load put
+    userdict (>>) cvn ([) cvn load put
+} if
+
+%%EndSetup
+setupLatin1
+%%Page: 1 1
+%%PageBoundingBox: 36 36 130 152
+%%PageOrientation: Portrait
+0 0 1 beginpage
+gsave
+36 36 94 116 boxprim clip newpath
+1 1 set_scale 0 rotate 40 41 translate
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+91 112 lineto
+91 -5 lineto
+closepath fill
+1 setlinewidth
+0.16355 0.45339 0.92549 graphcolor
+newpath -4 -5 moveto
+-4 112 lineto
+91 112 lineto
+91 -5 lineto
+closepath stroke
+% DFINTTLS
+gsave
+[ /Rect [ 0 72 86 108 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.4.pdf#nameddest=DFINTTLS) >>
+  /Subtype /Link
+/ANN pdfmark
+0.93939 0.73333 1 nodecolor
+newpath 86 108 moveto
+0 108 lineto
+0 72 lineto
+86 72 lineto
+closepath fill
+1 setlinewidth
+filled
+0.93939 0.73333 1 nodecolor
+newpath 86 108 moveto
+0 108 lineto
+0 72 lineto
+86 72 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+8 86.4 moveto 70 (DFINTTLS) alignedtext
+grestore
+% ACFS
+gsave
+[ /Rect [ 16 0 70 36 ]
+  /Border [ 0 0 0 ]
+  /Action << /Subtype /URI /URI (bookvol10.2.pdf#nameddest=ACFS) >>
+  /Subtype /Link
+/ANN pdfmark
+0.60606 0.73333 1 nodecolor
+newpath 70 36 moveto
+16 36 lineto
+16 0 lineto
+70 0 lineto
+closepath fill
+1 setlinewidth
+filled
+0.60606 0.73333 1 nodecolor
+newpath 70 36 moveto
+16 36 lineto
+16 0 lineto
+70 0 lineto
+closepath stroke
+0 0 0 nodecolor
+14 /Times-Roman set_font
+24.5 14.4 moveto 37 (ACFS) alignedtext
+grestore
+% DFINTTLS->ACFS
+gsave
+1 setlinewidth
+0 0 0 edgecolor
+newpath 43 71.83 moveto
+43 64.13 43 54.97 43 46.42 curveto
+stroke
+0 0 0 edgecolor
+newpath 46.5 46.41 moveto
+43 36.41 lineto
+39.5 46.41 lineto
+closepath fill
+1 setlinewidth
+solid
+0 0 0 edgecolor
+newpath 46.5 46.41 moveto
+43 36.41 lineto
+39.5 46.41 lineto
+closepath stroke
+grestore
+endpage
+showpage
+grestore
+%%PageTrailer
+%%EndPage: 1
+%%Trailer
+end
+restore
+%%EOF
diff --git a/changelog b/changelog
index d6feed8..30106ac 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,22 @@
+20140902 tpd src/axiom-website/patches.html 20140902.01.tpd.patch
+20140902 tpd books/bookvol10.3.pamphlet add CAD
+20140902 tpd books/bookvol10.4.pamphlet add CAD
+20140902 tpd books/bookvol10.pamphlet add CAD
+20140902 tpd books/bookvol5.pamphlet add CAD
+20140902 tpd books/bookvolbib.pamphlet add CAD references
+20140902 tpd books/ps/v103cell.eps
+20140902 tpd books/ps/v103simplecell.eps
+20140902 tpd books/ps/v104cylindricalalgebraicdecompositionpackage.eps
+20140902 tpd books/ps/v104cylindricalalgebraicdecompositionutilities.eps
+20140902 tpd books/ps/v104definiteintegrationtools.eps
+20140902 tpd src/input/Makefile.pamphlet add cad.input
+20140902 tpd src/input/cad.input test CAD
+20140902 tpd src/share/algebra/browse.daase add CAD
+20140902 tpd src/share/algebra/category.daase add CAD
+20140902 tpd src/share/algebra/dependents.daase/index.kaf add CAD
+20140902 tpd src/share/algebra/interp.daase add CAD
+20140902 tpd src/share/algebra/operation.daase add CAD
+20140902 tpd src/share/algebra/users.daase/index.kaf add CAD
 20140901 tpd src/axiom-website/patches.html 20140901.03.tpd.patch
 20140901 tpd src/axiom-website/documentation.html add Socrates quote
 20140901 tpd src/axiom-website/patches.html 20140901.02.tpd.patch
diff --git a/patch b/patch
index 5d4279f..d0800db 100644
--- a/patch
+++ b/patch
@@ -1,14 +1,3 @@
-src/axiom-website/documentation.html add Socrates quote
-
-Then anyone who leaves behind him a written manual, and likewise
-anyone who takes it over from him, on the supposition that such
-writing will provide something reliable and permanent, must be
-exceedingly simple-minded; he must really be ignorant of Ammon's
-utterance, if he imagines that written words can do anything more than
-remind one who knows that which the writing is concerned with.
-  -- Socrates
-
-All I need in the documenation is to be reminded of that which
-the writing is concerned with.
- -- Tim Daly
+books/bookvol10.3, vol10.4 add Cylindrical Algebraic Computation
 
+Add Cylindrical Algebraic Computation to Axiom
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 62c5fed..b3b257e 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -4620,6 +4620,8 @@ src/axiom-website/videos.html add Developer videos section<br/>
 src/axiom-website/videos.html add Website Pages video<br/>
 <a href="patches/20140901.03.tpd.patch">20140901.03.tpd.patch</a>
 src/axiom-website/documentation.html add Socrates quote<br/>
+<a href="patches/20140901.02.tpd.patch">20140901.02.tpd.patch</a>
+books/bookvol10.3, vol10.4 add Cylindrical Algebraic Computation<br/>
  </body>
 </html>
 
diff --git a/src/input/Makefile.pamphlet b/src/input/Makefile.pamphlet
index a3f5411..3305306 100644
--- a/src/input/Makefile.pamphlet
+++ b/src/input/Makefile.pamphlet
@@ -300,7 +300,7 @@ REGRESSTESTS= ackermann.regress \
     bug100.regress    bug101.regress \
     bug103.regress    bug10069.regress \
     bugs.regress      bug10312.regress bug6357.regress  bug9057.regress \
-    cachedf.regress   calcprob.regress  \
+    cachedf.regress   cad.regress      calcprob.regress  \
     calculus2.regress calculus.regress cardinal.regress card.regress \
     carten.regress    cclass.regress   char.regress     ch.regress \
     charlwood.regress cherry.regress    \
@@ -708,7 +708,8 @@ FILES= ${OUT}/ackermann.input \
        ${OUT}/bstree.input   ${OUT}/bug6357.input \
        ${OUT}/bug9057.input  ${OUT}/bug100.input     ${OUT}/bug101.input \
        ${OUT}/bug103.input \
-       ${OUT}/bug10069.input ${OUT}/bug10312.input   ${OUT}/cachedf.input \
+       ${OUT}/bug10069.input ${OUT}/bug10312.input   ${OUT}cad.input \
+       ${OUT}/cachedf.input \
        ${OUT}/calcprob.input ${OUT}/calculus.input \
        ${OUT}/cardinal.input ${OUT}/card.input       ${OUT}/carten.input \
        ${OUT}/cclass.input   ${OUT}/cdraw.input      ${OUT}/char.input \
@@ -1050,6 +1051,7 @@ DOCFILES= \
   ${DOC}/c06fuf.input.dvi      ${DOC}/c06gbf.input.dvi     \
   ${DOC}/c06gcf.input.dvi      ${DOC}/c06gqf.input.dvi     \
   ${DOC}/c06gsf.input.dvi      ${DOC}/cachedf.input.dvi    \
+  ${DOC}/cad.input.dvi         \
   ${DOC}/calcprob.input.dvi    ${DOC}/calculus2.input.dvi  \
   ${DOC}/calculus.input.dvi    ${DOC}/cardinal.input.dvi   \
   ${DOC}/card.input.dvi        ${DOC}/carten.input.dvi     \
diff --git a/src/input/cad.input.pamphlet b/src/input/cad.input.pamphlet
new file mode 100644
index 0000000..78ead8c
--- /dev/null
+++ b/src/input/cad.input.pamphlet
@@ -0,0 +1,179 @@
+\documentclass{article}
+\usepackage{axiom}
+\setlength{\textwidth}{400pt}
+\begin{document}
+\title{\$SPAD/src/input cad.input}
+\author{Renaud Rioboo}
+\maketitle
+\begin{abstract}
+\end{abstract}
+\eject
+\tableofcontents
+\eject
+\begin{chunk}{*}
+)set break resume
+)spool cad.output
+)set message test on
+)set message auto off
+)clear all
+ 
+--S 1 of 12
+Ran := RECLOS(FRAC INT)
+--R 
+--R
+--R   (1)  RealClosure(Fraction(Integer))
+--R                                                                 Type: Domain
+--E 1
+
+--S 2 of 12
+Cad := CAD(Ran)
+--R 
+--R
+--R   (2)
+--R   CylindricalAlgebraicDecompositionPackage(RealClosure(Fraction(Integer)))
+--R                                                                 Type: Domain
+--E 2
+
+--S 3 of 12
+p1 : POLY(Ran) := x^2+y^2-1
+--R 
+--R
+--R         2    2
+--R   (3)  y  + x  - 1
+--R                             Type: Polynomial(RealClosure(Fraction(Integer)))
+--E 3
+
+--S 4 of 12
+p2 : POLY(Ran) := y-x^2
+--R 
+--R
+--R             2
+--R   (4)  y - x
+--R                             Type: Polynomial(RealClosure(Fraction(Integer)))
+--E 4
+
+--S 5 of 12
+lpols : List(POLY(Ran)) := [p1,p2]
+--R 
+--R
+--R          2    2          2
+--R   (5)  [y  + x  - 1,y - x ]
+--R                       Type: List(Polynomial(RealClosure(Fraction(Integer))))
+--E 5
+
+--S 6 of 12
+cad := cylindricalDecomposition(lpols)$Cad;
+--R 
+--R
+--R                             Type: List(Cell(RealClosure(Fraction(Integer))))
+--E 6
+
+--S 7 of 12
+precision(30)
+--R 
+--R
+--R   (7)  68
+--R                                                        Type: PositiveInteger
+--E 7
+
+--S 8 of 12
+ls := [ samplePoint cell for cell in cad]
+--R 
+--R
+--R   (8)
+--R                                                      1
+--R   [[- 5,- 2], [4,- 2], [5,- 2], [- 2,- 1], [0,- 1], [-,- 1], [1,- 1], [2,- 1],
+--R                                                      2
+--R       113   7          7        7          7    339   7    49   7    113   7
+--R    [- ---,- -], [%A5,- -], [0,- -], [%A6,- -], [---,- -], [--,- -], [---,- -],
+--R        64   8          8        8          8    512   8    64   8    128   8
+--R          2                 2                    2           2
+--R    [- %A1  - 1,%A1], [- %A1 ,%A1], [0,%A1], [%A1 ,%A1], [%A1  + 1,%A1],
+--R                         1             1                           2
+--R    [- 2,0], [%A7,0], [- -,0], [0,0], [-,0], [%A8,0], [2,0], [- %A2  - 1,%A2],
+--R                         2             2
+--R          2                    2           2              113 7        7
+--R    [- %A2 ,%A2], [0,%A2], [%A2 ,%A2], [%A2  + 1,%A2], [- ---,-], [%A9,-],
+--R                                                           64 8        8
+--R       7         7    339 7    49 7    113 7                    1
+--R    [0,-], [%A10,-], [---,-], [--,-], [---,-], [- 2,1], [0,1], [-,1], [1,1],
+--R       8         8    512 8    64 8    128 8                    2
+--R    [2,1], [- 5,2], [4,2], [5,2]]
+--R                             Type: List(List(RealClosure(Fraction(Integer))))
+--E 8
+
+--S 9 of 12
+lf := [ [relativeApprox(coord,2^(-precision()))::Float for coord in point] for point in ls]
+--R 
+--R
+--R   (9)
+--R   [[- 5.0,- 2.0], [4.0,- 2.0], [5.0,- 2.0], [- 2.0,- 1.0], [0.0,- 1.0],
+--R    [0.5,- 1.0], [1.0,- 1.0], [2.0,- 1.0], [- 1.765625,- 0.875],
+--R    [- 0.48412292,- 0.875], [0.0,- 0.875], [0.48412292,- 0.875],
+--R    [0.66210938,- 0.875], [0.765625,- 0.875], [0.8828125,- 0.875],
+--R    [- 1.618034,- 0.78615138], [- 0.61803399,- 0.78615138], [0.0,- 0.78615138],
+--R    [0.61803399,- 0.78615138], [1.618034,- 0.78615138], [- 2.0,0.0],
+--R    [- 1.0,0.0], [- 0.5,0.0], [0.0,0.0], [0.5,0.0], [1.0,0.0], [2.0,0.0],
+--R    [- 1.618034,0.78615138], [- 0.61803399,0.78615138], [0.0,0.78615138],
+--R    [0.61803399,0.78615138], [1.618034,0.78615138], [- 1.765625,0.875],
+--R    [- 0.48412292,0.875], [0.0,0.875], [0.48412292,0.875], [0.66210938,0.875],
+--R    [0.765625,0.875], [0.8828125,0.875], [- 2.0,1.0], [0.0,1.0], [0.5,1.0],
+--R    [1.0,1.0], [2.0,1.0], [- 5.0,2.0], [4.0,2.0], [5.0,2.0]]
+--R                                                      Type: List(List(Float))
+--E 9
+
+--S 10 of 12
+lp := [ point(term::List(DoubleFloat))$Point(DoubleFloat) for term in lf ]
+--R 
+--R
+--R   (10)
+--R   [[- 5.,- 2.], [4.,- 2.], [5.,- 2.], [- 2.,- 1.], [0.,- 1.], [0.5,- 1.],
+--R    [1.,- 1.], [2.,- 1.], [- 1.765625,- 0.875],
+--R    [- 0.48412291845306754,- 0.875], [0.,- 0.875],
+--R    [0.48412291845306754,- 0.875], [0.662109375,- 0.875], [0.765625,- 0.875],
+--R    [0.8828125,- 0.875], [- 1.6180339884012938,- 0.78615137748420238],
+--R    [- 0.61803398933261633,- 0.78615137748420238], [0.,- 0.78615137748420238],
+--R    [0.61803398933261633,- 0.78615137748420238],
+--R    [1.6180339884012938,- 0.78615137748420238], [- 2.,0.], [- 1.,0.],
+--R    [- 0.5,0.], [0.,0.], [0.5,0.], [1.,0.], [2.,0.],
+--R    [- 1.6180339884012938,0.78615137748420238],
+--R    [- 0.61803398933261633,0.78615137748420238], [0.,0.78615137748420238],
+--R    [0.61803398933261633,0.78615137748420238],
+--R    [1.6180339884012938,0.78615137748420238], [- 1.765625,0.875],
+--R    [- 0.48412291845306754,0.875], [0.,0.875], [0.48412291845306754,0.875],
+--R    [0.662109375,0.875], [0.765625,0.875], [0.8828125,0.875], [- 2.,1.],
+--R    [0.,1.], [0.5,1.], [1.,1.], [2.,1.], [- 5.,2.], [4.,2.], [5.,2.]]
+--R                                               Type: List(Point(DoubleFloat))
+--E 10
+
+--S 11 of 12
+[ sign(eval(p1,variables(p1),samplePoint(cell))::Ran) for cell in cad ]
+--R 
+--R
+--R   (11)
+--R   [1, 1, 1, 1, 0, 1, 1, 1, 1, 0, - 1, 0, 1, 1, 1, 1, 0, - 1, 0, 1, 1, 0, - 1,
+--R    - 1, - 1, 0, 1, 1, 0, - 1, 0, 1, 1, 0, - 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1,
+--R    1, 1]
+--R                                                          Type: List(Integer)
+--E 11
+
+--S 12 of 12
+[ sign(eval(p2,variables(p2),samplePoint(cell))::Ran) for cell in cad ]
+--R 
+--R
+--R   (12)
+--R   [- 1, 0, 1, - 1, - 1, - 1, 0, 1, - 1, - 1, - 1, - 1, - 1, 0, 1, - 1, - 1,
+--R    - 1, 0, 1, - 1, - 1, - 1, 0, 1, 1, 1, - 1, - 1, - 1, 0, 1, - 1, - 1, - 1,
+--R    - 1, - 1, 0, 1, - 1, - 1, - 1, 0, 1, - 1, 0, 1]
+--R                                                          Type: List(Integer)
+--E 12
+
+)spool 
+)lisp (bye)
+ 
+\end{chunk}
+\eject
+\begin{thebibliography}{99}
+\bibitem{1} nothing
+\end{thebibliography}
+\end{document}
diff --git a/src/share/algebra/browse.daase b/src/share/algebra/browse.daase
index 800b954..5cceacb 100644
--- a/src/share/algebra/browse.daase
+++ b/src/share/algebra/browse.daase
@@ -1,5 +1,5 @@
 
-(2502193 . 3614189654)       
+(2502729 . 3618694787)       
 (|OneDimensionalArrayAggregate&| A S) 
 ((|constructor| (NIL "One-dimensional-array aggregates serves as models for one-dimensional arrays. Categorically, these aggregates are finite linear aggregates with the \\spadatt{shallowlyMutable} property, that is, any component of the array may be changed without affecting the identity of the overall array. Array data structures are typically represented by a fixed area in storage and cannot efficiently grow or shrink on demand as can list structures (see however \\spadtype{FlexibleArray} for a data structure which is a cross between a list and an array). Iteration over, and access to, elements of arrays is extremely fast (and often can be optimized to open-code). Insertion and deletion however is generally slow since an entirely new data structure must be created for the result."))) 
 NIL 
@@ -568,6 +568,14 @@ NIL
 ((|constructor| (NIL "A cachable set is a set whose elements keep an integer as part of their structure.")) (|setPosition| (((|Void|) $ (|NonNegativeInteger|)) "\\spad{setPosition(x, \\spad{n)}} associates the integer \\spad{n} to \\spad{x.}")) (|position| (((|NonNegativeInteger|) $) "\\spad{position(x)} returns the integer \\spad{n} associated to \\spad{x.}"))) 
 NIL 
 NIL 
+(|CylindricalAlgebraicDecompositionPackage| |TheField|) 
+NIL 
+NIL 
+NIL 
+(|CylindricalAlgebraicDecompositionUtilities| R P) 
+((|gcdBasisAdd| (((|List| |#2|) |#2| (|List| |#2|)) "add one polynomial to list of pairwise relatively prime polynomials")) (|gcdBasis| (((|List| |#2|) (|List| |#2|)) "decompose a list of polynomials into pairwise relatively prime polynomials")) (|squareFreeBasis| (((|List| |#2|) (|List| |#2|)) "\\blankline"))) 
+NIL 
+NIL 
 (|CardinalNumber|) 
 ((|constructor| (NIL "Members of the domain CardinalNumber are values indicating the cardinality of sets, both finite and infinite. Arithmetic operations are defined on cardinal numbers as follows. \\blankline If \\spad{x = \\spad{#X}} and \\spad{y = \\spad{#Y}} then\\br \\tab{5}\\spad{x+y = \\#(X+Y)} \\tab{5}disjoint union\\br \\tab{5}\\spad{x-y = \\#(X-Y)} \\tab{5}relative complement\\br \\tab{5}\\spad{x*y = \\#(X*Y)} \\tab{5}cartesian product\\br \\tab{5}\\spad{x**y = \\#(X**Y)} \\tab{4}\\spad{X**Y = \\spad{g|} g:Y->X} \\blankline The non-negative integers have a natural construction as cardinals\\br \\spad{0 = \\#\\{\\}}, \\spad{1 = \\{0\\}}, \\spad{2 = \\{0, 1\\}}, ..., \\spad{n = \\{i| 0 \\spad{<=} \\spad{i} < n\\}}. \\blankline That \\spad{0} acts as a zero for the multiplication of cardinals is equivalent to the axiom of choice. \\blankline The generalized continuum hypothesis asserts \\spad{\\br} \\spad{2**Aleph \\spad{i} = Aleph(i+1)} and is independent of the axioms of set theory [Goedel 1940]. \\blankline Three commonly encountered cardinal numbers are\\br \\tab{5}\\spad{a = \\spad{#Z}} \\tab{5}countable infinity\\br \\tab{5}\\spad{c = \\spad{#R}} \\tab{5}the continuum\\br \\tab{5}\\spad{f = \\# \\spad{g} | g:[0,1]->R\\} \\blankline In this domain, these values are obtained using\\br \\tab{5}\\spad{a \\spad{:=} Aleph 0}, \\spad{c \\spad{:=} 2**a}, \\spad{f \\spad{:=} 2**c}.")) (|generalizedContinuumHypothesisAssumed| (((|Boolean|) (|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed(bool)} \\indented{1}{is used to dictate whether the hypothesis is to be assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} a:=Aleph 0 \\spad{X} c:=2**a \\spad{X} f:=2**c")) (|generalizedContinuumHypothesisAssumed?| (((|Boolean|)) "\\indented{1}{generalizedContinuumHypothesisAssumed?()} \\indented{1}{tests if the hypothesis is currently assumed.} \\blankline \\spad{X} generalizedContinuumHypothesisAssumed?")) (|countable?| (((|Boolean|) $) "\\indented{1}{countable?(\\spad{a}) determines} \\indented{1}{whether \\spad{a} is a countable cardinal,} \\indented{1}{\\spadignore{i.e.} an integer or \\spad{Aleph 0}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} countable? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} countable? \\spad{A0} \\spad{X} A1:=Aleph 1 \\spad{X} countable? \\spad{A1}")) (|finite?| (((|Boolean|) $) "\\indented{1}{finite?(\\spad{a}) determines whether} \\indented{1}{\\spad{a} is a finite cardinal, \\spadignore{i.e.} an integer.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} finite? \\spad{c2} \\spad{X} A0:=Aleph 0 \\spad{X} finite? \\spad{A0}")) (|Aleph| (($ (|NonNegativeInteger|)) "\\indented{1}{Aleph(n) provides the named (infinite) cardinal number.} \\blankline \\spad{X} A0:=Aleph 0")) (** (($ $ $) "\\indented{1}{\\spad{x**y} returns \\spad{\\#(X**Y)} where \\spad{X**Y} is defined} \\indented{2}{as \\spad{\\{g| g:Y->X\\}}.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2**c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1**c2} \\spad{X} generalizedContinuumHypothesisAssumed \\spad{true} \\spad{X} \\spad{A1**A1}")) (- (((|Union| $ "failed") $ $) "\\indented{1}{\\spad{x - \\spad{y}} returns an element \\spad{z} such that} \\indented{1}{\\spad{z+y=x} or \"failed\" if no such element exists.} \\blankline \\spad{X} c2:=2::CardinalNumber \\spad{X} \\spad{c2-c2} \\spad{X} A1:=Aleph 1 \\spad{X} \\spad{A1-c2}")) (|commutative| ((|attribute| "*") "a domain \\spad{D} has \\spad{commutative(\"*\")} if it has an operation \\spad{\"*\": (D,D) \\spad{->} \\spad{D}} which is commutative."))) 
 (((|commutative| "*") . T)) 
@@ -596,6 +604,10 @@ NIL
 ((|constructor| (NIL "This is a low-level domain which implements vectors (one dimensional arrays) of complex double precision floating point numbers. Indexing is 0 based, there is no bound checking (unless provided by lower level).")) (|vector| (($ (|List| (|Complex| (|DoubleFloat|)))) "\\indented{1}{vector(l) converts the list \\spad{l} to a vector.} \\blankline \\spad{X} t1:List(Complex(DoubleFloat)):=[1+2*\\%i,3+4*\\%i,-5-6*\\%i] \\spad{X} t2:CDFVEC:=vector(t1)")) (|qnew| (($ (|Integer|)) "\\indented{1}{qnew(n) creates a new uninitialized vector of length \\spad{n.}} \\blankline \\spad{X} t1:CDFVEC:=qnew 7"))) 
 ((|shallowlyMutable| . T) (|finiteAggregate| . T)) 
 ((|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|SetCategory|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (LIST (QUOTE |ConvertibleTo|) (QUOTE (|InputForm|)))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|OrderedSet|))) (OR (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|OrderedSet|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|SetCategory|)))) (|HasCategory| (|Integer|) (QUOTE (|OrderedSet|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|AbelianSemiGroup|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|AbelianMonoid|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|AbelianGroup|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|Monoid|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|Ring|))) (AND (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|RadicalCategory|))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|Ring|)))) (AND (|HasCategory| (|Complex| (|DoubleFloat|)) (LIST (QUOTE |Evalable|) (LIST (QUOTE |Complex|) (QUOTE (|DoubleFloat|))))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|SetCategory|)))) (OR (AND (|HasCategory| (|Complex| (|DoubleFloat|)) (LIST (QUOTE |Evalable|) (LIST (QUOTE |Complex|) (QUOTE (|DoubleFloat|))))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|OrderedSet|)))) (AND (|HasCategory| (|Complex| (|DoubleFloat|)) (LIST (QUOTE |Evalable|) (LIST (QUOTE |Complex|) (QUOTE (|DoubleFloat|))))) (|HasCategory| (|Complex| (|DoubleFloat|)) (QUOTE (|SetCategory|)))))) 
+(|Cell| |TheField|) 
+NIL 
+NIL 
+NIL 
 (|CombinatorialFunctionCategory|) 
 ((|constructor| (NIL "Category for the usual combinatorial functions.")) (|permutation| (($ $ $) "\\spad{permutation(n, \\spad{m)}} returns the number of permutations of \\spad{n} objects taken \\spad{m} at a time. Note that \\spad{permutation(n,m) = n!/(n-m)!}.")) (|factorial| (($ $) "\\spad{factorial(n)} computes the factorial of \\spad{n} (denoted in the literature by \\spad{n!}) Note that \\spad{n! = \\spad{n} (n-1)! when \\spad{n} > 0}; also, \\spad{0! = 1}.")) (|binomial| (($ $ $) "\\indented{1}{binomial(n,r) returns the \\spad{(n,r)} binomial coefficient} \\indented{1}{(often denoted in the literature by \\spad{C(n,r)}).} \\indented{1}{Note that \\spad{C(n,r) = n!/(r!(n-r)!)} where \\spad{n \\spad{>=} \\spad{r} \\spad{>=} 0}.} \\blankline \\spad{X} [binomial(5,i) for \\spad{i} in 0..5]"))) 
 NIL 
@@ -4348,6 +4360,10 @@ NIL
 ((|constructor| (NIL "A sorted cache of a cachable set \\spad{S} is a dynamic structure that keeps the elements of \\spad{S} sorted and assigns an integer to each element of \\spad{S} once it is in the cache. This way, equality and ordering on \\spad{S} are tested directly on the integers associated with the elements of \\spad{S,} once they have been entered in the cache.")) (|enterInCache| ((|#1| |#1| (|Mapping| (|Integer|) |#1| |#1|)) "\\spad{enterInCache(x, \\spad{f)}} enters \\spad{x} in the cache, calling \\spad{f(x, \\spad{y)}} to determine whether \\spad{x < \\spad{y} (f(x,y) < 0), \\spad{x} = \\spad{y} (f(x,y) = 0)}, or \\spad{x > \\spad{y} (f(x,y) > 0)}. It returns \\spad{x} with an integer associated with it.") ((|#1| |#1| (|Mapping| (|Boolean|) |#1|)) "\\spad{enterInCache(x, \\spad{f)}} enters \\spad{x} in the cache, calling \\spad{f(y)} to determine whether \\spad{x} is equal to \\spad{y.} It returns \\spad{x} with an integer associated with it.")) (|cache| (((|List| |#1|)) "\\spad{cache()} returns the current cache as a list.")) (|clearCache| (((|Void|)) "\\spad{clearCache()} empties the cache."))) 
 NIL 
 NIL 
+(|SimpleCell| |TheField| |ThePols|) 
+NIL 
+NIL 
+NIL 
 (|StructuralConstantsPackage| R) 
 ((|constructor| (NIL "StructuralConstantsPackage provides functions creating structural constants from a multiplication tables or a basis of a matrix algebra and other useful functions in this context.")) (|coordinates| (((|Vector| |#1|) (|Matrix| |#1|) (|List| (|Matrix| |#1|))) "\\spad{coordinates(a,[v1,...,vn])} returns the coordinates of \\spad{a} with respect to the \\spad{R}-module basis \\spad{v1},...,\\spad{vn}.")) (|structuralConstants| (((|Vector| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) "\\spad{structuralConstants(basis)} takes the \\spad{basis} of a matrix algebra, \\spadignore{e.g.} the result of \\spadfun{basisOfCentroid} and calculates the structural constants. Note, that the it is not checked, whether \\spad{basis} really is a \\spad{basis} of a matrix algebra.") (((|Vector| (|Matrix| (|Polynomial| |#1|))) (|List| (|Symbol|)) (|Matrix| (|Polynomial| |#1|))) "\\spad{structuralConstants(ls,mt)} determines the structural constants of an algebra with generators \\spad{ls} and multiplication table \\spad{mt,} the entries of which must be given as linear polynomials in the indeterminates given by \\spad{ls.} The result is in particular useful \\indented{1}{as fourth argument for \\spadtype{AlgebraGivenByStructuralConstants}} \\indented{1}{and \\spadtype{GenericNonAssociativeAlgebra}.}") (((|Vector| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|)) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) "\\spad{structuralConstants(ls,mt)} determines the structural constants of an algebra with generators \\spad{ls} and multiplication table \\spad{mt,} the entries of which must be given as linear polynomials in the indeterminates given by \\spad{ls.} The result is in particular useful \\indented{1}{as fourth argument for \\spadtype{AlgebraGivenByStructuralConstants}} \\indented{1}{and \\spadtype{GenericNonAssociativeAlgebra}.}"))) 
 NIL 
@@ -5176,4 +5192,4 @@ NIL
 NIL 
 NIL 
 NIL 
-((|Category| NIL 2502173 2502178 2502183 2502188) (|Union| NIL 2502153 2502158 2502163 2502168) (|Record| NIL 2502133 2502138 2502143 2502148) (|Mapping| NIL 2502113 2502118 2502123 2502128) (|Enumeration| NIL 2502093 2502098 2502103 2502108) (|IntegerMod| "bookvol10.3.pamphlet" 2501871 2501891 2501999 2502088) (|IntegerLinearDependence| "bookvol10.4.pamphlet" 2500971 2501002 2501861 2501866) (|ZeroDimensionalSolvePackage| "bookvol10.4.pamphlet" 2491563 2491609 2500961 2500966) (|ParadoxicalCombinatorsForStreams| "bookvol10.4.pamphlet" 2491031 2491071 2491553 2491558) (|XRecursivePolynomial| "bookvol10.3.pamphlet" 2490172 2490209 2490810 2490932) (|XPolynomialRing| "bookvol10.3.pamphlet" 2487751 2487776 2489748 2489939) (|XPolynomial| "bookvol10.3.pamphlet" 2487238 2487257 2487530 2487652) (|XPolynomialsCat| "bookvol10.2.pamphlet" 2486491 2486519 2487111 2487233) (|XPBWPolynomial| "bookvol10.3.pamphlet" 2485053 2485084 2486179 2486301) (|ExtensionField| "bookvol10.2.pamphlet" 2483438 2483460 2484883 2485048) (|ExtensionField&| NIL 2481835 2481860 2483283 2483288) (|XFreeAlgebra| "bookvol10.2.pamphlet" 2478808 2478833 2481708 2481830) (|XExponentialPackage| "bookvol10.4.pamphlet" 2478191 2478233 2478798 2478803) (|XDistributedPolynomial| "bookvol10.3.pamphlet" 2477726 2477761 2477970 2478092) (|XAlgebra| "bookvol10.2.pamphlet" 2477396 2477412 2477658 2477721) (|WuWenTsunTriangularSet| "bookvol10.3.pamphlet" 2473964 2474000 2477017 2477069) (|WeightedPolynomials| "bookvol10.3.pamphlet" 2472912 2472972 2473756 2473873) (|WildFunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 2470464 2470509 2472902 2472907) (|WeierstrassPreparation| "bookvol10.4.pamphlet" 2468709 2468739 2470454 2470459) (|VectorSpace| "bookvol10.2.pamphlet" 2468357 2468376 2468660 2468704) (|VectorSpace&| NIL 2468041 2468063 2468347 2468352) (|Void| "bookvol10.3.pamphlet" 2467634 2467644 2468031 2468036) (|ViewportPackage| "bookvol10.4.pamphlet" 2465338 2465359 2467624 2467629) (|ViewDefaultsPackage| "bookvol10.4.pamphlet" 2460582 2460607 2465328 2465333) (|ThreeDimensionalViewport| "bookvol10.3.pamphlet" 2444777 2444807 2460572 2460577) (|TwoDimensionalViewport| "bookvol10.3.pamphlet" 2432949 2432977 2444767 2444772) (|Vector| "bookvol10.3.pamphlet" 2431663 2431677 2431917 2431969) (|VectorFunctions2| "bookvol10.4.pamphlet" 2430324 2430350 2431653 2431658) (|VectorCategory| "bookvol10.2.pamphlet" 2428288 2428310 2430255 2430319) (|VectorCategory&| NIL 2426040 2426065 2428010 2428015) (|Variable| "bookvol10.3.pamphlet" 2425815 2425835 2426030 2426035) (|UnivariateTaylorSeriesCZero| "bookvol10.3.pamphlet" 2420544 2420590 2423859 2424024) (|TaylorSolve| "bookvol10.4.pamphlet" 2420443 2420475 2420534 2420539) (|UTSodetools| "bookvol10.4.pamphlet" 2419721 2419749 2420387 2420392) (|UnivariateTaylorSeriesODESolver| "bookvol10.4.pamphlet" 2417883 2417931 2419711 2419716) (|UnivariateTaylorSeries| "bookvol10.3.pamphlet" 2412240 2412287 2415927 2416092) (|UnivariateTaylorSeriesCategory| "bookvol10.2.pamphlet" 2409462 2409505 2412070 2412235) (|UnivariateTaylorSeriesCategory&| NIL 2406269 2406315 2408880 2408885) (|UnivariateTaylorSeriesFunctions2| "bookvol10.4.pamphlet" 2405865 2405929 2406259 2406264) (|UnaryRecursiveAggregate| "bookvol10.2.pamphlet" 2401129 2401160 2405845 2405860) (|UnaryRecursiveAggregate&| NIL 2396353 2396387 2401072 2401077) (|UnivariatePuiseuxSeriesWithExponentialSingularity| "bookvol10.3.pamphlet" 2393488 2393560 2394948 2395189) (|UnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 2390549 2390597 2391150 2391402) (|UnivariatePuiseuxSeriesConstructor| "bookvol10.3.pamphlet" 2387809 2387860 2388211 2388463) (|UnivariatePuiseuxSeriesConstructorCategory| "bookvol10.2.pamphlet" 2386137 2386196 2387552 2387804) (|UnivariatePuiseuxSeriesConstructorCategory&| NIL 2384709 2384771 2386127 2386132) (|UnivariatePuiseuxSeriesCategory| "bookvol10.2.pamphlet" 2383169 2383213 2384452 2384704) (|UnivariatePuiseuxSeriesFunctions2| "bookvol10.4.pamphlet" 2382682 2382765 2383159 2383164) (|UnivariatePolynomialSquareFree| "bookvol10.4.pamphlet" 2381083 2381124 2382672 2382677) (|UnivariatePowerSeriesCategory| "bookvol10.2.pamphlet" 2378559 2378609 2380913 2381078) (|UnivariatePowerSeriesCategory&| NIL 2375772 2375825 2378129 2378134) (|UnivariatePolynomialCategory| "bookvol10.2.pamphlet" 2370011 2370047 2375490 2375767) (|UnivariatePolynomialCategory&| NIL 2364205 2364244 2369687 2369692) (|UnivariatePolynomialCategoryFunctions2| "bookvol10.4.pamphlet" 2363635 2363689 2364195 2364200) (|UnivariatePolynomial| "bookvol10.3.pamphlet" 2359516 2359548 2360124 2360401) (|UnivariatePolynomialMultiplicationPackage| "bookvol10.4.pamphlet" 2358412 2358463 2359506 2359511) (|UnivariatePolynomialDivisionPackage| "bookvol10.4.pamphlet" 2357945 2357991 2358402 2358407) (|UnivariatePolynomialDecompositionPackage| "bookvol10.4.pamphlet" 2356149 2356200 2357935 2357940) (|UnivariatePolynomialCommonDenominator| "bookvol10.4.pamphlet" 2355316 2355366 2356139 2356144) (|UnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 2354691 2354739 2355306 2355311) (|UniversalSegment| "bookvol10.3.pamphlet" 2354014 2354038 2354593 2354598) (|UniversalSegmentFunctions2| "bookvol10.4.pamphlet" 2353489 2353525 2353961 2353966) (|UnivariateFactorize| "bookvol10.4.pamphlet" 2352596 2352624 2353479 2353484) (|UnivariateLaurentSeries| "bookvol10.3.pamphlet" 2340419 2340467 2341412 2342122) (|UnivariateLaurentSeriesConstructor| "bookvol10.3.pamphlet" 2333157 2333208 2333556 2333808) (|UnivariateLaurentSeriesConstructorCategory| "bookvol10.2.pamphlet" 2330605 2330664 2332871 2333152) (|UnivariateLaurentSeriesConstructorCategory&| NIL 2328289 2328351 2330558 2330563) (|UnivariateLaurentSeriesCategory| "bookvol10.2.pamphlet" 2326368 2326412 2328032 2328284) (|UnivariateLaurentSeriesFunctions2| "bookvol10.4.pamphlet" 2325882 2325965 2326358 2326363) (|UnivariateFormalPowerSeries| "bookvol10.3.pamphlet" 2323828 2323868 2323926 2324091) (|UnivariateFormalPowerSeriesFunctions| "bookvol10.4.pamphlet" 2323710 2323759 2323818 2323823) (|UniqueFactorizationDomain| "bookvol10.2.pamphlet" 2322714 2322745 2323593 2323705) (|UniqueFactorizationDomain&| NIL 2321822 2321856 2322704 2322709) (|UserDefinedVariableOrdering| "bookvol10.4.pamphlet" 2320609 2320642 2321812 2321817) (|UserDefinedPartialOrdering| "bookvol10.4.pamphlet" 2318104 2318138 2320557 2320562) (|U8Vector| "bookvol10.3.pamphlet" 2317149 2317163 2317357 2317409) (|U8Matrix| "bookvol10.3.pamphlet" 2316248 2316262 2316640 2316692) (|U32Vector| "bookvol10.3.pamphlet" 2315291 2315306 2315501 2315553) (|U32Matrix| "bookvol10.3.pamphlet" 2314387 2314402 2314782 2314834) (|U16Vector| "bookvol10.3.pamphlet" 2313430 2313445 2313640 2313692) (|U16Matrix| "bookvol10.3.pamphlet" 2312526 2312541 2312921 2312973) (|Type| "bookvol10.2.pamphlet" 2312447 2312457 2312506 2312521) (|TwoFactorize| "bookvol10.4.pamphlet" 2311102 2311122 2312437 2312442) (|Tuple| "bookvol10.3.pamphlet" 2310101 2310114 2311049 2311054) (|TubePlotTools| "bookvol10.4.pamphlet" 2306985 2307004 2310091 2310096) (|TubePlot| "bookvol10.3.pamphlet" 2305670 2305692 2306975 2306980) (|TaylorSeries| "bookvol10.3.pamphlet" 2304082 2304107 2305065 2305230) (|TriangularSetCategory| "bookvol10.2.pamphlet" 2293595 2293630 2304013 2304077) (|TriangularSetCategory&| NIL 2283126 2283164 2293547 2293552) (|TranscendentalManipulations| "bookvol10.4.pamphlet" 2277502 2277539 2282772 2282777) (|TriangularMatrixOperations| "bookvol10.4.pamphlet" 2276450 2276498 2277492 2277497) (|TrigonometricManipulations| "bookvol10.4.pamphlet" 2274928 2274964 2276440 2276445) (|TrigonometricFunctionCategory| "bookvol10.2.pamphlet" 2274414 2274449 2274918 2274923) (|TrigonometricFunctionCategory&| NIL 2273897 2273935 2274404 2274409) (|Tree| "bookvol10.3.pamphlet" 2272062 2272074 2273680 2273732) (|TranscendentalFunctionCategory| "bookvol10.2.pamphlet" 2271882 2271918 2272052 2272057) (|TranscendentalFunctionCategory&| NIL 2271699 2271738 2271872 2271877) (|TopLevelThreeSpace| "bookvol10.4.pamphlet" 2271362 2271386 2271689 2271694) (|ToolsForSign| "bookvol10.4.pamphlet" 2271016 2271036 2271352 2271357) (|TextFile| "bookvol10.3.pamphlet" 2269590 2269604 2271006 2271011) (|TexFormat| "bookvol10.3.pamphlet" 2266721 2266736 2269580 2269585) (|TexFormat1| "bookvol10.4.pamphlet" 2266270 2266288 2266711 2266716) (|TemplateUtilities| "bookvol10.4.pamphlet" 2265817 2265840 2266260 2266265) (|TabulatedComputationPackage| "bookvol10.4.pamphlet" 2263984 2264031 2265807 2265812) (|TableAggregate| "bookvol10.2.pamphlet" 2262982 2263016 2263939 2263979) (|TableAggregate&| NIL 2262012 2262049 2262972 2262977) (|TangentExpansions| "bookvol10.4.pamphlet" 2261374 2261399 2262002 2262007) (|Table| "bookvol10.3.pamphlet" 2260189 2260214 2260461 2260513) (|Tableau| "bookvol10.3.pamphlet" 2259675 2259690 2260179 2260184) (|TableauxBumpers| "bookvol10.4.pamphlet" 2256581 2256604 2259665 2259670) (|SystemSolvePackage| "bookvol10.4.pamphlet" 2253197 2253223 2256571 2256576) (|SymbolTable| "bookvol10.3.pamphlet" 2251286 2251303 2253187 2253192) (|TheSymbolTable| "bookvol10.3.pamphlet" 2247340 2247360 2251276 2251281) (|SymmetricPolynomial| "bookvol10.3.pamphlet" 2245986 2246013 2246084 2246318) (|SymmetricFunctions| "bookvol10.4.pamphlet" 2245392 2245418 2245976 2245981) (|Symbol| "bookvol10.3.pamphlet" 2242851 2242863 2245382 2245387) (|Switch| "bookvol10.3.pamphlet" 2239594 2239606 2242841 2242846) (|SparseUnivariateTaylorSeries| "bookvol10.3.pamphlet" 2236177 2236230 2237638 2237803) (|SparseUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 2232815 2232869 2233839 2234091) (|SparseUnivariatePolynomial| "bookvol10.3.pamphlet" 2228426 2228460 2229304 2229581) (|SupFractionFactorizer| "bookvol10.4.pamphlet" 2227528 2227564 2228416 2228421) (|SparseUnivariatePolynomialExpressions| "bookvol10.3.pamphlet" 2223850 2223895 2223953 2224230) (|SparseUnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 2223211 2223257 2223840 2223845) (|RationalFunctionSum| "bookvol10.4.pamphlet" 2221797 2221824 2223201 2223206) (|FunctionSpaceSum| "bookvol10.4.pamphlet" 2221466 2221492 2221787 2221792) (|SparseUnivariateLaurentSeries| "bookvol10.3.pamphlet" 2208898 2208952 2209910 2210644) (|SuchThat| "bookvol10.3.pamphlet" 2208575 2208595 2208888 2208893) (|SubSpace| "bookvol10.3.pamphlet" 2200925 2200945 2208565 2208570) (|SubResultantPackage| "bookvol10.4.pamphlet" 2200068 2200098 2200868 2200873) (|StreamTranscendentalFunctions| "bookvol10.4.pamphlet" 2196143 2196185 2200058 2200063) (|StreamTranscendentalFunctionsNonCommutative| "bookvol10.4.pamphlet" 2192573 2192629 2196133 2196138) (|StreamTaylorSeriesOperations| "bookvol10.4.pamphlet" 2185100 2185136 2192434 2192439) (|StringTable| "bookvol10.3.pamphlet" 2183994 2184019 2184151 2184203) (|String| "bookvol10.3.pamphlet" 2183179 2183191 2183280 2183332) (|StringCategory| "bookvol10.2.pamphlet" 2182919 2182939 2183110 2183174) (|Stream| "bookvol10.3.pamphlet" 2178438 2178452 2182601 2182629) (|StreamFunctions3| "bookvol10.4.pamphlet" 2177766 2177794 2178428 2178433) (|StreamFunctions2| "bookvol10.4.pamphlet" 2176326 2176352 2177756 2177761) (|StreamFunctions1| "bookvol10.4.pamphlet" 2175821 2175845 2176316 2176321) (|StreamTensor| "bookvol10.4.pamphlet" 2175497 2175517 2175811 2175816) (|StreamInfiniteProduct| "bookvol10.4.pamphlet" 2174415 2174449 2175487 2175492) (|StepThrough| "bookvol10.2.pamphlet" 2173633 2173650 2174405 2174410) (|SparseTable| "bookvol10.3.pamphlet" 2172571 2172607 2172744 2172772) (|StreamAggregate| "bookvol10.2.pamphlet" 2171658 2171681 2172551 2172566) (|StreamAggregate&| NIL 2170752 2170778 2171648 2171653) (|Stack| "bookvol10.3.pamphlet" 2166740 2166753 2170535 2170587) (|SquareFreeRegularTriangularSet| "bookvol10.3.pamphlet" 2164879 2164923 2166361 2166413) (|SquareFreeRegularSetDecompositionPackage| "bookvol10.4.pamphlet" 2163608 2163665 2164869 2164874) (|StringAggregate| "bookvol10.2.pamphlet" 2158908 2158929 2163539 2163603) (|StringAggregate&| NIL 2154264 2154288 2158898 2158903) (|SquareMatrix| "bookvol10.3.pamphlet" 2151528 2151555 2152443 2152585) (|SplittingTree| "bookvol10.3.pamphlet" 2146938 2146961 2151192 2151244) (|SplittingNode| "bookvol10.3.pamphlet" 2143976 2143999 2146928 2146933) (|SpecialFunctionCategory| "bookvol10.2.pamphlet" 2142767 2142796 2143966 2143971) (|SpecialOutputPackage| "bookvol10.4.pamphlet" 2141319 2141345 2142757 2142762) (|ThreeSpaceCategory| "bookvol10.2.pamphlet" 2125694 2125720 2141309 2141314) (|ThreeSpace| "bookvol10.3.pamphlet" 2125469 2125487 2125684 2125689) (|SortPackage| "bookvol10.4.pamphlet" 2125002 2125023 2125417 2125422) (|TransSolvePackage| "bookvol10.4.pamphlet" 2122583 2122608 2124992 2124997) (|TransSolvePackageService| "bookvol10.4.pamphlet" 2121151 2121183 2122573 2122578) (|RadicalSolvePackage| "bookvol10.4.pamphlet" 2115623 2115650 2121141 2121146) (|PolynomialSolveByFormulas| "bookvol10.4.pamphlet" 2114069 2114105 2115613 2115618) (|SquareFreeNormalizedTriangularSetCategory| "bookvol10.2.pamphlet" 2113777 2113832 2114000 2114064) (|SparseMultivariateTaylorSeries| "bookvol10.3.pamphlet" 2111734 2111787 2113172 2113337) (|SparseMultivariatePolynomial| "bookvol10.3.pamphlet" 2108266 2108311 2108664 2108898) (|SmithNormalForm| "bookvol10.4.pamphlet" 2107091 2107128 2108256 2108261) (|SquareMatrixCategory| "bookvol10.2.pamphlet" 2105146 2105193 2106987 2107086) (|SquareMatrixCategory&| NIL 2103156 2103206 2105000 2105005) (|StackAggregate| "bookvol10.2.pamphlet" 2101722 2101744 2103087 2103151) (|SingleInteger| "bookvol10.3.pamphlet" 2099970 2099989 2101483 2101717) (|SimplifyAlgebraicNumberConvertPackage| "bookvol10.4.pamphlet" 2099679 2099722 2099960 2099965) (|RationalFunctionSign| "bookvol10.4.pamphlet" 2098752 2098780 2099669 2099674) (|ElementaryFunctionSign| "bookvol10.4.pamphlet" 2097996 2098028 2098742 2098747) (|SturmHabichtPackage| "bookvol10.4.pamphlet" 2095937 2095968 2097945 2097950) (|SplitHomogeneousDirectProduct| "bookvol10.3.pamphlet" 2085573 2085626 2086101 2086305) (|SemiGroup| "bookvol10.2.pamphlet" 2084879 2084894 2085563 2085568) (|SemiGroup&| NIL 2084182 2084200 2084869 2084874) (|SymmetricGroupCombinatoricFunctions| "bookvol10.4.pamphlet" 2077662 2077703 2084172 2084177) (|SquareFreeRegularTriangularSetCategory| "bookvol10.2.pamphlet" 2077165 2077217 2077593 2077657) (|SquareFreeRegularTriangularSetGcdPackage| "bookvol10.4.pamphlet" 2076827 2076884 2077155 2077160) (|SquareFreeQuasiComponentPackage| "bookvol10.4.pamphlet" 2072716 2072764 2076817 2076822) (|SimpleFortranProgram| "bookvol10.3.pamphlet" 2072160 2072191 2072706 2072711) (|SExpressionOf| "bookvol10.3.pamphlet" 2071993 2072043 2072150 2072155) (|SExpression| "bookvol10.3.pamphlet" 2071877 2071894 2071983 2071988) (|SExpressionCategory| "bookvol10.2.pamphlet" 2069112 2069168 2071867 2071872) (|Set| "bookvol10.3.pamphlet" 2067362 2067373 2068475 2068555) (|SetOfMIntegersInOneToN| "bookvol10.3.pamphlet" 2065823 2065859 2067352 2067357) (|SetCategory| "bookvol10.2.pamphlet" 2065305 2065322 2065813 2065818) (|SetCategory&| NIL 2064784 2064804 2065295 2065300) (|SetCategoryWithDegree| "bookvol10.2.pamphlet" 2064657 2064684 2064774 2064779) (|SetAggregate| "bookvol10.2.pamphlet" 2061522 2061542 2064609 2064652) (|SetAggregate&| NIL 2058422 2058445 2061512 2061517) (|SegmentExpansionCategory| "bookvol10.2.pamphlet" 2057463 2057497 2058402 2058417) (|Segment| "bookvol10.3.pamphlet" 2057255 2057270 2057365 2057370) (|SegmentCategory| "bookvol10.2.pamphlet" 2056031 2056054 2057235 2057250) (|SegmentBinding| "bookvol10.3.pamphlet" 2055098 2055120 2055978 2055983) (|SegmentBindingFunctions2| "bookvol10.4.pamphlet" 2054783 2054817 2055088 2055093) (|SegmentFunctions2| "bookvol10.4.pamphlet" 2054179 2054206 2054730 2054735) (|SequentialDifferentialVariable| "bookvol10.3.pamphlet" 2053450 2053488 2054169 2054174) (|SequentialDifferentialPolynomial| "bookvol10.3.pamphlet" 2049738 2049778 2050044 2050278) (|StochasticDifferential| "bookvol10.3.pamphlet" 2046173 2046203 2049689 2049733) (|StructuralConstantsPackage| "bookvol10.4.pamphlet" 2044253 2044287 2046163 2046168) (|SortedCache| "bookvol10.4.pamphlet" 2043094 2043113 2044243 2044248) (|SingletonAsOrderedSet| "bookvol10.3.pamphlet" 2042948 2042975 2043084 2043089) (|SAERationalFunctionAlgFactor| "bookvol10.4.pamphlet" 2042636 2042681 2042938 2042943) (|SimpleAlgebraicExtension| "bookvol10.3.pamphlet" 2040363 2040400 2041041 2041257) (|SimpleAlgebraicExtensionAlgFactor| "bookvol10.4.pamphlet" 2040034 2040084 2040353 2040358) (|RationalUnivariateRepresentationPackage| "bookvol10.4.pamphlet" 2037734 2037786 2040024 2040029) (|Ruleset| "bookvol10.3.pamphlet" 2037166 2037190 2037724 2037729) (|RewriteRule| "bookvol10.3.pamphlet" 2035344 2035372 2037156 2037161) (|RuleCalled| "bookvol10.3.pamphlet" 2035189 2035209 2035334 2035339) (|RegularTriangularSetGcdPackage| "bookvol10.4.pamphlet" 2032532 2032579 2035179 2035184) (|RegularTriangularSetCategory| "bookvol10.2.pamphlet" 2023320 2023362 2032463 2032527) (|RegularTriangularSetCategory&| NIL 2014164 2014209 2023310 2023315) (|RegularSetDecompositionPackage| "bookvol10.4.pamphlet" 2012890 2012937 2014154 2014159) (|RealRootCharacterizationCategory| "bookvol10.2.pamphlet" 2011267 2011326 2012880 2012885) (|RealRootCharacterizationCategory&| NIL 2009641 2009703 2011257 2011262) (|RecursivePolynomialCategory| "bookvol10.2.pamphlet" 1992752 1992791 2009402 2009636) (|RecursivePolynomialCategory&| NIL 1975566 1975608 1992219 1992224) (|RoutinesTable| "bookvol10.3.pamphlet" 1971842 1971861 1974596 1974648) (|RomanNumeral| "bookvol10.3.pamphlet" 1970975 1970993 1971603 1971837) (|RightOpenIntervalRootCharacterization| "bookvol10.3.pamphlet" 1970075 1970141 1970965 1970970) (|RealNumberSystem| "bookvol10.2.pamphlet" 1968813 1968835 1969905 1970070) (|RealNumberSystem&| NIL 1967708 1967733 1968803 1968808) (|Rng| "bookvol10.2.pamphlet" 1967228 1967237 1967698 1967703) (|RightModule| "bookvol10.2.pamphlet" 1966735 1966754 1967218 1967223) (|RectangularMatrixCategoryFunctions2| "bookvol10.4.pamphlet" 1966131 1966220 1966725 1966730) (|RectangularMatrix| "bookvol10.3.pamphlet" 1964690 1964723 1965192 1965260) (|RectangularMatrixCategory| "bookvol10.2.pamphlet" 1960275 1960328 1964605 1964685) (|RectangularMatrixCategory&| NIL 1955749 1955805 1960082 1960087) (|RationalInterpolation| "bookvol10.4.pamphlet" 1955623 1955657 1955739 1955744) (|Ring| "bookvol10.2.pamphlet" 1954974 1954984 1955596 1955618) (|Ring&| NIL 1954339 1954352 1954964 1954969) (|RandomIntegerDistributions| "bookvol10.4.pamphlet" 1953344 1953376 1954329 1954334) (|RegularChain| "bookvol10.3.pamphlet" 1951686 1951711 1952576 1952628) (|RootsFindingPackage| "bookvol10.4.pamphlet" 1949720 1949747 1951676 1951681) (|RationalFunction| "bookvol10.4.pamphlet" 1947363 1947387 1949710 1949715) (|RationalFunctionFactorizer| "bookvol10.4.pamphlet" 1946802 1946836 1947353 1947358) (|RationalFunctionFactor| "bookvol10.4.pamphlet" 1946518 1946549 1946792 1946797) (|RandomFloatDistributions| "bookvol10.4.pamphlet" 1945493 1945523 1946508 1946513) (|RetractSolvePackage| "bookvol10.4.pamphlet" 1944896 1944925 1945483 1945488) (|RetractableTo| "bookvol10.2.pamphlet" 1944228 1944249 1944886 1944891) (|RetractableTo&| NIL 1943557 1943581 1944218 1944223) (|Result| "bookvol10.3.pamphlet" 1941999 1942011 1942587 1942639) (|ResidueRing| "bookvol10.3.pamphlet" 1941310 1941361 1941905 1941994) (|ResolveLatticeCompletion| "bookvol10.4.pamphlet" 1940615 1940647 1941300 1941305) (|RepeatedSquaring| "bookvol10.4.pamphlet" 1940333 1940357 1940605 1940610) (|RadicalEigenPackage| "bookvol10.4.pamphlet" 1937873 1937898 1940323 1940328) (|RepeatedDoubling| "bookvol10.4.pamphlet" 1937559 1937583 1937863 1937868) (|RepresentationPackage2| "bookvol10.4.pamphlet" 1927537 1927567 1937378 1937383) (|RepresentationPackage1| "bookvol10.4.pamphlet" 1921898 1921928 1927479 1927484) (|RegularTriangularSet| "bookvol10.3.pamphlet" 1920095 1920129 1921519 1921571) (|Reference| "bookvol10.3.pamphlet" 1919431 1919448 1920042 1920047) (|ReductionOfOrder| "bookvol10.4.pamphlet" 1918552 1918578 1919421 1919426) (|RecurrenceOperator| "bookvol10.4.pamphlet" 1916947 1916975 1918506 1918511) (|RealClosure| "bookvol10.3.pamphlet" 1915568 1915596 1916230 1916395) (|RealSolvePackage| "bookvol10.4.pamphlet" 1914128 1914150 1915558 1915563) (|RealConstant| "bookvol10.2.pamphlet" 1914003 1914021 1914118 1914123) (|RealZeroPackageQ| "bookvol10.4.pamphlet" 1911341 1911369 1913993 1913998) (|RealZeroPackage| "bookvol10.4.pamphlet" 1908238 1908265 1911331 1911336) (|ReducedDivisor| "bookvol10.4.pamphlet" 1907976 1908012 1908228 1908233) (|RandomDistributions| "bookvol10.4.pamphlet" 1907527 1907554 1907966 1907971) (|TranscendentalRischDESystem| "bookvol10.4.pamphlet" 1906361 1906399 1907517 1907522) (|TranscendentalRischDE| "bookvol10.4.pamphlet" 1904312 1904344 1906351 1906356) (|ElementaryRischDESystem| "bookvol10.4.pamphlet" 1903537 1903570 1904302 1904307) (|ElementaryRischDE| "bookvol10.4.pamphlet" 1902583 1902610 1903527 1903532) (|RealClosedField| "bookvol10.2.pamphlet" 1899828 1899849 1902413 1902578) (|RealClosedField&| NIL 1897230 1897254 1899818 1899823) (|RecursiveAggregate| "bookvol10.2.pamphlet" 1895188 1895214 1897210 1897225) (|RecursiveAggregate&| NIL 1893061 1893090 1895086 1895091) (|RationalRetractions| "bookvol10.4.pamphlet" 1892466 1892493 1893051 1893056) (|RationalFactorize| "bookvol10.4.pamphlet" 1891636 1891662 1892456 1892461) (|RandomNumberSource| "bookvol10.4.pamphlet" 1890978 1891002 1891626 1891631) (|RadixUtilities| "bookvol10.4.pamphlet" 1890723 1890743 1890968 1890973) (|RadixExpansion| "bookvol10.3.pamphlet" 1886814 1886839 1888477 1888642) (|RadicalFunctionField| "bookvol10.3.pamphlet" 1884686 1884736 1884802 1885057) (|RadicalCategory| "bookvol10.2.pamphlet" 1884305 1884326 1884676 1884681) (|RadicalCategory&| NIL 1883921 1883945 1884295 1884300) (|Queue| "bookvol10.3.pamphlet" 1879689 1879702 1883704 1883756) (|Quaternion| "bookvol10.3.pamphlet" 1878012 1878030 1878313 1878421) (|QuaternionCategoryFunctions2| "bookvol10.4.pamphlet" 1877391 1877435 1878002 1878007) (|QuaternionCategory| "bookvol10.2.pamphlet" 1875539 1875565 1877278 1877386) (|QuaternionCategory&| NIL 1873378 1873407 1875120 1875125) (|QueueAggregate| "bookvol10.2.pamphlet" 1872155 1872177 1873309 1873373) (|QuadraticForm| "bookvol10.3.pamphlet" 1871613 1871638 1872145 1872150) (|QuotientFieldCategory| "bookvol10.2.pamphlet" 1870217 1870246 1871431 1871608) (|QuotientFieldCategory&| NIL 1868311 1868343 1869528 1869533) (|QuotientFieldCategoryFunctions2| "bookvol10.4.pamphlet" 1867983 1868028 1868301 1868306) (|QueryEquation| "bookvol10.3.pamphlet" 1867547 1867566 1867973 1867978) (|QuasiComponentPackage| "bookvol10.4.pamphlet" 1863512 1863550 1867537 1867542) (|QuasiAlgebraicSet| "bookvol10.3.pamphlet" 1859641 1859688 1863397 1863402) (|QuasiAlgebraicSet2| "bookvol10.4.pamphlet" 1857637 1857671 1859631 1859636) (|PAdicWildFunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 1854936 1854986 1857627 1857632) (|PushVariables| "bookvol10.4.pamphlet" 1854262 1854292 1854926 1854931) (|PartialTranscendentalFunctions| "bookvol10.2.pamphlet" 1850513 1850551 1854252 1854257) (|PointPackage| "bookvol10.4.pamphlet" 1847629 1847649 1850503 1850508) (|PointFunctions2| "bookvol10.4.pamphlet" 1847435 1847462 1847619 1847624) (|PointCategory| "bookvol10.2.pamphlet" 1846491 1846512 1847366 1847430) (|PolynomialSquareFree| "bookvol10.4.pamphlet" 1845784 1845826 1846481 1846486) (|PseudoLinearNormalForm| "bookvol10.4.pamphlet" 1844634 1844664 1845774 1845779) (|PolynomialSetUtilitiesPackage| "bookvol10.4.pamphlet" 1832080 1832123 1844476 1844481) (|PolynomialSetCategory| "bookvol10.2.pamphlet" 1826904 1826946 1832036 1832075) (|PolynomialSetCategory&| NIL 1821713 1821758 1826848 1826853) (|PlottableSpaceCurveCategory| "bookvol10.2.pamphlet" 1820713 1820746 1821703 1821708) (|PowerSeriesCategory| "bookvol10.2.pamphlet" 1819391 1819437 1820543 1820708) (|PowerSeriesCategory&| NIL 1818226 1818275 1819381 1819386) (|Partition| "bookvol10.3.pamphlet" 1817022 1817037 1818216 1818221) (|ProjectiveSpaceCategory| "bookvol10.2.pamphlet" 1814496 1814527 1817012 1817017) (|PseudoRemainderSequence| "bookvol10.4.pamphlet" 1806137 1806175 1814445 1814450) (|PriorityQueueAggregate| "bookvol10.2.pamphlet" 1805515 1805545 1806068 1806132) (|ProjectiveSpace| "bookvol10.3.pamphlet" 1805386 1805415 1805505 1805510) (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1805224 1805286 1805376 1805381) (|ProjectivePlane| "bookvol10.3.pamphlet" 1805101 1805124 1805214 1805219) (|Product| "bookvol10.3.pamphlet" 1801901 1801918 1802433 1802501) (|PolynomialRing| "bookvol10.3.pamphlet" 1799949 1799973 1800654 1800888) (|ProjectiveAlgebraicSetPackage| "bookvol10.4.pamphlet" 1799176 1799242 1799939 1799944) (|PrintPackage| "bookvol10.4.pamphlet" 1798918 1798936 1799166 1799171) (|IntegerPrimesPackage| "bookvol10.4.pamphlet" 1797133 1797161 1798908 1798913) (|PrimitiveElement| "bookvol10.4.pamphlet" 1795210 1795234 1797123 1797128) (|PrimitiveFunctionCategory| "bookvol10.2.pamphlet" 1794798 1794829 1795200 1795205) (|PrimitiveArray| "bookvol10.3.pamphlet" 1793915 1793937 1794080 1794132) (|PrimitiveArrayFunctions2| "bookvol10.4.pamphlet" 1791999 1792033 1793905 1793910) (|PrecomputedAssociatedEquations| "bookvol10.4.pamphlet" 1791337 1791377 1791989 1791994) (|PlottablePlaneCurveCategory| "bookvol10.2.pamphlet" 1790677 1790710 1791327 1791332) (|U32VectorPolynomialOperations| "bookvol10.4.pamphlet" 1785459 1785494 1790667 1790672) (|PolynomialRoots| "bookvol10.4.pamphlet" 1784187 1784218 1785408 1785413) (|Polynomial| "bookvol10.3.pamphlet" 1780583 1780601 1781087 1781321) (|PolynomialCategoryLifting| "bookvol10.4.pamphlet" 1779849 1779895 1780573 1780578) (|PolynomialCategoryQuotientFunctions| "bookvol10.4.pamphlet" 1777830 1777881 1779839 1779844) (|PolynomialCategory| "bookvol10.2.pamphlet" 1771137 1771174 1777591 1777825) (|PolynomialCategory&| NIL 1763591 1763631 1770048 1770053) (|PolynomialToUnivariatePolynomial| "bookvol10.4.pamphlet" 1763007 1763051 1763581 1763586) (|PolynomialFunctions2| "bookvol10.4.pamphlet" 1762595 1762625 1762997 1763002) (|RealPolynomialUtilitiesPackage| "bookvol10.4.pamphlet" 1761599 1761656 1762542 1762547) (|PolToPol| "bookvol10.4.pamphlet" 1760341 1760362 1761589 1761594) (|Point| "bookvol10.3.pamphlet" 1759219 1759232 1759309 1759361) (|PolynomialNumberTheoryFunctions| "bookvol10.4.pamphlet" 1755862 1755899 1759209 1759214) (|PatternMatchTools| "bookvol10.4.pamphlet" 1754668 1754697 1755852 1755857) (|PatternMatchSymbol| "bookvol10.4.pamphlet" 1754209 1754235 1754658 1754663) (|PatternMatchQuotientFieldCategory| "bookvol10.4.pamphlet" 1753777 1753822 1754199 1754204) (|AttachPredicates| "bookvol10.4.pamphlet" 1753287 1753311 1753767 1753772) (|FunctionSpaceAttachPredicates| "bookvol10.4.pamphlet" 1752763 1752804 1753277 1753282) (|PatternMatchPolynomialCategory| "bookvol10.4.pamphlet" 1751801 1751847 1752681 1752686) (|PatternMatchListAggregate| "bookvol10.4.pamphlet" 1751363 1751400 1751791 1751796) (|PatternMatchKernel| "bookvol10.4.pamphlet" 1750926 1750954 1751353 1751358) (|PatternMatchIntegerNumberSystem| "bookvol10.4.pamphlet" 1750477 1750516 1750916 1750921) (|PatternMatchFunctionSpace| "bookvol10.4.pamphlet" 1750043 1750080 1750467 1750472) (|PatternMatchPushDown| "bookvol10.4.pamphlet" 1749335 1749367 1750033 1750038) (|PatternMatchAssertions| "bookvol10.4.pamphlet" 1748382 1748410 1749325 1749330) (|FunctionSpaceAssertions| "bookvol10.4.pamphlet" 1747389 1747422 1748372 1748377) (|PolynomialPackageForCurve| "bookvol10.4.pamphlet" 1746264 1746325 1747379 1747384) (|PlotTools| "bookvol10.4.pamphlet" 1746037 1746052 1746254 1746259) (|Plot| "bookvol10.3.pamphlet" 1740887 1740897 1746027 1746032) (|Plot3D| "bookvol10.3.pamphlet" 1737497 1737509 1740877 1740882) (|PlotFunctions1| "bookvol10.4.pamphlet" 1736636 1736658 1737487 1737492) (|ParametricLinearEquations| "bookvol10.4.pamphlet" 1722726 1722776 1736626 1736631) (|Plcs| "bookvol10.3.pamphlet" 1722631 1722647 1722716 1722721) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1722499 1722552 1722621 1722626) (|Places| "bookvol10.3.pamphlet" 1722406 1722420 1722489 1722494) (|PlacesCategory| "bookvol10.2.pamphlet" 1721436 1721462 1722396 1722401) (|PolynomialInterpolation| "bookvol10.4.pamphlet" 1721041 1721077 1721426 1721431) (|PolynomialInterpolationAlgorithms| "bookvol10.4.pamphlet" 1720798 1720841 1721031 1721036) (|PositiveInteger| "bookvol10.3.pamphlet" 1720401 1720422 1720764 1720793) (|PrincipalIdealDomain| "bookvol10.2.pamphlet" 1719320 1719346 1720284 1720396) (|PiCoercions| "bookvol10.4.pamphlet" 1719056 1719075 1719310 1719315) (|PolyGroebner| "bookvol10.4.pamphlet" 1717668 1717688 1719046 1719051) (|PermutationGroupExamples| "bookvol10.4.pamphlet" 1709604 1709634 1717658 1717663) (|PolynomialGcdPackage| "bookvol10.4.pamphlet" 1708067 1708102 1709594 1709599) (|PartialFractionPackage| "bookvol10.4.pamphlet" 1707098 1707128 1708057 1708062) (|PartialFraction| "bookvol10.3.pamphlet" 1702583 1702606 1706928 1707093) (|PointsOfFiniteOrderTools| "bookvol10.4.pamphlet" 1701908 1701946 1702573 1702578) (|PackageForPoly| "bookvol10.4.pamphlet" 1700037 1700078 1701898 1701903) (|PointsOfFiniteOrderRational| "bookvol10.4.pamphlet" 1699382 1699425 1700027 1700032) (|PointsOfFiniteOrder| "bookvol10.4.pamphlet" 1698790 1698830 1699372 1699377) (|PrimeField| "bookvol10.3.pamphlet" 1698346 1698366 1698484 1698649) (|PolynomialFactorizationExplicit| "bookvol10.2.pamphlet" 1695982 1696019 1698229 1698341) (|PolynomialFactorizationExplicit&| NIL 1693669 1693709 1695919 1695924) (|PolynomialFactorizationByRecursionUnivariate| "bookvol10.4.pamphlet" 1691534 1691588 1693659 1693664) (|PolynomialFactorizationByRecursion| "bookvol10.4.pamphlet" 1689162 1689217 1691524 1691529) (|Permutation| "bookvol10.3.pamphlet" 1684447 1684466 1688964 1688986) (|PermutationGroup| "bookvol10.3.pamphlet" 1679198 1679222 1684437 1684442) (|PermutationCategory| "bookvol10.2.pamphlet" 1677837 1677864 1679171 1679193) (|Permanent| "bookvol10.4.pamphlet" 1676589 1676610 1677827 1677832) (|PendantTree| "bookvol10.3.pamphlet" 1675830 1675849 1676419 1676424) (|PartialDifferentialRing| "bookvol10.2.pamphlet" 1674177 1674208 1675803 1675825) (|PartialDifferentialRing&| NIL 1672538 1672572 1674167 1674172) (|NumericalPDEProblem| "bookvol10.3.pamphlet" 1670700 1670725 1672528 1672533) (|AnnaPartialDifferentialEquationPackage| "bookvol10.4.pamphlet" 1664740 1664784 1670690 1670695) (|PolynomialDecomposition| "bookvol10.4.pamphlet" 1664075 1664109 1664730 1664735) (|PartialDifferentialEquationsSolverCategory| "bookvol10.2.pamphlet" 1662185 1662233 1664065 1664070) (|PolynomialComposition| "bookvol10.4.pamphlet" 1661901 1661933 1662175 1662180) (|PoincareBirkhoffWittLyndonBasis| "bookvol10.3.pamphlet" 1660514 1660560 1661891 1661896) (|Pattern| "bookvol10.3.pamphlet" 1654794 1654809 1660504 1660509) (|PatternFunctions2| "bookvol10.4.pamphlet" 1654510 1654537 1654784 1654789) (|PatternFunctions1| "bookvol10.4.pamphlet" 1652797 1652824 1654500 1654505) (|PatternMatchResult| "bookvol10.3.pamphlet" 1650442 1650470 1652787 1652792) (|PatternMatchResultFunctions2| "bookvol10.4.pamphlet" 1650128 1650168 1650432 1650437) (|PatternMatch| "bookvol10.4.pamphlet" 1648298 1648339 1649795 1649800) (|PatternMatchable| "bookvol10.2.pamphlet" 1647723 1647747 1648288 1648293) (|PatternMatchListResult| "bookvol10.3.pamphlet" 1646813 1646847 1647713 1647718) (|Patternable| "bookvol10.2.pamphlet" 1646510 1646529 1646803 1646808) (|PartitionsAndPermutations| "bookvol10.4.pamphlet" 1644005 1644036 1646500 1646505) (|ParametricSurface| "bookvol10.3.pamphlet" 1643448 1643491 1643995 1644000) (|ParametricSurfaceFunctions2| "bookvol10.4.pamphlet" 1643216 1643257 1643438 1643443) (|ParametricSpaceCurve| "bookvol10.3.pamphlet" 1642656 1642702 1643206 1643211) (|ParametricSpaceCurveFunctions2| "bookvol10.4.pamphlet" 1642415 1642459 1642646 1642651) (|ParametricPlaneCurve| "bookvol10.3.pamphlet" 1641867 1641913 1642405 1642410) (|ParametricPlaneCurveFunctions2| "bookvol10.4.pamphlet" 1641626 1641670 1641857 1641862) (|ParametrizationPackage| "bookvol10.4.pamphlet" 1640429 1640498 1641616 1641621) (|PolynomialAN2Expression| "bookvol10.4.pamphlet" 1639822 1639851 1640419 1640424) (|Palette| "bookvol10.3.pamphlet" 1638825 1638838 1639812 1639817) (|PackageForAlgebraicFunctionField| "bookvol10.4.pamphlet" 1633238 1633291 1638777 1638782) (|PackageForAlgebraicFunctionFieldOverFiniteField| "bookvol10.4.pamphlet" 1627037 1627105 1633150 1633155) (|PAdicRationalConstructor| "bookvol10.3.pamphlet" 1623833 1623873 1624984 1625149) (|PAdicRational| "bookvol10.3.pamphlet" 1621017 1621040 1621201 1621366) (|PAdicInteger| "bookvol10.3.pamphlet" 1620709 1620731 1620900 1621012) (|PAdicIntegerCategory| "bookvol10.2.pamphlet" 1619194 1619224 1620592 1620704) (|PadeApproximantPackage| "bookvol10.4.pamphlet" 1618119 1618158 1619184 1619189) (|PadeApproximants| "bookvol10.4.pamphlet" 1617110 1617140 1618109 1618114) (|PseudoAlgebraicClosureOfRationalNumber| "bookvol10.3.pamphlet" 1615723 1615767 1616595 1616760) (|PseudoAlgebraicClosureOfRationalNumberCategory| "bookvol10.2.pamphlet" 1614591 1614643 1615553 1615718) (|PseudoAlgebraicClosureOfPerfectFieldCategory| "bookvol10.2.pamphlet" 1612776 1612826 1614421 1614586) (|PseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1611591 1611634 1612461 1612626) (|PseudoAlgebraicClosureOfFiniteFieldCategory| "bookvol10.2.pamphlet" 1610465 1610514 1611421 1611586) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| "bookvol10.3.pamphlet" 1608480 1608544 1609375 1609540) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| "bookvol10.2.pamphlet" 1607332 1607392 1608310 1608475) (|OrdinaryWeightedPolynomials| "bookvol10.3.pamphlet" 1606249 1606304 1607124 1607241) (|OrderedVariableList| "bookvol10.3.pamphlet" 1606013 1606053 1606239 1606244) (|OutputPackage| "bookvol10.4.pamphlet" 1605128 1605147 1606003 1606008) (|OutputForm| "bookvol10.3.pamphlet" 1594534 1594550 1605118 1605123) (|OrdSetInts| "bookvol10.3.pamphlet" 1594131 1594147 1594524 1594529) (|OrthogonalPolynomialFunctions| "bookvol10.4.pamphlet" 1592544 1592581 1594031 1594036) (|UnivariateSkewPolynomial| "bookvol10.3.pamphlet" 1591775 1591827 1592129 1592192) (|SparseUnivariateSkewPolynomial| "bookvol10.3.pamphlet" 1590935 1590989 1591360 1591423) (|UnivariateSkewPolynomialCategoryOps| "bookvol10.4.pamphlet" 1588647 1588692 1590840 1590845) (|UnivariateSkewPolynomialCategory| "bookvol10.2.pamphlet" 1582605 1582645 1588579 1588642) (|UnivariateSkewPolynomialCategory&| NIL 1576441 1576484 1582418 1582423) (|OrderedSet| "bookvol10.2.pamphlet" 1575573 1575589 1576431 1576436) (|OrderedSet&| NIL 1574702 1574721 1575563 1575568) (|OrderedRing| "bookvol10.2.pamphlet" 1574020 1574037 1574675 1574697) (|OrderedRing&| NIL 1573352 1573372 1574010 1574015) (|OrderedMonoid| "bookvol10.2.pamphlet" 1573065 1573084 1573342 1573347) (|OrderingFunctions| "bookvol10.4.pamphlet" 1572197 1572228 1573055 1573060) (|OrderedFinite| "bookvol10.2.pamphlet" 1572120 1572139 1572187 1572192) (|OrderedCompletion| "bookvol10.3.pamphlet" 1570470 1570495 1571540 1571585) (|OrderedCompletionFunctions2| "bookvol10.4.pamphlet" 1569797 1569834 1570460 1570465) (|NumericalOptimizationProblem| "bookvol10.3.pamphlet" 1567537 1567571 1569787 1569792) (|AnnaNumericalOptimizationPackage| "bookvol10.4.pamphlet" 1559959 1559997 1567527 1567532) (|NumericalOptimizationCategory| "bookvol10.2.pamphlet" 1557410 1557445 1559949 1559954) (|OperationsQuery| "bookvol10.4.pamphlet" 1556952 1556973 1557400 1557405) (|Operator| "bookvol10.3.pamphlet" 1556590 1556606 1556676 1556793) (|OnePointCompletion| "bookvol10.3.pamphlet" 1555223 1555249 1556010 1556055) (|OnePointCompletionFunctions2| "bookvol10.4.pamphlet" 1554688 1554726 1555213 1555218) (|OpenMathServerPackage| "bookvol10.4.pamphlet" 1553719 1553746 1554678 1554683) (|OrderedMultisetAggregate| "bookvol10.2.pamphlet" 1553440 1553472 1553622 1553714) (|OpenMathPackage| "bookvol10.4.pamphlet" 1552103 1552124 1553430 1553435) (|OpenMath| "bookvol10.2.pamphlet" 1551172 1551186 1552093 1552098) (|OppositeMonogenicLinearOperator| "bookvol10.3.pamphlet" 1550509 1550550 1551007 1551070) (|ExpressionToOpenMath| "bookvol10.4.pamphlet" 1550325 1550353 1550499 1550504) (|OpenMathError| "bookvol10.3.pamphlet" 1549867 1549886 1550315 1550320) (|OpenMathErrorKind| "bookvol10.3.pamphlet" 1548904 1548927 1549857 1549862) (|OpenMathEncoding| "bookvol10.3.pamphlet" 1548236 1548258 1548894 1548899) (|OpenMathDevice| "bookvol10.3.pamphlet" 1542967 1542987 1548226 1548231) (|OpenMathConnection| "bookvol10.3.pamphlet" 1542368 1542392 1542957 1542962) (|OrderedIntegralDomain| "bookvol10.2.pamphlet" 1542083 1542110 1542251 1542363) (|OrderedFreeMonoid| "bookvol10.3.pamphlet" 1535695 1535720 1542073 1542078) (|OrderlyDifferentialVariable| "bookvol10.3.pamphlet" 1534953 1534988 1535685 1535690) (|OrdinaryDifferentialRing| "bookvol10.3.pamphlet" 1534292 1534340 1534678 1534911) (|OrderlyDifferentialPolynomial| "bookvol10.3.pamphlet" 1530548 1530585 1530901 1531135) (|OrderedDirectProduct| "bookvol10.3.pamphlet" 1520336 1520374 1520712 1520916) (|ODETools| "bookvol10.4.pamphlet" 1518859 1518880 1520326 1520331) (|SystemODESolver| "bookvol10.4.pamphlet" 1516310 1516336 1518849 1518854) (|RationalRicDE| "bookvol10.4.pamphlet" 1512209 1512233 1516244 1516249) (|ReduceLODE| "bookvol10.4.pamphlet" 1511566 1511594 1512199 1512204) (|RationalLODE| "bookvol10.4.pamphlet" 1509004 1509027 1511556 1511561) (|PrimitiveRatRicDE| "bookvol10.4.pamphlet" 1506008 1506041 1508994 1508999) (|NumericalODEProblem| "bookvol10.3.pamphlet" 1504647 1504672 1505998 1506003) (|PrimitiveRatDE| "bookvol10.4.pamphlet" 1501897 1501927 1504637 1504642) (|PureAlgebraicLODE| "bookvol10.4.pamphlet" 1501252 1501287 1501887 1501892) (|AnnaOrdinaryDifferentialEquationPackage| "bookvol10.4.pamphlet" 1488959 1489004 1501242 1501247) (|ODEIntegration| "bookvol10.4.pamphlet" 1488370 1488394 1488949 1488954) (|ODEIntensityFunctionsTable| "bookvol10.3.pamphlet" 1485749 1485781 1488360 1488365) (|ElementaryFunctionODESolver| "bookvol10.4.pamphlet" 1481045 1481082 1485739 1485744) (|ConstantLODE| "bookvol10.4.pamphlet" 1480548 1480572 1481035 1481040) (|OrdinaryDifferentialEquationsSolverCategory| "bookvol10.2.pamphlet" 1478898 1478947 1480538 1480543) (|Octonion| "bookvol10.3.pamphlet" 1476747 1476763 1477435 1477498) (|OctonionCategoryFunctions2| "bookvol10.4.pamphlet" 1476372 1476414 1476737 1476742) (|OctonionCategory| "bookvol10.2.pamphlet" 1474282 1474306 1476304 1476367) (|OctonionCategory&| NIL 1471842 1471869 1473867 1473872) (|OrderedCancellationAbelianMonoid| "bookvol10.2.pamphlet" 1471662 1471700 1471832 1471837) (|OrderedAbelianSemiGroup| "bookvol10.2.pamphlet" 1471407 1471436 1471652 1471657) (|OrderedAbelianMonoidSup| "bookvol10.2.pamphlet" 1470740 1470769 1471397 1471402) (|OrderedAbelianMonoid| "bookvol10.2.pamphlet" 1470585 1470611 1470730 1470735) (|OrderedAbelianGroup| "bookvol10.2.pamphlet" 1470432 1470457 1470575 1470580) (|NumericTubePlot| "bookvol10.4.pamphlet" 1470146 1470175 1470422 1470427) (|NumericalQuadrature| "bookvol10.4.pamphlet" 1458858 1458883 1470136 1470141) (|NumericalOrdinaryDifferentialEquations| "bookvol10.4.pamphlet" 1450389 1450433 1458848 1458853) (|NumericalIntegrationCategory| "bookvol10.2.pamphlet" 1447718 1447752 1450379 1450384) (|NumberFormats| "bookvol10.4.pamphlet" 1446549 1446568 1447708 1447713) (|Numeric| "bookvol10.4.pamphlet" 1438656 1438671 1446308 1446313) (|NormalizedTriangularSetCategory| "bookvol10.2.pamphlet" 1438009 1438054 1438587 1438651) (|NumberTheoreticPolynomialFunctions| "bookvol10.4.pamphlet" 1437511 1437553 1437909 1437914) (|NewSparseUnivariatePolynomial| "bookvol10.3.pamphlet" 1430324 1430361 1434000 1434277) (|NewSparseUnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 1429683 1429732 1430314 1430319) (|NewSparseMultivariatePolynomial| "bookvol10.3.pamphlet" 1424669 1424717 1424990 1425224) (|NeitherSparseOrDensePowerSeries| "bookvol10.3.pamphlet" 1422843 1422882 1422949 1423114) (|NumericRealEigenPackage| "bookvol10.4.pamphlet" 1421212 1421247 1422833 1422838) (|NewtonPolygon| "bookvol10.4.pamphlet" 1421093 1421133 1421202 1421207) (|NPCoef| "bookvol10.4.pamphlet" 1420337 1420361 1421083 1421088) (|NottinghamGroup| "bookvol10.3.pamphlet" 1420209 1420232 1420310 1420332) (|NormRetractPackage| "bookvol10.4.pamphlet" 1419791 1419842 1420199 1420204) (|NormalizationPackage| "bookvol10.4.pamphlet" 1418621 1418658 1419781 1419786) (|NormInMonogenicAlgebra| "bookvol10.4.pamphlet" 1418283 1418329 1418611 1418616) (|None| "bookvol10.3.pamphlet" 1418022 1418032 1418273 1418278) (|NoneFunctions1| "bookvol10.4.pamphlet" 1417686 1417708 1418012 1418017) (|NonLinearFirstOrderODESolver| "bookvol10.4.pamphlet" 1417121 1417159 1417676 1417681) (|NonNegativeInteger| "bookvol10.3.pamphlet" 1415987 1416011 1417087 1417116) (|NonLinearSolvePackage| "bookvol10.4.pamphlet" 1414594 1414623 1415977 1415982) (|NumericalIntegrationProblem| "bookvol10.3.pamphlet" 1412257 1412290 1414584 1414589) (|NumberFieldIntegralBasis| "bookvol10.4.pamphlet" 1409707 1409742 1412247 1412252) (|NewtonInterpolation| "bookvol10.4.pamphlet" 1409013 1409040 1409697 1409702) (|NonCommutativeOperatorDivision| "bookvol10.4.pamphlet" 1407129 1407169 1409003 1409008) (|NumericContinuedFraction| "bookvol10.4.pamphlet" 1406768 1406800 1407119 1407124) (|NumericComplexEigenPackage| "bookvol10.4.pamphlet" 1404922 1404960 1406758 1406763) (|NonAssociativeRing| "bookvol10.2.pamphlet" 1404504 1404528 1404912 1404917) (|NonAssociativeRing&| NIL 1404083 1404110 1404494 1404499) (|NonAssociativeRng| "bookvol10.2.pamphlet" 1403446 1403469 1404073 1404078) (|NonAssociativeRng&| NIL 1402806 1402832 1403436 1403441) (|NAGLinkSupportPackage| "bookvol10.4.pamphlet" 1401864 1401891 1402796 1402801) (|NagSpecialFunctionsPackage| "bookvol10.4.pamphlet" 1392282 1392314 1401854 1401859) (|NagLapack| "bookvol10.4.pamphlet" 1390775 1390790 1392272 1392277) (|NagLinearEquationSolvingPackage| "bookvol10.4.pamphlet" 1385210 1385247 1390765 1390770) (|NagEigenPackage| "bookvol10.4.pamphlet" 1379353 1379374 1385200 1385205) (|NagMatrixOperationsPackage| "bookvol10.4.pamphlet" 1375139 1375171 1379343 1379348) (|NagOptimisationPackage| "bookvol10.4.pamphlet" 1368913 1368941 1375129 1375134) (|NagFittingPackage| "bookvol10.4.pamphlet" 1359655 1359678 1368903 1368908) (|NagInterpolationPackage| "bookvol10.4.pamphlet" 1355725 1355754 1359645 1359650) (|NagPartialDifferentialEquationsPackage| "bookvol10.4.pamphlet" 1353728 1353772 1355715 1355720) (|NagOrdinaryDifferentialEquationsPackage| "bookvol10.4.pamphlet" 1346497 1346542 1353718 1353723) (|NagIntegrationPackage| "bookvol10.4.pamphlet" 1341022 1341049 1346487 1346492) (|NagSeriesSummationPackage| "bookvol10.4.pamphlet" 1336931 1336962 1341012 1341017) (|NagRootFindingPackage| "bookvol10.4.pamphlet" 1335458 1335485 1336921 1336926) (|NagPolynomialRootsPackage| "bookvol10.4.pamphlet" 1334765 1334796 1335448 1335453) (|NonAssociativeAlgebra| "bookvol10.2.pamphlet" 1334281 1334310 1334716 1334760) (|NonAssociativeAlgebra&| NIL 1333833 1333865 1334271 1334276) (|MyUnivariatePolynomial| "bookvol10.3.pamphlet" 1329979 1330013 1330322 1330599) (|MyExpression| "bookvol10.3.pamphlet" 1327529 1327553 1327611 1327978) (|MultivariateSquareFree| "bookvol10.4.pamphlet" 1324477 1324514 1327519 1327524) (|MultivariateFactorize| "bookvol10.4.pamphlet" 1323856 1323892 1324467 1324472) (|MultivariateTaylorSeriesCategory| "bookvol10.2.pamphlet" 1321788 1321839 1323686 1323851) (|MergeThing| "bookvol10.4.pamphlet" 1321439 1321457 1321778 1321783) (|MoreSystemCommands| "bookvol10.4.pamphlet" 1320881 1320905 1321429 1321434) (|Multiset| "bookvol10.3.pamphlet" 1318857 1318873 1320562 1320642) (|MultisetAggregate| "bookvol10.2.pamphlet" 1318646 1318671 1318784 1318852) (|MonoidRing| "bookvol10.3.pamphlet" 1315559 1315579 1318240 1318357) (|MonoidRingFunctions2| "bookvol10.4.pamphlet" 1315103 1315135 1315549 1315554) (|MRationalFactorize| "bookvol10.4.pamphlet" 1314648 1314681 1315093 1315098) (|MPolyCatRationalFunctionFactorizer| "bookvol10.4.pamphlet" 1312689 1312740 1314638 1314643) (|MultivariatePolynomial| "bookvol10.3.pamphlet" 1309137 1309172 1309499 1309733) (|MPolyCatPolyFactorizer| "bookvol10.4.pamphlet" 1308396 1308435 1309127 1309132) (|MPolyCatFunctions3| "bookvol10.4.pamphlet" 1308193 1308249 1308386 1308391) (|MPolyCatFunctions2| "bookvol10.4.pamphlet" 1307928 1307977 1308183 1308188) (|MonomialExtensionTools| "bookvol10.4.pamphlet" 1306283 1306316 1307918 1307923) (|Monoid| "bookvol10.2.pamphlet" 1305181 1305193 1306273 1306278) (|Monoid&| NIL 1304076 1304091 1305171 1305176) (|MonogenicAlgebra| "bookvol10.2.pamphlet" 1302709 1302736 1303855 1304071) (|MonogenicAlgebra&| NIL 1301420 1301450 1302569 1302574) (|MonadWithUnit| "bookvol10.2.pamphlet" 1299562 1299581 1301410 1301415) (|MonadWithUnit&| NIL 1297701 1297723 1299552 1299557) (|Monad| "bookvol10.2.pamphlet" 1296889 1296900 1297691 1297696) (|Monad&| NIL 1296074 1296088 1296879 1296884) (|MoebiusTransform| "bookvol10.3.pamphlet" 1294714 1294738 1296047 1296069) (|Module| "bookvol10.2.pamphlet" 1294406 1294420 1294665 1294709) (|Module&| NIL 1294134 1294151 1294396 1294401) (|ModularRing| "bookvol10.3.pamphlet" 1293429 1293485 1294107 1294129) (|ModuleOperator| "bookvol10.3.pamphlet" 1291939 1291963 1293153 1293270) (|ModuleMonomial| "bookvol10.3.pamphlet" 1291440 1291470 1291929 1291934) (|ModMonic| "bookvol10.3.pamphlet" 1287012 1287034 1287836 1288113) (|ModularField| "bookvol10.3.pamphlet" 1286289 1286346 1286842 1287007) (|MathMLFormat| "bookvol10.3.pamphlet" 1285084 1285102 1286279 1286284) (|MultipleMap| "bookvol10.4.pamphlet" 1284809 1284852 1285074 1285079) (|MonogenicLinearOperator| "bookvol10.2.pamphlet" 1283182 1283213 1284741 1284804) (|MultivariateLifting| "bookvol10.4.pamphlet" 1281781 1281815 1283172 1283177) (|MakeUnaryCompiledFunction| "bookvol10.4.pamphlet" 1281202 1281239 1281771 1281776) (|MakeRecord| "bookvol10.4.pamphlet" 1280786 1280807 1281192 1281197) (|MakeFunction| "bookvol10.4.pamphlet" 1280061 1280081 1280776 1280781) (|MakeFloatCompiledFunction| "bookvol10.4.pamphlet" 1278888 1278921 1280051 1280056) (|MakeCachableSet| "bookvol10.3.pamphlet" 1278653 1278676 1278878 1278883) (|MakeBinaryCompiledFunction| "bookvol10.4.pamphlet" 1278068 1278110 1278643 1278648) (|MachineInteger| "bookvol10.3.pamphlet" 1277416 1277436 1277891 1278063) (|ModularHermitianRowReduction| "bookvol10.4.pamphlet" 1276029 1276065 1277406 1277411) (|MachineFloat| "bookvol10.3.pamphlet" 1274387 1274405 1275839 1276024) (|MultFiniteFactorize| "bookvol10.4.pamphlet" 1273774 1273809 1274377 1274382) (|MeshCreationRoutinesForThreeDimensions| "bookvol10.4.pamphlet" 1271650 1271694 1273764 1273769) (|ModularDistinctDegreeFactorizer| "bookvol10.4.pamphlet" 1269874 1269913 1271640 1271645) (|MultiDictionary| "bookvol10.2.pamphlet" 1269129 1269152 1269829 1269869) (|MachineComplex| "bookvol10.3.pamphlet" 1263042 1263062 1263668 1264073) (|MatrixCommonDenominator| "bookvol10.4.pamphlet" 1262223 1262256 1263032 1263037) (|MultiVariableCalculusFunctions| "bookvol10.4.pamphlet" 1259459 1259509 1262213 1262218) (|StorageEfficientMatrixOperations| "bookvol10.4.pamphlet" 1256709 1256749 1259449 1259454) (|Matrix| "bookvol10.3.pamphlet" 1255464 1255478 1255950 1256002) (|MatrixLinearAlgebraFunctions| "bookvol10.4.pamphlet" 1252818 1252868 1255320 1255325) (|MatrixCategory| "bookvol10.2.pamphlet" 1238909 1238943 1252749 1252813) (|MatrixCategory&| NIL 1224823 1224860 1238666 1238671) (|MatrixCategoryFunctions2| "bookvol10.4.pamphlet" 1224083 1224153 1224813 1224818) (|MappingPackage4| "bookvol10.4.pamphlet" 1222864 1222889 1224073 1224078) (|MappingPackage3| "bookvol10.4.pamphlet" 1221726 1221753 1222854 1222859) (|MappingPackage2| "bookvol10.4.pamphlet" 1221019 1221044 1221716 1221721) (|MappingPackage1| "bookvol10.4.pamphlet" 1219828 1219851 1221009 1221014) (|MappingPackageInternalHacks3| "bookvol10.4.pamphlet" 1219614 1219654 1219818 1219823) (|MappingPackageInternalHacks2| "bookvol10.4.pamphlet" 1219357 1219395 1219604 1219609) (|MappingPackageInternalHacks1| "bookvol10.4.pamphlet" 1218967 1219003 1219347 1219352) (|MatrixManipulation| "bookvol10.4.pamphlet" 1214623 1214663 1218957 1218962) (|Magma| "bookvol10.3.pamphlet" 1212904 1212924 1214613 1214618) (|ModularAlgebraicGcdOperations| "bookvol10.2.pamphlet" 1210733 1210775 1212894 1212899) (|ThreeDimensionalMatrix| "bookvol10.3.pamphlet" 1208657 1208687 1210293 1210298) (|LazyStreamAggregate| "bookvol10.2.pamphlet" 1204388 1204415 1208637 1208652) (|LazyStreamAggregate&| NIL 1200126 1200156 1204378 1204383) (|LyndonWord| "bookvol10.3.pamphlet" 1197356 1197381 1200116 1200121) (|LieSquareMatrix| "bookvol10.3.pamphlet" 1195269 1195296 1195664 1195751) (|LinearSystemPolynomialPackage| "bookvol10.4.pamphlet" 1194785 1194829 1195259 1195264) (|LinearSystemMatrixPackage| "bookvol10.4.pamphlet" 1193568 1193615 1194775 1194780) (|LinearSystemMatrixPackage1| "bookvol10.4.pamphlet" 1191310 1191344 1193558 1193563) (|ListAggregate| "bookvol10.2.pamphlet" 1190931 1190952 1191241 1191305) (|ListAggregate&| NIL 1190608 1190632 1190921 1190926) (|LiePolynomial| "bookvol10.3.pamphlet" 1189712 1189742 1190431 1190517) (|LinearPolynomialEquationByFractions| "bookvol10.4.pamphlet" 1188940 1188983 1189702 1189707) (|LocalParametrizationOfSimplePointPackage| "bookvol10.4.pamphlet" 1187378 1187465 1188930 1188935) (|LeftOreRing| "bookvol10.2.pamphlet" 1186823 1186840 1187287 1187373) (|LinesOpPack| "bookvol10.4.pamphlet" 1185487 1185506 1186813 1186818) (|Localize| "bookvol10.3.pamphlet" 1184844 1184864 1185387 1185431) (|Logic| "bookvol10.2.pamphlet" 1184473 1184484 1184834 1184839) (|Logic&| NIL 1184099 1184113 1184463 1184468) (|LinearOrdinaryDifferentialOperatorsOps| "bookvol10.4.pamphlet" 1182993 1183041 1184089 1184094) (|LinearOrdinaryDifferentialOperator| "bookvol10.3.pamphlet" 1182236 1182285 1182578 1182641) (|LinearOrdinaryDifferentialOperatorFactorizer| "bookvol10.4.pamphlet" 1181223 1181278 1182170 1182175) (|LinearOrdinaryDifferentialOperatorCategory| "bookvol10.2.pamphlet" 1179808 1179858 1181155 1181218) (|LinearOrdinaryDifferentialOperatorCategory&| NIL 1178411 1178464 1179761 1179766) (|LinearOrdinaryDifferentialOperator2| "bookvol10.3.pamphlet" 1177543 1177588 1177996 1178059) (|LinearOrdinaryDifferentialOperator1| "bookvol10.3.pamphlet" 1176802 1176845 1177128 1177191) (|ElementaryFunctionLODESolver| "bookvol10.4.pamphlet" 1175506 1175546 1176792 1176797) (|LocalPowerSeriesCategory| "bookvol10.2.pamphlet" 1173835 1173867 1175336 1175501) (|LinearAggregate| "bookvol10.2.pamphlet" 1170298 1170321 1173815 1173830) (|LinearAggregate&| NIL 1166721 1166747 1170241 1170246) (|ListMonoidOps| "bookvol10.3.pamphlet" 1163322 1163350 1166711 1166716) (|LeftModule| "bookvol10.2.pamphlet" 1162829 1162847 1163312 1163317) (|ListMultiDictionary| "bookvol10.3.pamphlet" 1161869 1161896 1162538 1162590) (|LinearSystemFromPowerSeriesPackage| "bookvol10.4.pamphlet" 1161288 1161334 1161859 1161864) (|List| "bookvol10.3.pamphlet" 1159119 1159131 1160528 1160580) (|ListFunctions3| "bookvol10.4.pamphlet" 1158422 1158448 1159109 1159114) (|ListFunctions2| "bookvol10.4.pamphlet" 1157090 1157114 1158412 1158417) (|ListToMap| "bookvol10.4.pamphlet" 1153946 1153965 1157080 1157085) (|LinearlyExplicitRingOver| "bookvol10.2.pamphlet" 1153295 1153327 1153919 1153941) (|LinearDependence| "bookvol10.4.pamphlet" 1152148 1152174 1153201 1153206) (|RationalFunctionLimitPackage| "bookvol10.4.pamphlet" 1150080 1150116 1152138 1152143) (|PowerSeriesLimitPackage| "bookvol10.4.pamphlet" 1148934 1148968 1150070 1150075) (|AssociatedLieAlgebra| "bookvol10.3.pamphlet" 1146639 1146669 1147917 1148161) (|LieAlgebra| "bookvol10.2.pamphlet" 1146199 1146217 1146548 1146634) (|LieAlgebra&| NIL 1145800 1145821 1146152 1146157) (|Library| "bookvol10.3.pamphlet" 1144143 1144156 1144854 1144882) (|LinGroebnerPackage| "bookvol10.4.pamphlet" 1141509 1141540 1144133 1144138) (|LiouvillianFunction| "bookvol10.4.pamphlet" 1140275 1140304 1141499 1141504) (|LiouvillianFunctionCategory| "bookvol10.2.pamphlet" 1139103 1139136 1140265 1140270) (|LexTriangularPackage| "bookvol10.4.pamphlet" 1134917 1134950 1139093 1139098) (|LieExponentials| "bookvol10.3.pamphlet" 1133132 1133172 1134890 1134912) (|LeadingCoefDetermination| "bookvol10.4.pamphlet" 1131540 1131579 1133122 1133127) (|LazardSetSolvingPackage| "bookvol10.4.pamphlet" 1130629 1130672 1131530 1131535) (|LaurentPolynomial| "bookvol10.3.pamphlet" 1129235 1129263 1130067 1130179) (|LaplaceTransform| "bookvol10.4.pamphlet" 1128770 1128796 1129225 1129230) (|LocalAlgebra| "bookvol10.3.pamphlet" 1128137 1128161 1128659 1128722) (|LeftAlgebra| "bookvol10.2.pamphlet" 1127897 1127916 1128110 1128132) (|LeftAlgebra&| NIL 1127671 1127693 1127887 1127892) (|Kovacic| "bookvol10.4.pamphlet" 1126351 1126369 1127661 1127666) (|ConvertibleTo| "bookvol10.2.pamphlet" 1126064 1126085 1126341 1126346) (|CoercibleTo| "bookvol10.2.pamphlet" 1125792 1125811 1126054 1126059) (|Kernel| "bookvol10.3.pamphlet" 1124291 1124305 1125518 1125523) (|KernelFunctions2| "bookvol10.4.pamphlet" 1123980 1124006 1124281 1124286) (|KeyedDictionary| "bookvol10.2.pamphlet" 1123093 1123128 1123935 1123975) (|KeyedDictionary&| NIL 1122238 1122276 1123083 1123088) (|KeyedAccessFile| "bookvol10.3.pamphlet" 1120710 1120739 1121432 1121484) (|AssociatedJordanAlgebra| "bookvol10.3.pamphlet" 1118391 1118424 1119693 1119937) (|IndexedAggregate| "bookvol10.2.pamphlet" 1116621 1116659 1118371 1118386) (|IndexedAggregate&| NIL 1114674 1114715 1116427 1116432) (|IndexedVector| "bookvol10.3.pamphlet" 1113491 1113517 1113642 1113694) (|InfiniteTuple| "bookvol10.3.pamphlet" 1112600 1112621 1113481 1113486) (|InnerTrigonometricManipulations| "bookvol10.4.pamphlet" 1111338 1111382 1112590 1112595) (|InfiniteTupleFunctions3| "bookvol10.4.pamphlet" 1110823 1110858 1111328 1111333) (|InfiniteTupleFunctions2| "bookvol10.4.pamphlet" 1110546 1110579 1110813 1110818) (|InnerTaylorSeries| "bookvol10.3.pamphlet" 1108236 1108266 1110279 1110495) (|InnerSparseUnivariatePowerSeries| "bookvol10.3.pamphlet" 1100363 1100408 1106979 1107144) (|InnerPolySum| "bookvol10.4.pamphlet" 1099820 1099846 1100353 1100358) (|IndexedString| "bookvol10.3.pamphlet" 1098817 1098841 1098994 1099046) (|InternalRationalUnivariateRepresentationPackage| "bookvol10.4.pamphlet" 1097767 1097831 1098807 1098812) (|IrrRepSymNatPackage| "bookvol10.4.pamphlet" 1095818 1095843 1097757 1097762) (|IntegrationResultRFToFunction| "bookvol10.4.pamphlet" 1094322 1094359 1095758 1095763) (|IrredPolyOverFiniteField| "bookvol10.4.pamphlet" 1093901 1093934 1094312 1094317) (|IntegerRoots| "bookvol10.4.pamphlet" 1092207 1092227 1093891 1093896) (|IntegrationResult| "bookvol10.3.pamphlet" 1089865 1089890 1092008 1092052) (|IntegrationResultFunctions2| "bookvol10.4.pamphlet" 1088988 1089025 1089855 1089860) (|IntegrationResultToFunction| "bookvol10.4.pamphlet" 1088144 1088181 1088978 1088983) (|InternalPrintPackage| "bookvol10.4.pamphlet" 1087902 1087928 1088134 1088139) (|InnerPrimeField| "bookvol10.3.pamphlet" 1087479 1087504 1087596 1087761) (|InnerPAdicInteger| "bookvol10.3.pamphlet" 1087192 1087233 1087362 1087474) (|InverseLaplaceTransform| "bookvol10.4.pamphlet" 1086772 1086805 1087182 1087187) (|TranscendentalIntegration| "bookvol10.4.pamphlet" 1079775 1079811 1086762 1086767) (|IntegrationTools| "bookvol10.4.pamphlet" 1077478 1077504 1079197 1079202) (|IntegerSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 1076764 1076806 1077468 1077473) (|Interval| "bookvol10.3.pamphlet" 1076483 1076499 1076627 1076759) (|RationalFunctionIntegration| "bookvol10.4.pamphlet" 1074826 1074861 1076473 1076478) (|IntegerRetractions| "bookvol10.4.pamphlet" 1074303 1074329 1074816 1074821) (|RationalIntegration| "bookvol10.4.pamphlet" 1072959 1072989 1074293 1074298) (|PatternMatchIntegration| "bookvol10.4.pamphlet" 1071130 1071163 1072477 1072482) (|PureAlgebraicIntegration| "bookvol10.4.pamphlet" 1068729 1068765 1071022 1071027) (|AnnaNumericalIntegrationPackage| "bookvol10.4.pamphlet" 1059225 1059262 1068719 1068724) (|Integer| "bookvol10.3.pamphlet" 1058471 1058484 1058969 1059220) (|TranscendentalHermiteIntegration| "bookvol10.4.pamphlet" 1057711 1057754 1058461 1058466) (|AlgebraicHermiteIntegration| "bookvol10.4.pamphlet" 1057335 1057380 1057701 1057706) (|IntegerNumberTheoryFunctions| "bookvol10.4.pamphlet" 1053688 1053722 1057325 1057330) (|GenusZeroIntegration| "bookvol10.4.pamphlet" 1046792 1046824 1053580 1053585) (|IntegrationFunctionsTable| "bookvol10.3.pamphlet" 1040767 1040798 1046782 1046787) (|InterpolateFormsPackage| "bookvol10.4.pamphlet" 1039898 1039976 1040757 1040762) (|IntegerFactorizationPackage| "bookvol10.4.pamphlet" 1038959 1038994 1039888 1039893) (|InterfaceGroebnerPackage| "bookvol10.4.pamphlet" 1038805 1038851 1038949 1038954) (|ElementaryIntegration| "bookvol10.4.pamphlet" 1037148 1037179 1038795 1038800) (|IntegralDomain| "bookvol10.2.pamphlet" 1035745 1035765 1037031 1037143) (|IntegralDomain&| NIL 1034446 1034469 1035735 1035740) (|IntersectionDivisorPackage| "bookvol10.4.pamphlet" 1033568 1033679 1034436 1034441) (|IntervalCategory| "bookvol10.2.pamphlet" 1032124 1032148 1033431 1033563) (|IntegerBits| "bookvol10.4.pamphlet" 1031646 1031663 1032114 1032119) (|AlgebraicIntegrate| "bookvol10.4.pamphlet" 1030792 1030831 1031636 1031641) (|AlgebraicIntegration| "bookvol10.4.pamphlet" 1030254 1030284 1030782 1030787) (|InnerTable| "bookvol10.3.pamphlet" 1029170 1029209 1029341 1029393) (|IntegerNumberSystem| "bookvol10.2.pamphlet" 1026408 1026433 1028993 1029165) (|IntegerNumberSystem&| NIL 1023810 1023838 1026398 1026403) (|InnerPolySign| "bookvol10.4.pamphlet" 1023247 1023271 1023800 1023805) (|InfiniteProductPrimeField| "bookvol10.4.pamphlet" 1022320 1022362 1023237 1023242) (|InfiniteProductFiniteField| "bookvol10.4.pamphlet" 1021384 1021432 1022310 1022315) (|InnerMultFact| "bookvol10.4.pamphlet" 1020379 1020407 1021374 1021379) (|InnerModularGcd| "bookvol10.4.pamphlet" 1019523 1019566 1020369 1020374) (|InnerNumericFloatSolvePackage| "bookvol10.4.pamphlet" 1017845 1017890 1019513 1019518) (|InfiniteProductCharacteristicZero| "bookvol10.4.pamphlet" 1016894 1016944 1017835 1017840) (|InputForm| "bookvol10.3.pamphlet" 1013808 1013823 1016884 1016889) (|InputFormFunctions1| "bookvol10.4.pamphlet" 1013436 1013463 1013798 1013803) (|Infinity| "bookvol10.4.pamphlet" 1013018 1013032 1013426 1013431) (|InfinitlyClosePoint| "bookvol10.3.pamphlet" 1012418 1012498 1013008 1013013) (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1011804 1011883 1012408 1012413) (|InfinitlyClosePointCategory| "bookvol10.2.pamphlet" 1010432 1010520 1011794 1011799) (|InnerNumericEigenPackage| "bookvol10.4.pamphlet" 1008958 1008998 1010422 1010427) (|IndexedExponents| "bookvol10.3.pamphlet" 1008850 1008881 1008948 1008953) (|IncrementingMaps| "bookvol10.4.pamphlet" 1008253 1008277 1008840 1008845) (|InnerNormalBasisFieldFunctions| "bookvol10.4.pamphlet" 1004119 1004158 1008243 1008248) (|IndexedMatrix| "bookvol10.3.pamphlet" 1003144 1003181 1003667 1003719) (|InnerMatrixQuotientFieldFunctions| "bookvol10.4.pamphlet" 1002192 1002267 1003087 1003092) (|InnerMatrixLinearAlgebraFunctions| "bookvol10.4.pamphlet" 1000761 1000816 1002135 1002140) (|IndexedList| "bookvol10.3.pamphlet" 999515 999539 1000043 1000095) (|InnerIndexedTwoDimensionalArray| "bookvol10.3.pamphlet" 999164 999231 999298 999350) (|InnerFiniteField| "bookvol10.3.pamphlet" 998384 998414 998649 998814) (|IndexedFlexibleArray| "bookvol10.3.pamphlet" 995475 995508 997666 997718) (|InnerFreeAbelianMonoid| "bookvol10.3.pamphlet" 995275 995312 995413 995418) (|InnerEvalable| "bookvol10.2.pamphlet" 994661 994684 995265 995270) (|InnerEvalable&| NIL 994044 994070 994651 994656) (|IndexedDirectProductObject| "bookvol10.3.pamphlet" 993833 993869 994034 994039) (|IndexedDirectProductOrderedAbelianMonoidSup| "bookvol10.3.pamphlet" 993565 993618 993823 993828) (|IndexedDirectProductOrderedAbelianMonoid| "bookvol10.3.pamphlet" 993262 993312 993555 993560) (|IndexedDirectProductCategory| "bookvol10.2.pamphlet" 992174 992212 993252 993257) (|IndexedDirectProductAbelianMonoid| "bookvol10.3.pamphlet" 991903 991946 992164 992169) (|IndexedDirectProductAbelianGroup| "bookvol10.3.pamphlet" 991635 991677 991893 991898) (|IdealDecompositionPackage| "bookvol10.4.pamphlet" 988884 988925 991625 991630) (|PolynomialIdeals| "bookvol10.3.pamphlet" 983940 983989 988805 988810) (|InfClsPt| "bookvol10.3.pamphlet" 983391 983420 983930 983935) (|InnerCommonDenominator| "bookvol10.4.pamphlet" 982604 982640 983381 983386) (|IndexCard| "bookvol10.3.pamphlet" 981880 981895 982594 982599) (|IntegralBasisPolynomialTools| "bookvol10.4.pamphlet" 980497 980540 981870 981875) (|IndexedBits| "bookvol10.3.pamphlet" 979654 979676 980075 980127) (|IntegralBasisTools| "bookvol10.4.pamphlet" 976569 976600 979644 979649) (|ChineseRemainderToolsForIntegralBases| "bookvol10.4.pamphlet" 975444 975494 976559 976564) (|IndexedTwoDimensionalArray| "bookvol10.3.pamphlet" 975104 975154 975227 975279) (|IndexedOneDimensionalArray| "bookvol10.3.pamphlet" 974269 974308 974386 974438) (|InnerAlgebraicNumber| "bookvol10.3.pamphlet" 972386 972412 973997 974162) (|InnerAlgFactor| "bookvol10.4.pamphlet" 971935 971976 972376 972381) (|HyperbolicFunctionCategory| "bookvol10.2.pamphlet" 971289 971321 971925 971930) (|HyperbolicFunctionCategory&| NIL 970640 970675 971279 971284) (|HTMLFormat| "bookvol10.3.pamphlet" 969484 969500 970630 970635) (|HomogeneousAggregate| "bookvol10.2.pamphlet" 967260 967288 969464 969479) (|HomogeneousAggregate&| NIL 964837 964868 967044 967049) (|HexadecimalExpansion| "bookvol10.3.pamphlet" 961975 962001 962591 962756) (|HeuGcd| "bookvol10.4.pamphlet" 960923 960938 961965 961970) (|HyperellipticFiniteDivisor| "bookvol10.3.pamphlet" 960535 960579 960913 960918) (|Heap| "bookvol10.3.pamphlet" 956623 956635 960318 960370) (|HomogeneousDirectProduct| "bookvol10.3.pamphlet" 946405 946443 946787 946991) (|HomogeneousDistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 942574 942631 943215 943449) (|HallBasis| "bookvol10.4.pamphlet" 941163 941178 942564 942569) (|HashTable| "bookvol10.3.pamphlet" 940034 940072 940250 940302) (|Pi| "bookvol10.3.pamphlet" 939573 939581 939864 940029) (|GuessUnivariatePolynomial| "bookvol10.4.pamphlet" 925647 925682 939563 939568) (|GuessPolynomial| "bookvol10.4.pamphlet" 925321 925342 925434 925439) (|Guess| "bookvol10.4.pamphlet" 909586 909628 925165 925170) (|GuessInteger| "bookvol10.4.pamphlet" 909295 909313 909403 909408) (|GuessFinite| "bookvol10.4.pamphlet" 909098 909117 909216 909221) (|GuessFiniteFunctions| "bookvol10.4.pamphlet" 908961 908989 909088 909093) (|GuessAlgebraicNumber| "bookvol10.4.pamphlet" 908749 908775 908867 908872) (|GeneralTriangularSet| "bookvol10.3.pamphlet" 907866 907900 908370 908422) (|GeneralSparseTable| "bookvol10.3.pamphlet" 906789 906840 906977 907005) (|GeneralUnivariatePowerSeries| "bookvol10.3.pamphlet" 903466 903519 904451 904703) (|Group| "bookvol10.2.pamphlet" 902434 902445 903439 903461) (|Group&| NIL 901416 901430 902424 902429) (|GroebnerSolve| "bookvol10.4.pamphlet" 900000 900028 901406 901411) (|GradedModule| "bookvol10.2.pamphlet" 898630 898652 899990 899995) (|GradedModule&| NIL 897257 897282 898620 898625) (|GraphImage| "bookvol10.3.pamphlet" 890288 890304 897247 897252) (|GraphicsDefaults| "bookvol10.4.pamphlet" 888669 888691 890278 890283) (|GrayCode| "bookvol10.4.pamphlet" 887204 887218 888659 888664) (|GradedAlgebra| "bookvol10.2.pamphlet" 886396 886419 887194 887199) (|GradedAlgebra&| NIL 885585 885611 886386 886391) (|GeneralPolynomialSet| "bookvol10.3.pamphlet" 885016 885057 885246 885298) (|GeneralPackageForAlgebraicFunctionField| "bookvol10.4.pamphlet" 879749 879873 884968 884973) (|GosperSummationMethod| "bookvol10.4.pamphlet" 878999 879036 879739 879744) (|GuessOption| "bookvol10.3.pamphlet" 873283 873300 878989 878994) (|GuessOptionFunctions0| "bookvol10.3.pamphlet" 869679 869706 873273 873278) (|GeneralModulePolynomial| "bookvol10.3.pamphlet" 868758 868806 869630 869674) (|GeneralHenselPackage| "bookvol10.4.pamphlet" 867912 867944 868748 868753) (|GenerateUnivariatePowerSeries| "bookvol10.4.pamphlet" 863698 863738 867902 867907) (|GenUFactorize| "bookvol10.4.pamphlet" 863291 863312 863688 863693) (|GeneralPolynomialGcdPackage| "bookvol10.4.pamphlet" 862916 862958 863281 863286) (|GeneralizedMultivariateFactorize| "bookvol10.4.pamphlet" 862353 862402 862906 862911) (|GenExEuclid| "bookvol10.4.pamphlet" 860826 860848 862343 862348) (|GnuDraw| "bookvol10.4.pamphlet" 859286 859299 860816 860821) (|GeneralDistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 855305 855360 856096 856330) (|GenericNonAssociativeAlgebra| "bookvol10.3.pamphlet" 849145 849198 854994 855111) (|GcdDomain| "bookvol10.2.pamphlet" 848049 848064 849028 849140) (|GcdDomain&| NIL 847057 847075 848039 848044) (|GroebnerPackage| "bookvol10.4.pamphlet" 842588 842639 847010 847015) (|GroebnerInternalPackage| "bookvol10.4.pamphlet" 838665 838724 842578 842583) (|GroebnerFactorizationPackage| "bookvol10.4.pamphlet" 834104 834168 838655 838660) (|EuclideanGroebnerBasisPackage| "bookvol10.4.pamphlet" 830730 830795 834094 834099) (|GaussianFactorizationPackage| "bookvol10.4.pamphlet" 830027 830061 830720 830725) (|GaloisGroupUtilities| "bookvol10.4.pamphlet" 828318 828346 829966 829971) (|GaloisGroupPolynomialUtilities| "bookvol10.4.pamphlet" 826757 826798 828308 828313) (|GaloisGroupFactorizationUtilities| "bookvol10.4.pamphlet" 824935 824981 826747 826752) (|GaloisGroupFactorizer| "bookvol10.4.pamphlet" 815354 815384 824925 824930) (|FortranVectorFunctionCategory| "bookvol10.2.pamphlet" 812270 812305 815334 815349) (|FortranVectorCategory| "bookvol10.2.pamphlet" 811295 811322 812250 812265) (|FunctionCalled| "bookvol10.3.pamphlet" 811132 811156 811285 811290) (|FortranType| "bookvol10.3.pamphlet" 809355 809372 811122 811127) (|FortranTemplate| "bookvol10.3.pamphlet" 808513 808534 809345 809350) (|FunctionSpaceUnivariatePolynomialFactor| "bookvol10.4.pamphlet" 807502 807554 808425 808430) (|FortranScalarType| "bookvol10.3.pamphlet" 805631 805654 807492 807497) (|FunctionSpaceReduce| "bookvol10.4.pamphlet" 805042 805071 805621 805626) (|FunctionSpacePrimitiveElement| "bookvol10.4.pamphlet" 803856 803895 804976 804981) (|FunctionalSpecialFunction| "bookvol10.4.pamphlet" 801124 801159 803846 803851) (|FunctionSpace| "bookvol10.2.pamphlet" 794876 794897 800740 801119) (|FunctionSpace&| NIL 788435 788459 794302 794307) (|FunctionSpaceIntegration| "bookvol10.4.pamphlet" 788033 788067 788425 788430) (|FourierSeries| "bookvol10.3.pamphlet" 787282 787305 787785 787940) (|FunctionSpaceComplexIntegration| "bookvol10.4.pamphlet" 786521 786562 787272 787277) (|FiniteSetAggregate| "bookvol10.2.pamphlet" 785641 785667 786424 786516) (|FiniteSetAggregate&| NIL 784763 784792 785549 785554) (|FiniteSetAggregateFunctions2| "bookvol10.4.pamphlet" 783480 783522 784753 784758) (|FunctionSpaceToUnivariatePowerSeries| "bookvol10.4.pamphlet" 777937 778005 783470 783475) (|FunctionSpaceFunctions2| "bookvol10.4.pamphlet" 777528 777565 777927 777932) (|FunctionSpaceToExponentialExpansion| "bookvol10.4.pamphlet" 776658 776714 777518 777523) (|FactoredFunctionUtilities| "bookvol10.4.pamphlet" 775635 775668 776648 776653) (|Factored| "bookvol10.3.pamphlet" 767339 767355 774393 774505) (|FramedNonAssociativeAlgebra| "bookvol10.2.pamphlet" 762461 762496 767245 767334) (|FramedNonAssociativeAlgebra&| NIL 757627 757665 762414 762419) (|FramedNonAssociativeAlgebraFunctions2| "bookvol10.4.pamphlet" 757040 757093 757617 757622) (|FramedModule| "bookvol10.3.pamphlet" 756434 756470 756961 756966) (|FractionalIdeal| "bookvol10.3.pamphlet" 755651 755681 756407 756429) (|FractionalIdealFunctions2| "bookvol10.4.pamphlet" 755366 755421 755641 755646) (|FullyRetractableTo| "bookvol10.2.pamphlet" 755024 755050 755356 755361) (|FullyRetractableTo&| NIL 754511 754540 754846 754851) (|FramedAlgebra| "bookvol10.2.pamphlet" 752882 752906 754443 754506) (|FramedAlgebra&| NIL 751308 751335 752872 752877) (|Fraction| "bookvol10.3.pamphlet" 747560 747576 747951 748245) (|FractionFunctions2| "bookvol10.4.pamphlet" 747157 747185 747550 747555) (|FactoredFunctions2| "bookvol10.4.pamphlet" 746499 746527 747147 747152) (|FloatingPointSystem| "bookvol10.2.pamphlet" 743351 743376 746309 746494) (|FloatingPointSystem&| NIL 740281 740309 743242 743247) (|FieldOfPrimeCharacteristic| "bookvol10.2.pamphlet" 739239 739271 740111 740276) (|FieldOfPrimeCharacteristic&| NIL 738354 738389 739229 739234) (|FullyPatternMatchable| "bookvol10.2.pamphlet" 738087 738116 738334 738349) (|FullPartialFractionExpansion| "bookvol10.3.pamphlet" 736815 736854 738077 738082) (|FortranProgram| "bookvol10.3.pamphlet" 735287 735349 736805 736810) (|FortranPackage| "bookvol10.4.pamphlet" 734224 734244 735277 735282) (|FortranFunctionCategory| "bookvol10.2.pamphlet" 731293 731322 734204 734219) (|FortranProgramCategory| "bookvol10.2.pamphlet" 730976 731004 731273 731288) (|ScriptFormulaFormat| "bookvol10.3.pamphlet" 728353 728378 730966 730971) (|ScriptFormulaFormat1| "bookvol10.4.pamphlet" 727814 727842 728343 728348) (|FindOrderFinite| "bookvol10.4.pamphlet" 727586 727619 727804 727809) (|FortranOutputStackPackage| "bookvol10.4.pamphlet" 726764 726795 727576 727581) (|FreeNilpotentLie| "bookvol10.3.pamphlet" 726155 726191 726715 726759) (|FileNameCategory| "bookvol10.2.pamphlet" 724485 724507 726145 726150) (|FileName| "bookvol10.3.pamphlet" 724371 724385 724475 724480) (|FortranMachineTypeCategory| "bookvol10.2.pamphlet" 724102 724134 724254 724366) (|FreeMonoid| "bookvol10.3.pamphlet" 720856 720874 724050 724055) (|FreeModule| "bookvol10.3.pamphlet" 720521 720541 720760 720804) (|FortranMatrixFunctionCategory| "bookvol10.2.pamphlet" 717444 717479 720501 720516) (|FortranMatrixCategory| "bookvol10.2.pamphlet" 716469 716496 717424 717439) (|FreeModuleCat| "bookvol10.2.pamphlet" 714135 714164 716420 716464) (|FreeModule1| "bookvol10.3.pamphlet" 713558 713579 714039 714083) (|FloatingRealPackage| "bookvol10.4.pamphlet" 711349 711380 713548 713553) (|Float| "bookvol10.3.pamphlet" 708142 708153 711106 711344) (|FloatingComplexPackage| "bookvol10.4.pamphlet" 705588 705622 708132 708137) (|FullyLinearlyExplicitRingOver| "bookvol10.2.pamphlet" 705256 705293 705561 705583) (|FullyLinearlyExplicitRingOver&| NIL 704857 704897 705165 705170) (|FiniteLinearAggregateSort| "bookvol10.4.pamphlet" 704090 704125 704847 704852) (|FreeLieAlgebra| "bookvol10.2.pamphlet" 702128 702159 703999 704085) (|FiniteLinearAggregate| "bookvol10.2.pamphlet" 699303 699332 702084 702123) (|FiniteLinearAggregate&| NIL 696373 696405 699157 699162) (|FiniteLinearAggregateFunctions2| "bookvol10.4.pamphlet" 695065 695110 696363 696368) (|FiniteRankAlgebra| "bookvol10.2.pamphlet" 693147 693175 694997 695060) (|FiniteRankAlgebra&| NIL 691140 691171 692993 692998) (|Finite| "bookvol10.2.pamphlet" 690131 690143 691130 691135) (|Finite&| NIL 689119 689134 690121 690126) (|FiniteRankNonAssociativeAlgebra| "bookvol10.2.pamphlet" 678403 678442 689025 689114) (|FiniteRankNonAssociativeAlgebra&| NIL 667722 667764 678347 678352) (|File| "bookvol10.3.pamphlet" 667307 667319 667712 667717) (|FileCategory| "bookvol10.2.pamphlet" 665744 665771 667297 667302) (|Field| "bookvol10.2.pamphlet" 665007 665018 665574 665739) (|Field&| NIL 664427 664441 664997 665002) (|FreeGroup| "bookvol10.3.pamphlet" 662954 662971 664400 664422) (|FGLMIfCanPackage| "bookvol10.4.pamphlet" 661847 661876 662944 662949) (|FiniteFieldExtension| "bookvol10.3.pamphlet" 661127 661160 661432 661597) (|FiniteFieldSquareFreeDecomposition| "bookvol10.4.pamphlet" 660968 661017 661117 661122) (|FiniteFieldSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 660437 660492 660958 660963) (|FiniteFieldPolynomialPackage| "bookvol10.4.pamphlet" 651810 651847 660427 660432) (|FiniteFieldPolynomialPackage2| "bookvol10.4.pamphlet" 650869 650909 651800 651805) (|FiniteFieldExtensionByPolynomial| "bookvol10.3.pamphlet" 650204 650254 650454 650619) (|FiniteField| "bookvol10.3.pamphlet" 649492 649517 649714 649879) (|FiniteFieldNormalBasisExtension| "bookvol10.3.pamphlet" 647882 647931 649077 649242) (|FiniteFieldNormalBasisExtensionByPolynomial| "bookvol10.3.pamphlet" 646246 646304 647467 647632) (|FiniteFieldNormalBasis| "bookvol10.3.pamphlet" 644596 644637 645756 645921) (|FunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 641946 641985 644586 644591) (|FiniteFieldCategory| "bookvol10.2.pamphlet" 639455 639480 641776 641941) (|FiniteFieldCategory&| NIL 637121 637149 639445 639450) (|FiniteFieldHomomorphisms| "bookvol10.4.pamphlet" 635892 635931 637111 637116) (|FiniteFieldFunctions| "bookvol10.4.pamphlet" 633349 633378 635882 635887) (|FractionFreeFastGaussian| "bookvol10.4.pamphlet" 627453 627487 633339 633344) (|FractionFreeFastGaussianFractions| "bookvol10.4.pamphlet" 626101 626147 627443 627448) (|FiniteFieldFactorizationWithSizeParseBySideEffect| "bookvol10.4.pamphlet" 625473 625537 626091 626096) (|FiniteFieldFactorization| "bookvol10.4.pamphlet" 625372 625411 625463 625468) (|FiniteFieldCyclicGroupExtension| "bookvol10.3.pamphlet" 624093 624142 624957 625122) (|FiniteFieldCyclicGroupExtensionByPolynomial| "bookvol10.3.pamphlet" 622836 622897 623678 623843) (|FiniteFieldCyclicGroup| "bookvol10.3.pamphlet" 621472 621513 622346 622511) (|FunctionFieldCategory| "bookvol10.2.pamphlet" 610163 610200 621212 621467) (|FunctionFieldCategory&| NIL 599024 599064 610076 610081) (|FunctionFieldCategoryFunctions2| "bookvol10.4.pamphlet" 598734 598803 599014 599019) (|FortranExpression| "bookvol10.3.pamphlet" 591327 591388 598422 598485) (|FullyEvalableOver| "bookvol10.2.pamphlet" 591022 591047 591317 591322) (|FullyEvalableOver&| NIL 590476 590504 590774 590779) (|FiniteDivisor| "bookvol10.3.pamphlet" 589920 589951 590466 590471) (|FiniteDivisorCategory| "bookvol10.2.pamphlet" 587917 587956 589910 589915) (|FiniteDivisorCategory&| NIL 585911 585953 587907 587912) (|FiniteDivisorFunctions2| "bookvol10.4.pamphlet" 585636 585697 585901 585906) (|FortranCodePackage1| "bookvol10.4.pamphlet" 584180 584205 585626 585631) (|FourierComponent| "bookvol10.3.pamphlet" 583697 583721 584170 584175) (|FortranCode| "bookvol10.3.pamphlet" 573653 573670 583687 583692) (|FiniteAlgebraicExtensionField| "bookvol10.2.pamphlet" 566835 566872 573483 573648) (|FiniteAlgebraicExtensionField&| NIL 560136 560176 566787 566792) (|FlexibleArray| "bookvol10.3.pamphlet" 558429 558450 559418 559470) (|FiniteAbelianMonoidRing| "bookvol10.2.pamphlet" 556482 556515 558259 558424) (|FiniteAbelianMonoidRing&| NIL 554554 554590 556334 556339) (|FiniteAbelianMonoidRingFunctions2| "bookvol10.4.pamphlet" 554097 554150 554544 554549) (|FreeAbelianMonoid| "bookvol10.3.pamphlet" 553705 553730 554017 554022) (|FreeAbelianMonoidCategory| "bookvol10.2.pamphlet" 551865 551900 553695 553700) (|FreeAbelianGroup| "bookvol10.3.pamphlet" 551417 551441 551713 551757) (|FactoringUtilities| "bookvol10.4.pamphlet" 549613 549646 551407 551412) (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| "bookvol10.4.pamphlet" 549442 549505 549603 549608) (|FactoredFunctions| "bookvol10.4.pamphlet" 548621 548646 549432 549437) (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| "bookvol10.4.pamphlet" 548442 548513 548611 548616) (|ExponentialOfUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 544775 544832 546104 546356) (|ExpressionTubePlot| "bookvol10.4.pamphlet" 542227 542251 544765 544770) (|ExpressionSolve| "bookvol10.4.pamphlet" 542120 542158 542217 542222) (|ExpressionSpaceODESolver| "bookvol10.4.pamphlet" 538846 538880 542110 542115) (|Expression| "bookvol10.3.pamphlet" 532927 532945 533657 534280) (|ExpressionToUnivariatePowerSeries| "bookvol10.4.pamphlet" 528986 529030 532917 532922) (|ExpressionFunctions2| "bookvol10.4.pamphlet" 528738 528768 528976 528981) (|ExponentialExpansion| "bookvol10.3.pamphlet" 523670 523713 524326 524491) (|Export3D| "bookvol10.4.pamphlet" 523517 523531 523660 523665) (|Exit| "bookvol10.3.pamphlet" 523186 523196 523507 523512) (|EvaluateCycleIndicators| "bookvol10.4.pamphlet" 522663 522694 523176 523181) (|Evalable| "bookvol10.2.pamphlet" 522221 522237 522653 522658) (|Evalable&| NIL 521776 521795 522211 522216) (|EuclideanDomain| "bookvol10.2.pamphlet" 519292 519313 521659 521771) (|EuclideanDomain&| NIL 516912 516936 519282 519287) (|ExpertSystemToolsPackage| "bookvol10.4.pamphlet" 508748 508778 516902 516907) (|ExpertSystemToolsPackage2| "bookvol10.4.pamphlet" 508320 508357 508738 508743) (|ExpertSystemToolsPackage1| "bookvol10.4.pamphlet" 507982 508016 508310 508315) (|ExpressionSpace| "bookvol10.2.pamphlet" 500916 500937 507972 507977) (|ExpressionSpace&| NIL 493739 493763 500798 500803) (|ExpertSystemContinuityPackage| "bookvol10.4.pamphlet" 490521 490556 493729 493734) (|ExpertSystemContinuityPackage1| "bookvol10.4.pamphlet" 490234 490274 490511 490516) (|ExpressionSpaceFunctions2| "bookvol10.4.pamphlet" 489722 489757 490224 490229) (|ExpressionSpaceFunctions1| "bookvol10.4.pamphlet" 489261 489296 489712 489717) (|ErrorFunctions| "bookvol10.4.pamphlet" 486725 486745 489251 489256) (|EqTable| "bookvol10.3.pamphlet" 485598 485625 485812 485864) (|Equation| "bookvol10.3.pamphlet" 480073 480089 482826 482965) (|EquationFunctions2| "bookvol10.4.pamphlet" 479775 479803 480063 480068) (|EigenPackage| "bookvol10.4.pamphlet" 476119 476139 479765 479770) (|EntireRing| "bookvol10.2.pamphlet" 475620 475636 476028 476114) (|EuclideanModularRing| "bookvol10.3.pamphlet" 474747 474814 475503 475615) (|EltableAggregate| "bookvol10.2.pamphlet" 473189 473222 474737 474742) (|EltableAggregate&| NIL 471581 471617 473132 473137) (|Eltable| "bookvol10.2.pamphlet" 471108 471131 471571 471576) (|EllipticFunctionsUnivariateTaylorSeries| "bookvol10.4.pamphlet" 470460 470516 471098 471103) (|ElementaryFunctionCategory| "bookvol10.2.pamphlet" 470133 470165 470450 470455) (|ElementaryFunctionCategory&| NIL 469803 469838 470123 470128) (|ExtensibleLinearAggregate| "bookvol10.2.pamphlet" 467683 467716 469758 469798) (|ExtensibleLinearAggregate&| NIL 465508 465544 467586 467591) (|ElementaryFunctionsUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 462240 462310 465461 465466) (|ElementaryFunctionsUnivariateLaurentSeries| "bookvol10.3.pamphlet" 459033 459096 462193 462198) (|ElementaryFunctionStructurePackage| "bookvol10.4.pamphlet" 457002 457046 459023 459028) (|ElementaryFunction| "bookvol10.4.pamphlet" 451766 451794 456992 456997) (|ExtAlgBasis| "bookvol10.3.pamphlet" 450071 450088 451756 451761) (|e04ucfAnnaType| "bookvol10.3.pamphlet" 449597 449617 450061 450066) (|e04nafAnnaType| "bookvol10.3.pamphlet" 449164 449184 449587 449592) (|e04mbfAnnaType| "bookvol10.3.pamphlet" 448734 448754 449154 449159) (|e04jafAnnaType| "bookvol10.3.pamphlet" 448260 448280 448724 448729) (|e04gcfAnnaType| "bookvol10.3.pamphlet" 447786 447806 448250 448255) (|e04fdfAnnaType| "bookvol10.3.pamphlet" 447312 447332 447776 447781) (|e04dgfAnnaType| "bookvol10.3.pamphlet" 446838 446858 447302 447307) (|e04AgentsPackage| "bookvol10.4.pamphlet" 442566 442588 446828 446833) (|DifferentialVariableCategory| "bookvol10.2.pamphlet" 439289 439325 442556 442561) (|DifferentialVariableCategory&| NIL 436009 436048 439279 439284) (|DesingTreePackage| "bookvol10.4.pamphlet" 433079 433181 435999 436004) (|DesingTree| "bookvol10.3.pamphlet" 432230 432248 432862 432914) (|DesingTreeCategory| "bookvol10.2.pamphlet" 431783 431809 432161 432225) (|DifferentialSparseMultivariatePolynomial| "bookvol10.3.pamphlet" 428251 428303 428582 428816) (|DrawOption| "bookvol10.3.pamphlet" 422006 422022 428241 428246) (|DrawOptionFunctions1| "bookvol10.4.pamphlet" 421659 421687 421996 422001) (|DrawOptionFunctions0| "bookvol10.4.pamphlet" 416600 416626 421649 421654) (|TopLevelDrawFunctionsForPoints| "bookvol10.4.pamphlet" 414813 414849 416590 416595) (|TopLevelDrawFunctions| "bookvol10.4.pamphlet" 407702 407734 414803 414808) (|DrawNumericHack| "bookvol10.4.pamphlet" 406952 406975 407692 407697) (|DrawComplex| "bookvol10.4.pamphlet" 404368 404385 406942 406947) (|TopLevelDrawFunctionsForAlgebraicCurves| "bookvol10.4.pamphlet" 403878 403930 404358 404363) (|TopLevelDrawFunctionsForCompiledFunctions| "bookvol10.4.pamphlet" 393279 393326 403868 403873) (|DequeueAggregate| "bookvol10.2.pamphlet" 391450 391474 393210 393274) (|DifferentialPolynomialCategory| "bookvol10.2.pamphlet" 386712 386756 391211 391445) (|DifferentialPolynomialCategory&| NIL 382152 382199 386654 386659) (|DirectProductModule| "bookvol10.3.pamphlet" 373919 373952 374058 374497) (|DirectProductMatrixModule| "bookvol10.3.pamphlet" 365677 365718 365825 366264) (|DistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 361903 361949 362487 362721) (|DiscreteLogarithmPackage| "bookvol10.4.pamphlet" 361221 361253 361893 361898) (|DataList| "bookvol10.3.pamphlet" 359806 359822 360503 360555) (|DoublyLinkedAggregate| "bookvol10.2.pamphlet" 358234 358263 359786 359801) (|DivisionRing| "bookvol10.2.pamphlet" 357630 357648 358143 358229) (|DivisionRing&| NIL 357104 357125 357620 357625) (|Divisor| "bookvol10.3.pamphlet" 356912 356927 356996 357040) (|DivisorCategory| "bookvol10.2.pamphlet" 355647 355670 356863 356907) (|DisplayPackage| "bookvol10.4.pamphlet" 353849 353869 355637 355642) (|DirichletRing| "bookvol10.3.pamphlet" 353010 353036 353577 353797) (|DirectProduct| "bookvol10.3.pamphlet" 342538 342565 343174 343378) (|DirectProductFunctions2| "bookvol10.4.pamphlet" 341378 341417 342528 342533) (|DirectProductCategory| "bookvol10.2.pamphlet" 340217 340252 341157 341373) (|DirectProductCategory&| NIL 338761 338799 339704 339709) (|DiophantineSolutionPackage| "bookvol10.4.pamphlet" 337582 337614 338751 338756) (|DictionaryOperations| "bookvol10.2.pamphlet" 336631 336659 337537 337577) (|DictionaryOperations&| NIL 335666 335697 336575 336580) (|DifferentialRing| "bookvol10.2.pamphlet" 334766 334788 335639 335661) (|DifferentialRing&| NIL 333880 333905 334756 334761) (|DifferentialExtension| "bookvol10.2.pamphlet" 333005 333034 333853 333875) (|DifferentialExtension&| NIL 332015 332047 332866 332871) (|Dictionary| "bookvol10.2.pamphlet" 331614 331632 331970 332010) (|Dictionary&| NIL 331245 331266 331604 331609) (|DenavitHartenbergMatrix| "bookvol10.3.pamphlet" 329410 329441 330793 330845) (|DoubleFloatVector| "bookvol10.3.pamphlet" 327764 327787 328165 328217) (|DoubleFloatSpecialFunctions| "bookvol10.4.pamphlet" 318933 318966 327754 327759) (|DoubleFloatMatrix| "bookvol10.3.pamphlet" 317958 317981 318388 318440) (|DoubleFloat| "bookvol10.3.pamphlet" 314254 314271 317768 317953) (|DefiniteIntegrationTools| "bookvol10.4.pamphlet" 312471 312505 314244 314249) (|DeRhamComplex| "bookvol10.3.pamphlet" 310411 310454 312444 312466) (|Dequeue| "bookvol10.3.pamphlet" 304549 304564 310194 310246) (|DegreeReductionPackage| "bookvol10.4.pamphlet" 304144 304178 304539 304544) (|RationalFunctionDefiniteIntegration| "bookvol10.4.pamphlet" 301576 301619 304134 304139) (|ElementaryFunctionDefiniteIntegration| "bookvol10.4.pamphlet" 300025 300072 301566 301571) (|DecimalExpansion| "bookvol10.3.pamphlet" 297179 297201 297779 297944) (|DistinctDegreeFactorize| "bookvol10.4.pamphlet" 295039 295073 297169 297174) (|DoubleResultantPackage| "bookvol10.4.pamphlet" 294631 294671 295029 295034) (|Database| "bookvol10.3.pamphlet" 293278 293294 294621 294626) (|d03fafAnnaType| "bookvol10.3.pamphlet" 293094 293114 293268 293273) (|d03eefAnnaType| "bookvol10.3.pamphlet" 292902 292922 293084 293089) (|d03AgentsPackage| "bookvol10.4.pamphlet" 291833 291855 292892 292897) (|d02ejfAnnaType| "bookvol10.3.pamphlet" 291285 291305 291823 291828) (|d02cjfAnnaType| "bookvol10.3.pamphlet" 290753 290773 291275 291280) (|d02bhfAnnaType| "bookvol10.3.pamphlet" 290233 290253 290743 290748) (|d02bbfAnnaType| "bookvol10.3.pamphlet" 289713 289733 290223 290228) (|d02AgentsPackage| "bookvol10.4.pamphlet" 284644 284666 289703 289708) (|d01WeightsPackage| "bookvol10.4.pamphlet" 282952 282975 284634 284639) (|d01TransformFunctionType| "bookvol10.3.pamphlet" 282907 282937 282942 282947) (|d01gbfAnnaType| "bookvol10.3.pamphlet" 282419 282439 282897 282902) (|d01fcfAnnaType| "bookvol10.3.pamphlet" 281931 281951 282409 282414) (|d01asfAnnaType| "bookvol10.3.pamphlet" 281389 281409 281921 281926) (|d01aqfAnnaType| "bookvol10.3.pamphlet" 280872 280892 281379 281384) (|d01apfAnnaType| "bookvol10.3.pamphlet" 280342 280362 280862 280867) (|d01anfAnnaType| "bookvol10.3.pamphlet" 279826 279846 280332 280337) (|d01amfAnnaType| "bookvol10.3.pamphlet" 279326 279346 279816 279821) (|d01alfAnnaType| "bookvol10.3.pamphlet" 278856 278876 279316 279321) (|d01akfAnnaType| "bookvol10.3.pamphlet" 278374 278394 278846 278851) (|d01ajfAnnaType| "bookvol10.3.pamphlet" 277887 277907 278364 278369) (|d01AgentsPackage| "bookvol10.4.pamphlet" 273980 274002 277877 277882) (|CyclotomicPolynomialPackage| "bookvol10.4.pamphlet" 273459 273492 273970 273975) (|CycleIndicators| "bookvol10.4.pamphlet" 270257 270278 273449 273454) (|CoerceVectorMatrixPackage| "bookvol10.4.pamphlet" 269619 269652 270247 270252) (|ComplexTrigonometricManipulations| "bookvol10.4.pamphlet" 268060 268103 269609 269614) (|CyclicStreamTools| "bookvol10.4.pamphlet" 266834 266862 268050 268055) (|ComplexRootFindingPackage| "bookvol10.4.pamphlet" 260826 260862 266824 266829) (|CRApackage| "bookvol10.4.pamphlet" 259975 259993 260816 260821) (|ComplexPatternMatch| "bookvol10.4.pamphlet" 259448 259480 259878 259883) (|CharacteristicPolynomialInMonogenicalAlgebra| "bookvol10.4.pamphlet" 259111 259172 259438 259443) (|CoordinateSystems| "bookvol10.4.pamphlet" 254111 254136 259101 259106) (|ContinuedFraction| "bookvol10.3.pamphlet" 250025 250050 253941 254106) (|CommutativeRing| "bookvol10.2.pamphlet" 249659 249680 249931 250020) (|SubSpaceComponentProperty| "bookvol10.3.pamphlet" 249136 249167 249649 249654) (|ComplexPattern| "bookvol10.4.pamphlet" 248891 248918 249126 249131) (|Complex| "bookvol10.3.pamphlet" 240748 240763 241002 241478) (|ComplexFunctions2| "bookvol10.4.pamphlet" 240456 240483 240738 240743) (|ComplexFactorization| "bookvol10.4.pamphlet" 240234 240266 240446 240451) (|ComplexCategory| "bookvol10.2.pamphlet" 238112 238135 239741 240229) (|ComplexCategory&| NIL 235678 235704 237310 237315) (|Comparable| "bookvol10.2.pamphlet" 235409 235425 235668 235673) (|CommuteUnivariatePolynomialCategory| "bookvol10.4.pamphlet" 235150 235201 235399 235404) (|CommonOperators| "bookvol10.4.pamphlet" 234676 234697 235140 235145) (|Commutator| "bookvol10.3.pamphlet" 234477 234493 234666 234671) (|CombinatorialOpsCategory| "bookvol10.2.pamphlet" 233490 233520 234467 234472) (|IntegerCombinatoricFunctions| "bookvol10.4.pamphlet" 231956 231992 233480 233485) (|CombinatorialFunction| "bookvol10.4.pamphlet" 229391 229422 231946 231951) (|Color| "bookvol10.3.pamphlet" 228226 228237 229381 229386) (|ComplexRootPackage| "bookvol10.4.pamphlet" 227544 227577 228216 228221) (|TwoDimensionalPlotClipping| "bookvol10.4.pamphlet" 223640 223672 227534 227539) (|CliffordAlgebra| "bookvol10.3.pamphlet" 222318 222347 223572 223635) (|Collection| "bookvol10.2.pamphlet" 219330 219348 222298 222313) (|Collection&| NIL 216184 216205 219155 219160) (|ComplexIntegerSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 215482 215536 216174 216179) (|ChangeOfVariable| "bookvol10.4.pamphlet" 213442 213474 215472 215477) (|CharacteristicZero| "bookvol10.2.pamphlet" 213334 213358 213415 213437) (|CharacteristicPolynomialPackage| "bookvol10.4.pamphlet" 212819 212858 213324 213329) (|CharacteristicNonZero| "bookvol10.2.pamphlet" 212546 212573 212792 212814) (|Character| "bookvol10.3.pamphlet" 208900 208915 212536 212541) (|CombinatorialFunctionCategory| "bookvol10.2.pamphlet" 208046 208081 208890 208895) (|ComplexDoubleFloatVector| "bookvol10.3.pamphlet" 205857 205887 206510 206562) (|ComplexDoubleFloatMatrix| "bookvol10.3.pamphlet" 204745 204775 205191 205243) (|CommonDenominator| "bookvol10.4.pamphlet" 203970 203999 204735 204740) (|CharacterClass| "bookvol10.3.pamphlet" 202164 202184 203234 203314) (|CartesianTensor| "bookvol10.3.pamphlet" 193330 193367 202154 202159) (|CartesianTensorFunctions2| "bookvol10.4.pamphlet" 192697 192747 193320 193325) (|CardinalNumber| "bookvol10.3.pamphlet" 189015 189035 192663 192692) (|CachableSet| "bookvol10.2.pamphlet" 188622 188639 189005 189010) (|CancellationAbelianMonoid| "bookvol10.2.pamphlet" 188092 188123 188612 188617) (|BinaryTree| "bookvol10.3.pamphlet" 187129 187147 187875 187927) (|BinaryTournament| "bookvol10.3.pamphlet" 186310 186334 186912 186964) (|BinaryTreeCategory| "bookvol10.2.pamphlet" 185643 185669 186241 186305) (|BinaryTreeCategory&| NIL 185032 185061 185633 185638) (|BitAggregate| "bookvol10.2.pamphlet" 184100 184118 184963 185027) (|BitAggregate&| NIL 183224 183245 184090 184095) (|BinarySearchTree| "bookvol10.3.pamphlet" 181821 181845 183007 183059) (|BasicStochasticDifferential| "Makefile.pamphlet" 179686 179719 181811 181816) (|BrillhartTests| "bookvol10.4.pamphlet" 178447 178470 179676 179681) (|BinaryRecursiveAggregate| "bookvol10.2.pamphlet" 177385 177417 178427 178442) (|BinaryRecursiveAggregate&| NIL 176283 176318 177328 177333) (|BalancedPAdicRational| "bookvol10.3.pamphlet" 173193 173224 173403 173568) (|BalancedPAdicInteger| "bookvol10.3.pamphlet" 172860 172890 173076 173188) (|BoundIntegerRoots| "bookvol10.4.pamphlet" 172507 172535 172850 172855) (|BasicOperator| "bookvol10.3.pamphlet" 168028 168047 172497 172502) (|BasicOperatorFunctions1| "bookvol10.4.pamphlet" 165485 165516 167976 167981) (|Boolean| "bookvol10.3.pamphlet" 164350 164363 165475 165480) (|BiModule| "bookvol10.2.pamphlet" 163971 163989 164301 164345) (|BlowUpPackage| "bookvol10.4.pamphlet" 162238 162285 163961 163966) (|BlowUpWithQuadTrans| "bookvol10.3.pamphlet" 162111 162136 162203 162233) (|BlowUpMethodCategory| "bookvol10.2.pamphlet" 162070 162096 162101 162106) (|BlowUpWithHamburgerNoether| "bookvol10.3.pamphlet" 161938 161970 162037 162065) (|BlasLevelOne| "bookvol10.5.pamphlet" 150200 150218 161928 161933) (|Bits| "bookvol10.3.pamphlet" 149561 149571 149778 149830) (|BinaryFile| "bookvol10.3.pamphlet" 148910 148926 149551 149556) (|BinaryExpansion| "bookvol10.3.pamphlet" 146032 146053 146664 146829) (|BagAggregate| "bookvol10.2.pamphlet" 145254 145274 145987 146027) (|BagAggregate&| NIL 144508 144531 145244 145249) (|BasicFunctions| "bookvol10.3.pamphlet" 143905 143925 144476 144503) (|BezoutMatrix| "bookvol10.4.pamphlet" 143027 143064 143847 143852) (|Bezier| "bookvol10.4.pamphlet" 140886 140900 143017 143022) (|BalancedBinaryTree| "bookvol10.3.pamphlet" 136455 136481 140669 140721) (|BasicType| "bookvol10.2.pamphlet" 136142 136157 136445 136450) (|BasicType&| NIL 135826 135844 136132 136137) (|BalancedFactorisation| "bookvol10.4.pamphlet" 135226 135258 135816 135821) (|AxiomServer| "bookvol10.4.pamphlet" 135077 135094 135216 135221) (|Automorphism| "bookvol10.3.pamphlet" 134504 134524 135050 135072) (|UnitsKnownAttribute| "bookvol10.2.pamphlet" 134282 134307 134484 134499) (|AttributeRegistry| "bookvol10.2.pamphlet" 130635 130658 133835 134277) (|AttributeButtons| "bookvol10.3.pamphlet" 126733 126755 130603 130630) (|ShallowlyMutableAttribute| "bookvol10.2.pamphlet" 126470 126501 126713 126728) (|ArcTrigonometricFunctionCategory| "bookvol10.2.pamphlet" 125909 125947 126460 126465) (|ArcTrigonometricFunctionCategory&| NIL 125345 125386 125899 125904) (|PartiallyOrderedSetAttribute| "bookvol10.2.pamphlet" 125117 125151 125325 125340) (|NoZeroDivisorsAttribute| "bookvol10.2.pamphlet" 124918 124947 125097 125112) (|NullSquareAttribute| "bookvol10.2.pamphlet" 124783 124808 124898 124913) (|NotherianAttribute| "bookvol10.2.pamphlet" 124641 124665 124763 124778) (|MultiplicativeValuationAttribute| "bookvol10.2.pamphlet" 124450 124488 124621 124636) (|LeftUnitaryAttribute| "bookvol10.2.pamphlet" 124293 124319 124430 124445) (|LazyRepresentationAttribute| "bookvol10.2.pamphlet" 124155 124188 124273 124288) (|JacobiIdentityAttribute| "bookvol10.2.pamphlet" 123988 124017 124135 124150) (|FiniteAggregateAttribute| "bookvol10.2.pamphlet" 123849 123879 123968 123983) (|CanonicalUnitNormalAttribute| "bookvol10.2.pamphlet" 123523 123557 123829 123844) (|CommutativeStarAttribute| "bookvol10.2.pamphlet" 123250 123280 123503 123518) (|CentralAttribute| "bookvol10.2.pamphlet" 122931 122953 123230 123245) (|CanonicalAttribute| "bookvol10.2.pamphlet" 122728 122752 122911 122926) (|CanonicalClosedAttribute| "bookvol10.2.pamphlet" 122544 122574 122708 122723) (|ArbitraryPrecisionAttribute| "bookvol10.2.pamphlet" 122374 122407 122524 122539) (|ArbitraryExponentAttribute| "bookvol10.2.pamphlet" 122242 122274 122354 122369) (|ApproximateAttribute| "bookvol10.2.pamphlet" 122131 122157 122222 122237) (|AdditiveValuationAttribute| "bookvol10.2.pamphlet" 121944 121976 122111 122126) (|ArrayStack| "bookvol10.3.pamphlet" 117592 117610 121727 121779) (|AssociatedEquations| "bookvol10.4.pamphlet" 116361 116390 117545 117550) (|Asp9| "bookvol10.3.pamphlet" 115514 115531 116351 116356) (|Asp8| "bookvol10.3.pamphlet" 114453 114470 115504 115509) (|Asp80| "bookvol10.3.pamphlet" 113780 113798 114443 114448) (|Asp7| "bookvol10.3.pamphlet" 112974 112991 113770 113775) (|Asp78| "bookvol10.3.pamphlet" 112448 112466 112964 112969) (|Asp77| "bookvol10.3.pamphlet" 111816 111834 112438 112443) (|Asp74| "bookvol10.3.pamphlet" 110838 110856 111806 111811) (|Asp73| "bookvol10.3.pamphlet" 110096 110114 110828 110833) (|Asp6| "bookvol10.3.pamphlet" 108772 108789 110086 110091) (|Asp55| "bookvol10.3.pamphlet" 107204 107222 108762 108767) (|Asp50| "bookvol10.3.pamphlet" 104855 104873 107194 107199) (|Asp4| "bookvol10.3.pamphlet" 104140 104157 104845 104850) (|Asp49| "bookvol10.3.pamphlet" 103124 103142 104130 104135) (|Asp42| "bookvol10.3.pamphlet" 101396 101439 103114 103119) (|Asp41| "bookvol10.3.pamphlet" 99894 99937 101386 101391) (|Asp35| "bookvol10.3.pamphlet" 98874 98892 99884 99889) (|Asp34| "bookvol10.3.pamphlet" 98120 98138 98864 98869) (|Asp33| "bookvol10.3.pamphlet" 97701 97719 98110 98115) (|Asp31| "bookvol10.3.pamphlet" 96810 96828 97691 97696) (|Asp30| "bookvol10.3.pamphlet" 95537 95555 96800 96805) (|Asp29| "bookvol10.3.pamphlet" 95016 95034 95527 95532) (|Asp28| "bookvol10.3.pamphlet" 85442 85460 95006 95011) (|Asp27| "bookvol10.3.pamphlet" 84293 84311 85432 85437) (|Asp24| "bookvol10.3.pamphlet" 83371 83389 84283 84288) (|Asp20| "bookvol10.3.pamphlet" 82539 82557 83361 83366) (|Asp1| "bookvol10.3.pamphlet" 81915 81932 82529 82534) (|Asp19| "bookvol10.3.pamphlet" 75989 76007 81905 81910) (|Asp12| "bookvol10.3.pamphlet" 75402 75420 75979 75984) (|Asp10| "bookvol10.3.pamphlet" 74678 74696 75392 75397) (|TwoDimensionalArray| "bookvol10.3.pamphlet" 74219 74246 74461 74513) (|OneDimensionalArray| "bookvol10.3.pamphlet" 72993 73020 73501 73553) (|OneDimensionalArrayFunctions2| "bookvol10.4.pamphlet" 71002 71041 72983 72988) (|TwoDimensionalArrayCategory| "bookvol10.2.pamphlet" 64227 64274 70933 70997) (|TwoDimensionalArrayCategory&| NIL 57508 57558 64217 64222) (|ApplyRules| "bookvol10.4.pamphlet" 56819 56846 57498 57503) (|ApplyUnivariateSkewPolynomial| "bookvol10.4.pamphlet" 56394 56435 56809 56814) (|ApplicationProgramInterface| "bookvol10.4.pamphlet" 55305 55338 56384 56389) (|Any| "bookvol10.3.pamphlet" 53651 53660 55295 55300) (|AnyFunctions1| "bookvol10.4.pamphlet" 52716 52737 53641 53646) (|AntiSymm| "bookvol10.3.pamphlet" 51159 51182 52689 52711) (|AnonymousFunction| "bookvol10.3.pamphlet" 51056 51079 51149 51154) (|AlgebraicNumber| "bookvol10.3.pamphlet" 49265 49286 50784 50949) (|AbelianMonoidRing| "bookvol10.2.pamphlet" 47392 47419 49095 49260) (|AbelianMonoidRing&| NIL 45343 45373 47049 47054) (|AssociationList| "bookvol10.3.pamphlet" 43080 43115 43442 43494) (|AlgebraGivenByStructuralConstants| "bookvol10.3.pamphlet" 42104 42162 42901 42990) (|AlgebraPackage| "bookvol10.4.pamphlet" 38043 38067 42047 42052) (|AlgebraicMultFact| "bookvol10.4.pamphlet" 37236 37266 38033 38038) (|AlgebraicManipulations| "bookvol10.4.pamphlet" 34652 34684 36992 36997) (|AlgebraicFunctionField| "bookvol10.3.pamphlet" 32419 32467 32640 32895) (|AlgFactor| "bookvol10.4.pamphlet" 31536 31554 32409 32414) (|Algebra| "bookvol10.2.pamphlet" 31006 31021 31468 31531) (|Algebra&| NIL 30531 30549 30996 31001) (|AssociationListAggregate| "bookvol10.2.pamphlet" 29985 30029 30462 30526) (|ArcHyperbolicFunctionCategory| "bookvol10.2.pamphlet" 29338 29373 29975 29980) (|Aggregate| "bookvol10.2.pamphlet" 27707 27722 29318 29333) (|Aggregate&| NIL 26037 26055 27651 27656) (|AffineSpaceCategory| "bookvol10.2.pamphlet" 23907 23934 26027 26032) (|AlgebraicFunction| "bookvol10.4.pamphlet" 22279 22306 23827 23832) (|AffineSpace| "bookvol10.3.pamphlet" 22112 22137 22269 22274) (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 21912 21970 22102 22107) (|AffinePlane| "bookvol10.3.pamphlet" 21751 21770 21902 21907) (|AffineAlgebraicSetComputeWithResultant| "bookvol10.4.pamphlet" 21597 21672 21741 21746) (|AffineAlgebraicSetComputeWithGroebnerBasis| "bookvol10.4.pamphlet" 21139 21218 21587 21592) (|PlaneAlgebraicCurvePlot| "bookvol10.3.pamphlet" 19405 19434 21129 21134) (|AlgebraicallyClosedFunctionSpace| "bookvol10.2.pamphlet" 17181 17221 19223 19400) (|AlgebraicallyClosedFunctionSpace&| NIL 15126 15169 17171 17176) (|AlgebraicallyClosedField| "bookvol10.2.pamphlet" 10185 10215 14956 15121) (|AlgebraicallyClosedField&| NIL 5401 5434 10175 10180) (|AbelianSemiGroup| "bookvol10.2.pamphlet" 4744 4766 5391 5396) (|AbelianSemiGroup&| NIL 4084 4109 4734 4739) (|AbelianMonoid| "bookvol10.2.pamphlet" 3441 3460 4074 4079) (|AbelianMonoid&| NIL 2795 2817 3431 3436) (|AbelianGroup| "bookvol10.2.pamphlet" 2290 2308 2785 2790) (|AbelianGroup&| NIL 1782 1803 2280 2285) (|OneDimensionalArrayAggregate| "bookvol10.2.pamphlet" 878 914 1713 1777) (|OneDimensionalArrayAggregate&| NIL 30 69 868 873)) 
\ No newline at end of file
+((|Category| NIL 2502709 2502714 2502719 2502724) (|Union| NIL 2502689 2502694 2502699 2502704) (|Record| NIL 2502669 2502674 2502679 2502684) (|Mapping| NIL 2502649 2502654 2502659 2502664) (|Enumeration| NIL 2502629 2502634 2502639 2502644) (|IntegerMod| "bookvol10.3.pamphlet" 2502407 2502427 2502535 2502624) (|IntegerLinearDependence| "bookvol10.4.pamphlet" 2501507 2501538 2502397 2502402) (|ZeroDimensionalSolvePackage| "bookvol10.4.pamphlet" 2492099 2492145 2501497 2501502) (|ParadoxicalCombinatorsForStreams| "bookvol10.4.pamphlet" 2491567 2491607 2492089 2492094) (|XRecursivePolynomial| "bookvol10.3.pamphlet" 2490708 2490745 2491346 2491468) (|XPolynomialRing| "bookvol10.3.pamphlet" 2488287 2488312 2490284 2490475) (|XPolynomial| "bookvol10.3.pamphlet" 2487774 2487793 2488066 2488188) (|XPolynomialsCat| "bookvol10.2.pamphlet" 2487027 2487055 2487647 2487769) (|XPBWPolynomial| "bookvol10.3.pamphlet" 2485589 2485620 2486715 2486837) (|ExtensionField| "bookvol10.2.pamphlet" 2483974 2483996 2485419 2485584) (|ExtensionField&| NIL 2482371 2482396 2483819 2483824) (|XFreeAlgebra| "bookvol10.2.pamphlet" 2479344 2479369 2482244 2482366) (|XExponentialPackage| "bookvol10.4.pamphlet" 2478727 2478769 2479334 2479339) (|XDistributedPolynomial| "bookvol10.3.pamphlet" 2478262 2478297 2478506 2478628) (|XAlgebra| "bookvol10.2.pamphlet" 2477932 2477948 2478194 2478257) (|WuWenTsunTriangularSet| "bookvol10.3.pamphlet" 2474500 2474536 2477553 2477605) (|WeightedPolynomials| "bookvol10.3.pamphlet" 2473448 2473508 2474292 2474409) (|WildFunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 2471000 2471045 2473438 2473443) (|WeierstrassPreparation| "bookvol10.4.pamphlet" 2469245 2469275 2470990 2470995) (|VectorSpace| "bookvol10.2.pamphlet" 2468893 2468912 2469196 2469240) (|VectorSpace&| NIL 2468577 2468599 2468883 2468888) (|Void| "bookvol10.3.pamphlet" 2468170 2468180 2468567 2468572) (|ViewportPackage| "bookvol10.4.pamphlet" 2465874 2465895 2468160 2468165) (|ViewDefaultsPackage| "bookvol10.4.pamphlet" 2461118 2461143 2465864 2465869) (|ThreeDimensionalViewport| "bookvol10.3.pamphlet" 2445313 2445343 2461108 2461113) (|TwoDimensionalViewport| "bookvol10.3.pamphlet" 2433485 2433513 2445303 2445308) (|Vector| "bookvol10.3.pamphlet" 2432199 2432213 2432453 2432505) (|VectorFunctions2| "bookvol10.4.pamphlet" 2430860 2430886 2432189 2432194) (|VectorCategory| "bookvol10.2.pamphlet" 2428824 2428846 2430791 2430855) (|VectorCategory&| NIL 2426576 2426601 2428546 2428551) (|Variable| "bookvol10.3.pamphlet" 2426351 2426371 2426566 2426571) (|UnivariateTaylorSeriesCZero| "bookvol10.3.pamphlet" 2421080 2421126 2424395 2424560) (|TaylorSolve| "bookvol10.4.pamphlet" 2420979 2421011 2421070 2421075) (|UTSodetools| "bookvol10.4.pamphlet" 2420257 2420285 2420923 2420928) (|UnivariateTaylorSeriesODESolver| "bookvol10.4.pamphlet" 2418419 2418467 2420247 2420252) (|UnivariateTaylorSeries| "bookvol10.3.pamphlet" 2412776 2412823 2416463 2416628) (|UnivariateTaylorSeriesCategory| "bookvol10.2.pamphlet" 2409998 2410041 2412606 2412771) (|UnivariateTaylorSeriesCategory&| NIL 2406805 2406851 2409416 2409421) (|UnivariateTaylorSeriesFunctions2| "bookvol10.4.pamphlet" 2406401 2406465 2406795 2406800) (|UnaryRecursiveAggregate| "bookvol10.2.pamphlet" 2401665 2401696 2406381 2406396) (|UnaryRecursiveAggregate&| NIL 2396889 2396923 2401608 2401613) (|UnivariatePuiseuxSeriesWithExponentialSingularity| "bookvol10.3.pamphlet" 2394024 2394096 2395484 2395725) (|UnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 2391085 2391133 2391686 2391938) (|UnivariatePuiseuxSeriesConstructor| "bookvol10.3.pamphlet" 2388345 2388396 2388747 2388999) (|UnivariatePuiseuxSeriesConstructorCategory| "bookvol10.2.pamphlet" 2386673 2386732 2388088 2388340) (|UnivariatePuiseuxSeriesConstructorCategory&| NIL 2385245 2385307 2386663 2386668) (|UnivariatePuiseuxSeriesCategory| "bookvol10.2.pamphlet" 2383705 2383749 2384988 2385240) (|UnivariatePuiseuxSeriesFunctions2| "bookvol10.4.pamphlet" 2383218 2383301 2383695 2383700) (|UnivariatePolynomialSquareFree| "bookvol10.4.pamphlet" 2381619 2381660 2383208 2383213) (|UnivariatePowerSeriesCategory| "bookvol10.2.pamphlet" 2379095 2379145 2381449 2381614) (|UnivariatePowerSeriesCategory&| NIL 2376308 2376361 2378665 2378670) (|UnivariatePolynomialCategory| "bookvol10.2.pamphlet" 2370547 2370583 2376026 2376303) (|UnivariatePolynomialCategory&| NIL 2364741 2364780 2370223 2370228) (|UnivariatePolynomialCategoryFunctions2| "bookvol10.4.pamphlet" 2364171 2364225 2364731 2364736) (|UnivariatePolynomial| "bookvol10.3.pamphlet" 2360052 2360084 2360660 2360937) (|UnivariatePolynomialMultiplicationPackage| "bookvol10.4.pamphlet" 2358948 2358999 2360042 2360047) (|UnivariatePolynomialDivisionPackage| "bookvol10.4.pamphlet" 2358481 2358527 2358938 2358943) (|UnivariatePolynomialDecompositionPackage| "bookvol10.4.pamphlet" 2356685 2356736 2358471 2358476) (|UnivariatePolynomialCommonDenominator| "bookvol10.4.pamphlet" 2355852 2355902 2356675 2356680) (|UnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 2355227 2355275 2355842 2355847) (|UniversalSegment| "bookvol10.3.pamphlet" 2354550 2354574 2355129 2355134) (|UniversalSegmentFunctions2| "bookvol10.4.pamphlet" 2354025 2354061 2354497 2354502) (|UnivariateFactorize| "bookvol10.4.pamphlet" 2353132 2353160 2354015 2354020) (|UnivariateLaurentSeries| "bookvol10.3.pamphlet" 2340955 2341003 2341948 2342658) (|UnivariateLaurentSeriesConstructor| "bookvol10.3.pamphlet" 2333693 2333744 2334092 2334344) (|UnivariateLaurentSeriesConstructorCategory| "bookvol10.2.pamphlet" 2331141 2331200 2333407 2333688) (|UnivariateLaurentSeriesConstructorCategory&| NIL 2328825 2328887 2331094 2331099) (|UnivariateLaurentSeriesCategory| "bookvol10.2.pamphlet" 2326904 2326948 2328568 2328820) (|UnivariateLaurentSeriesFunctions2| "bookvol10.4.pamphlet" 2326418 2326501 2326894 2326899) (|UnivariateFormalPowerSeries| "bookvol10.3.pamphlet" 2324364 2324404 2324462 2324627) (|UnivariateFormalPowerSeriesFunctions| "bookvol10.4.pamphlet" 2324246 2324295 2324354 2324359) (|UniqueFactorizationDomain| "bookvol10.2.pamphlet" 2323250 2323281 2324129 2324241) (|UniqueFactorizationDomain&| NIL 2322358 2322392 2323240 2323245) (|UserDefinedVariableOrdering| "bookvol10.4.pamphlet" 2321145 2321178 2322348 2322353) (|UserDefinedPartialOrdering| "bookvol10.4.pamphlet" 2318640 2318674 2321093 2321098) (|U8Vector| "bookvol10.3.pamphlet" 2317685 2317699 2317893 2317945) (|U8Matrix| "bookvol10.3.pamphlet" 2316784 2316798 2317176 2317228) (|U32Vector| "bookvol10.3.pamphlet" 2315827 2315842 2316037 2316089) (|U32Matrix| "bookvol10.3.pamphlet" 2314923 2314938 2315318 2315370) (|U16Vector| "bookvol10.3.pamphlet" 2313966 2313981 2314176 2314228) (|U16Matrix| "bookvol10.3.pamphlet" 2313062 2313077 2313457 2313509) (|Type| "bookvol10.2.pamphlet" 2312983 2312993 2313042 2313057) (|TwoFactorize| "bookvol10.4.pamphlet" 2311638 2311658 2312973 2312978) (|Tuple| "bookvol10.3.pamphlet" 2310637 2310650 2311585 2311590) (|TubePlotTools| "bookvol10.4.pamphlet" 2307521 2307540 2310627 2310632) (|TubePlot| "bookvol10.3.pamphlet" 2306206 2306228 2307511 2307516) (|TaylorSeries| "bookvol10.3.pamphlet" 2304618 2304643 2305601 2305766) (|TriangularSetCategory| "bookvol10.2.pamphlet" 2294131 2294166 2304549 2304613) (|TriangularSetCategory&| NIL 2283662 2283700 2294083 2294088) (|TranscendentalManipulations| "bookvol10.4.pamphlet" 2278038 2278075 2283308 2283313) (|TriangularMatrixOperations| "bookvol10.4.pamphlet" 2276986 2277034 2278028 2278033) (|TrigonometricManipulations| "bookvol10.4.pamphlet" 2275464 2275500 2276976 2276981) (|TrigonometricFunctionCategory| "bookvol10.2.pamphlet" 2274950 2274985 2275454 2275459) (|TrigonometricFunctionCategory&| NIL 2274433 2274471 2274940 2274945) (|Tree| "bookvol10.3.pamphlet" 2272598 2272610 2274216 2274268) (|TranscendentalFunctionCategory| "bookvol10.2.pamphlet" 2272418 2272454 2272588 2272593) (|TranscendentalFunctionCategory&| NIL 2272235 2272274 2272408 2272413) (|TopLevelThreeSpace| "bookvol10.4.pamphlet" 2271898 2271922 2272225 2272230) (|ToolsForSign| "bookvol10.4.pamphlet" 2271552 2271572 2271888 2271893) (|TextFile| "bookvol10.3.pamphlet" 2270126 2270140 2271542 2271547) (|TexFormat| "bookvol10.3.pamphlet" 2267257 2267272 2270116 2270121) (|TexFormat1| "bookvol10.4.pamphlet" 2266806 2266824 2267247 2267252) (|TemplateUtilities| "bookvol10.4.pamphlet" 2266353 2266376 2266796 2266801) (|TabulatedComputationPackage| "bookvol10.4.pamphlet" 2264520 2264567 2266343 2266348) (|TableAggregate| "bookvol10.2.pamphlet" 2263518 2263552 2264475 2264515) (|TableAggregate&| NIL 2262548 2262585 2263508 2263513) (|TangentExpansions| "bookvol10.4.pamphlet" 2261910 2261935 2262538 2262543) (|Table| "bookvol10.3.pamphlet" 2260725 2260750 2260997 2261049) (|Tableau| "bookvol10.3.pamphlet" 2260211 2260226 2260715 2260720) (|TableauxBumpers| "bookvol10.4.pamphlet" 2257117 2257140 2260201 2260206) (|SystemSolvePackage| "bookvol10.4.pamphlet" 2253733 2253759 2257107 2257112) (|SymbolTable| "bookvol10.3.pamphlet" 2251822 2251839 2253723 2253728) (|TheSymbolTable| "bookvol10.3.pamphlet" 2247876 2247896 2251812 2251817) (|SymmetricPolynomial| "bookvol10.3.pamphlet" 2246522 2246549 2246620 2246854) (|SymmetricFunctions| "bookvol10.4.pamphlet" 2245928 2245954 2246512 2246517) (|Symbol| "bookvol10.3.pamphlet" 2243387 2243399 2245918 2245923) (|Switch| "bookvol10.3.pamphlet" 2240130 2240142 2243377 2243382) (|SparseUnivariateTaylorSeries| "bookvol10.3.pamphlet" 2236713 2236766 2238174 2238339) (|SparseUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 2233351 2233405 2234375 2234627) (|SparseUnivariatePolynomial| "bookvol10.3.pamphlet" 2228962 2228996 2229840 2230117) (|SupFractionFactorizer| "bookvol10.4.pamphlet" 2228064 2228100 2228952 2228957) (|SparseUnivariatePolynomialExpressions| "bookvol10.3.pamphlet" 2224386 2224431 2224489 2224766) (|SparseUnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 2223747 2223793 2224376 2224381) (|RationalFunctionSum| "bookvol10.4.pamphlet" 2222333 2222360 2223737 2223742) (|FunctionSpaceSum| "bookvol10.4.pamphlet" 2222002 2222028 2222323 2222328) (|SparseUnivariateLaurentSeries| "bookvol10.3.pamphlet" 2209434 2209488 2210446 2211180) (|SuchThat| "bookvol10.3.pamphlet" 2209111 2209131 2209424 2209429) (|SubSpace| "bookvol10.3.pamphlet" 2201461 2201481 2209101 2209106) (|SubResultantPackage| "bookvol10.4.pamphlet" 2200604 2200634 2201404 2201409) (|StreamTranscendentalFunctions| "bookvol10.4.pamphlet" 2196679 2196721 2200594 2200599) (|StreamTranscendentalFunctionsNonCommutative| "bookvol10.4.pamphlet" 2193109 2193165 2196669 2196674) (|StreamTaylorSeriesOperations| "bookvol10.4.pamphlet" 2185636 2185672 2192970 2192975) (|StringTable| "bookvol10.3.pamphlet" 2184530 2184555 2184687 2184739) (|String| "bookvol10.3.pamphlet" 2183715 2183727 2183816 2183868) (|StringCategory| "bookvol10.2.pamphlet" 2183455 2183475 2183646 2183710) (|Stream| "bookvol10.3.pamphlet" 2178974 2178988 2183137 2183165) (|StreamFunctions3| "bookvol10.4.pamphlet" 2178302 2178330 2178964 2178969) (|StreamFunctions2| "bookvol10.4.pamphlet" 2176862 2176888 2178292 2178297) (|StreamFunctions1| "bookvol10.4.pamphlet" 2176357 2176381 2176852 2176857) (|StreamTensor| "bookvol10.4.pamphlet" 2176033 2176053 2176347 2176352) (|StreamInfiniteProduct| "bookvol10.4.pamphlet" 2174951 2174985 2176023 2176028) (|StepThrough| "bookvol10.2.pamphlet" 2174169 2174186 2174941 2174946) (|SparseTable| "bookvol10.3.pamphlet" 2173107 2173143 2173280 2173308) (|StreamAggregate| "bookvol10.2.pamphlet" 2172194 2172217 2173087 2173102) (|StreamAggregate&| NIL 2171288 2171314 2172184 2172189) (|Stack| "bookvol10.3.pamphlet" 2167276 2167289 2171071 2171123) (|SquareFreeRegularTriangularSet| "bookvol10.3.pamphlet" 2165415 2165459 2166897 2166949) (|SquareFreeRegularSetDecompositionPackage| "bookvol10.4.pamphlet" 2164144 2164201 2165405 2165410) (|StringAggregate| "bookvol10.2.pamphlet" 2159444 2159465 2164075 2164139) (|StringAggregate&| NIL 2154800 2154824 2159434 2159439) (|SquareMatrix| "bookvol10.3.pamphlet" 2152064 2152091 2152979 2153121) (|SplittingTree| "bookvol10.3.pamphlet" 2147474 2147497 2151728 2151780) (|SplittingNode| "bookvol10.3.pamphlet" 2144512 2144535 2147464 2147469) (|SpecialFunctionCategory| "bookvol10.2.pamphlet" 2143303 2143332 2144502 2144507) (|SpecialOutputPackage| "bookvol10.4.pamphlet" 2141855 2141881 2143293 2143298) (|ThreeSpaceCategory| "bookvol10.2.pamphlet" 2126230 2126256 2141845 2141850) (|ThreeSpace| "bookvol10.3.pamphlet" 2126005 2126023 2126220 2126225) (|SortPackage| "bookvol10.4.pamphlet" 2125538 2125559 2125953 2125958) (|TransSolvePackage| "bookvol10.4.pamphlet" 2123119 2123144 2125528 2125533) (|TransSolvePackageService| "bookvol10.4.pamphlet" 2121687 2121719 2123109 2123114) (|RadicalSolvePackage| "bookvol10.4.pamphlet" 2116159 2116186 2121677 2121682) (|PolynomialSolveByFormulas| "bookvol10.4.pamphlet" 2114605 2114641 2116149 2116154) (|SquareFreeNormalizedTriangularSetCategory| "bookvol10.2.pamphlet" 2114313 2114368 2114536 2114600) (|SparseMultivariateTaylorSeries| "bookvol10.3.pamphlet" 2112270 2112323 2113708 2113873) (|SparseMultivariatePolynomial| "bookvol10.3.pamphlet" 2108802 2108847 2109200 2109434) (|SmithNormalForm| "bookvol10.4.pamphlet" 2107627 2107664 2108792 2108797) (|SquareMatrixCategory| "bookvol10.2.pamphlet" 2105682 2105729 2107523 2107622) (|SquareMatrixCategory&| NIL 2103692 2103742 2105536 2105541) (|StackAggregate| "bookvol10.2.pamphlet" 2102258 2102280 2103623 2103687) (|SingleInteger| "bookvol10.3.pamphlet" 2100506 2100525 2102019 2102253) (|SimplifyAlgebraicNumberConvertPackage| "bookvol10.4.pamphlet" 2100215 2100258 2100496 2100501) (|RationalFunctionSign| "bookvol10.4.pamphlet" 2099288 2099316 2100205 2100210) (|ElementaryFunctionSign| "bookvol10.4.pamphlet" 2098532 2098564 2099278 2099283) (|SturmHabichtPackage| "bookvol10.4.pamphlet" 2096473 2096504 2098481 2098486) (|SplitHomogeneousDirectProduct| "bookvol10.3.pamphlet" 2086109 2086162 2086637 2086841) (|SemiGroup| "bookvol10.2.pamphlet" 2085415 2085430 2086099 2086104) (|SemiGroup&| NIL 2084718 2084736 2085405 2085410) (|SymmetricGroupCombinatoricFunctions| "bookvol10.4.pamphlet" 2078198 2078239 2084708 2084713) (|SquareFreeRegularTriangularSetCategory| "bookvol10.2.pamphlet" 2077701 2077753 2078129 2078193) (|SquareFreeRegularTriangularSetGcdPackage| "bookvol10.4.pamphlet" 2077363 2077420 2077691 2077696) (|SquareFreeQuasiComponentPackage| "bookvol10.4.pamphlet" 2073252 2073300 2077353 2077358) (|SimpleFortranProgram| "bookvol10.3.pamphlet" 2072696 2072727 2073242 2073247) (|SExpressionOf| "bookvol10.3.pamphlet" 2072529 2072579 2072686 2072691) (|SExpression| "bookvol10.3.pamphlet" 2072413 2072430 2072519 2072524) (|SExpressionCategory| "bookvol10.2.pamphlet" 2069648 2069704 2072403 2072408) (|Set| "bookvol10.3.pamphlet" 2067898 2067909 2069011 2069091) (|SetOfMIntegersInOneToN| "bookvol10.3.pamphlet" 2066359 2066395 2067888 2067893) (|SetCategory| "bookvol10.2.pamphlet" 2065841 2065858 2066349 2066354) (|SetCategory&| NIL 2065320 2065340 2065831 2065836) (|SetCategoryWithDegree| "bookvol10.2.pamphlet" 2065193 2065220 2065310 2065315) (|SetAggregate| "bookvol10.2.pamphlet" 2062058 2062078 2065145 2065188) (|SetAggregate&| NIL 2058958 2058981 2062048 2062053) (|SegmentExpansionCategory| "bookvol10.2.pamphlet" 2057999 2058033 2058938 2058953) (|Segment| "bookvol10.3.pamphlet" 2057791 2057806 2057901 2057906) (|SegmentCategory| "bookvol10.2.pamphlet" 2056567 2056590 2057771 2057786) (|SegmentBinding| "bookvol10.3.pamphlet" 2055634 2055656 2056514 2056519) (|SegmentBindingFunctions2| "bookvol10.4.pamphlet" 2055319 2055353 2055624 2055629) (|SegmentFunctions2| "bookvol10.4.pamphlet" 2054715 2054742 2055266 2055271) (|SequentialDifferentialVariable| "bookvol10.3.pamphlet" 2053986 2054024 2054705 2054710) (|SequentialDifferentialPolynomial| "bookvol10.3.pamphlet" 2050274 2050314 2050580 2050814) (|StochasticDifferential| "bookvol10.3.pamphlet" 2046709 2046739 2050225 2050269) (|StructuralConstantsPackage| "bookvol10.4.pamphlet" 2044789 2044823 2046699 2046704) (|SimpleCell| "bookvol10.3.pamphlet" 2044737 2044774 2044779 2044784) (|SortedCache| "bookvol10.4.pamphlet" 2043578 2043597 2044727 2044732) (|SingletonAsOrderedSet| "bookvol10.3.pamphlet" 2043432 2043459 2043568 2043573) (|SAERationalFunctionAlgFactor| "bookvol10.4.pamphlet" 2043120 2043165 2043422 2043427) (|SimpleAlgebraicExtension| "bookvol10.3.pamphlet" 2040847 2040884 2041525 2041741) (|SimpleAlgebraicExtensionAlgFactor| "bookvol10.4.pamphlet" 2040518 2040568 2040837 2040842) (|RationalUnivariateRepresentationPackage| "bookvol10.4.pamphlet" 2038218 2038270 2040508 2040513) (|Ruleset| "bookvol10.3.pamphlet" 2037650 2037674 2038208 2038213) (|RewriteRule| "bookvol10.3.pamphlet" 2035828 2035856 2037640 2037645) (|RuleCalled| "bookvol10.3.pamphlet" 2035673 2035693 2035818 2035823) (|RegularTriangularSetGcdPackage| "bookvol10.4.pamphlet" 2033016 2033063 2035663 2035668) (|RegularTriangularSetCategory| "bookvol10.2.pamphlet" 2023804 2023846 2032947 2033011) (|RegularTriangularSetCategory&| NIL 2014648 2014693 2023794 2023799) (|RegularSetDecompositionPackage| "bookvol10.4.pamphlet" 2013374 2013421 2014638 2014643) (|RealRootCharacterizationCategory| "bookvol10.2.pamphlet" 2011751 2011810 2013364 2013369) (|RealRootCharacterizationCategory&| NIL 2010125 2010187 2011741 2011746) (|RecursivePolynomialCategory| "bookvol10.2.pamphlet" 1993236 1993275 2009886 2010120) (|RecursivePolynomialCategory&| NIL 1976050 1976092 1992703 1992708) (|RoutinesTable| "bookvol10.3.pamphlet" 1972326 1972345 1975080 1975132) (|RomanNumeral| "bookvol10.3.pamphlet" 1971459 1971477 1972087 1972321) (|RightOpenIntervalRootCharacterization| "bookvol10.3.pamphlet" 1970559 1970625 1971449 1971454) (|RealNumberSystem| "bookvol10.2.pamphlet" 1969297 1969319 1970389 1970554) (|RealNumberSystem&| NIL 1968192 1968217 1969287 1969292) (|Rng| "bookvol10.2.pamphlet" 1967712 1967721 1968182 1968187) (|RightModule| "bookvol10.2.pamphlet" 1967219 1967238 1967702 1967707) (|RectangularMatrixCategoryFunctions2| "bookvol10.4.pamphlet" 1966615 1966704 1967209 1967214) (|RectangularMatrix| "bookvol10.3.pamphlet" 1965174 1965207 1965676 1965744) (|RectangularMatrixCategory| "bookvol10.2.pamphlet" 1960759 1960812 1965089 1965169) (|RectangularMatrixCategory&| NIL 1956233 1956289 1960566 1960571) (|RationalInterpolation| "bookvol10.4.pamphlet" 1956107 1956141 1956223 1956228) (|Ring| "bookvol10.2.pamphlet" 1955458 1955468 1956080 1956102) (|Ring&| NIL 1954823 1954836 1955448 1955453) (|RandomIntegerDistributions| "bookvol10.4.pamphlet" 1953828 1953860 1954813 1954818) (|RegularChain| "bookvol10.3.pamphlet" 1952170 1952195 1953060 1953112) (|RootsFindingPackage| "bookvol10.4.pamphlet" 1950204 1950231 1952160 1952165) (|RationalFunction| "bookvol10.4.pamphlet" 1947847 1947871 1950194 1950199) (|RationalFunctionFactorizer| "bookvol10.4.pamphlet" 1947286 1947320 1947837 1947842) (|RationalFunctionFactor| "bookvol10.4.pamphlet" 1947002 1947033 1947276 1947281) (|RandomFloatDistributions| "bookvol10.4.pamphlet" 1945977 1946007 1946992 1946997) (|RetractSolvePackage| "bookvol10.4.pamphlet" 1945380 1945409 1945967 1945972) (|RetractableTo| "bookvol10.2.pamphlet" 1944712 1944733 1945370 1945375) (|RetractableTo&| NIL 1944041 1944065 1944702 1944707) (|Result| "bookvol10.3.pamphlet" 1942483 1942495 1943071 1943123) (|ResidueRing| "bookvol10.3.pamphlet" 1941794 1941845 1942389 1942478) (|ResolveLatticeCompletion| "bookvol10.4.pamphlet" 1941099 1941131 1941784 1941789) (|RepeatedSquaring| "bookvol10.4.pamphlet" 1940817 1940841 1941089 1941094) (|RadicalEigenPackage| "bookvol10.4.pamphlet" 1938357 1938382 1940807 1940812) (|RepeatedDoubling| "bookvol10.4.pamphlet" 1938043 1938067 1938347 1938352) (|RepresentationPackage2| "bookvol10.4.pamphlet" 1928021 1928051 1937862 1937867) (|RepresentationPackage1| "bookvol10.4.pamphlet" 1922382 1922412 1927963 1927968) (|RegularTriangularSet| "bookvol10.3.pamphlet" 1920579 1920613 1922003 1922055) (|Reference| "bookvol10.3.pamphlet" 1919915 1919932 1920526 1920531) (|ReductionOfOrder| "bookvol10.4.pamphlet" 1919036 1919062 1919905 1919910) (|RecurrenceOperator| "bookvol10.4.pamphlet" 1917431 1917459 1918990 1918995) (|RealClosure| "bookvol10.3.pamphlet" 1916052 1916080 1916714 1916879) (|RealSolvePackage| "bookvol10.4.pamphlet" 1914612 1914634 1916042 1916047) (|RealConstant| "bookvol10.2.pamphlet" 1914487 1914505 1914602 1914607) (|RealZeroPackageQ| "bookvol10.4.pamphlet" 1911825 1911853 1914477 1914482) (|RealZeroPackage| "bookvol10.4.pamphlet" 1908722 1908749 1911815 1911820) (|ReducedDivisor| "bookvol10.4.pamphlet" 1908460 1908496 1908712 1908717) (|RandomDistributions| "bookvol10.4.pamphlet" 1908011 1908038 1908450 1908455) (|TranscendentalRischDESystem| "bookvol10.4.pamphlet" 1906845 1906883 1908001 1908006) (|TranscendentalRischDE| "bookvol10.4.pamphlet" 1904796 1904828 1906835 1906840) (|ElementaryRischDESystem| "bookvol10.4.pamphlet" 1904021 1904054 1904786 1904791) (|ElementaryRischDE| "bookvol10.4.pamphlet" 1903067 1903094 1904011 1904016) (|RealClosedField| "bookvol10.2.pamphlet" 1900312 1900333 1902897 1903062) (|RealClosedField&| NIL 1897714 1897738 1900302 1900307) (|RecursiveAggregate| "bookvol10.2.pamphlet" 1895672 1895698 1897694 1897709) (|RecursiveAggregate&| NIL 1893545 1893574 1895570 1895575) (|RationalRetractions| "bookvol10.4.pamphlet" 1892950 1892977 1893535 1893540) (|RationalFactorize| "bookvol10.4.pamphlet" 1892120 1892146 1892940 1892945) (|RandomNumberSource| "bookvol10.4.pamphlet" 1891462 1891486 1892110 1892115) (|RadixUtilities| "bookvol10.4.pamphlet" 1891207 1891227 1891452 1891457) (|RadixExpansion| "bookvol10.3.pamphlet" 1887298 1887323 1888961 1889126) (|RadicalFunctionField| "bookvol10.3.pamphlet" 1885170 1885220 1885286 1885541) (|RadicalCategory| "bookvol10.2.pamphlet" 1884789 1884810 1885160 1885165) (|RadicalCategory&| NIL 1884405 1884429 1884779 1884784) (|Queue| "bookvol10.3.pamphlet" 1880173 1880186 1884188 1884240) (|Quaternion| "bookvol10.3.pamphlet" 1878496 1878514 1878797 1878905) (|QuaternionCategoryFunctions2| "bookvol10.4.pamphlet" 1877875 1877919 1878486 1878491) (|QuaternionCategory| "bookvol10.2.pamphlet" 1876023 1876049 1877762 1877870) (|QuaternionCategory&| NIL 1873862 1873891 1875604 1875609) (|QueueAggregate| "bookvol10.2.pamphlet" 1872639 1872661 1873793 1873857) (|QuadraticForm| "bookvol10.3.pamphlet" 1872097 1872122 1872629 1872634) (|QuotientFieldCategory| "bookvol10.2.pamphlet" 1870701 1870730 1871915 1872092) (|QuotientFieldCategory&| NIL 1868795 1868827 1870012 1870017) (|QuotientFieldCategoryFunctions2| "bookvol10.4.pamphlet" 1868467 1868512 1868785 1868790) (|QueryEquation| "bookvol10.3.pamphlet" 1868031 1868050 1868457 1868462) (|QuasiComponentPackage| "bookvol10.4.pamphlet" 1863996 1864034 1868021 1868026) (|QuasiAlgebraicSet| "bookvol10.3.pamphlet" 1860125 1860172 1863881 1863886) (|QuasiAlgebraicSet2| "bookvol10.4.pamphlet" 1858121 1858155 1860115 1860120) (|PAdicWildFunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 1855420 1855470 1858111 1858116) (|PushVariables| "bookvol10.4.pamphlet" 1854746 1854776 1855410 1855415) (|PartialTranscendentalFunctions| "bookvol10.2.pamphlet" 1850997 1851035 1854736 1854741) (|PointPackage| "bookvol10.4.pamphlet" 1848113 1848133 1850987 1850992) (|PointFunctions2| "bookvol10.4.pamphlet" 1847919 1847946 1848103 1848108) (|PointCategory| "bookvol10.2.pamphlet" 1846975 1846996 1847850 1847914) (|PolynomialSquareFree| "bookvol10.4.pamphlet" 1846268 1846310 1846965 1846970) (|PseudoLinearNormalForm| "bookvol10.4.pamphlet" 1845118 1845148 1846258 1846263) (|PolynomialSetUtilitiesPackage| "bookvol10.4.pamphlet" 1832564 1832607 1844960 1844965) (|PolynomialSetCategory| "bookvol10.2.pamphlet" 1827388 1827430 1832520 1832559) (|PolynomialSetCategory&| NIL 1822197 1822242 1827332 1827337) (|PlottableSpaceCurveCategory| "bookvol10.2.pamphlet" 1821197 1821230 1822187 1822192) (|PowerSeriesCategory| "bookvol10.2.pamphlet" 1819875 1819921 1821027 1821192) (|PowerSeriesCategory&| NIL 1818710 1818759 1819865 1819870) (|Partition| "bookvol10.3.pamphlet" 1817506 1817521 1818700 1818705) (|ProjectiveSpaceCategory| "bookvol10.2.pamphlet" 1814980 1815011 1817496 1817501) (|PseudoRemainderSequence| "bookvol10.4.pamphlet" 1806621 1806659 1814929 1814934) (|PriorityQueueAggregate| "bookvol10.2.pamphlet" 1805999 1806029 1806552 1806616) (|ProjectiveSpace| "bookvol10.3.pamphlet" 1805870 1805899 1805989 1805994) (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1805708 1805770 1805860 1805865) (|ProjectivePlane| "bookvol10.3.pamphlet" 1805585 1805608 1805698 1805703) (|Product| "bookvol10.3.pamphlet" 1802385 1802402 1802917 1802985) (|PolynomialRing| "bookvol10.3.pamphlet" 1800433 1800457 1801138 1801372) (|ProjectiveAlgebraicSetPackage| "bookvol10.4.pamphlet" 1799660 1799726 1800423 1800428) (|PrintPackage| "bookvol10.4.pamphlet" 1799402 1799420 1799650 1799655) (|IntegerPrimesPackage| "bookvol10.4.pamphlet" 1797617 1797645 1799392 1799397) (|PrimitiveElement| "bookvol10.4.pamphlet" 1795694 1795718 1797607 1797612) (|PrimitiveFunctionCategory| "bookvol10.2.pamphlet" 1795282 1795313 1795684 1795689) (|PrimitiveArray| "bookvol10.3.pamphlet" 1794399 1794421 1794564 1794616) (|PrimitiveArrayFunctions2| "bookvol10.4.pamphlet" 1792483 1792517 1794389 1794394) (|PrecomputedAssociatedEquations| "bookvol10.4.pamphlet" 1791821 1791861 1792473 1792478) (|PlottablePlaneCurveCategory| "bookvol10.2.pamphlet" 1791161 1791194 1791811 1791816) (|U32VectorPolynomialOperations| "bookvol10.4.pamphlet" 1785943 1785978 1791151 1791156) (|PolynomialRoots| "bookvol10.4.pamphlet" 1784671 1784702 1785892 1785897) (|Polynomial| "bookvol10.3.pamphlet" 1781067 1781085 1781571 1781805) (|PolynomialCategoryLifting| "bookvol10.4.pamphlet" 1780333 1780379 1781057 1781062) (|PolynomialCategoryQuotientFunctions| "bookvol10.4.pamphlet" 1778314 1778365 1780323 1780328) (|PolynomialCategory| "bookvol10.2.pamphlet" 1771621 1771658 1778075 1778309) (|PolynomialCategory&| NIL 1764075 1764115 1770532 1770537) (|PolynomialToUnivariatePolynomial| "bookvol10.4.pamphlet" 1763491 1763535 1764065 1764070) (|PolynomialFunctions2| "bookvol10.4.pamphlet" 1763079 1763109 1763481 1763486) (|RealPolynomialUtilitiesPackage| "bookvol10.4.pamphlet" 1762083 1762140 1763026 1763031) (|PolToPol| "bookvol10.4.pamphlet" 1760825 1760846 1762073 1762078) (|Point| "bookvol10.3.pamphlet" 1759703 1759716 1759793 1759845) (|PolynomialNumberTheoryFunctions| "bookvol10.4.pamphlet" 1756346 1756383 1759693 1759698) (|PatternMatchTools| "bookvol10.4.pamphlet" 1755152 1755181 1756336 1756341) (|PatternMatchSymbol| "bookvol10.4.pamphlet" 1754693 1754719 1755142 1755147) (|PatternMatchQuotientFieldCategory| "bookvol10.4.pamphlet" 1754261 1754306 1754683 1754688) (|AttachPredicates| "bookvol10.4.pamphlet" 1753771 1753795 1754251 1754256) (|FunctionSpaceAttachPredicates| "bookvol10.4.pamphlet" 1753247 1753288 1753761 1753766) (|PatternMatchPolynomialCategory| "bookvol10.4.pamphlet" 1752285 1752331 1753165 1753170) (|PatternMatchListAggregate| "bookvol10.4.pamphlet" 1751847 1751884 1752275 1752280) (|PatternMatchKernel| "bookvol10.4.pamphlet" 1751410 1751438 1751837 1751842) (|PatternMatchIntegerNumberSystem| "bookvol10.4.pamphlet" 1750961 1751000 1751400 1751405) (|PatternMatchFunctionSpace| "bookvol10.4.pamphlet" 1750527 1750564 1750951 1750956) (|PatternMatchPushDown| "bookvol10.4.pamphlet" 1749819 1749851 1750517 1750522) (|PatternMatchAssertions| "bookvol10.4.pamphlet" 1748866 1748894 1749809 1749814) (|FunctionSpaceAssertions| "bookvol10.4.pamphlet" 1747873 1747906 1748856 1748861) (|PolynomialPackageForCurve| "bookvol10.4.pamphlet" 1746748 1746809 1747863 1747868) (|PlotTools| "bookvol10.4.pamphlet" 1746521 1746536 1746738 1746743) (|Plot| "bookvol10.3.pamphlet" 1741371 1741381 1746511 1746516) (|Plot3D| "bookvol10.3.pamphlet" 1737981 1737993 1741361 1741366) (|PlotFunctions1| "bookvol10.4.pamphlet" 1737120 1737142 1737971 1737976) (|ParametricLinearEquations| "bookvol10.4.pamphlet" 1723210 1723260 1737110 1737115) (|Plcs| "bookvol10.3.pamphlet" 1723115 1723131 1723200 1723205) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1722983 1723036 1723105 1723110) (|Places| "bookvol10.3.pamphlet" 1722890 1722904 1722973 1722978) (|PlacesCategory| "bookvol10.2.pamphlet" 1721920 1721946 1722880 1722885) (|PolynomialInterpolation| "bookvol10.4.pamphlet" 1721525 1721561 1721910 1721915) (|PolynomialInterpolationAlgorithms| "bookvol10.4.pamphlet" 1721282 1721325 1721515 1721520) (|PositiveInteger| "bookvol10.3.pamphlet" 1720885 1720906 1721248 1721277) (|PrincipalIdealDomain| "bookvol10.2.pamphlet" 1719804 1719830 1720768 1720880) (|PiCoercions| "bookvol10.4.pamphlet" 1719540 1719559 1719794 1719799) (|PolyGroebner| "bookvol10.4.pamphlet" 1718152 1718172 1719530 1719535) (|PermutationGroupExamples| "bookvol10.4.pamphlet" 1710088 1710118 1718142 1718147) (|PolynomialGcdPackage| "bookvol10.4.pamphlet" 1708551 1708586 1710078 1710083) (|PartialFractionPackage| "bookvol10.4.pamphlet" 1707582 1707612 1708541 1708546) (|PartialFraction| "bookvol10.3.pamphlet" 1703067 1703090 1707412 1707577) (|PointsOfFiniteOrderTools| "bookvol10.4.pamphlet" 1702392 1702430 1703057 1703062) (|PackageForPoly| "bookvol10.4.pamphlet" 1700521 1700562 1702382 1702387) (|PointsOfFiniteOrderRational| "bookvol10.4.pamphlet" 1699866 1699909 1700511 1700516) (|PointsOfFiniteOrder| "bookvol10.4.pamphlet" 1699274 1699314 1699856 1699861) (|PrimeField| "bookvol10.3.pamphlet" 1698830 1698850 1698968 1699133) (|PolynomialFactorizationExplicit| "bookvol10.2.pamphlet" 1696466 1696503 1698713 1698825) (|PolynomialFactorizationExplicit&| NIL 1694153 1694193 1696403 1696408) (|PolynomialFactorizationByRecursionUnivariate| "bookvol10.4.pamphlet" 1692018 1692072 1694143 1694148) (|PolynomialFactorizationByRecursion| "bookvol10.4.pamphlet" 1689646 1689701 1692008 1692013) (|Permutation| "bookvol10.3.pamphlet" 1684931 1684950 1689448 1689470) (|PermutationGroup| "bookvol10.3.pamphlet" 1679682 1679706 1684921 1684926) (|PermutationCategory| "bookvol10.2.pamphlet" 1678321 1678348 1679655 1679677) (|Permanent| "bookvol10.4.pamphlet" 1677073 1677094 1678311 1678316) (|PendantTree| "bookvol10.3.pamphlet" 1676314 1676333 1676903 1676908) (|PartialDifferentialRing| "bookvol10.2.pamphlet" 1674661 1674692 1676287 1676309) (|PartialDifferentialRing&| NIL 1673022 1673056 1674651 1674656) (|NumericalPDEProblem| "bookvol10.3.pamphlet" 1671184 1671209 1673012 1673017) (|AnnaPartialDifferentialEquationPackage| "bookvol10.4.pamphlet" 1665224 1665268 1671174 1671179) (|PolynomialDecomposition| "bookvol10.4.pamphlet" 1664559 1664593 1665214 1665219) (|PartialDifferentialEquationsSolverCategory| "bookvol10.2.pamphlet" 1662669 1662717 1664549 1664554) (|PolynomialComposition| "bookvol10.4.pamphlet" 1662385 1662417 1662659 1662664) (|PoincareBirkhoffWittLyndonBasis| "bookvol10.3.pamphlet" 1660998 1661044 1662375 1662380) (|Pattern| "bookvol10.3.pamphlet" 1655278 1655293 1660988 1660993) (|PatternFunctions2| "bookvol10.4.pamphlet" 1654994 1655021 1655268 1655273) (|PatternFunctions1| "bookvol10.4.pamphlet" 1653281 1653308 1654984 1654989) (|PatternMatchResult| "bookvol10.3.pamphlet" 1650926 1650954 1653271 1653276) (|PatternMatchResultFunctions2| "bookvol10.4.pamphlet" 1650612 1650652 1650916 1650921) (|PatternMatch| "bookvol10.4.pamphlet" 1648782 1648823 1650279 1650284) (|PatternMatchable| "bookvol10.2.pamphlet" 1648207 1648231 1648772 1648777) (|PatternMatchListResult| "bookvol10.3.pamphlet" 1647297 1647331 1648197 1648202) (|Patternable| "bookvol10.2.pamphlet" 1646994 1647013 1647287 1647292) (|PartitionsAndPermutations| "bookvol10.4.pamphlet" 1644489 1644520 1646984 1646989) (|ParametricSurface| "bookvol10.3.pamphlet" 1643932 1643975 1644479 1644484) (|ParametricSurfaceFunctions2| "bookvol10.4.pamphlet" 1643700 1643741 1643922 1643927) (|ParametricSpaceCurve| "bookvol10.3.pamphlet" 1643140 1643186 1643690 1643695) (|ParametricSpaceCurveFunctions2| "bookvol10.4.pamphlet" 1642899 1642943 1643130 1643135) (|ParametricPlaneCurve| "bookvol10.3.pamphlet" 1642351 1642397 1642889 1642894) (|ParametricPlaneCurveFunctions2| "bookvol10.4.pamphlet" 1642110 1642154 1642341 1642346) (|ParametrizationPackage| "bookvol10.4.pamphlet" 1640913 1640982 1642100 1642105) (|PolynomialAN2Expression| "bookvol10.4.pamphlet" 1640306 1640335 1640903 1640908) (|Palette| "bookvol10.3.pamphlet" 1639309 1639322 1640296 1640301) (|PackageForAlgebraicFunctionField| "bookvol10.4.pamphlet" 1633722 1633775 1639261 1639266) (|PackageForAlgebraicFunctionFieldOverFiniteField| "bookvol10.4.pamphlet" 1627521 1627589 1633634 1633639) (|PAdicRationalConstructor| "bookvol10.3.pamphlet" 1624317 1624357 1625468 1625633) (|PAdicRational| "bookvol10.3.pamphlet" 1621501 1621524 1621685 1621850) (|PAdicInteger| "bookvol10.3.pamphlet" 1621193 1621215 1621384 1621496) (|PAdicIntegerCategory| "bookvol10.2.pamphlet" 1619678 1619708 1621076 1621188) (|PadeApproximantPackage| "bookvol10.4.pamphlet" 1618603 1618642 1619668 1619673) (|PadeApproximants| "bookvol10.4.pamphlet" 1617594 1617624 1618593 1618598) (|PseudoAlgebraicClosureOfRationalNumber| "bookvol10.3.pamphlet" 1616207 1616251 1617079 1617244) (|PseudoAlgebraicClosureOfRationalNumberCategory| "bookvol10.2.pamphlet" 1615075 1615127 1616037 1616202) (|PseudoAlgebraicClosureOfPerfectFieldCategory| "bookvol10.2.pamphlet" 1613260 1613310 1614905 1615070) (|PseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1612075 1612118 1612945 1613110) (|PseudoAlgebraicClosureOfFiniteFieldCategory| "bookvol10.2.pamphlet" 1610949 1610998 1611905 1612070) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| "bookvol10.3.pamphlet" 1608964 1609028 1609859 1610024) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| "bookvol10.2.pamphlet" 1607816 1607876 1608794 1608959) (|OrdinaryWeightedPolynomials| "bookvol10.3.pamphlet" 1606733 1606788 1607608 1607725) (|OrderedVariableList| "bookvol10.3.pamphlet" 1606497 1606537 1606723 1606728) (|OutputPackage| "bookvol10.4.pamphlet" 1605612 1605631 1606487 1606492) (|OutputForm| "bookvol10.3.pamphlet" 1595018 1595034 1605602 1605607) (|OrdSetInts| "bookvol10.3.pamphlet" 1594615 1594631 1595008 1595013) (|OrthogonalPolynomialFunctions| "bookvol10.4.pamphlet" 1593028 1593065 1594515 1594520) (|UnivariateSkewPolynomial| "bookvol10.3.pamphlet" 1592259 1592311 1592613 1592676) (|SparseUnivariateSkewPolynomial| "bookvol10.3.pamphlet" 1591419 1591473 1591844 1591907) (|UnivariateSkewPolynomialCategoryOps| "bookvol10.4.pamphlet" 1589131 1589176 1591324 1591329) (|UnivariateSkewPolynomialCategory| "bookvol10.2.pamphlet" 1583089 1583129 1589063 1589126) (|UnivariateSkewPolynomialCategory&| NIL 1576925 1576968 1582902 1582907) (|OrderedSet| "bookvol10.2.pamphlet" 1576057 1576073 1576915 1576920) (|OrderedSet&| NIL 1575186 1575205 1576047 1576052) (|OrderedRing| "bookvol10.2.pamphlet" 1574504 1574521 1575159 1575181) (|OrderedRing&| NIL 1573836 1573856 1574494 1574499) (|OrderedMonoid| "bookvol10.2.pamphlet" 1573549 1573568 1573826 1573831) (|OrderingFunctions| "bookvol10.4.pamphlet" 1572681 1572712 1573539 1573544) (|OrderedFinite| "bookvol10.2.pamphlet" 1572604 1572623 1572671 1572676) (|OrderedCompletion| "bookvol10.3.pamphlet" 1570954 1570979 1572024 1572069) (|OrderedCompletionFunctions2| "bookvol10.4.pamphlet" 1570281 1570318 1570944 1570949) (|NumericalOptimizationProblem| "bookvol10.3.pamphlet" 1568021 1568055 1570271 1570276) (|AnnaNumericalOptimizationPackage| "bookvol10.4.pamphlet" 1560443 1560481 1568011 1568016) (|NumericalOptimizationCategory| "bookvol10.2.pamphlet" 1557894 1557929 1560433 1560438) (|OperationsQuery| "bookvol10.4.pamphlet" 1557436 1557457 1557884 1557889) (|Operator| "bookvol10.3.pamphlet" 1557074 1557090 1557160 1557277) (|OnePointCompletion| "bookvol10.3.pamphlet" 1555707 1555733 1556494 1556539) (|OnePointCompletionFunctions2| "bookvol10.4.pamphlet" 1555172 1555210 1555697 1555702) (|OpenMathServerPackage| "bookvol10.4.pamphlet" 1554203 1554230 1555162 1555167) (|OrderedMultisetAggregate| "bookvol10.2.pamphlet" 1553924 1553956 1554106 1554198) (|OpenMathPackage| "bookvol10.4.pamphlet" 1552587 1552608 1553914 1553919) (|OpenMath| "bookvol10.2.pamphlet" 1551656 1551670 1552577 1552582) (|OppositeMonogenicLinearOperator| "bookvol10.3.pamphlet" 1550993 1551034 1551491 1551554) (|ExpressionToOpenMath| "bookvol10.4.pamphlet" 1550809 1550837 1550983 1550988) (|OpenMathError| "bookvol10.3.pamphlet" 1550351 1550370 1550799 1550804) (|OpenMathErrorKind| "bookvol10.3.pamphlet" 1549388 1549411 1550341 1550346) (|OpenMathEncoding| "bookvol10.3.pamphlet" 1548720 1548742 1549378 1549383) (|OpenMathDevice| "bookvol10.3.pamphlet" 1543451 1543471 1548710 1548715) (|OpenMathConnection| "bookvol10.3.pamphlet" 1542852 1542876 1543441 1543446) (|OrderedIntegralDomain| "bookvol10.2.pamphlet" 1542567 1542594 1542735 1542847) (|OrderedFreeMonoid| "bookvol10.3.pamphlet" 1536179 1536204 1542557 1542562) (|OrderlyDifferentialVariable| "bookvol10.3.pamphlet" 1535437 1535472 1536169 1536174) (|OrdinaryDifferentialRing| "bookvol10.3.pamphlet" 1534776 1534824 1535162 1535395) (|OrderlyDifferentialPolynomial| "bookvol10.3.pamphlet" 1531032 1531069 1531385 1531619) (|OrderedDirectProduct| "bookvol10.3.pamphlet" 1520820 1520858 1521196 1521400) (|ODETools| "bookvol10.4.pamphlet" 1519343 1519364 1520810 1520815) (|SystemODESolver| "bookvol10.4.pamphlet" 1516794 1516820 1519333 1519338) (|RationalRicDE| "bookvol10.4.pamphlet" 1512693 1512717 1516728 1516733) (|ReduceLODE| "bookvol10.4.pamphlet" 1512050 1512078 1512683 1512688) (|RationalLODE| "bookvol10.4.pamphlet" 1509488 1509511 1512040 1512045) (|PrimitiveRatRicDE| "bookvol10.4.pamphlet" 1506492 1506525 1509478 1509483) (|NumericalODEProblem| "bookvol10.3.pamphlet" 1505131 1505156 1506482 1506487) (|PrimitiveRatDE| "bookvol10.4.pamphlet" 1502381 1502411 1505121 1505126) (|PureAlgebraicLODE| "bookvol10.4.pamphlet" 1501736 1501771 1502371 1502376) (|AnnaOrdinaryDifferentialEquationPackage| "bookvol10.4.pamphlet" 1489443 1489488 1501726 1501731) (|ODEIntegration| "bookvol10.4.pamphlet" 1488854 1488878 1489433 1489438) (|ODEIntensityFunctionsTable| "bookvol10.3.pamphlet" 1486233 1486265 1488844 1488849) (|ElementaryFunctionODESolver| "bookvol10.4.pamphlet" 1481529 1481566 1486223 1486228) (|ConstantLODE| "bookvol10.4.pamphlet" 1481032 1481056 1481519 1481524) (|OrdinaryDifferentialEquationsSolverCategory| "bookvol10.2.pamphlet" 1479382 1479431 1481022 1481027) (|Octonion| "bookvol10.3.pamphlet" 1477231 1477247 1477919 1477982) (|OctonionCategoryFunctions2| "bookvol10.4.pamphlet" 1476856 1476898 1477221 1477226) (|OctonionCategory| "bookvol10.2.pamphlet" 1474766 1474790 1476788 1476851) (|OctonionCategory&| NIL 1472326 1472353 1474351 1474356) (|OrderedCancellationAbelianMonoid| "bookvol10.2.pamphlet" 1472146 1472184 1472316 1472321) (|OrderedAbelianSemiGroup| "bookvol10.2.pamphlet" 1471891 1471920 1472136 1472141) (|OrderedAbelianMonoidSup| "bookvol10.2.pamphlet" 1471224 1471253 1471881 1471886) (|OrderedAbelianMonoid| "bookvol10.2.pamphlet" 1471069 1471095 1471214 1471219) (|OrderedAbelianGroup| "bookvol10.2.pamphlet" 1470916 1470941 1471059 1471064) (|NumericTubePlot| "bookvol10.4.pamphlet" 1470630 1470659 1470906 1470911) (|NumericalQuadrature| "bookvol10.4.pamphlet" 1459342 1459367 1470620 1470625) (|NumericalOrdinaryDifferentialEquations| "bookvol10.4.pamphlet" 1450873 1450917 1459332 1459337) (|NumericalIntegrationCategory| "bookvol10.2.pamphlet" 1448202 1448236 1450863 1450868) (|NumberFormats| "bookvol10.4.pamphlet" 1447033 1447052 1448192 1448197) (|Numeric| "bookvol10.4.pamphlet" 1439140 1439155 1446792 1446797) (|NormalizedTriangularSetCategory| "bookvol10.2.pamphlet" 1438493 1438538 1439071 1439135) (|NumberTheoreticPolynomialFunctions| "bookvol10.4.pamphlet" 1437995 1438037 1438393 1438398) (|NewSparseUnivariatePolynomial| "bookvol10.3.pamphlet" 1430808 1430845 1434484 1434761) (|NewSparseUnivariatePolynomialFunctions2| "bookvol10.4.pamphlet" 1430167 1430216 1430798 1430803) (|NewSparseMultivariatePolynomial| "bookvol10.3.pamphlet" 1425153 1425201 1425474 1425708) (|NeitherSparseOrDensePowerSeries| "bookvol10.3.pamphlet" 1423327 1423366 1423433 1423598) (|NumericRealEigenPackage| "bookvol10.4.pamphlet" 1421696 1421731 1423317 1423322) (|NewtonPolygon| "bookvol10.4.pamphlet" 1421577 1421617 1421686 1421691) (|NPCoef| "bookvol10.4.pamphlet" 1420821 1420845 1421567 1421572) (|NottinghamGroup| "bookvol10.3.pamphlet" 1420693 1420716 1420794 1420816) (|NormRetractPackage| "bookvol10.4.pamphlet" 1420275 1420326 1420683 1420688) (|NormalizationPackage| "bookvol10.4.pamphlet" 1419105 1419142 1420265 1420270) (|NormInMonogenicAlgebra| "bookvol10.4.pamphlet" 1418767 1418813 1419095 1419100) (|None| "bookvol10.3.pamphlet" 1418506 1418516 1418757 1418762) (|NoneFunctions1| "bookvol10.4.pamphlet" 1418170 1418192 1418496 1418501) (|NonLinearFirstOrderODESolver| "bookvol10.4.pamphlet" 1417605 1417643 1418160 1418165) (|NonNegativeInteger| "bookvol10.3.pamphlet" 1416471 1416495 1417571 1417600) (|NonLinearSolvePackage| "bookvol10.4.pamphlet" 1415078 1415107 1416461 1416466) (|NumericalIntegrationProblem| "bookvol10.3.pamphlet" 1412741 1412774 1415068 1415073) (|NumberFieldIntegralBasis| "bookvol10.4.pamphlet" 1410191 1410226 1412731 1412736) (|NewtonInterpolation| "bookvol10.4.pamphlet" 1409497 1409524 1410181 1410186) (|NonCommutativeOperatorDivision| "bookvol10.4.pamphlet" 1407613 1407653 1409487 1409492) (|NumericContinuedFraction| "bookvol10.4.pamphlet" 1407252 1407284 1407603 1407608) (|NumericComplexEigenPackage| "bookvol10.4.pamphlet" 1405406 1405444 1407242 1407247) (|NonAssociativeRing| "bookvol10.2.pamphlet" 1404988 1405012 1405396 1405401) (|NonAssociativeRing&| NIL 1404567 1404594 1404978 1404983) (|NonAssociativeRng| "bookvol10.2.pamphlet" 1403930 1403953 1404557 1404562) (|NonAssociativeRng&| NIL 1403290 1403316 1403920 1403925) (|NAGLinkSupportPackage| "bookvol10.4.pamphlet" 1402348 1402375 1403280 1403285) (|NagSpecialFunctionsPackage| "bookvol10.4.pamphlet" 1392766 1392798 1402338 1402343) (|NagLapack| "bookvol10.4.pamphlet" 1391259 1391274 1392756 1392761) (|NagLinearEquationSolvingPackage| "bookvol10.4.pamphlet" 1385694 1385731 1391249 1391254) (|NagEigenPackage| "bookvol10.4.pamphlet" 1379837 1379858 1385684 1385689) (|NagMatrixOperationsPackage| "bookvol10.4.pamphlet" 1375623 1375655 1379827 1379832) (|NagOptimisationPackage| "bookvol10.4.pamphlet" 1369397 1369425 1375613 1375618) (|NagFittingPackage| "bookvol10.4.pamphlet" 1360139 1360162 1369387 1369392) (|NagInterpolationPackage| "bookvol10.4.pamphlet" 1356209 1356238 1360129 1360134) (|NagPartialDifferentialEquationsPackage| "bookvol10.4.pamphlet" 1354212 1354256 1356199 1356204) (|NagOrdinaryDifferentialEquationsPackage| "bookvol10.4.pamphlet" 1346981 1347026 1354202 1354207) (|NagIntegrationPackage| "bookvol10.4.pamphlet" 1341506 1341533 1346971 1346976) (|NagSeriesSummationPackage| "bookvol10.4.pamphlet" 1337415 1337446 1341496 1341501) (|NagRootFindingPackage| "bookvol10.4.pamphlet" 1335942 1335969 1337405 1337410) (|NagPolynomialRootsPackage| "bookvol10.4.pamphlet" 1335249 1335280 1335932 1335937) (|NonAssociativeAlgebra| "bookvol10.2.pamphlet" 1334765 1334794 1335200 1335244) (|NonAssociativeAlgebra&| NIL 1334317 1334349 1334755 1334760) (|MyUnivariatePolynomial| "bookvol10.3.pamphlet" 1330463 1330497 1330806 1331083) (|MyExpression| "bookvol10.3.pamphlet" 1328013 1328037 1328095 1328462) (|MultivariateSquareFree| "bookvol10.4.pamphlet" 1324961 1324998 1328003 1328008) (|MultivariateFactorize| "bookvol10.4.pamphlet" 1324340 1324376 1324951 1324956) (|MultivariateTaylorSeriesCategory| "bookvol10.2.pamphlet" 1322272 1322323 1324170 1324335) (|MergeThing| "bookvol10.4.pamphlet" 1321923 1321941 1322262 1322267) (|MoreSystemCommands| "bookvol10.4.pamphlet" 1321365 1321389 1321913 1321918) (|Multiset| "bookvol10.3.pamphlet" 1319341 1319357 1321046 1321126) (|MultisetAggregate| "bookvol10.2.pamphlet" 1319130 1319155 1319268 1319336) (|MonoidRing| "bookvol10.3.pamphlet" 1316043 1316063 1318724 1318841) (|MonoidRingFunctions2| "bookvol10.4.pamphlet" 1315587 1315619 1316033 1316038) (|MRationalFactorize| "bookvol10.4.pamphlet" 1315132 1315165 1315577 1315582) (|MPolyCatRationalFunctionFactorizer| "bookvol10.4.pamphlet" 1313173 1313224 1315122 1315127) (|MultivariatePolynomial| "bookvol10.3.pamphlet" 1309621 1309656 1309983 1310217) (|MPolyCatPolyFactorizer| "bookvol10.4.pamphlet" 1308880 1308919 1309611 1309616) (|MPolyCatFunctions3| "bookvol10.4.pamphlet" 1308677 1308733 1308870 1308875) (|MPolyCatFunctions2| "bookvol10.4.pamphlet" 1308412 1308461 1308667 1308672) (|MonomialExtensionTools| "bookvol10.4.pamphlet" 1306767 1306800 1308402 1308407) (|Monoid| "bookvol10.2.pamphlet" 1305665 1305677 1306757 1306762) (|Monoid&| NIL 1304560 1304575 1305655 1305660) (|MonogenicAlgebra| "bookvol10.2.pamphlet" 1303193 1303220 1304339 1304555) (|MonogenicAlgebra&| NIL 1301904 1301934 1303053 1303058) (|MonadWithUnit| "bookvol10.2.pamphlet" 1300046 1300065 1301894 1301899) (|MonadWithUnit&| NIL 1298185 1298207 1300036 1300041) (|Monad| "bookvol10.2.pamphlet" 1297373 1297384 1298175 1298180) (|Monad&| NIL 1296558 1296572 1297363 1297368) (|MoebiusTransform| "bookvol10.3.pamphlet" 1295198 1295222 1296531 1296553) (|Module| "bookvol10.2.pamphlet" 1294890 1294904 1295149 1295193) (|Module&| NIL 1294618 1294635 1294880 1294885) (|ModularRing| "bookvol10.3.pamphlet" 1293913 1293969 1294591 1294613) (|ModuleOperator| "bookvol10.3.pamphlet" 1292423 1292447 1293637 1293754) (|ModuleMonomial| "bookvol10.3.pamphlet" 1291924 1291954 1292413 1292418) (|ModMonic| "bookvol10.3.pamphlet" 1287496 1287518 1288320 1288597) (|ModularField| "bookvol10.3.pamphlet" 1286773 1286830 1287326 1287491) (|MathMLFormat| "bookvol10.3.pamphlet" 1285568 1285586 1286763 1286768) (|MultipleMap| "bookvol10.4.pamphlet" 1285293 1285336 1285558 1285563) (|MonogenicLinearOperator| "bookvol10.2.pamphlet" 1283666 1283697 1285225 1285288) (|MultivariateLifting| "bookvol10.4.pamphlet" 1282265 1282299 1283656 1283661) (|MakeUnaryCompiledFunction| "bookvol10.4.pamphlet" 1281686 1281723 1282255 1282260) (|MakeRecord| "bookvol10.4.pamphlet" 1281270 1281291 1281676 1281681) (|MakeFunction| "bookvol10.4.pamphlet" 1280545 1280565 1281260 1281265) (|MakeFloatCompiledFunction| "bookvol10.4.pamphlet" 1279372 1279405 1280535 1280540) (|MakeCachableSet| "bookvol10.3.pamphlet" 1279137 1279160 1279362 1279367) (|MakeBinaryCompiledFunction| "bookvol10.4.pamphlet" 1278552 1278594 1279127 1279132) (|MachineInteger| "bookvol10.3.pamphlet" 1277900 1277920 1278375 1278547) (|ModularHermitianRowReduction| "bookvol10.4.pamphlet" 1276513 1276549 1277890 1277895) (|MachineFloat| "bookvol10.3.pamphlet" 1274871 1274889 1276323 1276508) (|MultFiniteFactorize| "bookvol10.4.pamphlet" 1274258 1274293 1274861 1274866) (|MeshCreationRoutinesForThreeDimensions| "bookvol10.4.pamphlet" 1272134 1272178 1274248 1274253) (|ModularDistinctDegreeFactorizer| "bookvol10.4.pamphlet" 1270358 1270397 1272124 1272129) (|MultiDictionary| "bookvol10.2.pamphlet" 1269613 1269636 1270313 1270353) (|MachineComplex| "bookvol10.3.pamphlet" 1263526 1263546 1264152 1264557) (|MatrixCommonDenominator| "bookvol10.4.pamphlet" 1262707 1262740 1263516 1263521) (|MultiVariableCalculusFunctions| "bookvol10.4.pamphlet" 1259943 1259993 1262697 1262702) (|StorageEfficientMatrixOperations| "bookvol10.4.pamphlet" 1257193 1257233 1259933 1259938) (|Matrix| "bookvol10.3.pamphlet" 1255948 1255962 1256434 1256486) (|MatrixLinearAlgebraFunctions| "bookvol10.4.pamphlet" 1253302 1253352 1255804 1255809) (|MatrixCategory| "bookvol10.2.pamphlet" 1239393 1239427 1253233 1253297) (|MatrixCategory&| NIL 1225307 1225344 1239150 1239155) (|MatrixCategoryFunctions2| "bookvol10.4.pamphlet" 1224567 1224637 1225297 1225302) (|MappingPackage4| "bookvol10.4.pamphlet" 1223348 1223373 1224557 1224562) (|MappingPackage3| "bookvol10.4.pamphlet" 1222210 1222237 1223338 1223343) (|MappingPackage2| "bookvol10.4.pamphlet" 1221503 1221528 1222200 1222205) (|MappingPackage1| "bookvol10.4.pamphlet" 1220312 1220335 1221493 1221498) (|MappingPackageInternalHacks3| "bookvol10.4.pamphlet" 1220098 1220138 1220302 1220307) (|MappingPackageInternalHacks2| "bookvol10.4.pamphlet" 1219841 1219879 1220088 1220093) (|MappingPackageInternalHacks1| "bookvol10.4.pamphlet" 1219451 1219487 1219831 1219836) (|MatrixManipulation| "bookvol10.4.pamphlet" 1215107 1215147 1219441 1219446) (|Magma| "bookvol10.3.pamphlet" 1213388 1213408 1215097 1215102) (|ModularAlgebraicGcdOperations| "bookvol10.2.pamphlet" 1211217 1211259 1213378 1213383) (|ThreeDimensionalMatrix| "bookvol10.3.pamphlet" 1209141 1209171 1210777 1210782) (|LazyStreamAggregate| "bookvol10.2.pamphlet" 1204872 1204899 1209121 1209136) (|LazyStreamAggregate&| NIL 1200610 1200640 1204862 1204867) (|LyndonWord| "bookvol10.3.pamphlet" 1197840 1197865 1200600 1200605) (|LieSquareMatrix| "bookvol10.3.pamphlet" 1195753 1195780 1196148 1196235) (|LinearSystemPolynomialPackage| "bookvol10.4.pamphlet" 1195269 1195313 1195743 1195748) (|LinearSystemMatrixPackage| "bookvol10.4.pamphlet" 1194052 1194099 1195259 1195264) (|LinearSystemMatrixPackage1| "bookvol10.4.pamphlet" 1191794 1191828 1194042 1194047) (|ListAggregate| "bookvol10.2.pamphlet" 1191415 1191436 1191725 1191789) (|ListAggregate&| NIL 1191092 1191116 1191405 1191410) (|LiePolynomial| "bookvol10.3.pamphlet" 1190196 1190226 1190915 1191001) (|LinearPolynomialEquationByFractions| "bookvol10.4.pamphlet" 1189424 1189467 1190186 1190191) (|LocalParametrizationOfSimplePointPackage| "bookvol10.4.pamphlet" 1187862 1187949 1189414 1189419) (|LeftOreRing| "bookvol10.2.pamphlet" 1187307 1187324 1187771 1187857) (|LinesOpPack| "bookvol10.4.pamphlet" 1185971 1185990 1187297 1187302) (|Localize| "bookvol10.3.pamphlet" 1185328 1185348 1185871 1185915) (|Logic| "bookvol10.2.pamphlet" 1184957 1184968 1185318 1185323) (|Logic&| NIL 1184583 1184597 1184947 1184952) (|LinearOrdinaryDifferentialOperatorsOps| "bookvol10.4.pamphlet" 1183477 1183525 1184573 1184578) (|LinearOrdinaryDifferentialOperator| "bookvol10.3.pamphlet" 1182720 1182769 1183062 1183125) (|LinearOrdinaryDifferentialOperatorFactorizer| "bookvol10.4.pamphlet" 1181707 1181762 1182654 1182659) (|LinearOrdinaryDifferentialOperatorCategory| "bookvol10.2.pamphlet" 1180292 1180342 1181639 1181702) (|LinearOrdinaryDifferentialOperatorCategory&| NIL 1178895 1178948 1180245 1180250) (|LinearOrdinaryDifferentialOperator2| "bookvol10.3.pamphlet" 1178027 1178072 1178480 1178543) (|LinearOrdinaryDifferentialOperator1| "bookvol10.3.pamphlet" 1177286 1177329 1177612 1177675) (|ElementaryFunctionLODESolver| "bookvol10.4.pamphlet" 1175990 1176030 1177276 1177281) (|LocalPowerSeriesCategory| "bookvol10.2.pamphlet" 1174319 1174351 1175820 1175985) (|LinearAggregate| "bookvol10.2.pamphlet" 1170782 1170805 1174299 1174314) (|LinearAggregate&| NIL 1167205 1167231 1170725 1170730) (|ListMonoidOps| "bookvol10.3.pamphlet" 1163806 1163834 1167195 1167200) (|LeftModule| "bookvol10.2.pamphlet" 1163313 1163331 1163796 1163801) (|ListMultiDictionary| "bookvol10.3.pamphlet" 1162353 1162380 1163022 1163074) (|LinearSystemFromPowerSeriesPackage| "bookvol10.4.pamphlet" 1161772 1161818 1162343 1162348) (|List| "bookvol10.3.pamphlet" 1159603 1159615 1161012 1161064) (|ListFunctions3| "bookvol10.4.pamphlet" 1158906 1158932 1159593 1159598) (|ListFunctions2| "bookvol10.4.pamphlet" 1157574 1157598 1158896 1158901) (|ListToMap| "bookvol10.4.pamphlet" 1154430 1154449 1157564 1157569) (|LinearlyExplicitRingOver| "bookvol10.2.pamphlet" 1153779 1153811 1154403 1154425) (|LinearDependence| "bookvol10.4.pamphlet" 1152632 1152658 1153685 1153690) (|RationalFunctionLimitPackage| "bookvol10.4.pamphlet" 1150564 1150600 1152622 1152627) (|PowerSeriesLimitPackage| "bookvol10.4.pamphlet" 1149418 1149452 1150554 1150559) (|AssociatedLieAlgebra| "bookvol10.3.pamphlet" 1147123 1147153 1148401 1148645) (|LieAlgebra| "bookvol10.2.pamphlet" 1146683 1146701 1147032 1147118) (|LieAlgebra&| NIL 1146284 1146305 1146636 1146641) (|Library| "bookvol10.3.pamphlet" 1144627 1144640 1145338 1145366) (|LinGroebnerPackage| "bookvol10.4.pamphlet" 1141993 1142024 1144617 1144622) (|LiouvillianFunction| "bookvol10.4.pamphlet" 1140759 1140788 1141983 1141988) (|LiouvillianFunctionCategory| "bookvol10.2.pamphlet" 1139587 1139620 1140749 1140754) (|LexTriangularPackage| "bookvol10.4.pamphlet" 1135401 1135434 1139577 1139582) (|LieExponentials| "bookvol10.3.pamphlet" 1133616 1133656 1135374 1135396) (|LeadingCoefDetermination| "bookvol10.4.pamphlet" 1132024 1132063 1133606 1133611) (|LazardSetSolvingPackage| "bookvol10.4.pamphlet" 1131113 1131156 1132014 1132019) (|LaurentPolynomial| "bookvol10.3.pamphlet" 1129719 1129747 1130551 1130663) (|LaplaceTransform| "bookvol10.4.pamphlet" 1129254 1129280 1129709 1129714) (|LocalAlgebra| "bookvol10.3.pamphlet" 1128621 1128645 1129143 1129206) (|LeftAlgebra| "bookvol10.2.pamphlet" 1128381 1128400 1128594 1128616) (|LeftAlgebra&| NIL 1128155 1128177 1128371 1128376) (|Kovacic| "bookvol10.4.pamphlet" 1126835 1126853 1128145 1128150) (|ConvertibleTo| "bookvol10.2.pamphlet" 1126548 1126569 1126825 1126830) (|CoercibleTo| "bookvol10.2.pamphlet" 1126276 1126295 1126538 1126543) (|Kernel| "bookvol10.3.pamphlet" 1124775 1124789 1126002 1126007) (|KernelFunctions2| "bookvol10.4.pamphlet" 1124464 1124490 1124765 1124770) (|KeyedDictionary| "bookvol10.2.pamphlet" 1123577 1123612 1124419 1124459) (|KeyedDictionary&| NIL 1122722 1122760 1123567 1123572) (|KeyedAccessFile| "bookvol10.3.pamphlet" 1121194 1121223 1121916 1121968) (|AssociatedJordanAlgebra| "bookvol10.3.pamphlet" 1118875 1118908 1120177 1120421) (|IndexedAggregate| "bookvol10.2.pamphlet" 1117105 1117143 1118855 1118870) (|IndexedAggregate&| NIL 1115158 1115199 1116911 1116916) (|IndexedVector| "bookvol10.3.pamphlet" 1113975 1114001 1114126 1114178) (|InfiniteTuple| "bookvol10.3.pamphlet" 1113084 1113105 1113965 1113970) (|InnerTrigonometricManipulations| "bookvol10.4.pamphlet" 1111822 1111866 1113074 1113079) (|InfiniteTupleFunctions3| "bookvol10.4.pamphlet" 1111307 1111342 1111812 1111817) (|InfiniteTupleFunctions2| "bookvol10.4.pamphlet" 1111030 1111063 1111297 1111302) (|InnerTaylorSeries| "bookvol10.3.pamphlet" 1108720 1108750 1110763 1110979) (|InnerSparseUnivariatePowerSeries| "bookvol10.3.pamphlet" 1100847 1100892 1107463 1107628) (|InnerPolySum| "bookvol10.4.pamphlet" 1100304 1100330 1100837 1100842) (|IndexedString| "bookvol10.3.pamphlet" 1099301 1099325 1099478 1099530) (|InternalRationalUnivariateRepresentationPackage| "bookvol10.4.pamphlet" 1098251 1098315 1099291 1099296) (|IrrRepSymNatPackage| "bookvol10.4.pamphlet" 1096302 1096327 1098241 1098246) (|IntegrationResultRFToFunction| "bookvol10.4.pamphlet" 1094806 1094843 1096242 1096247) (|IrredPolyOverFiniteField| "bookvol10.4.pamphlet" 1094385 1094418 1094796 1094801) (|IntegerRoots| "bookvol10.4.pamphlet" 1092691 1092711 1094375 1094380) (|IntegrationResult| "bookvol10.3.pamphlet" 1090349 1090374 1092492 1092536) (|IntegrationResultFunctions2| "bookvol10.4.pamphlet" 1089472 1089509 1090339 1090344) (|IntegrationResultToFunction| "bookvol10.4.pamphlet" 1088628 1088665 1089462 1089467) (|InternalPrintPackage| "bookvol10.4.pamphlet" 1088386 1088412 1088618 1088623) (|InnerPrimeField| "bookvol10.3.pamphlet" 1087963 1087988 1088080 1088245) (|InnerPAdicInteger| "bookvol10.3.pamphlet" 1087676 1087717 1087846 1087958) (|InverseLaplaceTransform| "bookvol10.4.pamphlet" 1087256 1087289 1087666 1087671) (|TranscendentalIntegration| "bookvol10.4.pamphlet" 1080259 1080295 1087246 1087251) (|IntegrationTools| "bookvol10.4.pamphlet" 1077962 1077988 1079681 1079686) (|IntegerSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 1077248 1077290 1077952 1077957) (|Interval| "bookvol10.3.pamphlet" 1076967 1076983 1077111 1077243) (|RationalFunctionIntegration| "bookvol10.4.pamphlet" 1075310 1075345 1076957 1076962) (|IntegerRetractions| "bookvol10.4.pamphlet" 1074787 1074813 1075300 1075305) (|RationalIntegration| "bookvol10.4.pamphlet" 1073443 1073473 1074777 1074782) (|PatternMatchIntegration| "bookvol10.4.pamphlet" 1071614 1071647 1072961 1072966) (|PureAlgebraicIntegration| "bookvol10.4.pamphlet" 1069213 1069249 1071506 1071511) (|AnnaNumericalIntegrationPackage| "bookvol10.4.pamphlet" 1059709 1059746 1069203 1069208) (|Integer| "bookvol10.3.pamphlet" 1058955 1058968 1059453 1059704) (|TranscendentalHermiteIntegration| "bookvol10.4.pamphlet" 1058195 1058238 1058945 1058950) (|AlgebraicHermiteIntegration| "bookvol10.4.pamphlet" 1057819 1057864 1058185 1058190) (|IntegerNumberTheoryFunctions| "bookvol10.4.pamphlet" 1054172 1054206 1057809 1057814) (|GenusZeroIntegration| "bookvol10.4.pamphlet" 1047276 1047308 1054064 1054069) (|IntegrationFunctionsTable| "bookvol10.3.pamphlet" 1041251 1041282 1047266 1047271) (|InterpolateFormsPackage| "bookvol10.4.pamphlet" 1040382 1040460 1041241 1041246) (|IntegerFactorizationPackage| "bookvol10.4.pamphlet" 1039443 1039478 1040372 1040377) (|InterfaceGroebnerPackage| "bookvol10.4.pamphlet" 1039289 1039335 1039433 1039438) (|ElementaryIntegration| "bookvol10.4.pamphlet" 1037632 1037663 1039279 1039284) (|IntegralDomain| "bookvol10.2.pamphlet" 1036229 1036249 1037515 1037627) (|IntegralDomain&| NIL 1034930 1034953 1036219 1036224) (|IntersectionDivisorPackage| "bookvol10.4.pamphlet" 1034052 1034163 1034920 1034925) (|IntervalCategory| "bookvol10.2.pamphlet" 1032608 1032632 1033915 1034047) (|IntegerBits| "bookvol10.4.pamphlet" 1032130 1032147 1032598 1032603) (|AlgebraicIntegrate| "bookvol10.4.pamphlet" 1031276 1031315 1032120 1032125) (|AlgebraicIntegration| "bookvol10.4.pamphlet" 1030738 1030768 1031266 1031271) (|InnerTable| "bookvol10.3.pamphlet" 1029654 1029693 1029825 1029877) (|IntegerNumberSystem| "bookvol10.2.pamphlet" 1026892 1026917 1029477 1029649) (|IntegerNumberSystem&| NIL 1024294 1024322 1026882 1026887) (|InnerPolySign| "bookvol10.4.pamphlet" 1023731 1023755 1024284 1024289) (|InfiniteProductPrimeField| "bookvol10.4.pamphlet" 1022804 1022846 1023721 1023726) (|InfiniteProductFiniteField| "bookvol10.4.pamphlet" 1021868 1021916 1022794 1022799) (|InnerMultFact| "bookvol10.4.pamphlet" 1020863 1020891 1021858 1021863) (|InnerModularGcd| "bookvol10.4.pamphlet" 1020007 1020050 1020853 1020858) (|InnerNumericFloatSolvePackage| "bookvol10.4.pamphlet" 1018329 1018374 1019997 1020002) (|InfiniteProductCharacteristicZero| "bookvol10.4.pamphlet" 1017378 1017428 1018319 1018324) (|InputForm| "bookvol10.3.pamphlet" 1014292 1014307 1017368 1017373) (|InputFormFunctions1| "bookvol10.4.pamphlet" 1013920 1013947 1014282 1014287) (|Infinity| "bookvol10.4.pamphlet" 1013502 1013516 1013910 1013915) (|InfinitlyClosePoint| "bookvol10.3.pamphlet" 1012902 1012982 1013492 1013497) (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 1012288 1012367 1012892 1012897) (|InfinitlyClosePointCategory| "bookvol10.2.pamphlet" 1010916 1011004 1012278 1012283) (|InnerNumericEigenPackage| "bookvol10.4.pamphlet" 1009442 1009482 1010906 1010911) (|IndexedExponents| "bookvol10.3.pamphlet" 1009334 1009365 1009432 1009437) (|IncrementingMaps| "bookvol10.4.pamphlet" 1008737 1008761 1009324 1009329) (|InnerNormalBasisFieldFunctions| "bookvol10.4.pamphlet" 1004603 1004642 1008727 1008732) (|IndexedMatrix| "bookvol10.3.pamphlet" 1003628 1003665 1004151 1004203) (|InnerMatrixQuotientFieldFunctions| "bookvol10.4.pamphlet" 1002676 1002751 1003571 1003576) (|InnerMatrixLinearAlgebraFunctions| "bookvol10.4.pamphlet" 1001245 1001300 1002619 1002624) (|IndexedList| "bookvol10.3.pamphlet" 999999 1000023 1000527 1000579) (|InnerIndexedTwoDimensionalArray| "bookvol10.3.pamphlet" 999648 999715 999782 999834) (|InnerFiniteField| "bookvol10.3.pamphlet" 998868 998898 999133 999298) (|IndexedFlexibleArray| "bookvol10.3.pamphlet" 995959 995992 998150 998202) (|InnerFreeAbelianMonoid| "bookvol10.3.pamphlet" 995759 995796 995897 995902) (|InnerEvalable| "bookvol10.2.pamphlet" 995145 995168 995749 995754) (|InnerEvalable&| NIL 994528 994554 995135 995140) (|IndexedDirectProductObject| "bookvol10.3.pamphlet" 994317 994353 994518 994523) (|IndexedDirectProductOrderedAbelianMonoidSup| "bookvol10.3.pamphlet" 994049 994102 994307 994312) (|IndexedDirectProductOrderedAbelianMonoid| "bookvol10.3.pamphlet" 993746 993796 994039 994044) (|IndexedDirectProductCategory| "bookvol10.2.pamphlet" 992658 992696 993736 993741) (|IndexedDirectProductAbelianMonoid| "bookvol10.3.pamphlet" 992387 992430 992648 992653) (|IndexedDirectProductAbelianGroup| "bookvol10.3.pamphlet" 992119 992161 992377 992382) (|IdealDecompositionPackage| "bookvol10.4.pamphlet" 989368 989409 992109 992114) (|PolynomialIdeals| "bookvol10.3.pamphlet" 984424 984473 989289 989294) (|InfClsPt| "bookvol10.3.pamphlet" 983875 983904 984414 984419) (|InnerCommonDenominator| "bookvol10.4.pamphlet" 983088 983124 983865 983870) (|IndexCard| "bookvol10.3.pamphlet" 982364 982379 983078 983083) (|IntegralBasisPolynomialTools| "bookvol10.4.pamphlet" 980981 981024 982354 982359) (|IndexedBits| "bookvol10.3.pamphlet" 980138 980160 980559 980611) (|IntegralBasisTools| "bookvol10.4.pamphlet" 977053 977084 980128 980133) (|ChineseRemainderToolsForIntegralBases| "bookvol10.4.pamphlet" 975928 975978 977043 977048) (|IndexedTwoDimensionalArray| "bookvol10.3.pamphlet" 975588 975638 975711 975763) (|IndexedOneDimensionalArray| "bookvol10.3.pamphlet" 974753 974792 974870 974922) (|InnerAlgebraicNumber| "bookvol10.3.pamphlet" 972870 972896 974481 974646) (|InnerAlgFactor| "bookvol10.4.pamphlet" 972419 972460 972860 972865) (|HyperbolicFunctionCategory| "bookvol10.2.pamphlet" 971773 971805 972409 972414) (|HyperbolicFunctionCategory&| NIL 971124 971159 971763 971768) (|HTMLFormat| "bookvol10.3.pamphlet" 969968 969984 971114 971119) (|HomogeneousAggregate| "bookvol10.2.pamphlet" 967744 967772 969948 969963) (|HomogeneousAggregate&| NIL 965321 965352 967528 967533) (|HexadecimalExpansion| "bookvol10.3.pamphlet" 962459 962485 963075 963240) (|HeuGcd| "bookvol10.4.pamphlet" 961407 961422 962449 962454) (|HyperellipticFiniteDivisor| "bookvol10.3.pamphlet" 961019 961063 961397 961402) (|Heap| "bookvol10.3.pamphlet" 957107 957119 960802 960854) (|HomogeneousDirectProduct| "bookvol10.3.pamphlet" 946889 946927 947271 947475) (|HomogeneousDistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 943058 943115 943699 943933) (|HallBasis| "bookvol10.4.pamphlet" 941647 941662 943048 943053) (|HashTable| "bookvol10.3.pamphlet" 940518 940556 940734 940786) (|Pi| "bookvol10.3.pamphlet" 940057 940065 940348 940513) (|GuessUnivariatePolynomial| "bookvol10.4.pamphlet" 926131 926166 940047 940052) (|GuessPolynomial| "bookvol10.4.pamphlet" 925805 925826 925918 925923) (|Guess| "bookvol10.4.pamphlet" 910070 910112 925649 925654) (|GuessInteger| "bookvol10.4.pamphlet" 909779 909797 909887 909892) (|GuessFinite| "bookvol10.4.pamphlet" 909582 909601 909700 909705) (|GuessFiniteFunctions| "bookvol10.4.pamphlet" 909445 909473 909572 909577) (|GuessAlgebraicNumber| "bookvol10.4.pamphlet" 909233 909259 909351 909356) (|GeneralTriangularSet| "bookvol10.3.pamphlet" 908350 908384 908854 908906) (|GeneralSparseTable| "bookvol10.3.pamphlet" 907273 907324 907461 907489) (|GeneralUnivariatePowerSeries| "bookvol10.3.pamphlet" 903950 904003 904935 905187) (|Group| "bookvol10.2.pamphlet" 902918 902929 903923 903945) (|Group&| NIL 901900 901914 902908 902913) (|GroebnerSolve| "bookvol10.4.pamphlet" 900484 900512 901890 901895) (|GradedModule| "bookvol10.2.pamphlet" 899114 899136 900474 900479) (|GradedModule&| NIL 897741 897766 899104 899109) (|GraphImage| "bookvol10.3.pamphlet" 890772 890788 897731 897736) (|GraphicsDefaults| "bookvol10.4.pamphlet" 889153 889175 890762 890767) (|GrayCode| "bookvol10.4.pamphlet" 887688 887702 889143 889148) (|GradedAlgebra| "bookvol10.2.pamphlet" 886880 886903 887678 887683) (|GradedAlgebra&| NIL 886069 886095 886870 886875) (|GeneralPolynomialSet| "bookvol10.3.pamphlet" 885500 885541 885730 885782) (|GeneralPackageForAlgebraicFunctionField| "bookvol10.4.pamphlet" 880233 880357 885452 885457) (|GosperSummationMethod| "bookvol10.4.pamphlet" 879483 879520 880223 880228) (|GuessOption| "bookvol10.3.pamphlet" 873767 873784 879473 879478) (|GuessOptionFunctions0| "bookvol10.3.pamphlet" 870163 870190 873757 873762) (|GeneralModulePolynomial| "bookvol10.3.pamphlet" 869242 869290 870114 870158) (|GeneralHenselPackage| "bookvol10.4.pamphlet" 868396 868428 869232 869237) (|GenerateUnivariatePowerSeries| "bookvol10.4.pamphlet" 864182 864222 868386 868391) (|GenUFactorize| "bookvol10.4.pamphlet" 863775 863796 864172 864177) (|GeneralPolynomialGcdPackage| "bookvol10.4.pamphlet" 863400 863442 863765 863770) (|GeneralizedMultivariateFactorize| "bookvol10.4.pamphlet" 862837 862886 863390 863395) (|GenExEuclid| "bookvol10.4.pamphlet" 861310 861332 862827 862832) (|GnuDraw| "bookvol10.4.pamphlet" 859770 859783 861300 861305) (|GeneralDistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 855789 855844 856580 856814) (|GenericNonAssociativeAlgebra| "bookvol10.3.pamphlet" 849629 849682 855478 855595) (|GcdDomain| "bookvol10.2.pamphlet" 848533 848548 849512 849624) (|GcdDomain&| NIL 847541 847559 848523 848528) (|GroebnerPackage| "bookvol10.4.pamphlet" 843072 843123 847494 847499) (|GroebnerInternalPackage| "bookvol10.4.pamphlet" 839149 839208 843062 843067) (|GroebnerFactorizationPackage| "bookvol10.4.pamphlet" 834588 834652 839139 839144) (|EuclideanGroebnerBasisPackage| "bookvol10.4.pamphlet" 831214 831279 834578 834583) (|GaussianFactorizationPackage| "bookvol10.4.pamphlet" 830511 830545 831204 831209) (|GaloisGroupUtilities| "bookvol10.4.pamphlet" 828802 828830 830450 830455) (|GaloisGroupPolynomialUtilities| "bookvol10.4.pamphlet" 827241 827282 828792 828797) (|GaloisGroupFactorizationUtilities| "bookvol10.4.pamphlet" 825419 825465 827231 827236) (|GaloisGroupFactorizer| "bookvol10.4.pamphlet" 815838 815868 825409 825414) (|FortranVectorFunctionCategory| "bookvol10.2.pamphlet" 812754 812789 815818 815833) (|FortranVectorCategory| "bookvol10.2.pamphlet" 811779 811806 812734 812749) (|FunctionCalled| "bookvol10.3.pamphlet" 811616 811640 811769 811774) (|FortranType| "bookvol10.3.pamphlet" 809839 809856 811606 811611) (|FortranTemplate| "bookvol10.3.pamphlet" 808997 809018 809829 809834) (|FunctionSpaceUnivariatePolynomialFactor| "bookvol10.4.pamphlet" 807986 808038 808909 808914) (|FortranScalarType| "bookvol10.3.pamphlet" 806115 806138 807976 807981) (|FunctionSpaceReduce| "bookvol10.4.pamphlet" 805526 805555 806105 806110) (|FunctionSpacePrimitiveElement| "bookvol10.4.pamphlet" 804340 804379 805460 805465) (|FunctionalSpecialFunction| "bookvol10.4.pamphlet" 801608 801643 804330 804335) (|FunctionSpace| "bookvol10.2.pamphlet" 795360 795381 801224 801603) (|FunctionSpace&| NIL 788919 788943 794786 794791) (|FunctionSpaceIntegration| "bookvol10.4.pamphlet" 788517 788551 788909 788914) (|FourierSeries| "bookvol10.3.pamphlet" 787766 787789 788269 788424) (|FunctionSpaceComplexIntegration| "bookvol10.4.pamphlet" 787005 787046 787756 787761) (|FiniteSetAggregate| "bookvol10.2.pamphlet" 786125 786151 786908 787000) (|FiniteSetAggregate&| NIL 785247 785276 786033 786038) (|FiniteSetAggregateFunctions2| "bookvol10.4.pamphlet" 783964 784006 785237 785242) (|FunctionSpaceToUnivariatePowerSeries| "bookvol10.4.pamphlet" 778421 778489 783954 783959) (|FunctionSpaceFunctions2| "bookvol10.4.pamphlet" 778012 778049 778411 778416) (|FunctionSpaceToExponentialExpansion| "bookvol10.4.pamphlet" 777142 777198 778002 778007) (|FactoredFunctionUtilities| "bookvol10.4.pamphlet" 776119 776152 777132 777137) (|Factored| "bookvol10.3.pamphlet" 767823 767839 774877 774989) (|FramedNonAssociativeAlgebra| "bookvol10.2.pamphlet" 762945 762980 767729 767818) (|FramedNonAssociativeAlgebra&| NIL 758111 758149 762898 762903) (|FramedNonAssociativeAlgebraFunctions2| "bookvol10.4.pamphlet" 757524 757577 758101 758106) (|FramedModule| "bookvol10.3.pamphlet" 756918 756954 757445 757450) (|FractionalIdeal| "bookvol10.3.pamphlet" 756135 756165 756891 756913) (|FractionalIdealFunctions2| "bookvol10.4.pamphlet" 755850 755905 756125 756130) (|FullyRetractableTo| "bookvol10.2.pamphlet" 755508 755534 755840 755845) (|FullyRetractableTo&| NIL 754995 755024 755330 755335) (|FramedAlgebra| "bookvol10.2.pamphlet" 753366 753390 754927 754990) (|FramedAlgebra&| NIL 751792 751819 753356 753361) (|Fraction| "bookvol10.3.pamphlet" 748044 748060 748435 748729) (|FractionFunctions2| "bookvol10.4.pamphlet" 747641 747669 748034 748039) (|FactoredFunctions2| "bookvol10.4.pamphlet" 746983 747011 747631 747636) (|FloatingPointSystem| "bookvol10.2.pamphlet" 743835 743860 746793 746978) (|FloatingPointSystem&| NIL 740765 740793 743726 743731) (|FieldOfPrimeCharacteristic| "bookvol10.2.pamphlet" 739723 739755 740595 740760) (|FieldOfPrimeCharacteristic&| NIL 738838 738873 739713 739718) (|FullyPatternMatchable| "bookvol10.2.pamphlet" 738571 738600 738818 738833) (|FullPartialFractionExpansion| "bookvol10.3.pamphlet" 737299 737338 738561 738566) (|FortranProgram| "bookvol10.3.pamphlet" 735771 735833 737289 737294) (|FortranPackage| "bookvol10.4.pamphlet" 734708 734728 735761 735766) (|FortranFunctionCategory| "bookvol10.2.pamphlet" 731777 731806 734688 734703) (|FortranProgramCategory| "bookvol10.2.pamphlet" 731460 731488 731757 731772) (|ScriptFormulaFormat| "bookvol10.3.pamphlet" 728837 728862 731450 731455) (|ScriptFormulaFormat1| "bookvol10.4.pamphlet" 728298 728326 728827 728832) (|FindOrderFinite| "bookvol10.4.pamphlet" 728070 728103 728288 728293) (|FortranOutputStackPackage| "bookvol10.4.pamphlet" 727248 727279 728060 728065) (|FreeNilpotentLie| "bookvol10.3.pamphlet" 726639 726675 727199 727243) (|FileNameCategory| "bookvol10.2.pamphlet" 724969 724991 726629 726634) (|FileName| "bookvol10.3.pamphlet" 724855 724869 724959 724964) (|FortranMachineTypeCategory| "bookvol10.2.pamphlet" 724586 724618 724738 724850) (|FreeMonoid| "bookvol10.3.pamphlet" 721340 721358 724534 724539) (|FreeModule| "bookvol10.3.pamphlet" 721005 721025 721244 721288) (|FortranMatrixFunctionCategory| "bookvol10.2.pamphlet" 717928 717963 720985 721000) (|FortranMatrixCategory| "bookvol10.2.pamphlet" 716953 716980 717908 717923) (|FreeModuleCat| "bookvol10.2.pamphlet" 714619 714648 716904 716948) (|FreeModule1| "bookvol10.3.pamphlet" 714042 714063 714523 714567) (|FloatingRealPackage| "bookvol10.4.pamphlet" 711833 711864 714032 714037) (|Float| "bookvol10.3.pamphlet" 708626 708637 711590 711828) (|FloatingComplexPackage| "bookvol10.4.pamphlet" 706072 706106 708616 708621) (|FullyLinearlyExplicitRingOver| "bookvol10.2.pamphlet" 705740 705777 706045 706067) (|FullyLinearlyExplicitRingOver&| NIL 705341 705381 705649 705654) (|FiniteLinearAggregateSort| "bookvol10.4.pamphlet" 704574 704609 705331 705336) (|FreeLieAlgebra| "bookvol10.2.pamphlet" 702612 702643 704483 704569) (|FiniteLinearAggregate| "bookvol10.2.pamphlet" 699787 699816 702568 702607) (|FiniteLinearAggregate&| NIL 696857 696889 699641 699646) (|FiniteLinearAggregateFunctions2| "bookvol10.4.pamphlet" 695549 695594 696847 696852) (|FiniteRankAlgebra| "bookvol10.2.pamphlet" 693631 693659 695481 695544) (|FiniteRankAlgebra&| NIL 691624 691655 693477 693482) (|Finite| "bookvol10.2.pamphlet" 690615 690627 691614 691619) (|Finite&| NIL 689603 689618 690605 690610) (|FiniteRankNonAssociativeAlgebra| "bookvol10.2.pamphlet" 678887 678926 689509 689598) (|FiniteRankNonAssociativeAlgebra&| NIL 668206 668248 678831 678836) (|File| "bookvol10.3.pamphlet" 667791 667803 668196 668201) (|FileCategory| "bookvol10.2.pamphlet" 666228 666255 667781 667786) (|Field| "bookvol10.2.pamphlet" 665491 665502 666058 666223) (|Field&| NIL 664911 664925 665481 665486) (|FreeGroup| "bookvol10.3.pamphlet" 663438 663455 664884 664906) (|FGLMIfCanPackage| "bookvol10.4.pamphlet" 662331 662360 663428 663433) (|FiniteFieldExtension| "bookvol10.3.pamphlet" 661611 661644 661916 662081) (|FiniteFieldSquareFreeDecomposition| "bookvol10.4.pamphlet" 661452 661501 661601 661606) (|FiniteFieldSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 660921 660976 661442 661447) (|FiniteFieldPolynomialPackage| "bookvol10.4.pamphlet" 652294 652331 660911 660916) (|FiniteFieldPolynomialPackage2| "bookvol10.4.pamphlet" 651353 651393 652284 652289) (|FiniteFieldExtensionByPolynomial| "bookvol10.3.pamphlet" 650688 650738 650938 651103) (|FiniteField| "bookvol10.3.pamphlet" 649976 650001 650198 650363) (|FiniteFieldNormalBasisExtension| "bookvol10.3.pamphlet" 648366 648415 649561 649726) (|FiniteFieldNormalBasisExtensionByPolynomial| "bookvol10.3.pamphlet" 646730 646788 647951 648116) (|FiniteFieldNormalBasis| "bookvol10.3.pamphlet" 645080 645121 646240 646405) (|FunctionFieldIntegralBasis| "bookvol10.4.pamphlet" 642430 642469 645070 645075) (|FiniteFieldCategory| "bookvol10.2.pamphlet" 639939 639964 642260 642425) (|FiniteFieldCategory&| NIL 637605 637633 639929 639934) (|FiniteFieldHomomorphisms| "bookvol10.4.pamphlet" 636376 636415 637595 637600) (|FiniteFieldFunctions| "bookvol10.4.pamphlet" 633833 633862 636366 636371) (|FractionFreeFastGaussian| "bookvol10.4.pamphlet" 627937 627971 633823 633828) (|FractionFreeFastGaussianFractions| "bookvol10.4.pamphlet" 626585 626631 627927 627932) (|FiniteFieldFactorizationWithSizeParseBySideEffect| "bookvol10.4.pamphlet" 625957 626021 626575 626580) (|FiniteFieldFactorization| "bookvol10.4.pamphlet" 625856 625895 625947 625952) (|FiniteFieldCyclicGroupExtension| "bookvol10.3.pamphlet" 624577 624626 625441 625606) (|FiniteFieldCyclicGroupExtensionByPolynomial| "bookvol10.3.pamphlet" 623320 623381 624162 624327) (|FiniteFieldCyclicGroup| "bookvol10.3.pamphlet" 621956 621997 622830 622995) (|FunctionFieldCategory| "bookvol10.2.pamphlet" 610647 610684 621696 621951) (|FunctionFieldCategory&| NIL 599508 599548 610560 610565) (|FunctionFieldCategoryFunctions2| "bookvol10.4.pamphlet" 599218 599287 599498 599503) (|FortranExpression| "bookvol10.3.pamphlet" 591811 591872 598906 598969) (|FullyEvalableOver| "bookvol10.2.pamphlet" 591506 591531 591801 591806) (|FullyEvalableOver&| NIL 590960 590988 591258 591263) (|FiniteDivisor| "bookvol10.3.pamphlet" 590404 590435 590950 590955) (|FiniteDivisorCategory| "bookvol10.2.pamphlet" 588401 588440 590394 590399) (|FiniteDivisorCategory&| NIL 586395 586437 588391 588396) (|FiniteDivisorFunctions2| "bookvol10.4.pamphlet" 586120 586181 586385 586390) (|FortranCodePackage1| "bookvol10.4.pamphlet" 584664 584689 586110 586115) (|FourierComponent| "bookvol10.3.pamphlet" 584181 584205 584654 584659) (|FortranCode| "bookvol10.3.pamphlet" 574137 574154 584171 584176) (|FiniteAlgebraicExtensionField| "bookvol10.2.pamphlet" 567319 567356 573967 574132) (|FiniteAlgebraicExtensionField&| NIL 560620 560660 567271 567276) (|FlexibleArray| "bookvol10.3.pamphlet" 558913 558934 559902 559954) (|FiniteAbelianMonoidRing| "bookvol10.2.pamphlet" 556966 556999 558743 558908) (|FiniteAbelianMonoidRing&| NIL 555038 555074 556818 556823) (|FiniteAbelianMonoidRingFunctions2| "bookvol10.4.pamphlet" 554581 554634 555028 555033) (|FreeAbelianMonoid| "bookvol10.3.pamphlet" 554189 554214 554501 554506) (|FreeAbelianMonoidCategory| "bookvol10.2.pamphlet" 552349 552384 554179 554184) (|FreeAbelianGroup| "bookvol10.3.pamphlet" 551901 551925 552197 552241) (|FactoringUtilities| "bookvol10.4.pamphlet" 550097 550130 551891 551896) (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| "bookvol10.4.pamphlet" 549926 549989 550087 550092) (|FactoredFunctions| "bookvol10.4.pamphlet" 549105 549130 549916 549921) (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| "bookvol10.4.pamphlet" 548926 548997 549095 549100) (|ExponentialOfUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 545259 545316 546588 546840) (|ExpressionTubePlot| "bookvol10.4.pamphlet" 542711 542735 545249 545254) (|ExpressionSolve| "bookvol10.4.pamphlet" 542604 542642 542701 542706) (|ExpressionSpaceODESolver| "bookvol10.4.pamphlet" 539330 539364 542594 542599) (|Expression| "bookvol10.3.pamphlet" 533411 533429 534141 534764) (|ExpressionToUnivariatePowerSeries| "bookvol10.4.pamphlet" 529470 529514 533401 533406) (|ExpressionFunctions2| "bookvol10.4.pamphlet" 529222 529252 529460 529465) (|ExponentialExpansion| "bookvol10.3.pamphlet" 524154 524197 524810 524975) (|Export3D| "bookvol10.4.pamphlet" 524001 524015 524144 524149) (|Exit| "bookvol10.3.pamphlet" 523670 523680 523991 523996) (|EvaluateCycleIndicators| "bookvol10.4.pamphlet" 523147 523178 523660 523665) (|Evalable| "bookvol10.2.pamphlet" 522705 522721 523137 523142) (|Evalable&| NIL 522260 522279 522695 522700) (|EuclideanDomain| "bookvol10.2.pamphlet" 519776 519797 522143 522255) (|EuclideanDomain&| NIL 517396 517420 519766 519771) (|ExpertSystemToolsPackage| "bookvol10.4.pamphlet" 509232 509262 517386 517391) (|ExpertSystemToolsPackage2| "bookvol10.4.pamphlet" 508804 508841 509222 509227) (|ExpertSystemToolsPackage1| "bookvol10.4.pamphlet" 508466 508500 508794 508799) (|ExpressionSpace| "bookvol10.2.pamphlet" 501400 501421 508456 508461) (|ExpressionSpace&| NIL 494223 494247 501282 501287) (|ExpertSystemContinuityPackage| "bookvol10.4.pamphlet" 491005 491040 494213 494218) (|ExpertSystemContinuityPackage1| "bookvol10.4.pamphlet" 490718 490758 490995 491000) (|ExpressionSpaceFunctions2| "bookvol10.4.pamphlet" 490206 490241 490708 490713) (|ExpressionSpaceFunctions1| "bookvol10.4.pamphlet" 489745 489780 490196 490201) (|ErrorFunctions| "bookvol10.4.pamphlet" 487209 487229 489735 489740) (|EqTable| "bookvol10.3.pamphlet" 486082 486109 486296 486348) (|Equation| "bookvol10.3.pamphlet" 480557 480573 483310 483449) (|EquationFunctions2| "bookvol10.4.pamphlet" 480259 480287 480547 480552) (|EigenPackage| "bookvol10.4.pamphlet" 476603 476623 480249 480254) (|EntireRing| "bookvol10.2.pamphlet" 476104 476120 476512 476598) (|EuclideanModularRing| "bookvol10.3.pamphlet" 475231 475298 475987 476099) (|EltableAggregate| "bookvol10.2.pamphlet" 473673 473706 475221 475226) (|EltableAggregate&| NIL 472065 472101 473616 473621) (|Eltable| "bookvol10.2.pamphlet" 471592 471615 472055 472060) (|EllipticFunctionsUnivariateTaylorSeries| "bookvol10.4.pamphlet" 470944 471000 471582 471587) (|ElementaryFunctionCategory| "bookvol10.2.pamphlet" 470617 470649 470934 470939) (|ElementaryFunctionCategory&| NIL 470287 470322 470607 470612) (|ExtensibleLinearAggregate| "bookvol10.2.pamphlet" 468167 468200 470242 470282) (|ExtensibleLinearAggregate&| NIL 465992 466028 468070 468075) (|ElementaryFunctionsUnivariatePuiseuxSeries| "bookvol10.3.pamphlet" 462724 462794 465945 465950) (|ElementaryFunctionsUnivariateLaurentSeries| "bookvol10.3.pamphlet" 459517 459580 462677 462682) (|ElementaryFunctionStructurePackage| "bookvol10.4.pamphlet" 457486 457530 459507 459512) (|ElementaryFunction| "bookvol10.4.pamphlet" 452250 452278 457476 457481) (|ExtAlgBasis| "bookvol10.3.pamphlet" 450555 450572 452240 452245) (|e04ucfAnnaType| "bookvol10.3.pamphlet" 450081 450101 450545 450550) (|e04nafAnnaType| "bookvol10.3.pamphlet" 449648 449668 450071 450076) (|e04mbfAnnaType| "bookvol10.3.pamphlet" 449218 449238 449638 449643) (|e04jafAnnaType| "bookvol10.3.pamphlet" 448744 448764 449208 449213) (|e04gcfAnnaType| "bookvol10.3.pamphlet" 448270 448290 448734 448739) (|e04fdfAnnaType| "bookvol10.3.pamphlet" 447796 447816 448260 448265) (|e04dgfAnnaType| "bookvol10.3.pamphlet" 447322 447342 447786 447791) (|e04AgentsPackage| "bookvol10.4.pamphlet" 443050 443072 447312 447317) (|DifferentialVariableCategory| "bookvol10.2.pamphlet" 439773 439809 443040 443045) (|DifferentialVariableCategory&| NIL 436493 436532 439763 439768) (|DesingTreePackage| "bookvol10.4.pamphlet" 433563 433665 436483 436488) (|DesingTree| "bookvol10.3.pamphlet" 432714 432732 433346 433398) (|DesingTreeCategory| "bookvol10.2.pamphlet" 432267 432293 432645 432709) (|DifferentialSparseMultivariatePolynomial| "bookvol10.3.pamphlet" 428735 428787 429066 429300) (|DrawOption| "bookvol10.3.pamphlet" 422490 422506 428725 428730) (|DrawOptionFunctions1| "bookvol10.4.pamphlet" 422143 422171 422480 422485) (|DrawOptionFunctions0| "bookvol10.4.pamphlet" 417084 417110 422133 422138) (|TopLevelDrawFunctionsForPoints| "bookvol10.4.pamphlet" 415297 415333 417074 417079) (|TopLevelDrawFunctions| "bookvol10.4.pamphlet" 408186 408218 415287 415292) (|DrawNumericHack| "bookvol10.4.pamphlet" 407436 407459 408176 408181) (|DrawComplex| "bookvol10.4.pamphlet" 404852 404869 407426 407431) (|TopLevelDrawFunctionsForAlgebraicCurves| "bookvol10.4.pamphlet" 404362 404414 404842 404847) (|TopLevelDrawFunctionsForCompiledFunctions| "bookvol10.4.pamphlet" 393763 393810 404352 404357) (|DequeueAggregate| "bookvol10.2.pamphlet" 391934 391958 393694 393758) (|DifferentialPolynomialCategory| "bookvol10.2.pamphlet" 387196 387240 391695 391929) (|DifferentialPolynomialCategory&| NIL 382636 382683 387138 387143) (|DirectProductModule| "bookvol10.3.pamphlet" 374403 374436 374542 374981) (|DirectProductMatrixModule| "bookvol10.3.pamphlet" 366161 366202 366309 366748) (|DistributedMultivariatePolynomial| "bookvol10.3.pamphlet" 362387 362433 362971 363205) (|DiscreteLogarithmPackage| "bookvol10.4.pamphlet" 361705 361737 362377 362382) (|DataList| "bookvol10.3.pamphlet" 360290 360306 360987 361039) (|DoublyLinkedAggregate| "bookvol10.2.pamphlet" 358718 358747 360270 360285) (|DivisionRing| "bookvol10.2.pamphlet" 358114 358132 358627 358713) (|DivisionRing&| NIL 357588 357609 358104 358109) (|Divisor| "bookvol10.3.pamphlet" 357396 357411 357480 357524) (|DivisorCategory| "bookvol10.2.pamphlet" 356131 356154 357347 357391) (|DisplayPackage| "bookvol10.4.pamphlet" 354333 354353 356121 356126) (|DirichletRing| "bookvol10.3.pamphlet" 353494 353520 354061 354281) (|DirectProduct| "bookvol10.3.pamphlet" 343022 343049 343658 343862) (|DirectProductFunctions2| "bookvol10.4.pamphlet" 341862 341901 343012 343017) (|DirectProductCategory| "bookvol10.2.pamphlet" 340701 340736 341641 341857) (|DirectProductCategory&| NIL 339245 339283 340188 340193) (|DiophantineSolutionPackage| "bookvol10.4.pamphlet" 338066 338098 339235 339240) (|DictionaryOperations| "bookvol10.2.pamphlet" 337115 337143 338021 338061) (|DictionaryOperations&| NIL 336150 336181 337059 337064) (|DifferentialRing| "bookvol10.2.pamphlet" 335250 335272 336123 336145) (|DifferentialRing&| NIL 334364 334389 335240 335245) (|DifferentialExtension| "bookvol10.2.pamphlet" 333489 333518 334337 334359) (|DifferentialExtension&| NIL 332499 332531 333350 333355) (|Dictionary| "bookvol10.2.pamphlet" 332098 332116 332454 332494) (|Dictionary&| NIL 331729 331750 332088 332093) (|DenavitHartenbergMatrix| "bookvol10.3.pamphlet" 329894 329925 331277 331329) (|DoubleFloatVector| "bookvol10.3.pamphlet" 328248 328271 328649 328701) (|DoubleFloatSpecialFunctions| "bookvol10.4.pamphlet" 319417 319450 328238 328243) (|DoubleFloatMatrix| "bookvol10.3.pamphlet" 318442 318465 318872 318924) (|DoubleFloat| "bookvol10.3.pamphlet" 314738 314755 318252 318437) (|DefiniteIntegrationTools| "bookvol10.4.pamphlet" 312955 312989 314728 314733) (|DeRhamComplex| "bookvol10.3.pamphlet" 310895 310938 312928 312950) (|Dequeue| "bookvol10.3.pamphlet" 305033 305048 310678 310730) (|DegreeReductionPackage| "bookvol10.4.pamphlet" 304628 304662 305023 305028) (|RationalFunctionDefiniteIntegration| "bookvol10.4.pamphlet" 302060 302103 304618 304623) (|ElementaryFunctionDefiniteIntegration| "bookvol10.4.pamphlet" 300509 300556 302050 302055) (|DecimalExpansion| "bookvol10.3.pamphlet" 297663 297685 298263 298428) (|DistinctDegreeFactorize| "bookvol10.4.pamphlet" 295523 295557 297653 297658) (|DoubleResultantPackage| "bookvol10.4.pamphlet" 295115 295155 295513 295518) (|Database| "bookvol10.3.pamphlet" 293762 293778 295105 295110) (|d03fafAnnaType| "bookvol10.3.pamphlet" 293578 293598 293752 293757) (|d03eefAnnaType| "bookvol10.3.pamphlet" 293386 293406 293568 293573) (|d03AgentsPackage| "bookvol10.4.pamphlet" 292317 292339 293376 293381) (|d02ejfAnnaType| "bookvol10.3.pamphlet" 291769 291789 292307 292312) (|d02cjfAnnaType| "bookvol10.3.pamphlet" 291237 291257 291759 291764) (|d02bhfAnnaType| "bookvol10.3.pamphlet" 290717 290737 291227 291232) (|d02bbfAnnaType| "bookvol10.3.pamphlet" 290197 290217 290707 290712) (|d02AgentsPackage| "bookvol10.4.pamphlet" 285128 285150 290187 290192) (|d01WeightsPackage| "bookvol10.4.pamphlet" 283436 283459 285118 285123) (|d01TransformFunctionType| "bookvol10.3.pamphlet" 283391 283421 283426 283431) (|d01gbfAnnaType| "bookvol10.3.pamphlet" 282903 282923 283381 283386) (|d01fcfAnnaType| "bookvol10.3.pamphlet" 282415 282435 282893 282898) (|d01asfAnnaType| "bookvol10.3.pamphlet" 281873 281893 282405 282410) (|d01aqfAnnaType| "bookvol10.3.pamphlet" 281356 281376 281863 281868) (|d01apfAnnaType| "bookvol10.3.pamphlet" 280826 280846 281346 281351) (|d01anfAnnaType| "bookvol10.3.pamphlet" 280310 280330 280816 280821) (|d01amfAnnaType| "bookvol10.3.pamphlet" 279810 279830 280300 280305) (|d01alfAnnaType| "bookvol10.3.pamphlet" 279340 279360 279800 279805) (|d01akfAnnaType| "bookvol10.3.pamphlet" 278858 278878 279330 279335) (|d01ajfAnnaType| "bookvol10.3.pamphlet" 278371 278391 278848 278853) (|d01AgentsPackage| "bookvol10.4.pamphlet" 274464 274486 278361 278366) (|CyclotomicPolynomialPackage| "bookvol10.4.pamphlet" 273943 273976 274454 274459) (|CycleIndicators| "bookvol10.4.pamphlet" 270741 270762 273933 273938) (|CoerceVectorMatrixPackage| "bookvol10.4.pamphlet" 270103 270136 270731 270736) (|ComplexTrigonometricManipulations| "bookvol10.4.pamphlet" 268544 268587 270093 270098) (|CyclicStreamTools| "bookvol10.4.pamphlet" 267318 267346 268534 268539) (|ComplexRootFindingPackage| "bookvol10.4.pamphlet" 261310 261346 267308 267313) (|CRApackage| "bookvol10.4.pamphlet" 260459 260477 261300 261305) (|ComplexPatternMatch| "bookvol10.4.pamphlet" 259932 259964 260362 260367) (|CharacteristicPolynomialInMonogenicalAlgebra| "bookvol10.4.pamphlet" 259595 259656 259922 259927) (|CoordinateSystems| "bookvol10.4.pamphlet" 254595 254620 259585 259590) (|ContinuedFraction| "bookvol10.3.pamphlet" 250509 250534 254425 254590) (|CommutativeRing| "bookvol10.2.pamphlet" 250143 250164 250415 250504) (|SubSpaceComponentProperty| "bookvol10.3.pamphlet" 249620 249651 250133 250138) (|ComplexPattern| "bookvol10.4.pamphlet" 249375 249402 249610 249615) (|Complex| "bookvol10.3.pamphlet" 241232 241247 241486 241962) (|ComplexFunctions2| "bookvol10.4.pamphlet" 240940 240967 241222 241227) (|ComplexFactorization| "bookvol10.4.pamphlet" 240718 240750 240930 240935) (|ComplexCategory| "bookvol10.2.pamphlet" 238596 238619 240225 240713) (|ComplexCategory&| NIL 236162 236188 237794 237799) (|Comparable| "bookvol10.2.pamphlet" 235893 235909 236152 236157) (|CommuteUnivariatePolynomialCategory| "bookvol10.4.pamphlet" 235634 235685 235883 235888) (|CommonOperators| "bookvol10.4.pamphlet" 235160 235181 235624 235629) (|Commutator| "bookvol10.3.pamphlet" 234961 234977 235150 235155) (|CombinatorialOpsCategory| "bookvol10.2.pamphlet" 233974 234004 234951 234956) (|IntegerCombinatoricFunctions| "bookvol10.4.pamphlet" 232440 232476 233964 233969) (|CombinatorialFunction| "bookvol10.4.pamphlet" 229875 229906 232430 232435) (|Color| "bookvol10.3.pamphlet" 228710 228721 229865 229870) (|ComplexRootPackage| "bookvol10.4.pamphlet" 228028 228061 228700 228705) (|TwoDimensionalPlotClipping| "bookvol10.4.pamphlet" 224124 224156 228018 228023) (|CliffordAlgebra| "bookvol10.3.pamphlet" 222802 222831 224056 224119) (|Collection| "bookvol10.2.pamphlet" 219814 219832 222782 222797) (|Collection&| NIL 216668 216689 219639 219644) (|ComplexIntegerSolveLinearPolynomialEquation| "bookvol10.4.pamphlet" 215966 216020 216658 216663) (|ChangeOfVariable| "bookvol10.4.pamphlet" 213926 213958 215956 215961) (|CharacteristicZero| "bookvol10.2.pamphlet" 213818 213842 213899 213921) (|CharacteristicPolynomialPackage| "bookvol10.4.pamphlet" 213303 213342 213808 213813) (|CharacteristicNonZero| "bookvol10.2.pamphlet" 213030 213057 213276 213298) (|Character| "bookvol10.3.pamphlet" 209384 209399 213020 213025) (|CombinatorialFunctionCategory| "bookvol10.2.pamphlet" 208530 208565 209374 209379) (|Cell| "bookvol10.3.pamphlet" 208494 208515 208520 208525) (|ComplexDoubleFloatVector| "bookvol10.3.pamphlet" 206305 206335 206958 207010) (|ComplexDoubleFloatMatrix| "bookvol10.3.pamphlet" 205193 205223 205639 205691) (|CommonDenominator| "bookvol10.4.pamphlet" 204418 204447 205183 205188) (|CharacterClass| "bookvol10.3.pamphlet" 202612 202632 203682 203762) (|CartesianTensor| "bookvol10.3.pamphlet" 193778 193815 202602 202607) (|CartesianTensorFunctions2| "bookvol10.4.pamphlet" 193145 193195 193768 193773) (|CardinalNumber| "bookvol10.3.pamphlet" 189463 189483 193111 193140) (|CylindricalAlgebraicDecompositionUtilities| "bookvol10.4.pamphlet" 189087 189139 189453 189458) (|CylindricalAlgebraicDecompositionPackage| "bookvol10.4.pamphlet" 189015 189072 189077 189082) (|CachableSet| "bookvol10.2.pamphlet" 188622 188639 189005 189010) (|CancellationAbelianMonoid| "bookvol10.2.pamphlet" 188092 188123 188612 188617) (|BinaryTree| "bookvol10.3.pamphlet" 187129 187147 187875 187927) (|BinaryTournament| "bookvol10.3.pamphlet" 186310 186334 186912 186964) (|BinaryTreeCategory| "bookvol10.2.pamphlet" 185643 185669 186241 186305) (|BinaryTreeCategory&| NIL 185032 185061 185633 185638) (|BitAggregate| "bookvol10.2.pamphlet" 184100 184118 184963 185027) (|BitAggregate&| NIL 183224 183245 184090 184095) (|BinarySearchTree| "bookvol10.3.pamphlet" 181821 181845 183007 183059) (|BasicStochasticDifferential| "bookvol10.3.pamphlet" 179686 179719 181811 181816) (|BrillhartTests| "bookvol10.4.pamphlet" 178447 178470 179676 179681) (|BinaryRecursiveAggregate| "bookvol10.2.pamphlet" 177385 177417 178427 178442) (|BinaryRecursiveAggregate&| NIL 176283 176318 177328 177333) (|BalancedPAdicRational| "bookvol10.3.pamphlet" 173193 173224 173403 173568) (|BalancedPAdicInteger| "bookvol10.3.pamphlet" 172860 172890 173076 173188) (|BoundIntegerRoots| "bookvol10.4.pamphlet" 172507 172535 172850 172855) (|BasicOperator| "bookvol10.3.pamphlet" 168028 168047 172497 172502) (|BasicOperatorFunctions1| "bookvol10.4.pamphlet" 165485 165516 167976 167981) (|Boolean| "bookvol10.3.pamphlet" 164350 164363 165475 165480) (|BiModule| "bookvol10.2.pamphlet" 163971 163989 164301 164345) (|BlowUpPackage| "bookvol10.4.pamphlet" 162238 162285 163961 163966) (|BlowUpWithQuadTrans| "bookvol10.3.pamphlet" 162111 162136 162203 162233) (|BlowUpMethodCategory| "bookvol10.2.pamphlet" 162070 162096 162101 162106) (|BlowUpWithHamburgerNoether| "bookvol10.3.pamphlet" 161938 161970 162037 162065) (|BlasLevelOne| "bookvol10.5.pamphlet" 150200 150218 161928 161933) (|Bits| "bookvol10.3.pamphlet" 149561 149571 149778 149830) (|BinaryFile| "bookvol10.3.pamphlet" 148910 148926 149551 149556) (|BinaryExpansion| "bookvol10.3.pamphlet" 146032 146053 146664 146829) (|BagAggregate| "bookvol10.2.pamphlet" 145254 145274 145987 146027) (|BagAggregate&| NIL 144508 144531 145244 145249) (|BasicFunctions| "bookvol10.3.pamphlet" 143905 143925 144476 144503) (|BezoutMatrix| "bookvol10.4.pamphlet" 143027 143064 143847 143852) (|Bezier| "bookvol10.4.pamphlet" 140886 140900 143017 143022) (|BalancedBinaryTree| "bookvol10.3.pamphlet" 136455 136481 140669 140721) (|BasicType| "bookvol10.2.pamphlet" 136142 136157 136445 136450) (|BasicType&| NIL 135826 135844 136132 136137) (|BalancedFactorisation| "bookvol10.4.pamphlet" 135226 135258 135816 135821) (|AxiomServer| "bookvol10.4.pamphlet" 135077 135094 135216 135221) (|Automorphism| "bookvol10.3.pamphlet" 134504 134524 135050 135072) (|UnitsKnownAttribute| "bookvol10.2.pamphlet" 134282 134307 134484 134499) (|AttributeRegistry| "bookvol10.2.pamphlet" 130635 130658 133835 134277) (|AttributeButtons| "bookvol10.3.pamphlet" 126733 126755 130603 130630) (|ShallowlyMutableAttribute| "bookvol10.2.pamphlet" 126470 126501 126713 126728) (|ArcTrigonometricFunctionCategory| "bookvol10.2.pamphlet" 125909 125947 126460 126465) (|ArcTrigonometricFunctionCategory&| NIL 125345 125386 125899 125904) (|PartiallyOrderedSetAttribute| "bookvol10.2.pamphlet" 125117 125151 125325 125340) (|NoZeroDivisorsAttribute| "bookvol10.2.pamphlet" 124918 124947 125097 125112) (|NullSquareAttribute| "bookvol10.2.pamphlet" 124783 124808 124898 124913) (|NotherianAttribute| "bookvol10.2.pamphlet" 124641 124665 124763 124778) (|MultiplicativeValuationAttribute| "bookvol10.2.pamphlet" 124450 124488 124621 124636) (|LeftUnitaryAttribute| "bookvol10.2.pamphlet" 124293 124319 124430 124445) (|LazyRepresentationAttribute| "bookvol10.2.pamphlet" 124155 124188 124273 124288) (|JacobiIdentityAttribute| "bookvol10.2.pamphlet" 123988 124017 124135 124150) (|FiniteAggregateAttribute| "bookvol10.2.pamphlet" 123849 123879 123968 123983) (|CanonicalUnitNormalAttribute| "bookvol10.2.pamphlet" 123523 123557 123829 123844) (|CommutativeStarAttribute| "bookvol10.2.pamphlet" 123250 123280 123503 123518) (|CentralAttribute| "bookvol10.2.pamphlet" 122931 122953 123230 123245) (|CanonicalAttribute| "bookvol10.2.pamphlet" 122728 122752 122911 122926) (|CanonicalClosedAttribute| "bookvol10.2.pamphlet" 122544 122574 122708 122723) (|ArbitraryPrecisionAttribute| "bookvol10.2.pamphlet" 122374 122407 122524 122539) (|ArbitraryExponentAttribute| "bookvol10.2.pamphlet" 122242 122274 122354 122369) (|ApproximateAttribute| "bookvol10.2.pamphlet" 122131 122157 122222 122237) (|AdditiveValuationAttribute| "bookvol10.2.pamphlet" 121944 121976 122111 122126) (|ArrayStack| "bookvol10.3.pamphlet" 117592 117610 121727 121779) (|AssociatedEquations| "bookvol10.4.pamphlet" 116361 116390 117545 117550) (|Asp9| "bookvol10.3.pamphlet" 115514 115531 116351 116356) (|Asp8| "bookvol10.3.pamphlet" 114453 114470 115504 115509) (|Asp80| "bookvol10.3.pamphlet" 113780 113798 114443 114448) (|Asp7| "bookvol10.3.pamphlet" 112974 112991 113770 113775) (|Asp78| "bookvol10.3.pamphlet" 112448 112466 112964 112969) (|Asp77| "bookvol10.3.pamphlet" 111816 111834 112438 112443) (|Asp74| "bookvol10.3.pamphlet" 110838 110856 111806 111811) (|Asp73| "bookvol10.3.pamphlet" 110096 110114 110828 110833) (|Asp6| "bookvol10.3.pamphlet" 108772 108789 110086 110091) (|Asp55| "bookvol10.3.pamphlet" 107204 107222 108762 108767) (|Asp50| "bookvol10.3.pamphlet" 104855 104873 107194 107199) (|Asp4| "bookvol10.3.pamphlet" 104140 104157 104845 104850) (|Asp49| "bookvol10.3.pamphlet" 103124 103142 104130 104135) (|Asp42| "bookvol10.3.pamphlet" 101396 101439 103114 103119) (|Asp41| "bookvol10.3.pamphlet" 99894 99937 101386 101391) (|Asp35| "bookvol10.3.pamphlet" 98874 98892 99884 99889) (|Asp34| "bookvol10.3.pamphlet" 98120 98138 98864 98869) (|Asp33| "bookvol10.3.pamphlet" 97701 97719 98110 98115) (|Asp31| "bookvol10.3.pamphlet" 96810 96828 97691 97696) (|Asp30| "bookvol10.3.pamphlet" 95537 95555 96800 96805) (|Asp29| "bookvol10.3.pamphlet" 95016 95034 95527 95532) (|Asp28| "bookvol10.3.pamphlet" 85442 85460 95006 95011) (|Asp27| "bookvol10.3.pamphlet" 84293 84311 85432 85437) (|Asp24| "bookvol10.3.pamphlet" 83371 83389 84283 84288) (|Asp20| "bookvol10.3.pamphlet" 82539 82557 83361 83366) (|Asp1| "bookvol10.3.pamphlet" 81915 81932 82529 82534) (|Asp19| "bookvol10.3.pamphlet" 75989 76007 81905 81910) (|Asp12| "bookvol10.3.pamphlet" 75402 75420 75979 75984) (|Asp10| "bookvol10.3.pamphlet" 74678 74696 75392 75397) (|TwoDimensionalArray| "bookvol10.3.pamphlet" 74219 74246 74461 74513) (|OneDimensionalArray| "bookvol10.3.pamphlet" 72993 73020 73501 73553) (|OneDimensionalArrayFunctions2| "bookvol10.4.pamphlet" 71002 71041 72983 72988) (|TwoDimensionalArrayCategory| "bookvol10.2.pamphlet" 64227 64274 70933 70997) (|TwoDimensionalArrayCategory&| NIL 57508 57558 64217 64222) (|ApplyRules| "bookvol10.4.pamphlet" 56819 56846 57498 57503) (|ApplyUnivariateSkewPolynomial| "bookvol10.4.pamphlet" 56394 56435 56809 56814) (|ApplicationProgramInterface| "bookvol10.4.pamphlet" 55305 55338 56384 56389) (|Any| "bookvol10.3.pamphlet" 53651 53660 55295 55300) (|AnyFunctions1| "bookvol10.4.pamphlet" 52716 52737 53641 53646) (|AntiSymm| "bookvol10.3.pamphlet" 51159 51182 52689 52711) (|AnonymousFunction| "bookvol10.3.pamphlet" 51056 51079 51149 51154) (|AlgebraicNumber| "bookvol10.3.pamphlet" 49265 49286 50784 50949) (|AbelianMonoidRing| "bookvol10.2.pamphlet" 47392 47419 49095 49260) (|AbelianMonoidRing&| NIL 45343 45373 47049 47054) (|AssociationList| "bookvol10.3.pamphlet" 43080 43115 43442 43494) (|AlgebraGivenByStructuralConstants| "bookvol10.3.pamphlet" 42104 42162 42901 42990) (|AlgebraPackage| "bookvol10.4.pamphlet" 38043 38067 42047 42052) (|AlgebraicMultFact| "bookvol10.4.pamphlet" 37236 37266 38033 38038) (|AlgebraicManipulations| "bookvol10.4.pamphlet" 34652 34684 36992 36997) (|AlgebraicFunctionField| "bookvol10.3.pamphlet" 32419 32467 32640 32895) (|AlgFactor| "bookvol10.4.pamphlet" 31536 31554 32409 32414) (|Algebra| "bookvol10.2.pamphlet" 31006 31021 31468 31531) (|Algebra&| NIL 30531 30549 30996 31001) (|AssociationListAggregate| "bookvol10.2.pamphlet" 29985 30029 30462 30526) (|ArcHyperbolicFunctionCategory| "bookvol10.2.pamphlet" 29338 29373 29975 29980) (|Aggregate| "bookvol10.2.pamphlet" 27707 27722 29318 29333) (|Aggregate&| NIL 26037 26055 27651 27656) (|AffineSpaceCategory| "bookvol10.2.pamphlet" 23907 23934 26027 26032) (|AlgebraicFunction| "bookvol10.4.pamphlet" 22279 22306 23827 23832) (|AffineSpace| "bookvol10.3.pamphlet" 22112 22137 22269 22274) (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| "bookvol10.3.pamphlet" 21912 21970 22102 22107) (|AffinePlane| "bookvol10.3.pamphlet" 21751 21770 21902 21907) (|AffineAlgebraicSetComputeWithResultant| "bookvol10.4.pamphlet" 21597 21672 21741 21746) (|AffineAlgebraicSetComputeWithGroebnerBasis| "bookvol10.4.pamphlet" 21139 21218 21587 21592) (|PlaneAlgebraicCurvePlot| "bookvol10.3.pamphlet" 19405 19434 21129 21134) (|AlgebraicallyClosedFunctionSpace| "bookvol10.2.pamphlet" 17181 17221 19223 19400) (|AlgebraicallyClosedFunctionSpace&| NIL 15126 15169 17171 17176) (|AlgebraicallyClosedField| "bookvol10.2.pamphlet" 10185 10215 14956 15121) (|AlgebraicallyClosedField&| NIL 5401 5434 10175 10180) (|AbelianSemiGroup| "bookvol10.2.pamphlet" 4744 4766 5391 5396) (|AbelianSemiGroup&| NIL 4084 4109 4734 4739) (|AbelianMonoid| "bookvol10.2.pamphlet" 3441 3460 4074 4079) (|AbelianMonoid&| NIL 2795 2817 3431 3436) (|AbelianGroup| "bookvol10.2.pamphlet" 2290 2308 2785 2790) (|AbelianGroup&| NIL 1782 1803 2280 2285) (|OneDimensionalArrayAggregate| "bookvol10.2.pamphlet" 878 914 1713 1777) (|OneDimensionalArrayAggregate&| NIL 30 69 868 873)) 
\ No newline at end of file
diff --git a/src/share/algebra/category.daase b/src/share/algebra/category.daase
index da7f683..08a434f 100644
--- a/src/share/algebra/category.daase
+++ b/src/share/algebra/category.daase
@@ -1,5 +1,5 @@
 
-(224261 . 3614189655)        
+(224313 . 3618694788)        
 (((|#2| |#2|) AND (|has| |#2| (|Evalable| |#2|)) (|has| |#2| (|SetCategory|))) (((|Record| (|:| |key| |#1|) (|:| |entry| |#2|)) (|Record| (|:| |key| |#1|) (|:| |entry| |#2|))) |has| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|)) (|Evalable| (|Record| (|:| |key| |#1|) (|:| |entry| |#2|))))) 
 (((|#2| |#2|) . T)) 
 ((((|Integer|)) . T)) 
@@ -2347,6 +2347,7 @@
 (((|#1|) . T)) 
 (((|#1|) . T)) 
 ((((|OutputForm|)) . T)) 
+((((|OutputForm|)) . T)) 
 (|has| |#1| (|SetCategory|)) 
 (((|#4|) . T)) 
 (((|#4|) . T)) 
@@ -2629,6 +2630,7 @@
 (((|#2|) |has| |#1| (|Field|))) 
 (((|#2|) |has| |#1| (|Field|))) 
 ((((|OutputForm|)) . T)) 
+((((|OutputForm|)) . T)) 
 ((((|Record| (|:| |key| |#1|) (|:| |entry| |#2|))) . T)) 
 (((|#1|) . T)) 
 (((|#1|) |has| |#1| (|CommutativeRing|))) 
@@ -3563,4 +3565,4 @@
 ((($ $) . T)) 
 ((($ $) . T) (((|OrderedVariableList| |#1|) $) . T) (((|OrderedVariableList| |#1|) |#2|) . T)) 
 ((($ $) . T) ((|#2| $) |has| |#1| (|DifferentialRing|)) ((|#2| |#1|) |has| |#1| (|DifferentialRing|)) ((|#3| |#1|) . T) ((|#3| $) . T)) 
-(((|Localize| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |InnerEvalable|) 224124) ((|DistributedMultivariatePolynomial| . |InnerEvalable|) 224028) ((|Interval| . |BiModule|) 224013) ((|IndexedExponents| . |AbelianMonoid|) T) ((|DataList| . |SetCategory|) 223950) ((|BalancedPAdicRational| . |Evalable|) 223834) ((|HashTable| . |InnerEvalable|) 223542) ((|MachineComplex| . |BasicType|) T) ((|SplittingTree| . |InnerEvalable|) 223404) ((|FreeNilpotentLie| . |CancellationAbelianMonoid|) T) ((|WuWenTsunTriangularSet| . |PolynomialSetCategory|) 223373) ((|DoubleFloatVector| . |OneDimensionalArrayAggregate|) 223346) ((|ComplexDoubleFloatVector| . |OneDimensionalArrayAggregate|) 223307) ((|IndexedVector| . |HomogeneousAggregate|) 223291) ((|OrderedFreeMonoid| . |OrderedMonoid|) T) ((|LocalAlgebra| . |CancellationAbelianMonoid|) T) ((|IndexedMatrix| . |TwoDimensionalArrayCategory|) 223219) ((|DoubleFloatVector| . |IndexedAggregate|) 223180) ((|ComplexDoubleFloatVector| . |IndexedAggregate|) 223129) ((|OneDimensionalArray| . |InnerEvalable|) 223048) ((|InnerIndexedTwoDimensionalArray| . |InnerEvalable|) 222967) ((|Factored| . |PartialDifferentialRing|) 222899) ((|Complex| . |Ring|) T) ((|IndexedFlexibleArray| . |InnerEvalable|) 222818) ((|IndexedTwoDimensionalArray| . |InnerEvalable|) 222737) ((|IndexedOneDimensionalArray| . |InnerEvalable|) 222656) ((|Octonion| . |RetractableTo|) 222333) ((|MachineFloat| . |Algebra|) 222287) ((|FiniteFieldCyclicGroup| . |FiniteFieldCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |StepThrough|) 222257) ((|Segment| . |SegmentCategory|) 222241) ((|Segment| . |SetCategory|) 222211) ((|Complex| . |DivisionRing|) 222145) ((|Complex| . |DifferentialRing|) 222068) ((|Segment| . |SegmentExpansionCategory|) 222015) ((|PAdicRationalConstructor| . |Eltable|) 221968) ((|DoubleFloat| . |OrderedCancellationAbelianMonoid|) T) ((|DoubleFloat| . |OrderedAbelianMonoid|) T) ((|MachineComplex| . |ElementaryFunctionCategory|) NIL) ((|SparseTable| . |TableAggregate|) 221947) ((|Fraction| . |QuotientFieldCategory|) 221931) ((|ProjectiveSpace| . |BasicType|) T) ((|MachineInteger| . |AbelianGroup|) T) ((|MachineInteger| . |AbelianSemiGroup|) T) ((|XDistributedPolynomial| . |LeftModule|) 221905) ((|U32Vector| . |Collection|) 221882) ((|U32Matrix| . |Type|) T) ((|SparseUnivariatePolynomialExpressions| . |Algebra|) 221622) ((|Expression| . |CombinatorialOpsCategory|) 221589) ((|Expression| . |CombinatorialFunctionCategory|) 221556) ((|SparseTable| . |BagAggregate|) 221498) ((|CardinalNumber| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |DifferentialExtension|) 221469) ((|BalancedPAdicInteger| . |AbelianGroup|) T) ((|BalancedPAdicInteger| . |AbelianSemiGroup|) T) ((|KeyedAccessFile| . |EltableAggregate|) 221442) ((|GeneralSparseTable| . |EltableAggregate|) 221421) ((|UnivariatePolynomial| . |Ring|) T) ((|UnivariateSkewPolynomial| . |Ring|) T) ((|Octonion| . |FullyEvalableOver|) 221405) ((|BalancedPAdicRational| . |StepThrough|) NIL) ((|ArrayStack| . |CoercibleTo|) 221356) ((|Pi| . |CancellationAbelianMonoid|) T) ((|UnivariatePolynomial| . |FiniteAbelianMonoidRing|) 221317) ((|IndexedString| . |Type|) T) ((|OrderlyDifferentialPolynomial| . |LeftOreRing|) 221235) ((|Interval| . |Ring|) T) ((|UnivariatePolynomial| . |DifferentialRing|) T) ((|Localize| . |Module|) 221219) ((|PrimitiveArray| . |EltableAggregate|) 221191) ((|NeitherSparseOrDensePowerSeries| . |HomogeneousAggregate|) 221132) ((|TwoDimensionalArray| . |Aggregate|) T) ((|RomanNumeral| . |OrderedCancellationAbelianMonoid|) T) ((|RomanNumeral| . |OrderedAbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |Monoid|) T) ((|MultivariatePolynomial| . |AbelianMonoidRing|) 221066) ((|LaurentPolynomial| . |Algebra|) 221053) ((|FiniteFieldExtensionByPolynomial| . |EntireRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |EntireRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |EntireRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |EntireRing|) 220939) ((|DistributedMultivariatePolynomial| . |EntireRing|) 220825) ((|RealClosure| . |BasicType|) T) ((|FractionalIdeal| . |Monoid|) T) ((|BalancedPAdicRational| . |Algebra|) 220741) ((|FractionalIdeal| . |Group|) T) ((|FiniteField| . |BasicType|) T) ((|TaylorSeries| . |Rng|) T) ((|ModularField| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |UnivariateTaylorSeriesCategory|) 220725) ((|UnivariateTaylorSeriesCZero| . |UnivariatePowerSeriesCategory|) 220686) ((|SparseUnivariateTaylorSeries| . |AbelianMonoidRing|) 220647) ((|SparseUnivariatePuiseuxSeries| . |AbelianMonoidRing|) 220606) ((|SparseUnivariateLaurentSeries| . |AbelianMonoidRing|) 220578) ((|Result| . |Collection|) 220511) ((|PrimeField| . |EntireRing|) T) ((|SparseMultivariateTaylorSeries| . |AbelianMonoidRing|) 220469) ((|MachineComplex| . |Evalable|) NIL) ((|InnerFreeAbelianMonoid| . |CoercibleTo|) 220443) ((|IndexedDirectProductOrderedAbelianMonoid| . |CoercibleTo|) 220417) ((|IndexedDirectProductAbelianMonoid| . |CoercibleTo|) 220391) ((|FlexibleArray| . |SetCategory|) 220328) ((|BlowUpWithHamburgerNoether| . |BasicType|) T) ((|ModMonic| . |GcdDomain|) 220223) ((|AlgebraicNumber| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Eltable|) 220208) ((|UnivariateLaurentSeriesConstructor| . |Eltable|) 220120) ((|List| . |ListAggregate|) 220104) ((|List| . |LinearAggregate|) 220088) ((|FortranExpression| . |AbelianGroup|) T) ((|FortranExpression| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |FiniteFieldCategory|) NIL) ((|PseudoAlgebraicClosureOfRationalNumber| . |SetCategory|) T) ((|ContinuedFraction| . |AbelianGroup|) T) ((|ContinuedFraction| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |SetCategory|) T) ((|List| . |FiniteLinearAggregate|) 220072) ((|IndexedVector| . |Eltable|) 220044) ((|FileName| . |BasicType|) T) ((|SingleInteger| . |CombinatorialFunctionCategory|) T) ((|BinaryTournament| . |CoercibleTo|) 219995) ((|Palette| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |FullyRetractableTo|) 219979) ((|ModuleOperator| . |CoercibleTo|) 219953) ((|XDistributedPolynomial| . |Monoid|) T) ((|DoubleFloatVector| . |CoercibleTo|) 219927) ((|DoubleFloatVector| . |ConvertibleTo|) 219902) ((|Color| . |CoercibleTo|) 219876) ((|ComplexDoubleFloatVector| . |CoercibleTo|) 219850) ((|ComplexDoubleFloatVector| . |ConvertibleTo|) 219763) ((|Commutator| . |CoercibleTo|) 219737) ((|Set| . |Aggregate|) T) ((|BlowUpWithHamburgerNoether| . |BlowUpMethodCategory|) T) ((|PAdicRational| . |OrderedCancellationAbelianMonoid|) NIL) ((|PAdicRational| . |OrderedAbelianMonoid|) NIL) ((|OrdSetInts| . |OrderedSet|) T) ((|MultivariatePolynomial| . |PatternMatchable|) NIL) ((|XRecursivePolynomial| . |CancellationAbelianMonoid|) T) ((|FreeModule1| . |CancellationAbelianMonoid|) T) ((|PermutationGroup| . |BasicType|) T) ((|MultivariatePolynomial| . |RetractableTo|) 219544) ((|IndexedExponents| . |CancellationAbelianMonoid|) T) ((|SequentialDifferentialPolynomial| . |FullyRetractableTo|) 219528) ((|Queue| . |HomogeneousAggregate|) 219512) ((|BalancedPAdicRational| . |FullyPatternMatchable|) 219471) ((|SparseUnivariateLaurentSeries| . |Type|) 219447) ((|NewSparseUnivariatePolynomial| . |FullyRetractableTo|) 219431) ((|NewSparseMultivariatePolynomial| . |FullyRetractableTo|) 219415) ((|Point| . |Aggregate|) T) ((|MachineComplex| . |StepThrough|) NIL) ((|DirectProductModule| . |LeftModule|) 219216) ((|DirectProductMatrixModule| . |LeftModule|) 219004) ((|OrdinaryDifferentialRing| . |PrincipalIdealDomain|) 218980) ((|GeneralDistributedMultivariatePolynomial| . |FullyRetractableTo|) 218964) ((|IndexedVector| . |OneDimensionalArrayAggregate|) 218948) ((|SquareFreeRegularTriangularSet| . |TriangularSetCategory|) 218917) ((|SparseUnivariateLaurentSeries| . |PatternMatchable|) NIL) ((|SparseUnivariateLaurentSeries| . |Patternable|) 218841) ((|IndexedVector| . |IndexedAggregate|) 218813) ((|Tree| . |CoercibleTo|) 218764) ((|Switch| . |CoercibleTo|) 218738) ((|Asp12| . |FortranProgramCategory|) T) ((|SparseUnivariatePuiseuxSeries| . |RetractableTo|) 218622) ((|SparseUnivariateLaurentSeries| . |RetractableTo|) 218563) ((|NeitherSparseOrDensePowerSeries| . |Eltable|) 218480) ((|MachineComplex| . |Algebra|) 218409) ((|GeneralUnivariatePowerSeries| . |Eltable|) 218394) ((|MultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 218378) ((|PseudoAlgebraicClosureOfRationalNumber| . |Module|) 218332) ((|LinearOrdinaryDifferentialOperator| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Module|) 218235) ((|UnivariatePuiseuxSeriesConstructor| . |RadicalCategory|) 218184) ((|UnivariateLaurentSeriesConstructor| . |RadicalCategory|) 218133) ((|RoutinesTable| . |TableAggregate|) 218103) ((|PAdicRationalConstructor| . |ConvertibleTo|) 217791) ((|PAdicRationalConstructor| . |CoercibleTo|) 217765) ((|Table| . |HomogeneousAggregate|) 217694) ((|Factored| . |RealConstant|) 217663) ((|AlgebraicNumber| . |Evalable|) 217650) ((|RoutinesTable| . |BagAggregate|) 217583) ((|HashTable| . |HomogeneousAggregate|) 217512) ((|IndexedList| . |Type|) T) ((|SplittingTree| . |HomogeneousAggregate|) 217473) ((|SparseUnivariateLaurentSeries| . |FullyEvalableOver|) 217397) ((|SparseUnivariateLaurentSeries| . |FullyLinearlyExplicitRingOver|) 217321) ((|FortranType| . |BasicType|) T) ((|SequentialDifferentialPolynomial| . |Rng|) T) ((|DirectProductModule| . |Aggregate|) T) ((|DirectProductMatrixModule| . |Aggregate|) T) ((|NeitherSparseOrDensePowerSeries| . |UnaryRecursiveAggregate|) 217262) ((|NewSparseUnivariatePolynomial| . |Rng|) T) ((|NewSparseMultivariatePolynomial| . |Rng|) T) ((|MultivariatePolynomial| . |PartialDifferentialRing|) 217222) ((|GeneralDistributedMultivariatePolynomial| . |Rng|) T) ((|NeitherSparseOrDensePowerSeries| . |IndexedAggregate|) 217151) ((|OneDimensionalArray| . |HomogeneousAggregate|) 217135) ((|ResidueRing| . |RightModule|) 217109) ((|Plcs| . |SetCategory|) T) ((|InnerIndexedTwoDimensionalArray| . |HomogeneousAggregate|) 217093) ((|IndexedFlexibleArray| . |HomogeneousAggregate|) 217077) ((|IndexedTwoDimensionalArray| . |HomogeneousAggregate|) 217061) ((|IndexedOneDimensionalArray| . |HomogeneousAggregate|) 217045) ((|MyUnivariatePolynomial| . |PrincipalIdealDomain|) 217021) ((|DataList| . |InnerEvalable|) 216940) ((|ResidueRing| . |BiModule|) 216907) ((|SparseUnivariateTaylorSeries| . |PartialDifferentialRing|) 216771) ((|DirichletRing| . |LeftModule|) 216718) ((|LieSquareMatrix| . |SemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |PartialDifferentialRing|) 216580) ((|SparseUnivariateLaurentSeries| . |PartialDifferentialRing|) 216326) ((|SparseMultivariateTaylorSeries| . |PartialDifferentialRing|) 216310) ((|FiniteField| . |StepThrough|) T) ((|FreeAbelianGroup| . |RightModule|) 216287) ((|DirectProductModule| . |OrderedAbelianGroup|) 216257) ((|DirectProductModule| . |OrderedAbelianSemiGroup|) 216181) ((|DirectProductModule| . |OrderedAbelianMonoidSup|) 216139) ((|DirectProductMatrixModule| . |OrderedAbelianGroup|) 216109) ((|DirectProductMatrixModule| . |OrderedAbelianSemiGroup|) 216033) ((|DirectProductMatrixModule| . |OrderedAbelianMonoidSup|) 215991) ((|AntiSymm| . |Rng|) T) ((|DirectProductModule| . |Monoid|) 215877) ((|DirectProductMatrixModule| . |Monoid|) 215763) ((|TaylorSeries| . |SetCategory|) T) ((|LieSquareMatrix| . |AbelianMonoid|) T) ((|InnerPrimeField| . |Rng|) T) ((|InnerFiniteField| . |Rng|) T) ((|Float| . |RightModule|) 215717) ((|FreeAbelianGroup| . |BiModule|) 215682) ((|Asp34| . |FortranMatrixCategory|) T) ((|Asp34| . |FortranProgramCategory|) T) ((|RealClosure| . |Algebra|) 215603) ((|MachineComplex| . |FullyPatternMatchable|) 215575) ((|Automorphism| . |BasicType|) T) ((|ModularField| . |SetCategory|) T) ((|RadicalFunctionField| . |CharacteristicNonZero|) 215522) ((|Float| . |BiModule|) 215449) ((|ExponentialOfUnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 215425) ((|GeneralUnivariatePowerSeries| . |RadicalCategory|) 215374) ((|FiniteField| . |Algebra|) 215328) ((|AlgebraicFunctionField| . |FiniteRankAlgebra|) 215294) ((|RadicalFunctionField| . |CharacteristicZero|) 215244) ((|BinaryTree| . |BinaryTreeCategory|) 215228) ((|BinarySearchTree| . |BinaryTreeCategory|) 215212) ((|Operator| . |RightModule|) 215169) ((|OnePointCompletion| . |AbelianGroup|) 215104) ((|OppositeMonogenicLinearOperator| . |RightModule|) 215088) ((|OnePointCompletion| . |AbelianSemiGroup|) 215023) ((|ExponentialOfUnivariatePuiseuxSeries| . |IntegralDomain|) 214962) ((|Integer| . |OpenMath|) T) ((|DirectProduct| . |Type|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |CommutativeRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CommutativeRing|) T) ((|Operator| . |BiModule|) 214914) ((|OppositeMonogenicLinearOperator| . |BiModule|) 214893) ((|UnivariatePuiseuxSeriesConstructor| . |CoercibleTo|) 214867) ((|UnivariateLaurentSeriesConstructor| . |CoercibleTo|) 214841) ((|UnivariateLaurentSeriesConstructor| . |ConvertibleTo|) 214384) ((|SparseUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 214334) ((|SparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 214284) ((|AlgebraicNumber| . |Algebra|) 214238) ((|XPolynomial| . |SemiGroup|) T) ((|IndexedVector| . |CoercibleTo|) 214156) ((|IndexedVector| . |ConvertibleTo|) 214092) ((|XPBWPolynomial| . |SemiGroup|) T) ((|DirectProduct| . |RetractableTo|) 213843) ((|SparseUnivariatePolynomial| . |LeftModule|) 213740) ((|SparseMultivariatePolynomial| . |LeftModule|) 213637) ((|MoebiusTransform| . |CoercibleTo|) 213611) ((|SparseUnivariateSkewPolynomial| . |LeftModule|) 213585) ((|XPolynomial| . |AbelianMonoid|) T) ((|XPBWPolynomial| . |AbelianMonoid|) T) ((|SparseUnivariatePolynomialExpressions| . |DifferentialExtension|) 213569) ((|ResidueRing| . |Ring|) T) ((|Table| . |Eltable|) 213548) ((|Complex| . |Finite|) 213481) ((|RadixExpansion| . |Type|) T) ((|AlgebraGivenByStructuralConstants| . |AbelianMonoid|) T) ((|IntegerMod| . |BasicType|) T) ((|TaylorSeries| . |Module|) 213325) ((|HashTable| . |Eltable|) 213304) ((|IntegrationResult| . |SetCategory|) T) ((|TexFormat| . |SetCategory|) T) ((|SquareFreeRegularTriangularSet| . |SquareFreeRegularTriangularSetCategory|) 213273) ((|SExpression| . |SExpressionCategory|) 213197) ((|FreeNilpotentLie| . |AbelianGroup|) T) ((|FreeNilpotentLie| . |AbelianSemiGroup|) T) ((|CliffordAlgebra| . |SemiGroup|) T) ((|RadixExpansion| . |RetractableTo|) 213141) ((|RadixExpansion| . |Patternable|) 213118) ((|RadixExpansion| . |PatternMatchable|) 213095) ((|MyExpression| . |BasicType|) T) ((|DirichletRing| . |Monoid|) T) ((|LaurentPolynomial| . |DifferentialExtension|) 213079) ((|LocalAlgebra| . |AbelianGroup|) T) ((|EuclideanModularRing| . |IntegralDomain|) T) ((|LocalAlgebra| . |AbelianSemiGroup|) T) ((|ModularField| . |Module|) 213033) ((|Float| . |Ring|) T) ((|DirectProduct| . |FullyLinearlyExplicitRingOver|) 213001) ((|DoubleFloatVector| . |EltableAggregate|) 212962) ((|ComplexDoubleFloatVector| . |EltableAggregate|) 212911) ((|DeRhamComplex| . |Rng|) T) ((|BalancedPAdicRational| . |DifferentialExtension|) 212870) ((|OneDimensionalArray| . |Eltable|) 212842) ((|CliffordAlgebra| . |AbelianMonoid|) T) ((|IndexedFlexibleArray| . |Eltable|) 212814) ((|FlexibleArray| . |InnerEvalable|) 212733) ((|IndexedOneDimensionalArray| . |Eltable|) 212705) ((|Float| . |DivisionRing|) T) ((|Float| . |DifferentialRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 212679) ((|Operator| . |Ring|) T) ((|OppositeMonogenicLinearOperator| . |Ring|) T) ((|NeitherSparseOrDensePowerSeries| . |CoercibleTo|) 212653) ((|NeitherSparseOrDensePowerSeries| . |ConvertibleTo|) NIL) ((|ModMonic| . |PolynomialCategory|) 212588) ((|MachineInteger| . |OrderedSet|) T) ((|GeneralUnivariatePowerSeries| . |CoercibleTo|) 212562) ((|OppositeMonogenicLinearOperator| . |DifferentialRing|) 212527) ((|CardinalNumber| . |OrderedSet|) T) ((|U16Matrix| . |Type|) T) ((|LinearOrdinaryDifferentialOperator| . |SetCategory|) T) ((|Table| . |IndexedAggregate|) 212506) ((|InnerTable| . |TableAggregate|) 212485) ((|FiniteDivisor| . |SetCategory|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Field|) 212461) ((|Fraction| . |CharacteristicZero|) 212424) ((|Fraction| . |CharacteristicNonZero|) 212384) ((|U16Vector| . |Collection|) 212361) ((|Divisor| . |SetCategory|) T) ((|Product| . |SemiGroup|) 212249) ((|DirectProduct| . |PartialDifferentialRing|) 212153) ((|OrderedDirectProduct| . |SemiGroup|) 212039) ((|LinearOrdinaryDifferentialOperator2| . |UnivariateSkewPolynomialCategory|) 212023) ((|HashTable| . |IndexedAggregate|) 212002) ((|InnerTable| . |BagAggregate|) 211944) ((|RadixExpansion| . |FullyLinearlyExplicitRingOver|) 211921) ((|RadixExpansion| . |FullyEvalableOver|) 211898) ((|Symbol| . |CoercibleTo|) 211872) ((|SparseUnivariatePolynomial| . |LeftOreRing|) 211767) ((|AttributeButtons| . |SetCategory|) T) ((|Product| . |AbelianMonoid|) 211447) ((|Pi| . |AbelianGroup|) T) ((|Pi| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |AbelianMonoid|) 211250) ((|SparseMultivariatePolynomial| . |LeftOreRing|) 211168) ((|OneDimensionalArray| . |OneDimensionalArrayAggregate|) 211152) ((|Symbol| . |ConvertibleTo|) 211046) ((|SparseUnivariatePolynomial| . |Monoid|) T) ((|SparseMultivariatePolynomial| . |Monoid|) T) ((|IndexedFlexibleArray| . |OneDimensionalArrayAggregate|) 211030) ((|IndexedOneDimensionalArray| . |OneDimensionalArrayAggregate|) 211014) ((|OneDimensionalArray| . |IndexedAggregate|) 210986) ((|SequentialDifferentialPolynomial| . |SetCategory|) T) ((|PendantTree| . |BasicType|) 210956) ((|SparseUnivariateSkewPolynomial| . |Monoid|) T) ((|NewSparseUnivariatePolynomial| . |SetCategory|) T) ((|IndexedFlexibleArray| . |IndexedAggregate|) 210928) ((|IndexedOneDimensionalArray| . |IndexedAggregate|) 210900) ((|NewSparseMultivariatePolynomial| . |SetCategory|) T) ((|NewSparseMultivariatePolynomial| . |RecursivePolynomialCategory|) 210853) ((|GeneralModulePolynomial| . |SetCategory|) T) ((|GeneralDistributedMultivariatePolynomial| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |BasicType|) T) ((|IntegrationResult| . |Module|) 210817) ((|DesingTree| . |BasicType|) 210787) ((|ListMonoidOps| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |ElementaryFunctionCategory|) 210736) ((|UnivariateTaylorSeries| . |AbelianMonoidRing|) 210697) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |BasicType|) T) ((|UnivariatePuiseuxSeries| . |AbelianMonoidRing|) 210656) ((|RadixExpansion| . |PartialDifferentialRing|) NIL) ((|UnivariateLaurentSeries| . |AbelianMonoidRing|) 210628) ((|LieExponentials| . |SemiGroup|) T) ((|LieSquareMatrix| . |CancellationAbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |AbelianMonoidRing|) 210589) ((|TaylorSeries| . |CommutativeRing|) 210518) ((|SparseUnivariatePuiseuxSeries| . |EuclideanDomain|) 210494) ((|SparseUnivariateLaurentSeries| . |EuclideanDomain|) 210470) ((|SimpleAlgebraicExtension| . |UniqueFactorizationDomain|) 210404) ((|ExtAlgBasis| . |SetCategory|) T) ((|Asp78| . |FortranVectorFunctionCategory|) T) ((|Asp78| . |FortranProgramCategory|) T) ((|SimpleAlgebraicExtension| . |IntegralDomain|) 210338) ((|NottinghamGroup| . |CoercibleTo|) 210312) ((|AntiSymm| . |SetCategory|) T) ((|ModularField| . |CommutativeRing|) T) ((|InnerSparseUnivariatePowerSeries| . |AbelianMonoidRing|) 210284) ((|DoubleFloat| . |LeftModule|) 210238) ((|InnerPrimeField| . |SetCategory|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|InnerFiniteField| . |SetCategory|) T) ((|FiniteFieldExtension| . |UniqueFactorizationDomain|) T) ((|FiniteFieldNormalBasisExtension| . |UniqueFactorizationDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |UniqueFactorizationDomain|) T) ((|HexadecimalExpansion| . |OrderedIntegralDomain|) T) ((|HexadecimalExpansion| . |PrincipalIdealDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |SemiGroup|) T) ((|BinaryExpansion| . |UniqueFactorizationDomain|) T) ((|MyExpression| . |Evalable|) 210225) ((|FortranExpression| . |OrderedSet|) T) ((|DecimalExpansion| . |PrincipalIdealDomain|) T) ((|DecimalExpansion| . |OrderedIntegralDomain|) T) ((|ModuleOperator| . |RightModule|) 210182) ((|FiniteFieldExtension| . |IntegralDomain|) T) ((|FiniteFieldNormalBasisExtension| . |IntegralDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |IntegralDomain|) T) ((|BinaryExpansion| . |IntegralDomain|) T) ((|SparseUnivariateLaurentSeries| . |RealConstant|) NIL) ((|LinearOrdinaryDifferentialOperator| . |Module|) 210139) ((|PseudoAlgebraicClosureOfRationalNumber| . |EntireRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |EntireRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|Asp27| . |Type|) T) ((|Queue| . |CoercibleTo|) 210090) ((|MachineComplex| . |DifferentialExtension|) 210062) ((|Divisor| . |Module|) 210039) ((|ModuleOperator| . |BiModule|) 209991) ((|List| . |Aggregate|) T) ((|DataList| . |HomogeneousAggregate|) 209975) ((|Set| . |SetAggregate|) 209959) ((|SubSpaceComponentProperty| . |SetCategory|) T) ((|Polynomial| . |PolynomialFactorizationExplicit|) 209909) ((|HomogeneousDistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 209859) ((|XRecursivePolynomial| . |AbelianGroup|) T) ((|XRecursivePolynomial| . |AbelianSemiGroup|) T) ((|XPolynomial| . |CancellationAbelianMonoid|) T) ((|XPBWPolynomial| . |CancellationAbelianMonoid|) T) ((|SequentialDifferentialPolynomial| . |Module|) 209622) ((|RomanNumeral| . |LeftModule|) 209609) ((|Polynomial| . |LeftModule|) 209506) ((|NewSparseUnivariatePolynomial| . |Module|) 209246) ((|InputForm| . |CoercibleTo|) 209220) ((|InputForm| . |ConvertibleTo|) 209193) ((|NewSparseMultivariatePolynomial| . |Module|) 208956) ((|WuWenTsunTriangularSet| . |BasicType|) T) ((|Ruleset| . |BasicType|) T) ((|FreeModule1| . |AbelianSemiGroup|) T) ((|FreeModule1| . |AbelianGroup|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |LeftModule|) 208853) ((|GeneralModulePolynomial| . |Module|) 208824) ((|GeneralDistributedMultivariatePolynomial| . |Module|) 208587) ((|QuasiAlgebraicSet| . |BasicType|) T) ((|Multiset| . |BasicType|) T) ((|IntegerMod| . |StepThrough|) T) ((|Variable| . |CoercibleTo|) 208542) ((|IndexedExponents| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeries| . |Type|) 208518) ((|UnivariatePuiseuxSeries| . |RetractableTo|) 208414) ((|UnivariateLaurentSeries| . |PatternMatchable|) NIL) ((|UnivariateLaurentSeries| . |Patternable|) 208344) ((|CharacterClass| . |BasicType|) T) ((|AlgebraGivenByStructuralConstants| . |CancellationAbelianMonoid|) T) ((|Table| . |ConvertibleTo|) NIL) ((|Table| . |CoercibleTo|) 208318) ((|SquareMatrix| . |SquareMatrixCategory|) 208241) ((|FiniteFieldCyclicGroup| . |Rng|) T) ((|LiePolynomial| . |CoercibleTo|) 208215) ((|EuclideanModularRing| . |SemiGroup|) T) ((|FiniteFieldExtensionByPolynomial| . |CoercibleTo|) 208189) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CoercibleTo|) 208163) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CoercibleTo|) 208137) ((|DifferentialSparseMultivariatePolynomial| . |ConvertibleTo|) 207744) ((|DifferentialSparseMultivariatePolynomial| . |CoercibleTo|) 207718) ((|DistributedMultivariatePolynomial| . |CoercibleTo|) 207692) ((|DistributedMultivariatePolynomial| . |ConvertibleTo|) 207470) ((|RegularChain| . |TriangularSetCategory|) 207305) ((|PendantTree| . |Evalable|) 207229) ((|UnivariateLaurentSeries| . |RetractableTo|) 207176) ((|TaylorSeries| . |InnerEvalable|) 207140) ((|SplittingTree| . |CoercibleTo|) 207114) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 207088) ((|OrderedFreeMonoid| . |Monoid|) T) ((|InnerPrimeField| . |Module|) 207042) ((|IndexedVector| . |EltableAggregate|) 207014) ((|InnerFiniteField| . |Module|) 206935) ((|HashTable| . |ConvertibleTo|) NIL) ((|HashTable| . |CoercibleTo|) 206909) ((|Expression| . |BasicType|) T) ((|DesingTree| . |Evalable|) 206833) ((|ExponentialExpansion| . |BasicType|) T) ((|EuclideanModularRing| . |AbelianMonoid|) T) ((|CliffordAlgebra| . |CancellationAbelianMonoid|) T) ((|PrimeField| . |CoercibleTo|) 206807) ((|PrimeField| . |ConvertibleTo|) 206784) ((|FreeMonoid| . |Monoid|) T) ((|PAdicRationalConstructor| . |RightModule|) 206725) ((|PAdicRationalConstructor| . |BiModule|) 206634) ((|DoubleFloat| . |LeftOreRing|) T) ((|MyExpression| . |Algebra|) 206522) ((|CartesianTensor| . |BasicType|) T) ((|BasicOperator| . |BasicType|) T) ((|ModMonic| . |UnivariatePolynomialCategory|) 206506) ((|ModuleOperator| . |Ring|) T) ((|MachineComplex| . |FiniteFieldCategory|) NIL) ((|InnerIndexedTwoDimensionalArray| . |CoercibleTo|) 206457) ((|Float| . |OrderedCancellationAbelianMonoid|) T) ((|DeRhamComplex| . |SetCategory|) T) ((|Float| . |OrderedAbelianMonoid|) T) ((|DoubleFloat| . |OrderedAbelianSemiGroup|) T) ((|DoubleFloat| . |OrderedAbelianGroup|) T) ((|OneDimensionalArray| . |ConvertibleTo|) 206393) ((|OneDimensionalArray| . |CoercibleTo|) 206311) ((|DoubleFloat| . |Monoid|) T) ((|IndexedFlexibleArray| . |ConvertibleTo|) 206247) ((|IndexedFlexibleArray| . |CoercibleTo|) 206165) ((|IndexedTwoDimensionalArray| . |CoercibleTo|) 206116) ((|IndexedOneDimensionalArray| . |ConvertibleTo|) 206052) ((|IndexedOneDimensionalArray| . |CoercibleTo|) 205970) ((|SimpleAlgebraicExtension| . |Field|) 205904) ((|AlgebraicFunctionField| . |FullyRetractableTo|) 205875) ((|Asp49| . |Type|) T) ((|BlowUpWithQuadTrans| . |BasicType|) T) ((|ProjectivePlane| . |ProjectiveSpaceCategory|) 205859) ((|PAdicRational| . |PolynomialFactorizationExplicit|) NIL) ((|FiniteFieldExtension| . |FiniteAlgebraicExtensionField|) 205843) ((|FiniteFieldExtension| . |Field|) T) ((|FiniteFieldNormalBasisExtension| . |FiniteAlgebraicExtensionField|) 205827) ((|FiniteFieldNormalBasisExtension| . |Field|) T) ((|FiniteFieldCyclicGroupExtension| . |FiniteAlgebraicExtensionField|) 205811) ((|FiniteFieldCyclicGroupExtension| . |Field|) T) ((|Expression| . |ElementaryFunctionCategory|) 205778) ((|BinaryExpansion| . |Field|) T) ((|Asp30| . |Type|) T) ((|UnivariateLaurentSeries| . |FullyEvalableOver|) 205708) ((|PAdicRational| . |LeftModule|) 205632) ((|UnivariateLaurentSeries| . |FullyLinearlyExplicitRingOver|) 205562) ((|Product| . |CancellationAbelianMonoid|) 205310) ((|OrderedDirectProduct| . |CancellationAbelianMonoid|) 205113) ((|RomanNumeral| . |LeftOreRing|) T) ((|PrimitiveArray| . |LinearAggregate|) 205097) ((|Polynomial| . |LeftOreRing|) 205015) ((|SequentialDifferentialPolynomial| . |CommutativeRing|) 204868) ((|RomanNumeral| . |OrderedAbelianSemiGroup|) T) ((|RomanNumeral| . |OrderedAbelianGroup|) T) ((|PrimitiveArray| . |FiniteLinearAggregate|) 204852) ((|BlowUpWithQuadTrans| . |BlowUpMethodCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |LeftOreRing|) 204770) ((|NeitherSparseOrDensePowerSeries| . |EltableAggregate|) 204699) ((|NewSparseUnivariatePolynomial| . |CommutativeRing|) 204529) ((|NewSparseMultivariatePolynomial| . |CommutativeRing|) 204382) ((|OrderlyDifferentialPolynomial| . |AbelianMonoidRing|) 204302) ((|RomanNumeral| . |Monoid|) T) ((|FlexibleArray| . |HomogeneousAggregate|) 204286) ((|Polynomial| . |Monoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |CommutativeRing|) 204139) ((|DataList| . |Eltable|) 204111) ((|HomogeneousDistributedMultivariatePolynomial| . |Monoid|) T) ((|WuWenTsunTriangularSet| . |Evalable|) 204035) ((|UnivariateTaylorSeriesCZero| . |Algebra|) 203879) ((|UnivariateTaylorSeries| . |PartialDifferentialRing|) 203743) ((|UnivariatePuiseuxSeries| . |PartialDifferentialRing|) 203605) ((|UnivariatePuiseuxSeriesConstructor| . |RightModule|) 203387) ((|UnivariateLaurentSeries| . |PartialDifferentialRing|) 203139) ((|UnivariateLaurentSeriesConstructor| . |RightModule|) 202891) ((|UnivariateFormalPowerSeries| . |PartialDifferentialRing|) 202755) ((|U32Vector| . |BasicType|) T) ((|TaylorSeries| . |EntireRing|) 202722) ((|SquareFreeRegularTriangularSet| . |Collection|) 202706) ((|RuleCalled| . |BasicType|) T) ((|Plot| . |PlottablePlaneCurveCategory|) T) ((|Multiset| . |Evalable|) 202630) ((|Asp41| . |Type|) T) ((|Complex| . |PolynomialFactorizationExplicit|) 202541) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|LiePolynomial| . |FreeModuleCat|) 202505) ((|PlaneAlgebraicCurvePlot| . |PlottablePlaneCurveCategory|) T) ((|Mapping| . |CoercibleTo|) 202479) ((|SingleInteger| . |BasicType|) T) ((|SimpleAlgebraicExtension| . |AbelianMonoid|) T) ((|AntiSymm| . |LeftAlgebra|) 202463) ((|SimpleAlgebraicExtension| . |SemiGroup|) T) ((|RadicalFunctionField| . |FramedAlgebra|) 202429) ((|InnerSparseUnivariatePowerSeries| . |PartialDifferentialRing|) 202304) ((|FunctionCalled| . |BasicType|) T) ((|CharacterClass| . |Evalable|) NIL) ((|PAdicRationalConstructor| . |Ring|) T) ((|OnePointCompletion| . |OrderedSet|) 202274) ((|Asp6| . |Type|) T) ((|ModularField| . |EntireRing|) T) ((|AlgebraicFunctionField| . |Rng|) T) ((|InnerPrimeField| . |CommutativeRing|) T) ((|InnerFiniteField| . |CommutativeRing|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |CoercibleTo|) 202248) ((|Complex| . |LeftModule|) 202130) ((|IndexedDirectProductAbelianGroup| . |CoercibleTo|) 202104) ((|FiniteFieldNormalBasis| . |CharacteristicZero|) 202070) ((|FiniteFieldNormalBasis| . |CharacteristicNonZero|) T) ((|FiniteFieldExtension| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |SemiGroup|) T) ((|FiniteFieldCyclicGroupExtension| . |SemiGroup|) T) ((|RadixExpansion| . |EuclideanDomain|) T) ((|PartialFraction| . |EuclideanDomain|) T) ((|PAdicRationalConstructor| . |DivisionRing|) T) ((|BinaryExpansion| . |SemiGroup|) T) ((|PAdicRationalConstructor| . |DifferentialRing|) 202035) ((|MyExpression| . |FullyPatternMatchable|) 202019) ((|UnivariatePuiseuxSeriesConstructor| . |BiModule|) 201769) ((|UnivariateLaurentSeriesConstructor| . |BiModule|) 201484) ((|DataList| . |UnaryRecursiveAggregate|) 201468) ((|Integer| . |OrderedRing|) T) ((|FiniteFieldExtension| . |AbelianMonoid|) T) ((|FiniteField| . |FiniteFieldCategory|) T) ((|Expression| . |Evalable|) 201455) ((|ExponentialExpansion| . |Evalable|) 201207) ((|FiniteFieldNormalBasisExtension| . |AbelianMonoid|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtension| . |AbelianMonoid|) T) ((|RadixExpansion| . |RealConstant|) T) ((|BinaryExpansion| . |AbelianMonoid|) T) ((|DataList| . |IndexedAggregate|) 201179) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Algebra|) 200935) ((|UnivariatePolynomial| . |PolynomialFactorizationExplicit|) 200885) ((|Boolean| . |SetCategory|) T) ((|PAdicRational| . |LeftOreRing|) T) ((|Result| . |BasicType|) T) ((|UnivariatePolynomial| . |LeftModule|) 200782) ((|PAdicRational| . |OrderedAbelianSemiGroup|) NIL) ((|UnivariateSkewPolynomial| . |LeftModule|) 200756) ((|PAdicRational| . |OrderedAbelianGroup|) NIL) ((|OrderlyDifferentialPolynomial| . |PatternMatchable|) NIL) ((|PAdicRational| . |Monoid|) T) ((|SequentialDifferentialPolynomial| . |InnerEvalable|) 200525) ((|NewSparseUnivariatePolynomial| . |InnerEvalable|) 200435) ((|NewSparseMultivariatePolynomial| . |InnerEvalable|) 200387) ((|Interval| . |LeftModule|) 200374) ((|OrderlyDifferentialPolynomial| . |RetractableTo|) 200091) ((|GeneralDistributedMultivariatePolynomial| . |InnerEvalable|) 199995) ((|FileName| . |FileNameCategory|) T) ((|TwoDimensionalArray| . |Type|) T) ((|LocalAlgebra| . |OrderedSet|) 199965) ((|IndexedBits| . |Logic|) T) ((|SquareFreeRegularTriangularSet| . |PolynomialSetCategory|) 199934) ((|PseudoAlgebraicClosureOfFiniteField| . |RightModule|) 199875) ((|NeitherSparseOrDensePowerSeries| . |RightModule|) 199816) ((|RadicalFunctionField| . |GcdDomain|) T) ((|MachineFloat| . |OrderedRing|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedAbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |RightModule|) 199598) ((|FiniteFieldCyclicGroup| . |SetCategory|) T) ((|ExponentialExpansion| . |StepThrough|) NIL) ((|EuclideanModularRing| . |CancellationAbelianMonoid|) T) ((|ScriptFormulaFormat| . |SetCategory|) T) ((|PAdicInteger| . |Rng|) T) ((|MachineComplex| . |FiniteRankAlgebra|) 199522) ((|PseudoAlgebraicClosureOfFiniteField| . |BiModule|) 199431) ((|NeitherSparseOrDensePowerSeries| . |BiModule|) 199340) ((|DeRhamComplex| . |LeftAlgebra|) 199309) ((|Complex| . |LeftOreRing|) 199210) ((|FlexibleArray| . |Eltable|) 199182) ((|U32Vector| . |Evalable|) NIL) ((|GeneralUnivariatePowerSeries| . |BiModule|) 198932) ((|UnivariatePuiseuxSeriesConstructor| . |Ring|) T) ((|UnivariateLaurentSeriesConstructor| . |Ring|) T) ((|OrderlyDifferentialPolynomial| . |FullyLinearlyExplicitRingOver|) 198916) ((|Complex| . |Monoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |DivisionRing|) 198892) ((|UnivariatePuiseuxSeriesConstructor| . |DifferentialRing|) 198827) ((|UnivariateLaurentSeriesConstructor| . |DifferentialRing|) 198707) ((|UnivariateLaurentSeriesConstructor| . |DivisionRing|) 198683) ((|RadicalFunctionField| . |FieldOfPrimeCharacteristic|) NIL) ((|LieSquareMatrix| . |LinearlyExplicitRingOver|) 198599) ((|Expression| . |Algebra|) 198461) ((|ExponentialExpansion| . |Algebra|) 198333) ((|Asp29| . |CoercibleTo|) 198307) ((|ExponentialOfUnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 198256) ((|Table| . |EltableAggregate|) 198235) ((|SplitHomogeneousDirectProduct| . |SemiGroup|) 198121) ((|Asp74| . |Type|) T) ((|Asp10| . |CoercibleTo|) 198095) ((|HashTable| . |EltableAggregate|) 198074) ((|XDistributedPolynomial| . |RetractableTo|) 198036) ((|SubSpace| . |SetCategory|) T) ((|SplitHomogeneousDirectProduct| . |AbelianMonoid|) 197839) ((|UnivariatePolynomial| . |LeftOreRing|) 197734) ((|OrderlyDifferentialPolynomial| . |PartialDifferentialRing|) 197615) ((|UnivariatePolynomial| . |Monoid|) T) ((|Set| . |Type|) T) ((|SequentialDifferentialPolynomial| . |EntireRing|) 197501) ((|PoincareBirkhoffWittLyndonBasis| . |BasicType|) T) ((|NewSparseUnivariatePolynomial| . |EntireRing|) 197364) ((|Interval| . |LeftOreRing|) T) ((|FlexibleArray| . |OneDimensionalArrayAggregate|) 197348) ((|OneDimensionalArray| . |EltableAggregate|) 197320) ((|NewSparseMultivariatePolynomial| . |EntireRing|) 197206) ((|UnivariateSkewPolynomial| . |Monoid|) T) ((|BalancedPAdicRational| . |OrderedRing|) NIL) ((|IndexedFlexibleArray| . |EltableAggregate|) 197178) ((|FlexibleArray| . |IndexedAggregate|) 197150) ((|IndexedOneDimensionalArray| . |EltableAggregate|) 197122) ((|GeneralDistributedMultivariatePolynomial| . |EntireRing|) 197008) ((|Result| . |Evalable|) 196814) ((|Interval| . |Monoid|) T) ((|Localize| . |CoercibleTo|) 196788) ((|DataList| . |ConvertibleTo|) 196724) ((|DataList| . |CoercibleTo|) 196642) ((|Stack| . |Aggregate|) T) ((|Point| . |Type|) T) ((|FiniteFieldCyclicGroup| . |Module|) 196568) ((|PseudoAlgebraicClosureOfFiniteField| . |Ring|) T) ((|NeitherSparseOrDensePowerSeries| . |Ring|) T) ((|LieSquareMatrix| . |AbelianSemiGroup|) T) ((|LieSquareMatrix| . |AbelianGroup|) T) ((|SingleInteger| . |StepThrough|) T) ((|GeneralUnivariatePowerSeries| . |Ring|) T) ((|AssociatedLieAlgebra| . |FramedNonAssociativeAlgebra|) 196508) ((|AssociatedJordanAlgebra| . |FramedNonAssociativeAlgebra|) 196448) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |DifferentialRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |DivisionRing|) T) ((|NeitherSparseOrDensePowerSeries| . |DifferentialRing|) 196396) ((|NeitherSparseOrDensePowerSeries| . |DivisionRing|) T) ((|InnerPrimeField| . |EntireRing|) T) ((|InnerFiniteField| . |EntireRing|) T) ((|UnivariatePuiseuxSeries| . |EuclideanDomain|) 196372) ((|GeneralUnivariatePowerSeries| . |DifferentialRing|) 196307) ((|GeneralUnivariatePowerSeries| . |DivisionRing|) 196283) ((|UnivariateLaurentSeries| . |EuclideanDomain|) 196259) ((|SimpleAlgebraicExtension| . |CancellationAbelianMonoid|) T) ((|PAdicRationalConstructor| . |OrderedCancellationAbelianMonoid|) 196219) ((|Character| . |BasicType|) T) ((|AlgebraicFunctionField| . |SetCategory|) T) ((|PAdicRationalConstructor| . |OrderedAbelianMonoid|) 196179) ((|List| . |RecursiveAggregate|) 196163) ((|InnerPAdicInteger| . |Rng|) T) ((|Integer| . |Rng|) T) ((|InnerAlgebraicNumber| . |Rng|) T) ((|Fraction| . |GcdDomain|) T) ((|FiniteFieldExtension| . |CancellationAbelianMonoid|) T) ((|Expression| . |FullyPatternMatchable|) 196147) ((|ExponentialExpansion| . |FullyPatternMatchable|) 196062) ((|FiniteFieldNormalBasisExtension| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtension| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeries| . |RealConstant|) NIL) ((|Segment| . |CoercibleTo|) 196013) ((|BinaryExpansion| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |Algebra|) 196000) ((|PositiveInteger| . |SetCategory|) T) ((|NonNegativeInteger| . |SetCategory|) T) ((|LyndonWord| . |SetCategory|) T) ((|MachineInteger| . |CharacteristicZero|) T) ((|SparseUnivariatePolynomialExpressions| . |FullyRetractableTo|) 195984) ((|BalancedPAdicInteger| . |CharacteristicZero|) T) ((|XPolynomial| . |AbelianGroup|) T) ((|XPolynomial| . |AbelianSemiGroup|) T) ((|XPBWPolynomial| . |AbelianGroup|) T) ((|XPBWPolynomial| . |AbelianSemiGroup|) T) ((|LiePolynomial| . |RightModule|) 195968) ((|IndexedExponents| . |OrderedSet|) T) ((|IndexedBits| . |OrderedSet|) T) ((|FiniteFieldExtensionByPolynomial| . |RightModule|) 195909) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |RightModule|) 195850) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |RightModule|) 195791) ((|DirectProductModule| . |Type|) T) ((|DirectProductMatrixModule| . |Type|) T) ((|DifferentialSparseMultivariatePolynomial| . |RightModule|) 195548) ((|DistributedMultivariatePolynomial| . |RightModule|) 195305) ((|LiePolynomial| . |BiModule|) 195284) ((|FiniteFieldExtensionByPolynomial| . |BiModule|) 195193) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |BiModule|) 195102) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |BiModule|) 195011) ((|DifferentialSparseMultivariatePolynomial| . |BiModule|) 194736) ((|DistributedMultivariatePolynomial| . |BiModule|) 194461) ((|OrdinaryDifferentialRing| . |UniqueFactorizationDomain|) 194437) ((|LaurentPolynomial| . |FullyRetractableTo|) 194421) ((|AlgebraGivenByStructuralConstants| . |AbelianGroup|) T) ((|AlgebraGivenByStructuralConstants| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |LinearlyExplicitRingOver|) 194293) ((|OrdinaryDifferentialRing| . |IntegralDomain|) 194269) ((|DirectProductModule| . |RetractableTo|) 194020) ((|DirectProductMatrixModule| . |RetractableTo|) 193771) ((|BinaryTournament| . |BinaryRecursiveAggregate|) 193755) ((|PrimeField| . |RightModule|) 193709) ((|MachineFloat| . |Rng|) T) ((|ModMonic| . |BasicType|) T) ((|DoubleFloatVector| . |LinearAggregate|) 193682) ((|ComplexDoubleFloatVector| . |LinearAggregate|) 193643) ((|FiniteFieldCyclicGroup| . |CommutativeRing|) T) ((|DoubleFloatVector| . |FiniteLinearAggregate|) 193616) ((|ComplexDoubleFloatVector| . |FiniteLinearAggregate|) 193577) ((|CliffordAlgebra| . |AbelianGroup|) T) ((|CliffordAlgebra| . |AbelianSemiGroup|) T) ((|Asp8| . |CoercibleTo|) 193551) ((|PrimeField| . |BiModule|) 193478) ((|AlgebraicFunctionField| . |Module|) 193406) ((|PAdicInteger| . |SetCategory|) T) ((|FlexibleArray| . |ConvertibleTo|) 193342) ((|FlexibleArray| . |CoercibleTo|) 193260) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianMonoid|) 193191) ((|SparseUnivariatePolynomialExpressions| . |Rng|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedCancellationAbelianMonoid|) 193122) ((|DirectProductModule| . |FullyLinearlyExplicitRingOver|) 193090) ((|DirectProductMatrixModule| . |FullyLinearlyExplicitRingOver|) 193058) ((|PseudoAlgebraicClosureOfRationalNumber| . |CoercibleTo|) 193032) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CoercibleTo|) 193006) ((|LinearOrdinaryDifferentialOperator2| . |Algebra|) 192963) ((|KeyedAccessFile| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |SemiGroup|) 192849) ((|GeneralSparseTable| . |Aggregate|) T) ((|SplitHomogeneousDirectProduct| . |CancellationAbelianMonoid|) 192652) ((|SymmetricPolynomial| . |IntegralDomain|) 192619) ((|Product| . |AbelianSemiGroup|) 192299) ((|Palette| . |CoercibleTo|) 192273) ((|Product| . |AbelianGroup|) 192206) ((|OrderedDirectProduct| . |AbelianGroup|) 192093) ((|OrderedDirectProduct| . |AbelianSemiGroup|) 191862) ((|SparseUnivariatePolynomial| . |AbelianMonoidRing|) 191823) ((|LaurentPolynomial| . |Rng|) T) ((|SparseMultivariatePolynomial| . |AbelianMonoidRing|) 191781) ((|GuessOptionFunctions0| . |SetCategory|) T) ((|FiniteFieldExtensionByPolynomial| . |Ring|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Ring|) T) ((|HomogeneousDirectProduct| . |AbelianMonoid|) 191584) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Ring|) T) ((|DifferentialSparseMultivariatePolynomial| . |Ring|) T) ((|DistributedMultivariatePolynomial| . |Ring|) T) ((|ResidueRing| . |LeftModule|) 191558) ((|BalancedPAdicRational| . |Rng|) T) ((|PrimitiveArray| . |Aggregate|) T) ((|MyUnivariatePolynomial| . |UniqueFactorizationDomain|) 191508) ((|FiniteFieldExtensionByPolynomial| . |DifferentialRing|) 191483) ((|FiniteFieldExtensionByPolynomial| . |DivisionRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |DifferentialRing|) 191458) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |DivisionRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |DifferentialRing|) 191433) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |DivisionRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 191391) ((|DistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 191323) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialRing|) 191288) ((|Stream| . |Collection|) 191272) ((|MyUnivariatePolynomial| . |IntegralDomain|) 191135) ((|DirectProductModule| . |PartialDifferentialRing|) 191039) ((|DirectProductMatrixModule| . |PartialDifferentialRing|) 190943) ((|SingletonAsOrderedSet| . |OrderedSet|) T) ((|UniversalSegment| . |Type|) T) ((|FramedModule| . |SemiGroup|) T) ((|U16Vector| . |BasicType|) T) ((|RectangularMatrix| . |AbelianMonoid|) T) ((|PrimeField| . |Ring|) T) ((|FreeAbelianGroup| . |LeftModule|) 190920) ((|RealClosure| . |OrderedRing|) T) ((|TaylorSeries| . |RadicalCategory|) 190869) ((|SparseUnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 190845) ((|SparseUnivariateLaurentSeries| . |PrincipalIdealDomain|) 190821) ((|PrimeField| . |DivisionRing|) T) ((|OrdinaryDifferentialRing| . |Field|) 190797) ((|FreeModule| . |AbelianMonoid|) T) ((|BinaryTree| . |SetCategory|) 190767) ((|BinarySearchTree| . |SetCategory|) 190737) ((|PrimeField| . |DifferentialRing|) T) ((|SparseUnivariateLaurentSeries| . |OrderedIntegralDomain|) NIL) ((|Float| . |LeftModule|) 190691) ((|PAdicInteger| . |Module|) 190678) ((|U8Vector| . |SetCategory|) T) ((|RegularChain| . |Collection|) 190597) ((|AlgebraicFunctionField| . |CommutativeRing|) T) ((|MachineComplex| . |FullyRetractableTo|) 190569) ((|ModMonic| . |Evalable|) 190556) ((|Operator| . |LeftModule|) 190503) ((|OppositeMonogenicLinearOperator| . |LeftModule|) 190477) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator| . |Eltable|) 190456) ((|InnerPAdicInteger| . |SetCategory|) T) ((|Integer| . |SetCategory|) T) ((|InnerAlgebraicNumber| . |SetCategory|) T) ((|DataList| . |EltableAggregate|) 190428) ((|ExponentialExpansion| . |DifferentialExtension|) 190343) ((|SparseUnivariatePolynomial| . |PatternMatchable|) NIL) ((|SparseMultivariatePolynomial| . |PatternMatchable|) 190122) ((|SparseUnivariatePolynomial| . |RetractableTo|) 189932) ((|SparseMultivariatePolynomial| . |RetractableTo|) 189763) ((|SparseUnivariateSkewPolynomial| . |RetractableTo|) 189607) ((|NewSparseUnivariatePolynomial| . |Eltable|) 189510) ((|Plcs| . |CoercibleTo|) 189484) ((|OrdinaryDifferentialRing| . |SemiGroup|) T) ((|ResidueRing| . |Monoid|) T) ((|IndexedVector| . |LinearAggregate|) 189468) ((|RegularChain| . |PolynomialSetCategory|) 189303) ((|Quaternion| . |BasicType|) T) ((|OrdinaryDifferentialRing| . |AbelianMonoid|) T) ((|ModMonic| . |StepThrough|) 189273) ((|MachineComplex| . |Rng|) T) ((|IndexedVector| . |FiniteLinearAggregate|) 189257) ((|FiniteFieldNormalBasis| . |GcdDomain|) T) ((|FiniteFieldCyclicGroup| . |EntireRing|) T) ((|TwoDimensionalViewport| . |SetCategory|) T) ((|GuessOption| . |BasicType|) T) ((|FullPartialFractionExpansion| . |BasicType|) T) ((|EuclideanModularRing| . |AbelianGroup|) T) ((|EuclideanModularRing| . |AbelianSemiGroup|) T) ((|FreeGroup| . |Monoid|) T) ((|Float| . |LeftOreRing|) T) ((|MathMLFormat| . |SetCategory|) T) ((|MachineFloat| . |SetCategory|) T) ((|FreeGroup| . |Group|) T) ((|U16Vector| . |Evalable|) NIL) ((|TaylorSeries| . |CoercibleTo|) 189231) ((|SparseUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 189215) ((|SparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 189199) ((|RealClosure| . |FullyRetractableTo|) 189150) ((|CharacterClass| . |Dictionary|) 189125) ((|Float| . |OrderedAbelianSemiGroup|) T) ((|Float| . |OrderedAbelianGroup|) T) ((|PAdicInteger| . |CommutativeRing|) T) ((|Float| . |Monoid|) T) ((|ModularField| . |CoercibleTo|) 189099) ((|ModMonic| . |Algebra|) 188839) ((|Vector| . |VectorCategory|) 188823) ((|FiniteFieldNormalBasis| . |FieldOfPrimeCharacteristic|) T) ((|Vector| . |SetCategory|) 188760) ((|InnerPAdicInteger| . |Module|) 188747) ((|Integer| . |Module|) 188734) ((|InnerAlgebraicNumber| . |Module|) 188688) ((|PseudoAlgebraicClosureOfFiniteField| . |ExtensionField|) 188672) ((|Expression| . |LiouvillianFunctionCategory|) 188639) ((|Operator| . |Monoid|) T) ((|OppositeMonogenicLinearOperator| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |SetCategory|) T) ((|List| . |Type|) T) ((|SimpleAlgebraicExtension| . |LinearlyExplicitRingOver|) 188555) ((|SparseUnivariatePolynomial| . |PartialDifferentialRing|) 188453) ((|SparseMultivariatePolynomial| . |PartialDifferentialRing|) 188437) ((|Localize| . |RightModule|) 188421) ((|BinaryExpansion| . |LinearlyExplicitRingOver|) 188398) ((|HomogeneousDirectProduct| . |CancellationAbelianMonoid|) 188201) ((|NeitherSparseOrDensePowerSeries| . |LinearAggregate|) 188142) ((|SymmetricPolynomial| . |SemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Finite|) T) ((|Polynomial| . |AbelianMonoidRing|) 188094) ((|MyUnivariatePolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |SetCategory|) T) ((|Localize| . |BiModule|) 188073) ((|FlexibleArray| . |EltableAggregate|) 188045) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianMonoidRing|) 187966) ((|SymmetricPolynomial| . |AbelianMonoid|) T) ((|BasicStochasticDifferential| . |SetCategory|) T) ((|BalancedPAdicRational| . |SetCategory|) T) ((|BalancedBinaryTree| . |BasicType|) 187936) ((|MyUnivariatePolynomial| . |AbelianMonoid|) T) ((|WeightedPolynomials| . |SemiGroup|) T) ((|RectangularMatrix| . |CancellationAbelianMonoid|) T) ((|RealClosure| . |Rng|) T) ((|OrderedFreeMonoid| . |RetractableTo|) 187920) ((|RadicalFunctionField| . |MonogenicAlgebra|) 187886) ((|WeightedPolynomials| . |AbelianMonoid|) T) ((|MachineFloat| . |Module|) 187840) ((|IntegrationResult| . |CoercibleTo|) 187814) ((|FreeMonoid| . |RetractableTo|) 187798) ((|FiniteField| . |Rng|) T) ((|FreeModule| . |CancellationAbelianMonoid|) T) ((|FreeAbelianMonoid| . |RetractableTo|) 187782) ((|DoubleFloat| . |PatternMatchable|) 187761) ((|RadixExpansion| . |PrincipalIdealDomain|) T) ((|ArrayStack| . |Aggregate|) T) ((|RadixExpansion| . |OrderedIntegralDomain|) T) ((|PartialFraction| . |PrincipalIdealDomain|) T) ((|HexadecimalExpansion| . |UniqueFactorizationDomain|) T) ((|TexFormat| . |CoercibleTo|) 187735) ((|SExpressionOf| . |SetCategory|) T) ((|DecimalExpansion| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |Evalable|) 187694) ((|DoubleFloat| . |RetractableTo|) 187638) ((|AlgebraicFunctionField| . |EntireRing|) T) ((|SimpleAlgebraicExtension| . |AbelianGroup|) T) ((|SimpleAlgebraicExtension| . |AbelianSemiGroup|) T) ((|SingleInteger| . |OpenMath|) T) ((|HexadecimalExpansion| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |AbelianGroup|) T) ((|FiniteFieldNormalBasisExtension| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |AbelianGroup|) T) ((|ModuleOperator| . |LeftModule|) 187585) ((|FiniteFieldCyclicGroupExtension| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroupExtension| . |AbelianGroup|) T) ((|BinaryExpansion| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |AbelianGroup|) T) ((|AlgebraicNumber| . |Rng|) T) ((|SparseUnivariatePolynomialExpressions| . |Module|) 187325) ((|InnerPAdicInteger| . |CommutativeRing|) T) ((|Integer| . |CommutativeRing|) T) ((|InnerAlgebraicNumber| . |CommutativeRing|) T) ((|LinearOrdinaryDifferentialOperator| . |CoercibleTo|) 187299) ((|Multiset| . |MultisetAggregate|) 187283) ((|FiniteDivisor| . |CoercibleTo|) 187257) ((|Divisor| . |CoercibleTo|) 187231) ((|Asp28| . |FortranMatrixCategory|) T) ((|Asp28| . |FortranProgramCategory|) T) ((|Set| . |BagAggregate|) 187215) ((|RomanNumeral| . |PatternMatchable|) 187192) ((|Polynomial| . |PatternMatchable|) 187073) ((|LinearOrdinaryDifferentialOperator1| . |SemiGroup|) T) ((|LaurentPolynomial| . |Module|) 187060) ((|HomogeneousDistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|SquareFreeRegularTriangularSet| . |BasicType|) T) ((|RomanNumeral| . |RetractableTo|) 187037) ((|AttributeButtons| . |CoercibleTo|) 187011) ((|Pi| . |CharacteristicZero|) T) ((|Polynomial| . |RetractableTo|) 186836) ((|BalancedPAdicRational| . |Module|) 186752) ((|LinearOrdinaryDifferentialOperator1| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |RetractableTo|) 186559) ((|SequentialDifferentialPolynomial| . |ConvertibleTo|) NIL) ((|SequentialDifferentialPolynomial| . |CoercibleTo|) 186533) ((|NewSparseUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|NewSparseUnivariatePolynomial| . |CoercibleTo|) 186463) ((|NewSparseMultivariatePolynomial| . |ConvertibleTo|) 185902) ((|NewSparseMultivariatePolynomial| . |CoercibleTo|) 185761) ((|SplitHomogeneousDirectProduct| . |LinearlyExplicitRingOver|) 185633) ((|GeneralModulePolynomial| . |CoercibleTo|) 185607) ((|GeneralDistributedMultivariatePolynomial| . |CoercibleTo|) 185581) ((|GeneralDistributedMultivariatePolynomial| . |ConvertibleTo|) 185359) ((|Result| . |Dictionary|) 185292) ((|BinaryTournament| . |Aggregate|) T) ((|OrdinaryDifferentialRing| . |CancellationAbelianMonoid|) T) ((|PAdicRationalConstructor| . |PolynomialFactorizationExplicit|) 185242) ((|ListMonoidOps| . |CoercibleTo|) 185216) ((|FiniteFieldExtensionByPolynomial| . |ExtensionField|) 185200) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |ExtensionField|) 185184) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |ExtensionField|) 185168) ((|BinaryTree| . |InnerEvalable|) 185087) ((|BinarySearchTree| . |InnerEvalable|) 185006) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedCancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedAbelianSemiGroup|) T) ((|BalancedBinaryTree| . |Evalable|) 184930) ((|Dequeue| . |BasicType|) 184900) ((|DoubleFloatVector| . |Aggregate|) T) ((|ComplexDoubleFloatVector| . |Aggregate|) T) ((|MachineComplex| . |SetCategory|) T) ((|MachineFloat| . |CommutativeRing|) T) ((|U8Vector| . |InnerEvalable|) NIL) ((|PAdicRationalConstructor| . |LeftModule|) 184841) ((|Quaternion| . |Algebra|) 184775) ((|Asp20| . |FortranMatrixFunctionCategory|) T) ((|ExtAlgBasis| . |CoercibleTo|) 184749) ((|Asp20| . |FortranProgramCategory|) T) ((|Polynomial| . |FullyLinearlyExplicitRingOver|) 184733) ((|PAdicInteger| . |EntireRing|) T) ((|AntiSymm| . |CoercibleTo|) 184707) ((|PseudoAlgebraicClosureOfRationalNumber| . |RightModule|) 184661) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |RightModule|) 184564) ((|InnerPrimeField| . |CoercibleTo|) 184538) ((|InnerPrimeField| . |ConvertibleTo|) 184515) ((|HomogeneousDistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 184499) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 184473) ((|InnerFiniteField| . |CoercibleTo|) 184447) ((|PrimeField| . |ExtensionField|) 184434) ((|PAdicRational| . |Type|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |BiModule|) 184361) ((|MachineInteger| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |BiModule|) 184194) ((|InnerAlgebraicNumber| . |InnerEvalable|) 184156) ((|HexadecimalExpansion| . |Field|) T) ((|FiniteFieldExtensionByPolynomial| . |Finite|) 184131) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Finite|) 184106) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Finite|) 184081) ((|DecimalExpansion| . |Field|) T) ((|ModuleOperator| . |Monoid|) T) ((|BalancedPAdicInteger| . |GcdDomain|) T) ((|SparseUnivariatePolynomialExpressions| . |CommutativeRing|) 183911) ((|XPolynomialRing| . |XAlgebra|) 183895) ((|PAdicRational| . |Patternable|) 183862) ((|PAdicRational| . |PatternMatchable|) NIL) ((|Product| . |OrderedSet|) 183706) ((|OrderedDirectProduct| . |OrderedSet|) 183630) ((|LinearOrdinaryDifferentialOperator2| . |LinearOrdinaryDifferentialOperatorCategory|) 183614) ((|Tree| . |Aggregate|) T) ((|SubSpaceComponentProperty| . |CoercibleTo|) 183588) ((|SplitHomogeneousDirectProduct| . |AbelianGroup|) 183475) ((|SplitHomogeneousDirectProduct| . |AbelianSemiGroup|) 183244) ((|ProjectiveSpace| . |SetCategory|) T) ((|PAdicRational| . |RetractableTo|) 183211) ((|Polynomial| . |PartialDifferentialRing|) 183189) ((|UnivariatePolynomial| . |AbelianMonoidRing|) 183150) ((|PrimeField| . |Finite|) T) ((|OneDimensionalArray| . |LinearAggregate|) 183134) ((|IndexedFlexibleArray| . |LinearAggregate|) 183118) ((|HomogeneousDistributedMultivariatePolynomial| . |PartialDifferentialRing|) 183078) ((|Asp31| . |FortranVectorFunctionCategory|) T) ((|Asp31| . |FortranProgramCategory|) T) ((|IndexedOneDimensionalArray| . |LinearAggregate|) 183062) ((|OneDimensionalArray| . |FiniteLinearAggregate|) 183046) ((|LaurentPolynomial| . |CommutativeRing|) T) ((|IndexedFlexibleArray| . |FiniteLinearAggregate|) 183030) ((|IndexedOneDimensionalArray| . |FiniteLinearAggregate|) 183014) ((|OppositeMonogenicLinearOperator| . |MonogenicLinearOperator|) 182998) ((|SparseUnivariatePolynomial| . |EuclideanDomain|) 182974) ((|SymmetricPolynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |CommutativeRing|) T) ((|MyUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|SquareFreeRegularTriangularSet| . |Evalable|) 182898) ((|Complex| . |Type|) T) ((|AssociatedLieAlgebra| . |NonAssociativeAlgebra|) 182882) ((|AssociatedJordanAlgebra| . |NonAssociativeAlgebra|) 182866) ((|WeightedPolynomials| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 182842) ((|UnivariateLaurentSeries| . |PrincipalIdealDomain|) 182818) ((|UnivariateLaurentSeries| . |OrderedIntegralDomain|) NIL) ((|MachineComplex| . |Module|) 182747) ((|UnivariateLaurentSeriesConstructor| . |PolynomialFactorizationExplicit|) 182668) ((|RealClosure| . |SetCategory|) T) ((|PAdicRational| . |FullyLinearlyExplicitRingOver|) 182635) ((|PAdicRational| . |FullyEvalableOver|) 182602) ((|Permutation| . |SemiGroup|) T) ((|Complex| . |Patternable|) 182586) ((|Complex| . |PatternMatchable|) 182467) ((|Vector| . |InnerEvalable|) 182386) ((|PAdicRationalConstructor| . |LeftOreRing|) T) ((|HexadecimalExpansion| . |SemiGroup|) T) ((|FiniteField| . |SetCategory|) T) ((|DecimalExpansion| . |SemiGroup|) T) ((|Asp42| . |FortranVectorFunctionCategory|) T) ((|Asp42| . |FortranProgramCategory|) T) ((|UnivariatePuiseuxSeriesConstructor| . |LeftModule|) 182255) ((|Complex| . |RetractableTo|) 182099) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedSet|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Ring|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Ring|) T) ((|UnivariateLaurentSeriesConstructor| . |LeftModule|) 181938) ((|PAdicRationalConstructor| . |OrderedAbelianSemiGroup|) 181898) ((|PAdicRationalConstructor| . |OrderedAbelianGroup|) 181858) ((|XRecursivePolynomial| . |XFreeAlgebra|) 181837) ((|PAdicRationalConstructor| . |Monoid|) T) ((|HexadecimalExpansion| . |AbelianMonoid|) T) ((|DeRhamComplex| . |CoercibleTo|) 181811) ((|ContinuedFraction| . |GcdDomain|) T) ((|Dequeue| . |Evalable|) 181735) ((|Asp7| . |FortranVectorFunctionCategory|) T) ((|Asp7| . |FortranProgramCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |DivisionRing|) T) ((|DecimalExpansion| . |AbelianMonoid|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |DivisionRing|) T) ((|MyExpression| . |FullyRetractableTo|) 181719) ((|InfClsPt| . |InfinitlyClosePointCategory|) 181483) ((|InnerPAdicInteger| . |EntireRing|) T) ((|Integer| . |EntireRing|) T) ((|Magma| . |RetractableTo|) 181467) ((|InnerAlgebraicNumber| . |EntireRing|) T) ((|SparseUnivariatePolynomialExpressions| . |InnerEvalable|) 181377) ((|CartesianTensor| . |GradedModule|) 181295) ((|BlowUpWithHamburgerNoether| . |SetCategory|) T) ((|AlgebraicNumber| . |SetCategory|) T) ((|ModMonic| . |DifferentialExtension|) 181279) ((|PAdicRational| . |PartialDifferentialRing|) NIL) ((|UnivariatePolynomial| . |PatternMatchable|) NIL) ((|PatternMatchResult| . |BasicType|) T) ((|PatternMatchListResult| . |BasicType|) T) ((|FileName| . |SetCategory|) T) ((|Complex| . |FullyLinearlyExplicitRingOver|) 181263) ((|Complex| . |FullyEvalableOver|) 181247) ((|UnivariatePolynomial| . |RetractableTo|) 181057) ((|UnivariateSkewPolynomial| . |RetractableTo|) 180901) ((|SquareMatrix| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator1| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |InnerEvalable|) 180615) ((|Localize| . |OrderedAbelianMonoid|) 180577) ((|Localize| . |OrderedCancellationAbelianMonoid|) 180539) ((|Interval| . |RetractableTo|) 180516) ((|Equation| . |VectorSpace|) 180483) ((|OrdinaryWeightedPolynomials| . |BasicType|) T) ((|PolynomialRing| . |IntegralDomain|) 180450) ((|TaylorSeries| . |RightModule|) 180283) ((|HomogeneousDirectProduct| . |LinearlyExplicitRingOver|) 180155) ((|PermutationGroup| . |SetCategory|) T) ((|RealClosure| . |Module|) 180076) ((|ModularField| . |RightModule|) 180030) ((|PseudoAlgebraicClosureOfFiniteField| . |LeftModule|) 179971) ((|NeitherSparseOrDensePowerSeries| . |LeftModule|) 179912) ((|IndexedVector| . |Aggregate|) T) ((|Stack| . |Type|) T) ((|TaylorSeries| . |BiModule|) 179713) ((|GeneralUnivariatePowerSeries| . |LeftModule|) 179582) ((|FiniteField| . |Module|) 179508) ((|Complex| . |PartialDifferentialRing|) 179440) ((|MachineFloat| . |EntireRing|) T) ((|MyExpression| . |Rng|) T) ((|MachineComplex| . |CommutativeRing|) T) ((|ModularField| . |BiModule|) 179367) ((|IntegerMod| . |Rng|) T) ((|UnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 179351) ((|Factored| . |UniqueFactorizationDomain|) 179307) ((|ExponentialExpansion| . |OrderedRing|) NIL) ((|UnivariatePuiseuxSeriesConstructor| . |LeftOreRing|) 179283) ((|UnivariateLaurentSeriesConstructor| . |LeftOreRing|) 179259) ((|Factored| . |IntegralDomain|) T) ((|DoubleFloat| . |EuclideanDomain|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianGroup|) 179190) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianSemiGroup|) 179121) ((|AffinePlane| . |SetCategoryWithDegree|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Monoid|) T) ((|UnivariateLaurentSeriesConstructor| . |Monoid|) T) ((|AlgebraicNumber| . |Module|) 179075) ((|SparseUnivariatePolynomialExpressions| . |EntireRing|) 178938) ((|DoubleFloat| . |RealConstant|) T) ((|FiniteFieldNormalBasis| . |VectorSpace|) 178907) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |FullyRetractableTo|) 178853) ((|MoebiusTransform| . |Monoid|) T) ((|UnivariatePolynomial| . |PartialDifferentialRing|) 178751) ((|Boolean| . |CoercibleTo|) 178725) ((|Boolean| . |ConvertibleTo|) 178700) ((|MoebiusTransform| . |Group|) T) ((|HomogeneousDirectProduct| . |AbelianGroup|) 178587) ((|BinaryTree| . |HomogeneousAggregate|) 178571) ((|BinarySearchTree| . |HomogeneousAggregate|) 178555) ((|HomogeneousDirectProduct| . |AbelianSemiGroup|) 178324) ((|LaurentPolynomial| . |EntireRing|) T) ((|NeitherSparseOrDensePowerSeries| . |Aggregate|) T) ((|U8Vector| . |HomogeneousAggregate|) 178301) ((|IntegrationResult| . |RightModule|) 178265) ((|U8Matrix| . |TwoDimensionalArrayCategory|) 178216) ((|FortranType| . |SetCategory|) T) ((|RomanNumeral| . |EuclideanDomain|) T) ((|BalancedPAdicRational| . |EntireRing|) T) ((|SExpression| . |BasicType|) T) ((|RadicalFunctionField| . |BasicType|) T) ((|IntegrationResult| . |BiModule|) 178155) ((|UnivariateTaylorSeriesCZero| . |Rng|) T) ((|SquareMatrix| . |Evalable|) 178079) ((|TaylorSeries| . |Ring|) T) ((|RomanNumeral| . |RealConstant|) T) ((|Asp24| . |Type|) T) ((|RectangularMatrix| . |AbelianSemiGroup|) T) ((|RectangularMatrix| . |AbelianGroup|) T) ((|ModularField| . |Ring|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |LeftOreRing|) T) ((|NeitherSparseOrDensePowerSeries| . |LeftOreRing|) T) ((|FreeModule| . |AbelianGroup|) T) ((|FreeModule| . |AbelianSemiGroup|) T) ((|MachineComplex| . |InnerEvalable|) NIL) ((|RealClosure| . |CommutativeRing|) T) ((|GeneralUnivariatePowerSeries| . |LeftOreRing|) 178055) ((|ModularField| . |DivisionRing|) T) ((|RomanNumeral| . |IntegerNumberSystem|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Monoid|) T) ((|NeitherSparseOrDensePowerSeries| . |Monoid|) T) ((|IndexCard| . |BasicType|) T) ((|FiniteField| . |CommutativeRing|) T) ((|FiniteFieldCyclicGroup| . |CoercibleTo|) 178029) ((|ScriptFormulaFormat| . |CoercibleTo|) 178003) ((|GeneralUnivariatePowerSeries| . |Monoid|) T) ((|SingleInteger| . |OrderedRing|) T) ((|Pattern| . |RetractableTo|) 177968) ((|BinaryExpansion| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator| . |RightModule|) 177952) ((|HexadecimalExpansion| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Rng|) T) ((|DecimalExpansion| . |CancellationAbelianMonoid|) T) ((|Divisor| . |RightModule|) 177929) ((|Stream| . |BasicType|) 177899) ((|Automorphism| . |SetCategory|) T) ((|DataList| . |ListAggregate|) 177883) ((|DataList| . |LinearAggregate|) 177867) ((|LinearOrdinaryDifferentialOperator| . |BiModule|) 177846) ((|Expression| . |FullyRetractableTo|) 177830) ((|DataList| . |FiniteLinearAggregate|) 177814) ((|StringTable| . |DictionaryOperations|) 177750) ((|Quaternion| . |DifferentialExtension|) 177734) ((|Divisor| . |BiModule|) 177699) ((|Asp35| . |Type|) T) ((|AlgebraicNumber| . |CommutativeRing|) T) ((|MachineInteger| . |FortranMachineTypeCategory|) T) ((|MachineInteger| . |CombinatorialFunctionCategory|) T) ((|XPolynomialRing| . |BasicType|) T) ((|SequentialDifferentialPolynomial| . |RightModule|) 177456) ((|DifferentialSparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 177406) ((|DistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 177356) ((|NewSparseUnivariatePolynomial| . |RightModule|) 177090) ((|NewSparseMultivariatePolynomial| . |RightModule|) 176847) ((|KeyedAccessFile| . |Type|) T) ((|SubSpace| . |CoercibleTo|) 176821) ((|SequentialDifferentialPolynomial| . |BiModule|) 176546) ((|RegularChain| . |BasicType|) T) ((|GeneralSparseTable| . |Type|) T) ((|GeneralModulePolynomial| . |RightModule|) 176517) ((|GeneralDistributedMultivariatePolynomial| . |RightModule|) 176274) ((|LiePolynomial| . |LeftModule|) 176258) ((|PAdicRational| . |EuclideanDomain|) T) ((|NewSparseUnivariatePolynomial| . |BiModule|) 175960) ((|NewSparseMultivariatePolynomial| . |BiModule|) 175685) ((|FiniteFieldExtensionByPolynomial| . |LeftModule|) 175626) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |LeftModule|) 175567) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |LeftModule|) 175508) ((|DifferentialSparseMultivariatePolynomial| . |LeftModule|) 175405) ((|DistributedMultivariatePolynomial| . |LeftModule|) 175302) ((|String| . |OrderedSet|) T) ((|GeneralModulePolynomial| . |BiModule|) 175263) ((|GeneralDistributedMultivariatePolynomial| . |BiModule|) 174988) ((|SequentialDifferentialVariable| . |RetractableTo|) 174972) ((|RewriteRule| . |RetractableTo|) 174943) ((|Queue| . |Aggregate|) T) ((|PrimitiveArray| . |Type|) T) ((|BinaryTournament| . |RecursiveAggregate|) 174927) ((|PolynomialRing| . |SemiGroup|) T) ((|PAdicRational| . |RealConstant|) NIL) ((|MonoidRing| . |SemiGroup|) T) ((|ModularRing| . |SemiGroup|) T) ((|Vector| . |HomogeneousAggregate|) 174911) ((|SquareMatrix| . |Algebra|) 174856) ((|PolynomialRing| . |AbelianMonoid|) T) ((|PrimeField| . |LeftModule|) 174810) ((|OrderedCompletion| . |BasicType|) T) ((|OrdinaryDifferentialRing| . |AbelianGroup|) T) ((|OrdinaryDifferentialRing| . |AbelianSemiGroup|) T) ((|MonoidRing| . |AbelianMonoid|) T) ((|ModularRing| . |AbelianMonoid|) T) ((|Bits| . |Logic|) T) ((|NottinghamGroup| . |Monoid|) T) ((|InnerPrimeField| . |RightModule|) 174764) ((|InnerFiniteField| . |RightModule|) 174685) ((|DenavitHartenbergMatrix| . |TwoDimensionalArrayCategory|) 174637) ((|GenericNonAssociativeAlgebra| . |AbelianMonoid|) T) ((|Fraction| . |BasicType|) T) ((|DrawOption| . |BasicType|) T) ((|NottinghamGroup| . |Group|) T) ((|ProjectivePlane| . |BasicType|) T) ((|MachineComplex| . |EntireRing|) T) ((|OrdinaryWeightedPolynomials| . |Algebra|) 174594) ((|U8Vector| . |Eltable|) 174559) ((|InnerPrimeField| . |BiModule|) 174486) ((|InnerFiniteField| . |BiModule|) 174355) ((|MyUnivariatePolynomial| . |LinearlyExplicitRingOver|) 174271) ((|Factored| . |SemiGroup|) T) ((|Expression| . |Rng|) 174103) ((|ExponentialExpansion| . |Rng|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 174077) ((|MyExpression| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |Ring|) T) ((|IntegerMod| . |SetCategory|) T) ((|Complex| . |EuclideanDomain|) 173978) ((|Factored| . |AbelianMonoid|) T) ((|AlgebraicFunctionField| . |CoercibleTo|) 173952) ((|AlgebraicFunctionField| . |ConvertibleTo|) 173936) ((|BinaryExpansion| . |QuotientFieldCategory|) 173913) ((|BalancedPAdicInteger| . |PAdicIntegerCategory|) 173897) ((|AlgebraicNumber| . |InnerEvalable|) 173859) ((|Tree| . |RecursiveAggregate|) 173843) ((|Table| . |Aggregate|) T) ((|PositiveInteger| . |CoercibleTo|) 173817) ((|SplitHomogeneousDirectProduct| . |OrderedSet|) 173741) ((|NonNegativeInteger| . |CoercibleTo|) 173715) ((|LyndonWord| . |CoercibleTo|) 173689) ((|UnivariatePolynomial| . |EuclideanDomain|) 173665) ((|U8Vector| . |OneDimensionalArrayAggregate|) 173642) ((|U8Vector| . |IndexedAggregate|) 173607) ((|Stream| . |Evalable|) 173531) ((|SegmentBinding| . |Type|) T) ((|HashTable| . |Aggregate|) T) ((|SequentialDifferentialPolynomial| . |Ring|) T) ((|Pi| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |ExtensionField|) 173495) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |ExtensionField|) 173408) ((|SplittingTree| . |Aggregate|) T) ((|NewSparseUnivariatePolynomial| . |Ring|) T) ((|NewSparseMultivariatePolynomial| . |Ring|) T) ((|ListMultiDictionary| . |DictionaryOperations|) 173392) ((|Library| . |DictionaryOperations|) 173325) ((|SymmetricPolynomial| . |AbelianGroup|) T) ((|SymmetricPolynomial| . |AbelianSemiGroup|) T) ((|SequentialDifferentialPolynomial| . |FiniteAbelianMonoidRing|) 173242) ((|SequentialDifferentialPolynomial| . |DifferentialRing|) 173207) ((|NewSparseUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 173168) ((|NewSparseUnivariatePolynomial| . |DifferentialRing|) T) ((|GeneralDistributedMultivariatePolynomial| . |Ring|) T) ((|NewSparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 173126) ((|MultivariatePolynomial| . |UniqueFactorizationDomain|) 173076) ((|FiniteFieldExtensionByPolynomial| . |LeftOreRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |LeftOreRing|) T) ((|FlexibleArray| . |LinearAggregate|) 173060) ((|DifferentialSparseMultivariatePolynomial| . |LeftOreRing|) 172978) ((|DistributedMultivariatePolynomial| . |LeftOreRing|) 172896) ((|OneDimensionalArray| . |Aggregate|) T) ((|InnerIndexedTwoDimensionalArray| . |Aggregate|) T) ((|IndexedFlexibleArray| . |Aggregate|) T) ((|GeneralDistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 172875) ((|FlexibleArray| . |FiniteLinearAggregate|) 172859) ((|IndexedTwoDimensionalArray| . |Aggregate|) T) ((|IndexedOneDimensionalArray| . |Aggregate|) T) ((|RadicalFunctionField| . |StepThrough|) NIL) ((|MultivariatePolynomial| . |IntegralDomain|) 172745) ((|AssociatedLieAlgebra| . |BasicType|) T) ((|AssociatedJordanAlgebra| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |Monoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Monoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Monoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |Monoid|) T) ((|DistributedMultivariatePolynomial| . |Monoid|) T) ((|MyUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|MyUnivariatePolynomial| . |AbelianGroup|) T) ((|WeightedPolynomials| . |AbelianGroup|) T) ((|RegularChain| . |Evalable|) 172509) ((|WeightedPolynomials| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeriesCZero| . |SetCategory|) T) ((|PendantTree| . |SetCategory|) 172479) ((|AntiSymm| . |Ring|) T) ((|SparseUnivariateTaylorSeries| . |IntegralDomain|) 172446) ((|SparseUnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 172422) ((|SparseUnivariatePuiseuxSeries| . |IntegralDomain|) 172361) ((|SparseUnivariateLaurentSeries| . |UniqueFactorizationDomain|) 172337) ((|PrimeField| . |LeftOreRing|) T) ((|InnerPrimeField| . |Ring|) T) ((|InnerFiniteField| . |Ring|) T) ((|InfClsPt| . |BasicType|) T) ((|RealClosure| . |EntireRing|) T) ((|FreeGroup| . |RetractableTo|) 172321) ((|FreeAbelianGroup| . |RetractableTo|) 172305) ((|DesingTree| . |SetCategory|) 172275) ((|Float| . |PatternMatchable|) 172254) ((|SparseUnivariateLaurentSeries| . |IntegralDomain|) 172193) ((|SparseMultivariateTaylorSeries| . |IntegralDomain|) 172160) ((|RadicalFunctionField| . |Algebra|) 172088) ((|Octonion| . |SemiGroup|) T) ((|PrimeField| . |Monoid|) T) ((|InnerPrimeField| . |DivisionRing|) T) ((|InnerPrimeField| . |DifferentialRing|) T) ((|InnerFiniteField| . |DifferentialRing|) T) ((|InnerFiniteField| . |DivisionRing|) T) ((|MyExpression| . |Module|) 171976) ((|FiniteField| . |EntireRing|) T) ((|ListMultiDictionary| . |MultiDictionary|) 171960) ((|Float| . |RetractableTo|) 171904) ((|DesingTree| . |DesingTreeCategory|) 171888) ((|SingleInteger| . |Rng|) T) ((|BalancedBinaryTree| . |BinaryTreeCategory|) 171872) ((|Octonion| . |AbelianMonoid|) T) ((|XPolynomial| . |XFreeAlgebra|) 171845) ((|XPBWPolynomial| . |XFreeAlgebra|) 171824) ((|Vector| . |Eltable|) 171796) ((|Fraction| . |Evalable|) 171755) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |SetCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |Eltable|) 171658) ((|PAdicInteger| . |CoercibleTo|) 171632) ((|Operator| . |RetractableTo|) 171590) ((|d01TransformFunctionType| . |NumericalIntegrationCategory|) T) ((|d01gbfAnnaType| . |NumericalIntegrationCategory|) T) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |AffineSpaceCategory|) 171534) ((|d01fcfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01asfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01aqfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01apfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01anfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01amfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01alfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01akfAnnaType| . |NumericalIntegrationCategory|) T) ((|InnerAlgebraicNumber| . |RadicalCategory|) T) ((|e04ucfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04nafAnnaType| . |NumericalOptimizationCategory|) T) ((|e04mbfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04jafAnnaType| . |NumericalOptimizationCategory|) T) ((|AlgebraicNumber| . |EntireRing|) T) ((|e04gcfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04fdfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04dgfAnnaType| . |NumericalOptimizationCategory|) T) ((|d01ajfAnnaType| . |NumericalIntegrationCategory|) T) ((|Kernel| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator2| . |FullyRetractableTo|) 171518) ((|Bits| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator1| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator1| . |AbelianSemiGroup|) T) ((|GuessOptionFunctions0| . |CoercibleTo|) 171492) ((|XPolynomialRing| . |Algebra|) 171449) ((|Vector| . |OneDimensionalArrayAggregate|) 171433) ((|BalancedPAdicRational| . |Eltable|) 171286) ((|DoubleFloatMatrix| . |BasicType|) T) ((|ComplexDoubleFloatMatrix| . |BasicType|) T) ((|Vector| . |IndexedAggregate|) 171258) ((|WuWenTsunTriangularSet| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |Module|) 171102) ((|Ruleset| . |SetCategory|) T) ((|QuasiAlgebraicSet| . |SetCategory|) T) ((|PolynomialRing| . |CancellationAbelianMonoid|) T) ((|Multiset| . |SetCategory|) T) ((|MonoidRing| . |CancellationAbelianMonoid|) T) ((|ModularRing| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianMonoidSup|) T) ((|Fraction| . |StepThrough|) 171072) ((|GenericNonAssociativeAlgebra| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianSemiGroup|) T) ((|DeRhamComplex| . |Ring|) T) ((|Equation| . |BasicType|) 170769) ((|CharacterClass| . |SetCategory|) T) ((|MachineFloat| . |RadicalCategory|) T) ((|ArrayStack| . |Type|) T) ((|BinaryTree| . |CoercibleTo|) 170720) ((|BinarySearchTree| . |CoercibleTo|) 170671) ((|MyExpression| . |CommutativeRing|) T) ((|IntegerMod| . |CommutativeRing|) T) ((|U8Vector| . |ConvertibleTo|) 170646) ((|U8Vector| . |CoercibleTo|) 170620) ((|SparseUnivariatePuiseuxSeries| . |Field|) 170596) ((|SparseUnivariateLaurentSeries| . |Field|) 170572) ((|Expression| . |SetCategory|) T) ((|Factored| . |CancellationAbelianMonoid|) T) ((|ExponentialExpansion| . |SetCategory|) T) ((|Fraction| . |Algebra|) 170513) ((|ThreeSpace| . |BasicType|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Module|) 170269) ((|LinearOrdinaryDifferentialOperator2| . |Rng|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CharacteristicNonZero|) 170229) ((|ExponentialOfUnivariatePuiseuxSeries| . |CharacteristicZero|) 170192) ((|CartesianTensor| . |SetCategory|) T) ((|BasicOperator| . |SetCategory|) T) ((|OrdSetInts| . |BasicType|) T) ((|InnerPAdicInteger| . |CoercibleTo|) 170166) ((|Integer| . |ConvertibleTo|) 170028) ((|Integer| . |CoercibleTo|) 170002) ((|InnerAlgebraicNumber| . |CoercibleTo|) 169976) ((|InnerAlgebraicNumber| . |ConvertibleTo|) 169901) ((|HyperellipticFiniteDivisor| . |AbelianMonoid|) T) ((|HomogeneousDirectProduct| . |OrderedSet|) 169825) ((|BlowUpWithQuadTrans| . |SetCategory|) T) ((|HexadecimalExpansion| . |LinearlyExplicitRingOver|) 169802) ((|NeitherSparseOrDensePowerSeries| . |RecursiveAggregate|) 169743) ((|DecimalExpansion| . |LinearlyExplicitRingOver|) 169720) ((|DoubleFloat| . |FloatingPointSystem|) T) ((|Localize| . |LeftModule|) 169704) ((|SparseUnivariatePolynomial| . |PrincipalIdealDomain|) 169680) ((|MultivariatePolynomial| . |SemiGroup|) T) ((|FiniteFieldNormalBasis| . |BasicType|) T) ((|OrderlyDifferentialVariable| . |OrderedSet|) T) ((|MultivariatePolynomial| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |RightModule|) 169606) ((|String| . |StringCategory|) T) ((|Stack| . |BagAggregate|) 169590) ((|UnivariateTaylorSeriesCZero| . |CommutativeRing|) 169519) ((|SparseUnivariateTaylorSeries| . |SemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |SemiGroup|) T) ((|SparseUnivariateLaurentSeries| . |SemiGroup|) T) ((|SparseMultivariateTaylorSeries| . |SemiGroup|) T) ((|InnerFreeAbelianMonoid| . |RetractableTo|) 169503) ((|FiniteFieldCyclicGroup| . |BiModule|) 169382) ((|DoubleFloatMatrix| . |Evalable|) NIL) ((|ComplexDoubleFloatMatrix| . |Evalable|) NIL) ((|RadixExpansion| . |UniqueFactorizationDomain|) T) ((|BinaryTournament| . |Type|) T) ((|PartialFraction| . |UniqueFactorizationDomain|) T) ((|TwoDimensionalViewport| . |CoercibleTo|) 169356) ((|U32Vector| . |SetCategory|) T) ((|MachineComplex| . |Eltable|) NIL) ((|SparseUnivariateTaylorSeries| . |AbelianMonoid|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |AbelianMonoid|) T) ((|SquareMatrix| . |DifferentialExtension|) 169340) ((|SparseMultivariateTaylorSeries| . |AbelianMonoid|) T) ((|RuleCalled| . |SetCategory|) T) ((|RadixExpansion| . |IntegralDomain|) T) ((|PartialFraction| . |IntegralDomain|) T) ((|Octonion| . |CancellationAbelianMonoid|) T) ((|DoubleFloatVector| . |Type|) T) ((|ComplexDoubleFloatVector| . |Type|) T) ((|MyExpression| . |InnerEvalable|) 169302) ((|MathMLFormat| . |CoercibleTo|) 169276) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|Expression| . |Module|) 169138) ((|ExponentialExpansion| . |Module|) 169010) ((|MachineFloat| . |CoercibleTo|) 168984) ((|MachineFloat| . |ConvertibleTo|) 168909) ((|Fraction| . |FullyPatternMatchable|) 168893) ((|FunctionCalled| . |SetCategory|) T) ((|HexadecimalExpansion| . |AbelianSemiGroup|) T) ((|HexadecimalExpansion| . |AbelianGroup|) T) ((|SingleInteger| . |SetCategory|) T) ((|DecimalExpansion| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |AbelianGroup|) T) ((|ModMonic| . |FullyRetractableTo|) 168877) ((|ModuleOperator| . |RetractableTo|) 168835) ((|Vector| . |CoercibleTo|) 168753) ((|Vector| . |ConvertibleTo|) 168689) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CommutativeRing|) T) ((|DataList| . |Aggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |ConvertibleTo|) NIL) ((|SparseUnivariatePolynomialExpressions| . |CoercibleTo|) 168663) ((|Plot3D| . |PlottableSpaceCurveCategory|) T) ((|Tree| . |Type|) T) ((|Localize| . |OrderedAbelianGroup|) 168625) ((|Localize| . |OrderedAbelianSemiGroup|) 168587) ((|FortranProgram| . |FortranProgramCategory|) T) ((|IndexedMatrix| . |BasicType|) 168557) ((|Result| . |SetCategory|) T) ((|Dequeue| . |QueueAggregate|) 168541) ((|PolynomialIdeals| . |BasicType|) T) ((|LaurentPolynomial| . |CoercibleTo|) 168515) ((|AssociationList| . |OrderedSet|) NIL) ((|LaurentPolynomial| . |ConvertibleTo|) 168486) ((|Result| . |KeyedDictionary|) 168456) ((|PendantTree| . |InnerEvalable|) 168375) ((|FiniteFieldCyclicGroup| . |Ring|) T) ((|BasicStochasticDifferential| . |CoercibleTo|) 168349) ((|BalancedPAdicRational| . |ConvertibleTo|) NIL) ((|BalancedPAdicRational| . |CoercibleTo|) 168323) ((|PAdicRationalConstructor| . |Type|) T) ((|LieSquareMatrix| . |FramedNonAssociativeAlgebra|) 168307) ((|LieSquareMatrix| . |SquareMatrixCategory|) 168230) ((|DesingTree| . |InnerEvalable|) 168149) ((|IndexedBits| . |Collection|) 168126) ((|FiniteFieldCyclicGroup| . |DifferentialRing|) T) ((|FiniteFieldCyclicGroup| . |DivisionRing|) T) ((|AlgebraicFunctionField| . |RightModule|) 168054) ((|PAdicRationalConstructor| . |Patternable|) 168038) ((|PAdicRationalConstructor| . |PatternMatchable|) 167919) ((|ModMonic| . |Rng|) T) ((|MachineComplex| . |RadicalCategory|) NIL) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianMonoidRing|) 167878) ((|UnivariateLaurentSeriesConstructor| . |AbelianMonoidRing|) 167850) ((|SplittingTree| . |RecursiveAggregate|) 167811) ((|SingleInteger| . |Module|) 167798) ((|SExpressionOf| . |CoercibleTo|) 167772) ((|PAdicRationalConstructor| . |RetractableTo|) 167574) ((|DoubleFloat| . |PrincipalIdealDomain|) T) ((|AlgebraicFunctionField| . |BiModule|) 167457) ((|MyExpression| . |EntireRing|) T) ((|SimpleAlgebraicExtension| . |CharacteristicZero|) 167420) ((|SimpleAlgebraicExtension| . |CharacteristicNonZero|) 167338) ((|RadixExpansion| . |Field|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |LeftModule|) 167292) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |LeftModule|) 167195) ((|ExponentialOfUnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 167144) ((|Float| . |EuclideanDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 167093) ((|Expression| . |CommutativeRing|) 167060) ((|ExponentialExpansion| . |CommutativeRing|) T) ((|RadicalFunctionField| . |DifferentialExtension|) 167031) ((|PartialFraction| . |Field|) T) ((|InnerPrimeField| . |ExtensionField|) 167018) ((|InnerFiniteField| . |ExtensionField|) 166982) ((|FiniteFieldExtension| . |CharacteristicZero|) 166945) ((|FiniteFieldExtension| . |CharacteristicNonZero|) 166876) ((|FiniteFieldNormalBasisExtension| . |CharacteristicZero|) 166839) ((|FiniteFieldNormalBasisExtension| . |CharacteristicNonZero|) 166770) ((|KeyedAccessFile| . |TableAggregate|) 166743) ((|FiniteFieldCyclicGroupExtension| . |CharacteristicZero|) 166706) ((|FiniteFieldCyclicGroupExtension| . |CharacteristicNonZero|) 166637) ((|ExponentialOfUnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 166586) ((|GeneralSparseTable| . |TableAggregate|) 166565) ((|Enumeration| . |EnumerationCategory|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 166514) ((|Float| . |RealConstant|) T) ((|BinaryExpansion| . |CharacteristicZero|) T) ((|BinaryExpansion| . |CharacteristicNonZero|) NIL) ((|AssociationList| . |DictionaryOperations|) 166456) ((|LinearOrdinaryDifferentialOperator2| . |SetCategory|) T) ((|KeyedAccessFile| . |BagAggregate|) 166392) ((|HyperellipticFiniteDivisor| . |CancellationAbelianMonoid|) T) ((|GeneralSparseTable| . |BagAggregate|) 166334) ((|DirectProduct| . |SemiGroup|) 166220) ((|StochasticDifferential| . |SemiGroup|) T) ((|PAdicRationalConstructor| . |FullyLinearlyExplicitRingOver|) 166204) ((|PAdicRationalConstructor| . |FullyEvalableOver|) 166188) ((|DirectProduct| . |AbelianMonoid|) 165991) ((|RomanNumeral| . |PrincipalIdealDomain|) T) ((|RomanNumeral| . |OrderedIntegralDomain|) T) ((|InnerPrimeField| . |Finite|) T) ((|InnerFiniteField| . |Finite|) T) ((|MyUnivariatePolynomial| . |OrderedSet|) 165962) ((|U8Vector| . |EltableAggregate|) 165927) ((|FiniteFieldNormalBasis| . |StepThrough|) T) ((|FlexibleArray| . |Aggregate|) T) ((|AlgebraGivenByStructuralConstants| . |FramedNonAssociativeAlgebra|) 165911) ((|StochasticDifferential| . |AbelianMonoid|) T) ((|FreeNilpotentLie| . |NonAssociativeAlgebra|) 165895) ((|WuWenTsunTriangularSet| . |InnerEvalable|) 165814) ((|MultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|UnivariateTaylorSeriesCZero| . |EntireRing|) 165781) ((|UnivariateTaylorSeries| . |IntegralDomain|) 165748) ((|UnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 165724) ((|UnivariatePuiseuxSeries| . |IntegralDomain|) 165663) ((|UnivariateLaurentSeries| . |UniqueFactorizationDomain|) 165639) ((|UnivariateLaurentSeries| . |IntegralDomain|) 165578) ((|Multiset| . |InnerEvalable|) 165497) ((|UnivariateLaurentSeriesConstructor| . |Type|) 165473) ((|UnivariateLaurentSeriesConstructor| . |PatternMatchable|) 165296) ((|PoincareBirkhoffWittLyndonBasis| . |SetCategory|) T) ((|Character| . |OrderedFinite|) T) ((|UnivariateLaurentSeriesConstructor| . |Patternable|) 165263) ((|UnivariateFormalPowerSeries| . |IntegralDomain|) 165230) ((|SparseUnivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|IndexedMatrix| . |Evalable|) 165154) ((|SparseUnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|CharacterClass| . |InnerEvalable|) NIL) ((|SparseUnivariateLaurentSeries| . |CancellationAbelianMonoid|) T) ((|SparseMultivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|RealClosure| . |RadicalCategory|) T) ((|RadixExpansion| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasis| . |Algebra|) 165108) ((|RadixExpansion| . |SemiGroup|) T) ((|PartialFraction| . |SemiGroup|) T) ((|Asp73| . |CoercibleTo|) 165082) ((|AlgebraicFunctionField| . |Ring|) T) ((|PAdicInteger| . |RightModule|) 165069) ((|PAdicRationalConstructor| . |PartialDifferentialRing|) 165001) ((|NeitherSparseOrDensePowerSeries| . |AbelianMonoidRing|) 164973) ((|MachineInteger| . |BasicType|) T) ((|RadicalFunctionField| . |FiniteFieldCategory|) NIL) ((|IndexedVector| . |Type|) T) ((|Partition| . |AbelianMonoid|) T) ((|PartialFraction| . |AbelianMonoid|) T) ((|PAdicInteger| . |BiModule|) 164958) ((|FourierSeries| . |SemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |AbelianMonoidRing|) 164917) ((|CardinalNumber| . |BasicType|) T) ((|AlgebraicFunctionField| . |DifferentialRing|) 164869) ((|AlgebraicFunctionField| . |DivisionRing|) T) ((|BalancedPAdicInteger| . |BasicType|) T) ((|InnerTaylorSeries| . |IntegralDomain|) 164836) ((|InnerSparseUnivariatePowerSeries| . |IntegralDomain|) 164803) ((|MachineComplex| . |CoercibleTo|) 164777) ((|MachineComplex| . |ConvertibleTo|) 164622) ((|Expression| . |InnerEvalable|) 164584) ((|ExponentialExpansion| . |InnerEvalable|) 163990) ((|PseudoAlgebraicClosureOfRationalNumber| . |LeftOreRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |LeftOreRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |RetractableTo|) 163974) ((|UnivariateLaurentSeriesConstructor| . |RetractableTo|) 163689) ((|Quaternion| . |FullyRetractableTo|) 163673) ((|FourierSeries| . |AbelianMonoid|) T) ((|SingleInteger| . |CommutativeRing|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Monoid|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Monoid|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |EntireRing|) T) ((|LinearOrdinaryDifferentialOperator2| . |Module|) 163630) ((|Character| . |SetCategory|) T) ((|AlgebraicNumber| . |RadicalCategory|) T) ((|Fraction| . |DifferentialExtension|) 163614) ((|EqTable| . |DictionaryOperations|) 163556) ((|PAdicRational| . |PrincipalIdealDomain|) T) ((|PAdicRational| . |OrderedIntegralDomain|) NIL) ((|ProjectiveSpace| . |CoercibleTo|) 163530) ((|OrderedVariableList| . |OrderedSet|) T) ((|UnivariateLaurentSeriesConstructor| . |FullyEvalableOver|) 163497) ((|UnivariateLaurentSeriesConstructor| . |FullyLinearlyExplicitRingOver|) 163464) ((|Dequeue| . |StackAggregate|) 163448) ((|NeitherSparseOrDensePowerSeries| . |Type|) T) ((|Vector| . |EltableAggregate|) 163420) ((|HTMLFormat| . |BasicType|) T) ((|TaylorSeries| . |LeftModule|) 163317) ((|PolynomialRing| . |AbelianGroup|) T) ((|PolynomialRing| . |AbelianSemiGroup|) T) ((|MonoidRing| . |AbelianGroup|) T) ((|MonoidRing| . |AbelianSemiGroup|) T) ((|ModularRing| . |AbelianGroup|) T) ((|ModularRing| . |AbelianSemiGroup|) T) ((|ModularField| . |LeftModule|) 163271) ((|GenericNonAssociativeAlgebra| . |AbelianGroup|) T) ((|GenericNonAssociativeAlgebra| . |AbelianSemiGroup|) T) ((|FortranExpression| . |BasicType|) T) ((|ContinuedFraction| . |BasicType|) T) ((|Quaternion| . |Rng|) T) ((|PAdicInteger| . |Ring|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |RetractableTo|) 163255) ((|None| . |BasicType|) T) ((|U32Vector| . |InnerEvalable|) NIL) ((|UnivariatePuiseuxSeries| . |Field|) 163231) ((|UnivariatePuiseuxSeriesConstructor| . |PartialDifferentialRing|) 163093) ((|UnivariateLaurentSeries| . |Field|) 163069) ((|UnivariateLaurentSeriesConstructor| . |PartialDifferentialRing|) 162858) ((|RealClosure| . |CoercibleTo|) 162832) ((|Fraction| . |OpenMath|) 162762) ((|SparseUnivariateTaylorSeries| . |HyperbolicFunctionCategory|) 162711) ((|Complex| . |PrincipalIdealDomain|) 162612) ((|SparseUnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 162561) ((|SparseUnivariateLaurentSeries| . |HyperbolicFunctionCategory|) 162510) ((|ModMonic| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |HyperbolicFunctionCategory|) 162459) ((|InnerPAdicInteger| . |RightModule|) 162446) ((|Integer| . |RightModule|) 162433) ((|InnerAlgebraicNumber| . |RightModule|) 162387) ((|Expression| . |EntireRing|) 162354) ((|ExponentialExpansion| . |EntireRing|) T) ((|FiniteField| . |CoercibleTo|) 162328) ((|Factored| . |AbelianSemiGroup|) T) ((|Factored| . |AbelianGroup|) T) ((|Automorphism| . |Eltable|) 162307) ((|InnerPAdicInteger| . |BiModule|) 162292) ((|Integer| . |BiModule|) 162277) ((|InnerAlgebraicNumber| . |BiModule|) 162204) ((|Symbol| . |PatternMatchable|) 162163) ((|AffineSpace| . |BasicType|) T) ((|PendantTree| . |HomogeneousAggregate|) 162147) ((|BlowUpWithHamburgerNoether| . |CoercibleTo|) 162121) ((|AlgebraicNumber| . |CoercibleTo|) 162095) ((|AlgebraicNumber| . |ConvertibleTo|) 162020) ((|DesingTree| . |HomogeneousAggregate|) 162004) ((|DirectProduct| . |CancellationAbelianMonoid|) 161807) ((|UnivariatePolynomial| . |PrincipalIdealDomain|) 161783) ((|OrderlyDifferentialPolynomial| . |UniqueFactorizationDomain|) 161733) ((|Result| . |InnerEvalable|) 161483) ((|StochasticDifferential| . |CancellationAbelianMonoid|) T) ((|FileName| . |CoercibleTo|) 161457) ((|OrderlyDifferentialPolynomial| . |IntegralDomain|) 161343) ((|IntegrationResult| . |LeftModule|) 161307) ((|DifferentialSparseMultivariatePolynomial| . |AbelianMonoidRing|) 161265) ((|DistributedMultivariatePolynomial| . |AbelianMonoidRing|) 161197) ((|IndexedExponents| . |IndexedDirectProductCategory|) 161158) ((|Queue| . |Type|) T) ((|UnivariateTaylorSeries| . |AbelianMonoid|) T) ((|UnivariateTaylorSeries| . |SemiGroup|) T) ((|UnivariatePuiseuxSeries| . |SemiGroup|) T) ((|MachineFloat| . |RightModule|) 161112) ((|NeitherSparseOrDensePowerSeries| . |PartialDifferentialRing|) 160987) ((|UnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|UnivariateLaurentSeries| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |SemiGroup|) T) ((|RadicalFunctionField| . |FiniteRankAlgebra|) 160953) ((|ModularField| . |LeftOreRing|) T) ((|Boolean| . |Finite|) T) ((|GeneralUnivariatePowerSeries| . |PartialDifferentialRing|) 160815) ((|UnivariateLaurentSeries| . |AbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |AbelianMonoid|) T) ((|PermutationGroup| . |CoercibleTo|) 160789) ((|ArrayStack| . |BagAggregate|) 160773) ((|TaylorSeries| . |Monoid|) T) ((|Permutation| . |OrderedSet|) 160715) ((|MachineInteger| . |StepThrough|) T) ((|MachineFloat| . |BiModule|) 160642) ((|U16Vector| . |SetCategory|) T) ((|InnerTaylorSeries| . |SemiGroup|) T) ((|InnerSparseUnivariatePowerSeries| . |SemiGroup|) T) ((|ModMonic| . |Module|) 160382) ((|ModularField| . |Monoid|) T) ((|SingleInteger| . |EntireRing|) T) ((|RadixExpansion| . |CancellationAbelianMonoid|) T) ((|HexadecimalExpansion| . |OrderedSet|) T) ((|Partition| . |CancellationAbelianMonoid|) T) ((|PartialFraction| . |CancellationAbelianMonoid|) T) ((|Octonion| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |OrderedSet|) T) ((|Octonion| . |AbelianGroup|) T) ((|InnerPAdicInteger| . |Ring|) T) ((|Integer| . |Ring|) T) ((|InnerAlgebraicNumber| . |Ring|) T) ((|InnerTaylorSeries| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |ExtensionField|) 160351) ((|ExponentialOfUnivariatePuiseuxSeries| . |GcdDomain|) 160327) ((|FortranExpression| . |Evalable|) 160314) ((|InnerSparseUnivariatePowerSeries| . |AbelianMonoid|) T) ((|FourierSeries| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator| . |LeftModule|) 160288) ((|SparseUnivariatePolynomialExpressions| . |RightModule|) 160022) ((|DataList| . |RecursiveAggregate|) 160006) ((|PAdicRationalConstructor| . |EuclideanDomain|) T) ((|XRecursivePolynomial| . |XAlgebra|) 159990) ((|NonNegativeInteger| . |OrderedAbelianMonoid|) T) ((|NonNegativeInteger| . |OrderedCancellationAbelianMonoid|) T) ((|MachineInteger| . |Algebra|) 159977) ((|Divisor| . |LeftModule|) 159954) ((|Integer| . |DifferentialRing|) T) ((|InnerAlgebraicNumber| . |DivisionRing|) T) ((|InnerAlgebraicNumber| . |DifferentialRing|) T) ((|SparseUnivariatePolynomialExpressions| . |BiModule|) 159656) ((|SparseTable| . |DictionaryOperations|) 159598) ((|SequentialDifferentialPolynomial| . |PolynomialFactorizationExplicit|) 159548) ((|BalancedPAdicInteger| . |Algebra|) 159535) ((|d02ejfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02cjfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02bhfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02bbfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|PAdicRationalConstructor| . |RealConstant|) 159504) ((|WuWenTsunTriangularSet| . |HomogeneousAggregate|) 159488) ((|NewSparseUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 159438) ((|NewSparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 159388) ((|Table| . |Type|) T) ((|GeneralDistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 159338) ((|Multiset| . |HomogeneousAggregate|) 159322) ((|SequentialDifferentialPolynomial| . |LeftModule|) 159219) ((|NewSparseUnivariatePolynomial| . |LeftModule|) 159116) ((|LaurentPolynomial| . |RightModule|) 159103) ((|HashTable| . |Type|) T) ((|FiniteFieldCyclicGroup| . |Finite|) T) ((|CharacterClass| . |HomogeneousAggregate|) 159078) ((|NewSparseMultivariatePolynomial| . |LeftModule|) 158975) ((|SplittingTree| . |Type|) T) ((|GeneralModulePolynomial| . |LeftModule|) 158946) ((|DifferentialSparseMultivariatePolynomial| . |PatternMatchable|) 158725) ((|DistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|BalancedPAdicRational| . |RightModule|) 158641) ((|GeneralDistributedMultivariatePolynomial| . |LeftModule|) 158538) ((|LiePolynomial| . |RetractableTo|) 158507) ((|LaurentPolynomial| . |BiModule|) 158492) ((|FiniteFieldExtensionByPolynomial| . |RetractableTo|) 158476) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |RetractableTo|) 158460) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |RetractableTo|) 158444) ((|DifferentialSparseMultivariatePolynomial| . |RetractableTo|) 158211) ((|DistributedMultivariatePolynomial| . |RetractableTo|) 158018) ((|BalancedPAdicRational| . |BiModule|) 157877) ((|OneDimensionalArray| . |Type|) T) ((|InnerIndexedTwoDimensionalArray| . |Type|) T) ((|IndexedFlexibleArray| . |Type|) T) ((|IndexedTwoDimensionalArray| . |Type|) T) ((|IndexedOneDimensionalArray| . |Type|) T) ((|FortranType| . |CoercibleTo|) 157851) ((|FortranScalarType| . |CoercibleTo|) 157825) ((|Union| . |BasicType|) T) ((|RegularTriangularSet| . |TriangularSetCategory|) 157794) ((|OnePointCompletion| . |BasicType|) T) ((|Matrix| . |TwoDimensionalArrayCategory|) 157746) ((|MachineFloat| . |Ring|) T) ((|AntiSymm| . |LeftModule|) 157720) ((|EuclideanModularRing| . |GcdDomain|) T) ((|GeneralTriangularSet| . |TriangularSetCategory|) 157689) ((|UnivariateTaylorSeriesCZero| . |Eltable|) 157674) ((|Enumeration| . |BasicType|) T) ((|InnerPrimeField| . |LeftModule|) 157628) ((|InnerFiniteField| . |LeftModule|) 157549) ((|AnonymousFunction| . |BasicType|) T) ((|PrimeField| . |RetractableTo|) 157536) ((|MachineFloat| . |DivisionRing|) T) ((|SimpleAlgebraicExtension| . |FramedAlgebra|) 157515) ((|MultivariatePolynomial| . |LinearlyExplicitRingOver|) 157431) ((|Quaternion| . |SetCategory|) T) ((|ModMonic| . |CommutativeRing|) 157261) ((|HexadecimalExpansion| . |QuotientFieldCategory|) 157238) ((|GuessOption| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 157222) ((|DistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 157206) ((|FullPartialFractionExpansion| . |SetCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |Ring|) T) ((|FortranExpression| . |Algebra|) 157190) ((|Reference| . |BasicType|) 157160) ((|DecimalExpansion| . |QuotientFieldCategory|) 157137) ((|ContinuedFraction| . |Algebra|) 157052) ((|UnivariatePuiseuxSeriesConstructor| . |EuclideanDomain|) 157028) ((|UnivariateLaurentSeriesConstructor| . |EuclideanDomain|) 157004) ((|SparseUnivariatePolynomialExpressions| . |FiniteAbelianMonoidRing|) 156965) ((|LinearOrdinaryDifferentialOperator| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |DifferentialRing|) T) ((|Automorphism| . |CoercibleTo|) 156939) ((|SparseUnivariateLaurentSeries| . |LinearlyExplicitRingOver|) 156863) ((|HyperellipticFiniteDivisor| . |AbelianSemiGroup|) T) ((|HyperellipticFiniteDivisor| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |RealConstant|) 156803) ((|SequentialDifferentialPolynomial| . |LeftOreRing|) 156721) ((|LaurentPolynomial| . |Ring|) T) ((|Float| . |FloatingPointSystem|) T) ((|NewSparseUnivariatePolynomial| . |LeftOreRing|) 156616) ((|NewSparseMultivariatePolynomial| . |LeftOreRing|) 156534) ((|FreeNilpotentLie| . |BasicType|) T) ((|DifferentialSparseMultivariatePolynomial| . |PartialDifferentialRing|) 156453) ((|DistributedMultivariatePolynomial| . |PartialDifferentialRing|) 156413) ((|BalancedPAdicRational| . |Ring|) T) ((|GeneralDistributedMultivariatePolynomial| . |LeftOreRing|) 156331) ((|OrderlyDifferentialPolynomial| . |SemiGroup|) T) ((|SequentialDifferentialPolynomial| . |Monoid|) T) ((|LaurentPolynomial| . |DifferentialRing|) 156296) ((|LocalAlgebra| . |BasicType|) T) ((|U32Vector| . |HomogeneousAggregate|) 156273) ((|NewSparseUnivariatePolynomial| . |Monoid|) T) ((|NewSparseMultivariatePolynomial| . |Monoid|) T) ((|U32Matrix| . |TwoDimensionalArrayCategory|) 156222) ((|FractionalIdeal| . |SemiGroup|) T) ((|BalancedPAdicRational| . |DivisionRing|) T) ((|AlgebraicFunctionField| . |Finite|) NIL) ((|BalancedPAdicRational| . |DifferentialRing|) NIL) ((|GeneralDistributedMultivariatePolynomial| . |Monoid|) T) ((|OrderlyDifferentialPolynomial| . |AbelianMonoid|) T) ((|MultivariatePolynomial| . |AbelianSemiGroup|) T) ((|MultivariatePolynomial| . |AbelianGroup|) T) ((|MakeCachableSet| . |OrderedSet|) T) ((|Ruleset| . |Eltable|) 156201) ((|Asp4| . |FortranFunctionCategory|) T) ((|Asp4| . |FortranProgramCategory|) T) ((|UnivariateTaylorSeriesCZero| . |RadicalCategory|) 156150) ((|UnivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|MachineComplex| . |RightModule|) 156079) ((|UnivariateLaurentSeries| . |CancellationAbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |CancellationAbelianMonoid|) T) ((|SparseUnivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|Stream| . |StreamAggregate|) 156063) ((|SquareMatrix| . |FullyRetractableTo|) 156047) ((|InnerPrimeField| . |LeftOreRing|) T) ((|AssociatedLieAlgebra| . |FiniteRankNonAssociativeAlgebra|) 155928) ((|AssociatedJordanAlgebra| . |FiniteRankNonAssociativeAlgebra|) 155809) ((|InnerFiniteField| . |LeftOreRing|) T) ((|BalancedBinaryTree| . |SetCategory|) 155779) ((|SparseUnivariateTaylorSeries| . |AbelianGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|Quaternion| . |Module|) 155713) ((|DeRhamComplex| . |LeftModule|) 155672) ((|MachineComplex| . |BiModule|) 155557) ((|AntiSymm| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |AbelianGroup|) T) ((|FiniteFieldNormalBasis| . |FiniteFieldCategory|) T) ((|SparseUnivariateLaurentSeries| . |AbelianSemiGroup|) T) ((|SimpleAlgebraicExtension| . |GcdDomain|) 155491) ((|SparseMultivariateTaylorSeries| . |AbelianGroup|) T) ((|ModMonic| . |InnerEvalable|) 155401) ((|InnerPrimeField| . |Monoid|) T) ((|InnerFiniteField| . |Monoid|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |EuclideanDomain|) T) ((|SparseMultivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|NeitherSparseOrDensePowerSeries| . |EuclideanDomain|) T) ((|InnerTaylorSeries| . |CancellationAbelianMonoid|) T) ((|InnerSparseUnivariatePowerSeries| . |CancellationAbelianMonoid|) T) ((|FiniteFieldExtension| . |GcdDomain|) T) ((|FiniteFieldNormalBasisExtension| . |GcdDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |GcdDomain|) T) ((|GeneralUnivariatePowerSeries| . |EuclideanDomain|) 155377) ((|ExponentialExpansion| . |Eltable|) 155054) ((|BinaryExpansion| . |GcdDomain|) T) ((|Asp50| . |FortranVectorFunctionCategory|) T) ((|Asp50| . |FortranProgramCategory|) T) ((|Pi| . |BasicType|) T) ((|MyExpression| . |ConvertibleTo|) 154832) ((|MyExpression| . |CoercibleTo|) 154806) ((|IntegerMod| . |CoercibleTo|) 154780) ((|IntegerMod| . |ConvertibleTo|) 154757) ((|SimpleAlgebraicExtension| . |FieldOfPrimeCharacteristic|) 154719) ((|Result| . |HomogeneousAggregate|) 154636) ((|Integer| . |OrderedCancellationAbelianMonoid|) T) ((|Integer| . |OrderedAbelianMonoid|) T) ((|RoutinesTable| . |DictionaryOperations|) 154569) ((|FiniteFieldExtension| . |FieldOfPrimeCharacteristic|) 154500) ((|FiniteFieldNormalBasisExtension| . |FieldOfPrimeCharacteristic|) 154431) ((|FiniteFieldCyclicGroupExtension| . |FieldOfPrimeCharacteristic|) 154362) ((|XDistributedPolynomial| . |SemiGroup|) T) ((|XDistributedPolynomial| . |AbelianMonoid|) T) ((|ThreeDimensionalViewport| . |BasicType|) T) ((|SquareMatrix| . |Rng|) T) ((|LieSquareMatrix| . |NonAssociativeAlgebra|) 154346) ((|SymmetricPolynomial| . |CharacteristicNonZero|) 154306) ((|SymmetricPolynomial| . |CharacteristicZero|) 154269) ((|SquareFreeRegularTriangularSet| . |SetCategory|) T) ((|SquareFreeRegularTriangularSet| . |RegularTriangularSetCategory|) 154238) ((|Asp29| . |Type|) T) ((|RealClosure| . |RightModule|) 154159) ((|OrdinaryWeightedPolynomials| . |Rng|) T) ((|MyUnivariatePolynomial| . |CharacteristicNonZero|) 154119) ((|MyUnivariatePolynomial| . |CharacteristicZero|) 154082) ((|DirectProduct| . |LinearlyExplicitRingOver|) 153954) ((|MachineComplex| . |Ring|) T) ((|DirichletRing| . |IntegralDomain|) 153920) ((|FiniteField| . |RightModule|) 153846) ((|Asp10| . |Type|) T) ((|RealClosure| . |BiModule|) 153723) ((|PendantTree| . |CoercibleTo|) 153674) ((|MachineComplex| . |DivisionRing|) T) ((|MachineComplex| . |DifferentialRing|) NIL) ((|U16Vector| . |InnerEvalable|) NIL) ((|OrderedCompletion| . |OrderedRing|) 153644) ((|MachineFloat| . |OrderedCancellationAbelianMonoid|) T) ((|MachineFloat| . |OrderedAbelianMonoid|) T) ((|UnivariateTaylorSeriesCZero| . |CoercibleTo|) 153618) ((|U32Vector| . |Eltable|) 153583) ((|RadicalFunctionField| . |FullyRetractableTo|) 153554) ((|FiniteField| . |BiModule|) 153433) ((|DesingTree| . |CoercibleTo|) 153384) ((|Float| . |PrincipalIdealDomain|) T) ((|Fraction| . |OrderedRing|) 153344) ((|ModMonic| . |EntireRing|) 153207) ((|DeRhamComplex| . |Monoid|) T) ((|UnivariateTaylorSeries| . |HyperbolicFunctionCategory|) 153156) ((|UnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 153105) ((|UnivariateLaurentSeries| . |HyperbolicFunctionCategory|) 153054) ((|UnivariateFormalPowerSeries| . |HyperbolicFunctionCategory|) 153003) ((|Expression| . |RadicalCategory|) 152970) ((|Dequeue| . |SetCategory|) 152940) ((|ExponentialOfUnivariatePuiseuxSeries| . |PowerSeriesCategory|) 152873) ((|BasicFunctions| . |BasicType|) T) ((|AlgebraicNumber| . |RightModule|) 152827) ((|XRecursivePolynomial| . |BasicType|) T) ((|FreeModule1| . |BasicType|) T) ((|AlgebraicNumber| . |BiModule|) 152754) ((|RadixExpansion| . |LinearlyExplicitRingOver|) 152731) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CoercibleTo|) 152705) ((|IndexedExponents| . |BasicType|) T) ((|IndexedBits| . |BasicType|) T) ((|ThreeSpace| . |ThreeSpaceCategory|) 152689) ((|CliffordAlgebra| . |VectorSpace|) 152673) ((|DataList| . |Type|) T) ((|U32Vector| . |OneDimensionalArrayAggregate|) 152650) ((|NeitherSparseOrDensePowerSeries| . |LazyStreamAggregate|) 152591) ((|SparseUnivariatePolynomial| . |UniqueFactorizationDomain|) 152541) ((|SparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 152491) ((|DirectProduct| . |AbelianGroup|) 152378) ((|DirectProduct| . |AbelianSemiGroup|) 152147) ((|BinaryTree| . |BinaryRecursiveAggregate|) 152131) ((|BinarySearchTree| . |BinaryRecursiveAggregate|) 152115) ((|U8Vector| . |LinearAggregate|) 152092) ((|AlgebraGivenByStructuralConstants| . |NonAssociativeAlgebra|) 152076) ((|U32Vector| . |IndexedAggregate|) 152041) ((|SparseUnivariatePolynomial| . |IntegralDomain|) 151904) ((|SparseMultivariatePolynomial| . |IntegralDomain|) 151790) ((|U8Vector| . |FiniteLinearAggregate|) 151767) ((|Result| . |Eltable|) 151737) ((|StochasticDifferential| . |AbelianSemiGroup|) T) ((|StochasticDifferential| . |AbelianGroup|) T) ((|OrderlyDifferentialPolynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |OrderedCancellationAbelianMonoid|) NIL) ((|BalancedPAdicRational| . |OrderedAbelianMonoid|) NIL) ((|FiniteFieldExtensionByPolynomial| . |EuclideanDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |EuclideanDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |EuclideanDomain|) T) ((|Segment| . |Type|) T) ((|DirectProductModule| . |SemiGroup|) 151623) ((|DirectProductMatrixModule| . |SemiGroup|) 151509) ((|RealClosure| . |Ring|) T) ((|RadicalFunctionField| . |Rng|) T) ((|FiniteFieldCyclicGroup| . |LeftModule|) 151435) ((|LocalAlgebra| . |Algebra|) 151419) ((|WuWenTsunTriangularSet| . |CoercibleTo|) 151371) ((|WuWenTsunTriangularSet| . |ConvertibleTo|) 151307) ((|Ruleset| . |CoercibleTo|) 151281) ((|RealClosure| . |DivisionRing|) T) ((|FiniteField| . |Ring|) T) ((|OrderedDirectProduct| . |VectorSpace|) 151248) ((|DirectProductModule| . |AbelianMonoid|) T) ((|DirectProductMatrixModule| . |AbelianMonoid|) T) ((|QuasiAlgebraicSet| . |CoercibleTo|) 151222) ((|Multiset| . |ConvertibleTo|) 151158) ((|Multiset| . |CoercibleTo|) 151132) ((|Octonion| . |OrderedSet|) 151103) ((|Quaternion| . |InnerEvalable|) 150992) ((|FiniteField| . |DifferentialRing|) T) ((|FiniteField| . |DivisionRing|) T) ((|StringTable| . |Collection|) 150928) ((|RadixExpansion| . |AbelianSemiGroup|) T) ((|CharacterClass| . |CoercibleTo|) 150902) ((|CharacterClass| . |ConvertibleTo|) 150849) ((|PrimeField| . |EuclideanDomain|) T) ((|RadixExpansion| . |AbelianGroup|) T) ((|Partition| . |AbelianSemiGroup|) T) ((|PartialFraction| . |AbelianGroup|) T) ((|PartialFraction| . |AbelianSemiGroup|) T) ((|FourierSeries| . |AbelianGroup|) T) ((|FourierSeries| . |AbelianSemiGroup|) T) ((|OrderedCompletion| . |FullyRetractableTo|) 150833) ((|AlgebraicNumber| . |Ring|) T) ((|XPolynomial| . |XAlgebra|) 150817) ((|XPBWPolynomial| . |XAlgebra|) 150801) ((|Result| . |IndexedAggregate|) 150771) ((|Expression| . |ConvertibleTo|) 150549) ((|Expression| . |CoercibleTo|) 150523) ((|ExponentialExpansion| . |ConvertibleTo|) NIL) ((|ExponentialExpansion| . |CoercibleTo|) 150497) ((|AlgebraicNumber| . |DivisionRing|) T) ((|AlgebraicNumber| . |DifferentialRing|) T) ((|LinearOrdinaryDifferentialOperator2| . |Eltable|) 150458) ((|InnerTable| . |DictionaryOperations|) 150400) ((|CartesianTensor| . |CoercibleTo|) 150374) ((|BasicOperator| . |CoercibleTo|) 150348) ((|Pi| . |Algebra|) 150302) ((|XRecursivePolynomial| . |XPolynomialsCat|) 150281) ((|XDistributedPolynomial| . |CancellationAbelianMonoid|) T) ((|XPolynomialRing| . |Rng|) T) ((|SingletonAsOrderedSet| . |BasicType|) T) ((|BlowUpWithQuadTrans| . |CoercibleTo|) 150255) ((|Asp8| . |Type|) T) ((|IndexedBits| . |Evalable|) NIL) ((|Queue| . |BagAggregate|) 150239) ((|PatternMatchResult| . |SetCategory|) T) ((|PatternMatchListResult| . |SetCategory|) T) ((|Vector| . |LinearAggregate|) 150223) ((|Vector| . |FiniteLinearAggregate|) 150207) ((|FlexibleArray| . |Type|) T) ((|IndexedString| . |OrderedSet|) T) ((|DirichletRing| . |SemiGroup|) T) ((|SquareMatrix| . |SetCategory|) T) ((|SquareMatrix| . |RectangularMatrixCategory|) 150125) ((|FiniteFieldCyclicGroup| . |LeftOreRing|) T) ((|BalancedBinaryTree| . |InnerEvalable|) 150044) ((|Plot| . |CoercibleTo|) 150018) ((|DirichletRing| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |Monoid|) T) ((|PlaneAlgebraicCurvePlot| . |CoercibleTo|) 149992) ((|OrdinaryWeightedPolynomials| . |SetCategory|) T) ((|OrderedCompletion| . |Rng|) 149962) ((|AlgebraicFunctionField| . |LeftModule|) 149890) ((|DoubleFloat| . |UniqueFactorizationDomain|) T) ((|Fraction| . |Rng|) T) ((|String| . |Collection|) 149865) ((|Quaternion| . |EntireRing|) 149808) ((|DoubleFloat| . |IntegralDomain|) T) ((|U32Vector| . |ConvertibleTo|) 149783) ((|ExponentialOfUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 149767) ((|ExponentialOfUnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 149726) ((|U32Vector| . |CoercibleTo|) 149700) ((|Table| . |TableAggregate|) 149679) ((|RuleCalled| . |CoercibleTo|) 149653) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 149627) ((|PseudoAlgebraicClosureOfRationalNumber| . |RetractableTo|) 149571) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |RetractableTo|) 149464) ((|ListMultiDictionary| . |Collection|) 149448) ((|Library| . |Collection|) 149381) ((|Table| . |BagAggregate|) 149323) ((|HashTable| . |TableAggregate|) 149302) ((|HexadecimalExpansion| . |CharacteristicZero|) T) ((|HexadecimalExpansion| . |CharacteristicNonZero|) NIL) ((|SingleInteger| . |ConvertibleTo|) 149183) ((|FunctionCalled| . |CoercibleTo|) 149157) ((|DecimalExpansion| . |CharacteristicZero|) T) ((|DecimalExpansion| . |CharacteristicNonZero|) NIL) ((|SingleInteger| . |CoercibleTo|) 149131) ((|Any| . |BasicType|) T) ((|UnivariateLaurentSeries| . |LinearlyExplicitRingOver|) 149061) ((|HashTable| . |BagAggregate|) 149003) ((|QuadraticForm| . |AbelianMonoid|) T) ((|XRecursivePolynomial| . |Algebra|) 148960) ((|SparseUnivariatePolynomial| . |SemiGroup|) T) ((|SparseMultivariatePolynomial| . |SemiGroup|) T) ((|RomanNumeral| . |UniqueFactorizationDomain|) T) ((|SparseUnivariateSkewPolynomial| . |SemiGroup|) T) ((|Polynomial| . |UniqueFactorizationDomain|) 148910) ((|U16Vector| . |HomogeneousAggregate|) 148887) ((|HomogeneousDistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 148837) ((|MultivariatePolynomial| . |OrderedSet|) 148808) ((|RomanNumeral| . |IntegralDomain|) T) ((|U16Matrix| . |TwoDimensionalArrayCategory|) 148757) ((|Polynomial| . |IntegralDomain|) 148643) ((|SparseUnivariatePolynomial| . |AbelianMonoid|) T) ((|SparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |IntegralDomain|) 148529) ((|SquareMatrix| . |Module|) 148436) ((|SquareFreeRegularTriangularSet| . |InnerEvalable|) 148355) ((|Result| . |ConvertibleTo|) NIL) ((|Result| . |CoercibleTo|) 148329) ((|IntegerMod| . |RightModule|) 148316) ((|OrdinaryWeightedPolynomials| . |Module|) 148273) ((|IntegerMod| . |BiModule|) 148258) ((|UnivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|TaylorSeries| . |AbelianMonoidRing|) 148210) ((|DirectProductModule| . |CancellationAbelianMonoid|) T) ((|DirectProductMatrixModule| . |CancellationAbelianMonoid|) T) ((|SExpression| . |SetCategory|) T) ((|RadicalFunctionField| . |SetCategory|) T) ((|Asp12| . |CoercibleTo|) 148184) ((|SparseUnivariateLaurentSeries| . |OrderedSet|) NIL) ((|RealClosure| . |OrderedAbelianMonoid|) T) ((|RealClosure| . |OrderedCancellationAbelianMonoid|) T) ((|UnivariateTaylorSeries| . |AbelianGroup|) T) ((|MyExpression| . |RightModule|) 148072) ((|UnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|AlgebraicFunctionField| . |LeftOreRing|) T) ((|PAdicInteger| . |LeftModule|) 148059) ((|UnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeries| . |AbelianGroup|) T) ((|UnivariateLaurentSeries| . |AbelianSemiGroup|) T) ((|UnivariateFormalPowerSeries| . |AbelianSemiGroup|) T) ((|UnivariateFormalPowerSeries| . |AbelianGroup|) T) ((|RegularTriangularSet| . |Collection|) 148043) ((|PAdicRationalConstructor| . |OrderedIntegralDomain|) 148003) ((|PAdicRationalConstructor| . |PrincipalIdealDomain|) T) ((|MyExpression| . |BiModule|) 147859) ((|ModMonic| . |Eltable|) 147762) ((|InnerTaylorSeries| . |AbelianGroup|) T) ((|InnerTaylorSeries| . |AbelianSemiGroup|) T) ((|InnerSparseUnivariatePowerSeries| . |AbelianGroup|) T) ((|AlgebraicFunctionField| . |Monoid|) T) ((|Dequeue| . |InnerEvalable|) 147681) ((|InnerSparseUnivariatePowerSeries| . |AbelianSemiGroup|) T) ((|GeneralTriangularSet| . |Collection|) 147665) ((|GeneralPolynomialSet| . |Collection|) 147649) ((|PositiveInteger| . |Monoid|) T) ((|NonNegativeInteger| . |OrderedAbelianMonoidSup|) T) ((|NonNegativeInteger| . |OrderedAbelianSemiGroup|) T) ((|IndexCard| . |SetCategory|) T) ((|NonNegativeInteger| . |Monoid|) T) ((|DoubleFloat| . |Field|) T) ((|Stream| . |SetCategory|) 147619) ((|PAdicRational| . |UniqueFactorizationDomain|) T) ((|LinearOrdinaryDifferentialOperator2| . |CoercibleTo|) 147593) ((|PAdicRational| . |IntegralDomain|) T) ((|MachineComplex| . |Finite|) NIL) ((|FiniteFieldExtension| . |VectorSpace|) 147577) ((|LieSquareMatrix| . |BasicType|) T) ((|FiniteFieldNormalBasisExtension| . |VectorSpace|) 147561) ((|FiniteFieldCyclicGroupExtension| . |VectorSpace|) 147545) ((|XPolynomialRing| . |SetCategory|) T) ((|IndexedList| . |OrderedSet|) 147516) ((|UnivariateTaylorSeriesCZero| . |RightModule|) 147349) ((|OrdinaryDifferentialRing| . |GcdDomain|) 147325) ((|RegularChain| . |SetCategory|) T) ((|RegularChain| . |RegularTriangularSetCategory|) 147160) ((|RegularTriangularSet| . |PolynomialSetCategory|) 147129) ((|OrderedFreeMonoid| . |SemiGroup|) T) ((|RadicalFunctionField| . |Module|) 147057) ((|UnivariateTaylorSeriesCZero| . |BiModule|) 146858) ((|DirichletRing| . |CancellationAbelianMonoid|) T) ((|FreeMonoid| . |SemiGroup|) T) ((|GeneralTriangularSet| . |PolynomialSetCategory|) 146827) ((|GeneralPolynomialSet| . |PolynomialSetCategory|) 146796) ((|Places| . |SetCategoryWithDegree|) T) ((|Bits| . |Collection|) 146773) ((|Asp34| . |CoercibleTo|) 146747) ((|PoincareBirkhoffWittLyndonBasis| . |CoercibleTo|) 146721) ((|SimpleAlgebraicExtension| . |MonogenicAlgebra|) 146700) ((|MyExpression| . |Ring|) T) ((|IntegerMod| . |Ring|) T) ((|U16Vector| . |Eltable|) 146665) ((|PAdicInteger| . |LeftOreRing|) T) ((|OrderlyDifferentialPolynomial| . |LinearlyExplicitRingOver|) 146581) ((|Equation| . |Rng|) 146501) ((|Complex| . |UniqueFactorizationDomain|) 146347) ((|DoubleFloat| . |SemiGroup|) T) ((|FreeAbelianMonoid| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |QuotientFieldCategory|) 146271) ((|OrderedCompletion| . |SetCategory|) T) ((|MyExpression| . |DivisionRing|) 146238) ((|SparseMultivariateTaylorSeries| . |MultivariateTaylorSeriesCategory|) 146217) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |RightModule|) 146038) ((|UnivariatePuiseuxSeriesConstructor| . |PrincipalIdealDomain|) 146014) ((|PAdicInteger| . |Monoid|) T) ((|Complex| . |IntegralDomain|) 145883) ((|UnivariateLaurentSeriesConstructor| . |PrincipalIdealDomain|) 145859) ((|InnerPAdicInteger| . |LeftModule|) 145846) ((|Fraction| . |SetCategory|) T) ((|Integer| . |LeftModule|) 145833) ((|DrawOption| . |SetCategory|) T) ((|InnerAlgebraicNumber| . |LeftModule|) 145787) ((|DoubleFloat| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedIntegralDomain|) 145718) ((|ProjectivePlane| . |SetCategory|) T) ((|XPolynomial| . |BasicType|) T) ((|FiniteField| . |ExtensionField|) 145687) ((|XPBWPolynomial| . |BasicType|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |BiModule|) 145438) ((|Character| . |CoercibleTo|) 145412) ((|QuadraticForm| . |CancellationAbelianMonoid|) T) ((|AlgebraGivenByStructuralConstants| . |BasicType|) T) ((|DirectProduct| . |OrderedSet|) 145336) ((|XPolynomialRing| . |Module|) 145293) ((|UnivariatePolynomial| . |UniqueFactorizationDomain|) 145243) ((|BalancedBinaryTree| . |HomogeneousAggregate|) 145227) ((|UnivariatePolynomial| . |IntegralDomain|) 145090) ((|U16Vector| . |OneDimensionalArrayAggregate|) 145067) ((|SequentialDifferentialPolynomial| . |AbelianMonoidRing|) 144984) ((|RomanNumeral| . |SemiGroup|) T) ((|Polynomial| . |SemiGroup|) T) ((|BinaryTree| . |Aggregate|) T) ((|BinarySearchTree| . |Aggregate|) T) ((|U8Vector| . |Aggregate|) T) ((|U32Vector| . |EltableAggregate|) 144949) ((|NewSparseUnivariatePolynomial| . |AbelianMonoidRing|) 144910) ((|NewSparseMultivariatePolynomial| . |AbelianMonoidRing|) 144868) ((|U16Vector| . |IndexedAggregate|) 144833) ((|SparseUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteField| . |Finite|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |SemiGroup|) T) ((|SparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|RomanNumeral| . |AbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianMonoidRing|) 144812) ((|PAdicRational| . |Field|) T) ((|SparseUnivariateSkewPolynomial| . |CancellationAbelianMonoid|) T) ((|CliffordAlgebra| . |BasicType|) T) ((|MyUnivariatePolynomial| . |GcdDomain|) 144707) ((|Polynomial| . |AbelianMonoid|) T) ((|Interval| . |IntegralDomain|) T) ((|OrderlyDifferentialPolynomial| . |AbelianSemiGroup|) T) ((|OrderlyDifferentialPolynomial| . |AbelianGroup|) T) ((|SquareMatrix| . |InnerEvalable|) 144626) ((|IntegrationResult| . |RetractableTo|) 144610) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasis| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |Ring|) T) ((|TaylorSeries| . |PartialDifferentialRing|) 144588) ((|LieSquareMatrix| . |Evalable|) 144512) ((|UnivariateTaylorSeriesCZero| . |DifferentialRing|) 144449) ((|SplitHomogeneousDirectProduct| . |VectorSpace|) 144416) ((|MachineFloat| . |LeftModule|) 144370) ((|RadixExpansion| . |OrderedSet|) T) ((|RadicalFunctionField| . |CommutativeRing|) T) ((|PolynomialRing| . |CharacteristicNonZero|) 144330) ((|AssociatedLieAlgebra| . |SetCategory|) T) ((|AssociatedJordanAlgebra| . |SetCategory|) T) ((|PolynomialRing| . |CharacteristicZero|) 144293) ((|PseudoAlgebraicClosureOfFiniteField| . |PrincipalIdealDomain|) T) ((|MonoidRing| . |CharacteristicZero|) 144256) ((|MonoidRing| . |CharacteristicNonZero|) 144216) ((|Partition| . |OrderedSet|) T) ((|NeitherSparseOrDensePowerSeries| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |PrincipalIdealDomain|) 144192) ((|Expression| . |RightModule|) 144054) ((|ExponentialExpansion| . |RightModule|) 143926) ((|Quaternion| . |Eltable|) 143879) ((|SparseUnivariatePolynomialExpressions| . |PolynomialFactorizationExplicit|) 143829) ((|Fraction| . |Module|) 143770) ((|MachineInteger| . |OrderedRing|) T) ((|InfinitlyClosePoint| . |SetCategoryWithDegree|) T) ((|InfClsPt| . |SetCategory|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |FiniteAbelianMonoidRing|) 143660) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Ring|) T) ((|InnerPAdicInteger| . |LeftOreRing|) T) ((|Expression| . |BiModule|) 143490) ((|ExponentialExpansion| . |BiModule|) 143261) ((|Integer| . |LeftOreRing|) T) ((|InnerAlgebraicNumber| . |LeftOreRing|) T) ((|SparseUnivariatePolynomialExpressions| . |LeftModule|) 143158) ((|Product| . |BasicType|) T) ((|OrderedDirectProduct| . |BasicType|) 142850) ((|ModMonic| . |ConvertibleTo|) NIL) ((|ModMonic| . |CoercibleTo|) 142824) ((|Result| . |EltableAggregate|) 142794) ((|LinearOrdinaryDifferentialOperator| . |RetractableTo|) 142638) ((|PseudoAlgebraicClosureOfRationalNumber| . |EuclideanDomain|) T) ((|InnerPAdicInteger| . |Monoid|) T) ((|Integer| . |OrderedAbelianSemiGroup|) T) ((|Integer| . |OrderedAbelianGroup|) T) ((|Complex| . |Field|) 142572) ((|Integer| . |Monoid|) T) ((|InnerAlgebraicNumber| . |Monoid|) T) ((|Divisor| . |RetractableTo|) 142556) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |EuclideanDomain|) T) ((|SquareFreeRegularTriangularSet| . |HomogeneousAggregate|) 142540) ((|SequentialDifferentialPolynomial| . |PatternMatchable|) NIL) ((|PAdicRational| . |SemiGroup|) T) ((|BalancedPAdicRational| . |PolynomialFactorizationExplicit|) NIL) ((|XPolynomial| . |XPolynomialsCat|) 142513) ((|XPBWPolynomial| . |XPolynomialsCat|) 142492) ((|NewSparseUnivariatePolynomial| . |PatternMatchable|) NIL) ((|NewSparseMultivariatePolynomial| . |PatternMatchable|) 142271) ((|XDistributedPolynomial| . |AbelianSemiGroup|) T) ((|XDistributedPolynomial| . |AbelianGroup|) T) ((|Tuple| . |BasicType|) 142241) ((|SimpleFortranProgram| . |FortranProgramCategory|) T) ((|LaurentPolynomial| . |LeftModule|) 142228) ((|GeneralDistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|ThreeDimensionalMatrix| . |BasicType|) 142198) ((|SequentialDifferentialPolynomial| . |RetractableTo|) 141912) ((|PAdicRational| . |AbelianMonoid|) T) ((|NewSparseUnivariatePolynomial| . |RetractableTo|) 141678) ((|NewSparseMultivariatePolynomial| . |RetractableTo|) 141458) ((|BalancedPAdicRational| . |LeftModule|) 141374) ((|GeneralDistributedMultivariatePolynomial| . |RetractableTo|) 141181) ((|ListMonoidOps| . |RetractableTo|) 141165) ((|LieExponentials| . |BasicType|) T) ((|Dequeue| . |HomogeneousAggregate|) 141149) ((|Vector| . |Aggregate|) T) ((|AssociatedLieAlgebra| . |Module|) 141133) ((|AssociatedJordanAlgebra| . |Module|) 141117) ((|LieSquareMatrix| . |Algebra|) 141062) ((|MachineFloat| . |LeftOreRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |BasicType|) T) ((|DoubleFloatMatrix| . |SetCategory|) T) ((|ComplexDoubleFloatMatrix| . |SetCategory|) T) ((|Asp78| . |CoercibleTo|) 141036) ((|AntiSymm| . |RetractableTo|) 141020) ((|SingleInteger| . |RightModule|) 141007) ((|SequentialDifferentialPolynomial| . |FullyLinearlyExplicitRingOver|) 140991) ((|NewSparseUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140975) ((|TwoDimensionalArray| . |TwoDimensionalArrayCategory|) 140901) ((|MachineFloat| . |OrderedAbelianSemiGroup|) T) ((|MachineFloat| . |OrderedAbelianGroup|) T) ((|InnerPrimeField| . |RetractableTo|) 140888) ((|InnerFiniteField| . |RetractableTo|) 140852) ((|MachineFloat| . |Monoid|) T) ((|FreeAbelianMonoid| . |CancellationAbelianMonoid|) T) ((|Expression| . |Ring|) 140684) ((|ExponentialExpansion| . |Ring|) T) ((|Complex| . |SemiGroup|) T) ((|NewSparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140668) ((|AssociationList| . |Collection|) 140610) ((|RadixExpansion| . |QuotientFieldCategory|) 140587) ((|U16Vector| . |ConvertibleTo|) 140562) ((|U16Vector| . |CoercibleTo|) 140536) ((|GeneralDistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140520) ((|Fraction| . |CommutativeRing|) T) ((|Expression| . |DivisionRing|) 140487) ((|ExponentialExpansion| . |DivisionRing|) T) ((|ExponentialExpansion| . |DifferentialRing|) NIL) ((|Equation| . |SetCategory|) 140184) ((|DoubleFloat| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |BiModule|) 140169) ((|Complex| . |AbelianMonoid|) T) ((|Octonion| . |CharacteristicZero|) 140132) ((|Octonion| . |CharacteristicNonZero|) 140092) ((|DirectProductModule| . |LinearlyExplicitRingOver|) 139964) ((|DirectProductMatrixModule| . |LinearlyExplicitRingOver|) 139836) ((|SparseUnivariatePolynomialExpressions| . |LeftOreRing|) 139731) ((|ExponentialOfUnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 139680) ((|SparseUnivariatePolynomialExpressions| . |Monoid|) T) ((|Stream| . |InnerEvalable|) 139599) ((|ThreeSpace| . |SetCategory|) T) ((|DoubleFloat| . |RealNumberSystem|) T) ((|OrderedDirectProduct| . |Evalable|) 139523) ((|SequentialDifferentialPolynomial| . |PartialDifferentialRing|) 139401) ((|NewSparseUnivariatePolynomial| . |PartialDifferentialRing|) 139299) ((|NewSparseMultivariatePolynomial| . |PartialDifferentialRing|) 139283) ((|XPolynomial| . |Algebra|) 139240) ((|XPBWPolynomial| . |Algebra|) 139197) ((|UnivariatePolynomial| . |SemiGroup|) T) ((|UnivariateSkewPolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |LeftOreRing|) 139173) ((|GeneralDistributedMultivariatePolynomial| . |PartialDifferentialRing|) 139133) ((|OrdSetInts| . |SetCategory|) T) ((|BalancedPAdicRational| . |LeftOreRing|) T) ((|UnivariatePolynomial| . |AbelianMonoid|) T) ((|Interval| . |SemiGroup|) T) ((|UnivariateSkewPolynomial| . |AbelianMonoid|) T) ((|LaurentPolynomial| . |Monoid|) T) ((|FiniteFieldExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|EuclideanModularRing| . |BasicType|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|RomanNumeral| . |CancellationAbelianMonoid|) T) ((|Polynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |OrderedAbelianSemiGroup|) NIL) ((|BalancedPAdicRational| . |OrderedAbelianGroup|) NIL) ((|BalancedPAdicRational| . |Monoid|) T) ((|MachineComplex| . |PolynomialFactorizationExplicit|) NIL) ((|RegularChain| . |InnerEvalable|) 138827) ((|HomogeneousDistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|Interval| . |AbelianMonoid|) T) ((|ThreeDimensionalMatrix| . |Evalable|) 138751) ((|AssociatedLieAlgebra| . |NonAssociativeRng|) T) ((|AssociatedJordanAlgebra| . |NonAssociativeRng|) T) ((|UnivariateLaurentSeries| . |OrderedSet|) NIL) ((|RadicalFunctionField| . |EntireRing|) T) ((|DirectProductModule| . |AbelianGroup|) T) ((|MachineComplex| . |LeftModule|) 138680) ((|FiniteFieldNormalBasis| . |SetCategory|) T) ((|DirectProductModule| . |AbelianSemiGroup|) T) ((|DirectProductMatrixModule| . |AbelianGroup|) T) ((|DirectProductMatrixModule| . |AbelianSemiGroup|) T) ((|CliffordAlgebra| . |Algebra|) 138664) ((|Record| . |BasicType|) T) ((|PrimeField| . |PrincipalIdealDomain|) T) ((|HomogeneousDirectProduct| . |VectorSpace|) 138631) ((|DeRhamComplex| . |RetractableTo|) 138600) ((|SingleInteger| . |Ring|) T) ((|ModularField| . |EuclideanDomain|) T) ((|Equation| . |Module|) 138529) ((|MachineInteger| . |Rng|) T) ((|HexadecimalExpansion| . |GcdDomain|) T) ((|Fraction| . |InnerEvalable|) 138418) ((|DecimalExpansion| . |GcdDomain|) T) ((|SingleInteger| . |DifferentialRing|) T) ((|EqTable| . |Collection|) 138360) ((|Quaternion| . |ConvertibleTo|) 138296) ((|Quaternion| . |CoercibleTo|) 138270) ((|QueryEquation| . |CoercibleTo|) 138244) ((|BalancedPAdicInteger| . |Rng|) T) ((|LinearOrdinaryDifferentialOperator2| . |RightModule|) 138228) ((|DoubleFloat| . |HyperbolicFunctionCategory|) T) ((|GuessOption| . |CoercibleTo|) 138202) ((|FullPartialFractionExpansion| . |CoercibleTo|) 138176) ((|FullPartialFractionExpansion| . |ConvertibleTo|) 138147) ((|RectangularMatrix| . |VectorSpace|) 138114) ((|LinearOrdinaryDifferentialOperator2| . |BiModule|) 138093) ((|SquareMatrix| . |HomogeneousAggregate|) 138077) ((|OrderedDirectProduct| . |Algebra|) 138034) ((|Asp19| . |FortranVectorFunctionCategory|) T) ((|Asp19| . |FortranProgramCategory|) T) ((|StringTable| . |BasicType|) T) ((|PAdicRational| . |CancellationAbelianMonoid|) T) ((|Heap| . |BasicType|) 138004) ((|IntegerMod| . |Finite|) T) ((|MyUnivariatePolynomial| . |PolynomialCategory|) 137939) ((|SimpleAlgebraicExtension| . |BasicType|) T) ((|RightOpenIntervalRootCharacterization| . |BasicType|) T) ((|FiniteFieldNormalBasis| . |Module|) 137865) ((|MultivariatePolynomial| . |CharacteristicZero|) 137828) ((|MultivariatePolynomial| . |CharacteristicNonZero|) 137788) ((|RealClosure| . |LeftModule|) 137709) ((|IndexedMatrix| . |SetCategory|) 137679) ((|FiniteFieldExtension| . |BasicType|) T) ((|FiniteFieldNormalBasisExtension| . |BasicType|) T) ((|MachineComplex| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtension| . |BasicType|) T) ((|DirichletRing| . |AbelianGroup|) T) ((|DirichletRing| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |BasicType|) T) ((|PolynomialIdeals| . |SetCategory|) T) ((|FiniteField| . |LeftModule|) 137605) ((|SparseUnivariatePolynomial| . |LinearlyExplicitRingOver|) 137521) ((|SparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 137437) ((|FreeModule| . |IndexedDirectProductCategory|) 137416) ((|OnePointCompletion| . |OrderedRing|) 137386) ((|Float| . |UniqueFactorizationDomain|) T) ((|MachineComplex| . |Monoid|) T) ((|FortranExpression| . |Rng|) T) ((|UnivariateLaurentSeries| . |QuotientFieldCategory|) 137316) ((|ContinuedFraction| . |Rng|) T) ((|BalancedBinaryTree| . |CoercibleTo|) 137267) ((|SparseUnivariateTaylorSeries| . |CharacteristicNonZero|) 137227) ((|SparseUnivariateTaylorSeries| . |CharacteristicZero|) 137190) ((|Float| . |IntegralDomain|) T) ((|SparseUnivariatePuiseuxSeries| . |CharacteristicZero|) 137153) ((|SparseUnivariatePuiseuxSeries| . |CharacteristicNonZero|) 137113) ((|SparseUnivariateLaurentSeries| . |CharacteristicNonZero|) 136957) ((|Fraction| . |EntireRing|) T) ((|SparseUnivariateLaurentSeries| . |CharacteristicZero|) 136807) ((|SparseMultivariateTaylorSeries| . |CharacteristicZero|) 136770) ((|SparseMultivariateTaylorSeries| . |CharacteristicNonZero|) 136730) ((|ExponentialOfUnivariatePuiseuxSeries| . |Algebra|) 136518) ((|Complex| . |CancellationAbelianMonoid|) T) ((|ExponentialExpansion| . |OrderedCancellationAbelianMonoid|) NIL) ((|ExponentialExpansion| . |OrderedAbelianMonoid|) NIL) ((|LinearOrdinaryDifferentialOperator2| . |Ring|) T) ((|AlgebraicNumber| . |LeftModule|) 136472) ((|QuadraticForm| . |AbelianGroup|) T) ((|BinaryTree| . |RecursiveAggregate|) 136456) ((|BinarySearchTree| . |RecursiveAggregate|) 136440) ((|QuadraticForm| . |AbelianSemiGroup|) T) ((|PendantTree| . |BinaryRecursiveAggregate|) 136424) ((|String| . |BasicType|) T) ((|UnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |OrderedSet|) 136395) ((|U16Vector| . |EltableAggregate|) 136360) ((|SparseUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|SparseUnivariatePolynomial| . |AbelianGroup|) T) ((|StringTable| . |Evalable|) 136102) ((|Stream| . |HomogeneousAggregate|) 136086) ((|UnivariateSkewPolynomial| . |CancellationAbelianMonoid|) T) ((|SparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|SparseMultivariatePolynomial| . |AbelianGroup|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianSemiGroup|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianGroup|) T) ((|NewSparseUnivariatePolynomial| . |EuclideanDomain|) 136062) ((|AffineSpace| . |AffineSpaceCategory|) 136046) ((|SparseTable| . |Collection|) 135988) ((|SquareFreeRegularTriangularSet| . |CoercibleTo|) 135940) ((|ListMultiDictionary| . |BasicType|) 135910) ((|Library| . |BasicType|) T) ((|SquareFreeRegularTriangularSet| . |ConvertibleTo|) 135846) ((|Interval| . |CancellationAbelianMonoid|) T) ((|LocalAlgebra| . |OrderedRing|) 135816) ((|RealClosure| . |OrderedAbelianGroup|) T) ((|RealClosure| . |OrderedAbelianSemiGroup|) T) ((|RealClosure| . |LeftOreRing|) T) ((|RealClosure| . |Monoid|) T) ((|Heap| . |Evalable|) 135740) ((|GenericNonAssociativeAlgebra| . |FramedNonAssociativeAlgebra|) 135696) ((|FiniteFieldNormalBasis| . |CommutativeRing|) T) ((|DoubleFloatMatrix| . |InnerEvalable|) NIL) ((|ComplexDoubleFloatMatrix| . |InnerEvalable|) NIL) ((|EuclideanModularRing| . |Algebra|) 135683) ((|e04ucfAnnaType| . |BasicType|) T) ((|e04nafAnnaType| . |BasicType|) T) ((|e04mbfAnnaType| . |BasicType|) T) ((|e04jafAnnaType| . |BasicType|) T) ((|e04gcfAnnaType| . |BasicType|) T) ((|e04fdfAnnaType| . |BasicType|) T) ((|e04dgfAnnaType| . |BasicType|) T) ((|d03fafAnnaType| . |BasicType|) T) ((|FiniteFieldCyclicGroup| . |RetractableTo|) 135652) ((|d03eefAnnaType| . |BasicType|) T) ((|d02ejfAnnaType| . |BasicType|) T) ((|d02cjfAnnaType| . |BasicType|) T) ((|d02bhfAnnaType| . |BasicType|) T) ((|d02bbfAnnaType| . |BasicType|) T) ((|FiniteField| . |LeftOreRing|) T) ((|d01TransformFunctionType| . |BasicType|) T) ((|d01gbfAnnaType| . |BasicType|) T) ((|ModMonic| . |RightModule|) 135386) ((|d01fcfAnnaType| . |BasicType|) T) ((|d01asfAnnaType| . |BasicType|) T) ((|d01aqfAnnaType| . |BasicType|) T) ((|d01apfAnnaType| . |BasicType|) T) ((|d01anfAnnaType| . |BasicType|) T) ((|d01amfAnnaType| . |BasicType|) T) ((|d01alfAnnaType| . |BasicType|) T) ((|d01akfAnnaType| . |BasicType|) T) ((|d01ajfAnnaType| . |BasicType|) T) ((|FiniteField| . |Monoid|) T) ((|ModMonic| . |BiModule|) 135088) ((|LieSquareMatrix| . |DifferentialExtension|) 135072) ((|InnerPrimeField| . |EuclideanDomain|) T) ((|InnerFiniteField| . |EuclideanDomain|) T) ((|Equation| . |InnerEvalable|) 135004) ((|BinaryExpansion| . |Evalable|) NIL) ((|Asp33| . |FortranProgramCategory|) T) ((|SplitHomogeneousDirectProduct| . |BasicType|) 134696) ((|OnePointCompletion| . |FullyRetractableTo|) 134680) ((|SingleInteger| . |OrderedCancellationAbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianMonoid|) T) ((|MachineInteger| . |SetCategory|) T) ((|AlgebraicNumber| . |LeftOreRing|) T) ((|Float| . |Field|) T) ((|Complex| . |HyperbolicFunctionCategory|) 134631) ((|Dequeue| . |CoercibleTo|) 134582) ((|CardinalNumber| . |SetCategory|) T) ((|BalancedPAdicInteger| . |SetCategory|) T) ((|AlgebraicNumber| . |Monoid|) T) ((|RegularChain| . |HomogeneousAggregate|) 134501) ((|CharacterClass| . |FiniteSetAggregate|) 134476) ((|CharacterClass| . |Finite|) T) ((|RegularTriangularSet| . |BasicType|) T) ((|IndexedDirectProductObject| . |IndexedDirectProductCategory|) 134455) ((|GeneralTriangularSet| . |BasicType|) T) ((|GeneralPolynomialSet| . |BasicType|) T) ((|ResidueRing| . |SemiGroup|) T) ((|MyUnivariatePolynomial| . |UnivariatePolynomialCategory|) 134439) ((|SparseUnivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 134388) ((|SparseUnivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 134337) ((|SparseUnivariateTaylorSeries| . |TrigonometricFunctionCategory|) 134286) ((|SparseUnivariateTaylorSeries| . |TranscendentalFunctionCategory|) 134235) ((|SparseUnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 134184) ((|String| . |Evalable|) NIL) ((|Asp9| . |FortranFunctionCategory|) T) ((|Asp9| . |FortranProgramCategory|) T) ((|SimpleAlgebraicExtension| . |StepThrough|) 134146) ((|SparseUnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 134095) ((|SparseUnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 134044) ((|ResidueRing| . |AbelianMonoid|) T) ((|SparseUnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 133993) ((|Interval| . |HyperbolicFunctionCategory|) T) ((|SparseUnivariateLaurentSeries| . |TranscendentalFunctionCategory|) 133942) ((|SparseUnivariateLaurentSeries| . |TrigonometricFunctionCategory|) 133891) ((|SparseUnivariateLaurentSeries| . |ArcTrigonometricFunctionCategory|) 133840) ((|SparseUnivariateLaurentSeries| . |ArcHyperbolicFunctionCategory|) 133789) ((|FreeGroup| . |SemiGroup|) T) ((|FiniteFieldExtension| . |StepThrough|) 133764) ((|FiniteFieldNormalBasisExtension| . |StepThrough|) 133739) ((|FiniteFieldCyclicGroupExtension| . |StepThrough|) 133714) ((|SparseMultivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 133663) ((|SparseMultivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 133612) ((|SparseMultivariateTaylorSeries| . |TrigonometricFunctionCategory|) 133561) ((|BinaryExpansion| . |StepThrough|) T) ((|SparseMultivariateTaylorSeries| . |TranscendentalFunctionCategory|) 133510) ((|OnePointCompletion| . |Rng|) 133480) ((|ListMultiDictionary| . |Evalable|) 133404) ((|Library| . |Evalable|) 133210) ((|SimpleAlgebraicExtension| . |Algebra|) 133033) ((|ModMonic| . |Ring|) T) ((|RomanNumeral| . |LinearlyExplicitRingOver|) 133010) ((|RadixExpansion| . |CharacteristicZero|) T) ((|Polynomial| . |LinearlyExplicitRingOver|) 132926) ((|HTMLFormat| . |SetCategory|) T) ((|RadixExpansion| . |CharacteristicNonZero|) NIL) ((|Float| . |SemiGroup|) T) ((|FreeAbelianMonoid| . |AbelianSemiGroup|) T) ((|FreeAbelianGroup| . |AbelianMonoid|) T) ((|Point| . |OrderedSet|) 132897) ((|ModMonic| . |FiniteAbelianMonoidRing|) 132858) ((|HomogeneousDistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 132774) ((|AlgebraicFunctionField| . |RetractableTo|) 132579) ((|MachineInteger| . |Module|) 132566) ((|ModMonic| . |DifferentialRing|) T) ((|FortranExpression| . |SetCategory|) T) ((|ContinuedFraction| . |SetCategory|) T) ((|FourierComponent| . |OrderedSet|) T) ((|Factored| . |GcdDomain|) 132490) ((|Float| . |AbelianMonoid|) T) ((|FiniteFieldExtension| . |Algebra|) 132444) ((|FiniteFieldNormalBasisExtension| . |Algebra|) 132398) ((|FiniteFieldCyclicGroupExtension| . |Algebra|) 132352) ((|Asp55| . |FortranVectorFunctionCategory|) T) ((|Asp55| . |FortranProgramCategory|) T) ((|DoubleFloat| . |AbelianSemiGroup|) T) ((|DoubleFloat| . |AbelianGroup|) T) ((|Operator| . |SemiGroup|) T) ((|BinaryExpansion| . |Algebra|) 132286) ((|OppositeMonogenicLinearOperator| . |SemiGroup|) T) ((|None| . |SetCategory|) T) ((|BalancedPAdicInteger| . |Module|) 132273) ((|LyndonWord| . |RetractableTo|) 132257) ((|Kernel| . |BasicType|) T) ((|Operator| . |AbelianMonoid|) T) ((|OppositeMonogenicLinearOperator| . |AbelianMonoid|) T) ((|U8Matrix| . |BasicType|) T) ((|Stream| . |Eltable|) 132229) ((|SplitHomogeneousDirectProduct| . |Evalable|) 132153) ((|Set| . |DictionaryOperations|) 132137) ((|Asp1| . |FortranFunctionCategory|) T) ((|Asp1| . |FortranProgramCategory|) T) ((|Bits| . |BasicType|) T) ((|AlgebraicFunctionField| . |FullyLinearlyExplicitRingOver|) 132108) ((|AffineSpace| . |SetCategory|) T) ((|U32Vector| . |LinearAggregate|) 132085) ((|LinearOrdinaryDifferentialOperator1| . |UnivariateSkewPolynomialCategory|) 132069) ((|U32Vector| . |FiniteLinearAggregate|) 132046) ((|RomanNumeral| . |AbelianGroup|) T) ((|RomanNumeral| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |DifferentialExtension|) 132014) ((|Polynomial| . |AbelianSemiGroup|) T) ((|Polynomial| . |AbelianGroup|) T) ((|LocalAlgebra| . |Rng|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|RegularTriangularSet| . |Evalable|) 131938) ((|PatternMatchResult| . |CoercibleTo|) 131912) ((|PatternMatchListResult| . |CoercibleTo|) 131886) ((|DirectProductModule| . |OrderedSet|) 131810) ((|DirectProductMatrixModule| . |OrderedSet|) 131734) ((|IndexedMatrix| . |InnerEvalable|) 131653) ((|PAdicRational| . |LinearlyExplicitRingOver|) 131620) ((|GeneralTriangularSet| . |Evalable|) 131544) ((|GeneralPolynomialSet| . |Evalable|) 131468) ((|FiniteFieldNormalBasis| . |EntireRing|) T) ((|Stream| . |UnaryRecursiveAggregate|) 131452) ((|SquareMatrix| . |CoercibleTo|) 131402) ((|SquareMatrix| . |ConvertibleTo|) 131338) ((|SplittingNode| . |BasicType|) T) ((|Quaternion| . |RightModule|) 131212) ((|AlgebraicFunctionField| . |PartialDifferentialRing|) 131131) ((|Stream| . |IndexedAggregate|) 131103) ((|MyExpression| . |LeftModule|) 130991) ((|IntegerMod| . |LeftModule|) 130978) ((|RoutinesTable| . |Collection|) 130911) ((|PAdicRationalConstructor| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |BiModule|) 130753) ((|FortranExpression| . |Module|) 130737) ((|OrdinaryWeightedPolynomials| . |CoercibleTo|) 130711) ((|ContinuedFraction| . |Module|) 130626) ((|Fraction| . |Eltable|) 130579) ((|PAdicRationalConstructor| . |IntegralDomain|) T) ((|BinaryExpansion| . |FullyPatternMatchable|) 130556) ((|Asp77| . |FortranMatrixFunctionCategory|) T) ((|Asp77| . |FortranProgramCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |PrincipalIdealDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PrincipalIdealDomain|) T) ((|MachineInteger| . |CommutativeRing|) T) ((|Automorphism| . |Monoid|) T) ((|HomogeneousDirectProduct| . |BasicType|) 130248) ((|Automorphism| . |Group|) T) ((|BalancedPAdicInteger| . |CommutativeRing|) T) ((|SplitHomogeneousDirectProduct| . |Algebra|) 130205) ((|Complex| . |LinearlyExplicitRingOver|) 130121) ((|DoubleFloatMatrix| . |HomogeneousAggregate|) 130094) ((|ComplexDoubleFloatMatrix| . |HomogeneousAggregate|) 130055) ((|RectangularMatrix| . |BasicType|) T) ((|PAdicRational| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |DirectProductCategory|) 130034) ((|PAdicRational| . |AbelianGroup|) T) ((|OrderlyDifferentialVariable| . |BasicType|) T) ((|U8Matrix| . |Evalable|) NIL) ((|FramedModule| . |BasicType|) T) ((|FreeModule| . |BasicType|) T) ((|Bits| . |Evalable|) NIL) ((|DenavitHartenbergMatrix| . |BasicType|) 130004) ((|BinaryTree| . |Type|) T) ((|BinarySearchTree| . |Type|) T) ((|U8Vector| . |Type|) T) ((|ResidueRing| . |CancellationAbelianMonoid|) T) ((|LieSquareMatrix| . |FiniteRankNonAssociativeAlgebra|) 129988) ((|UnivariateTaylorSeriesCZero| . |LeftModule|) 129885) ((|IntegerMod| . |Monoid|) T) ((|UnivariateTaylorSeries| . |CharacteristicNonZero|) 129845) ((|UnivariateTaylorSeries| . |CharacteristicZero|) 129808) ((|Quaternion| . |Ring|) T) ((|UnivariatePuiseuxSeries| . |CharacteristicZero|) 129771) ((|UnivariatePolynomial| . |LinearlyExplicitRingOver|) 129687) ((|SExpression| . |CoercibleTo|) 129661) ((|RadicalFunctionField| . |CoercibleTo|) 129635) ((|MyExpression| . |LeftOreRing|) 129602) ((|InnerFreeAbelianMonoid| . |AbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |EuclideanDomain|) T) ((|IndexedDirectProductAbelianMonoid| . |AbelianMonoid|) T) ((|FreeAbelianGroup| . |CancellationAbelianMonoid|) T) ((|Union| . |SetCategory|) T) ((|RadicalFunctionField| . |ConvertibleTo|) 129586) ((|Quaternion| . |DivisionRing|) 129562) ((|Quaternion| . |DifferentialRing|) 129527) ((|UnivariatePuiseuxSeries| . |CharacteristicNonZero|) 129487) ((|UnivariatePuiseuxSeriesConstructor| . |UniqueFactorizationDomain|) 129463) ((|OnePointCompletion| . |SetCategory|) T) ((|UnivariateLaurentSeries| . |CharacteristicNonZero|) 129313) ((|UnivariateLaurentSeries| . |CharacteristicZero|) 129169) ((|UnivariateLaurentSeriesConstructor| . |UniqueFactorizationDomain|) 129145) ((|UnivariateFormalPowerSeries| . |CharacteristicNonZero|) 129105) ((|UnivariateFormalPowerSeries| . |CharacteristicZero|) 129068) ((|MyExpression| . |Group|) 129044) ((|MyExpression| . |Monoid|) T) ((|Float| . |CancellationAbelianMonoid|) T) ((|Integer| . |PatternMatchable|) 129021) ((|Enumeration| . |SetCategory|) T) ((|ContinuedFraction| . |CommutativeRing|) T) ((|Complex| . |AbelianGroup|) T) ((|Complex| . |AbelianSemiGroup|) T) ((|AnonymousFunction| . |SetCategory|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |LeftModule|) 128842) ((|UnivariatePuiseuxSeriesConstructor| . |IntegralDomain|) 128781) ((|ModuleOperator| . |SemiGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |IntegralDomain|) 128720) ((|Integer| . |RetractableTo|) 128697) ((|InnerSparseUnivariatePowerSeries| . |CharacteristicZero|) 128660) ((|InnerSparseUnivariatePowerSeries| . |CharacteristicNonZero|) 128620) ((|InnerAlgebraicNumber| . |RetractableTo|) 128543) ((|Asp80| . |FortranMatrixFunctionCategory|) T) ((|Asp80| . |FortranProgramCategory|) T) ((|PAdicRationalConstructor| . |Field|) T) ((|SparseUnivariatePolynomialExpressions| . |AbelianMonoidRing|) 128504) ((|Operator| . |CancellationAbelianMonoid|) T) ((|OppositeMonogenicLinearOperator| . |CancellationAbelianMonoid|) T) ((|ModuleOperator| . |AbelianMonoid|) T) ((|IndexCard| . |CoercibleTo|) 128478) ((|XRecursivePolynomial| . |Rng|) T) ((|Float| . |RealNumberSystem|) T) ((|Reference| . |SetCategory|) 128448) ((|PendantTree| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Evalable|) 128372) ((|Stream| . |ConvertibleTo|) 128308) ((|Stream| . |CoercibleTo|) 128259) ((|DesingTree| . |Aggregate|) T) ((|SparseUnivariatePolynomial| . |OrderedSet|) 128230) ((|AssociationList| . |BasicType|) T) ((|SparseMultivariatePolynomial| . |OrderedSet|) 128201) ((|OrdinaryDifferentialRing| . |BasicType|) T) ((|UnivariatePolynomial| . |AbelianSemiGroup|) T) ((|UnivariatePolynomial| . |AbelianGroup|) T) ((|UnivariateSkewPolynomial| . |AbelianSemiGroup|) T) ((|AlgebraGivenByStructuralConstants| . |FiniteRankNonAssociativeAlgebra|) 128185) ((|UnivariateSkewPolynomial| . |AbelianGroup|) T) ((|MultivariatePolynomial| . |GcdDomain|) 128103) ((|XPolynomialRing| . |CoercibleTo|) 128077) ((|Interval| . |AbelianSemiGroup|) T) ((|Interval| . |AbelianGroup|) T) ((|FreeNilpotentLie| . |SetCategory|) T) ((|RectangularMatrix| . |Evalable|) 128001) ((|LocalAlgebra| . |SetCategory|) T) ((|MachineFloat| . |PatternMatchable|) 127980) ((|Vector| . |Type|) T) ((|DenavitHartenbergMatrix| . |Evalable|) 127904) ((|Character| . |Finite|) T) ((|RegularChain| . |ConvertibleTo|) 127775) ((|RegularChain| . |CoercibleTo|) 127662) ((|PseudoAlgebraicClosureOfFiniteField| . |UniqueFactorizationDomain|) T) ((|ExponentialExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|NeitherSparseOrDensePowerSeries| . |UniqueFactorizationDomain|) T) ((|UnivariateTaylorSeriesCZero| . |Monoid|) T) ((|MachineFloat| . |RetractableTo|) 127588) ((|ModularField| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |UniqueFactorizationDomain|) 127564) ((|SparseUnivariatePuiseuxSeries| . |GcdDomain|) 127540) ((|SparseUnivariateLaurentSeries| . |GcdDomain|) 127516) ((|PseudoAlgebraicClosureOfFiniteField| . |IntegralDomain|) T) ((|FortranCode| . |BasicType|) T) ((|NeitherSparseOrDensePowerSeries| . |IntegralDomain|) T) ((|PAdicRationalConstructor| . |SemiGroup|) T) ((|Expression| . |LeftModule|) 127243) ((|ExponentialExpansion| . |LeftModule|) 127115) ((|GeneralUnivariatePowerSeries| . |IntegralDomain|) 127054) ((|FortranExpression| . |InnerEvalable|) 127016) ((|InnerTable| . |Collection|) 126958) ((|AlgebraicFunctionField| . |EuclideanDomain|) T) ((|SparseUnivariatePolynomialExpressions| . |PatternMatchable|) NIL) ((|OrderedCompletion| . |CoercibleTo|) 126932) ((|MachineInteger| . |EntireRing|) T) ((|PAdicRationalConstructor| . |AbelianMonoid|) T) ((|Float| . |HyperbolicFunctionCategory|) T) ((|SimpleAlgebraicExtension| . |DifferentialExtension|) 126899) ((|IndexedDirectProductObject| . |BasicType|) T) ((|Fraction| . |ConvertibleTo|) 126587) ((|Fraction| . |CoercibleTo|) 126561) ((|DrawOption| . |CoercibleTo|) 126535) ((|BalancedPAdicInteger| . |EntireRing|) T) ((|SparseUnivariatePolynomialExpressions| . |RetractableTo|) 126345) ((|ProjectivePlane| . |CoercibleTo|) 126319) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Monoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Field|) 126295) ((|UnivariateLaurentSeriesConstructor| . |Field|) 126271) ((|WuWenTsunTriangularSet| . |Aggregate|) T) ((|BalancedPAdicRational| . |Type|) T) ((|BinaryExpansion| . |DifferentialExtension|) 126248) ((|SymmetricPolynomial| . |BasicType|) T) ((|Pi| . |SetCategory|) T) ((|IndexedMatrix| . |HomogeneousAggregate|) 126232) ((|MyUnivariatePolynomial| . |BasicType|) T) ((|Multiset| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Algebra|) 126189) ((|CharacterClass| . |Aggregate|) T) ((|BalancedPAdicRational| . |Patternable|) 126148) ((|BalancedPAdicRational| . |PatternMatchable|) NIL) ((|LaurentPolynomial| . |RetractableTo|) 125979) ((|List| . |OrderedSet|) 125950) ((|WeightedPolynomials| . |BasicType|) T) ((|EqTable| . |BasicType|) T) ((|ModMonic| . |Finite|) 125925) ((|BalancedPAdicRational| . |RetractableTo|) 125884) ((|FreeNilpotentLie| . |Module|) 125868) ((|SparseUnivariatePolynomialExpressions| . |FullyLinearlyExplicitRingOver|) 125852) ((|LocalAlgebra| . |Module|) 125836) ((|AssociationList| . |Evalable|) 125596) ((|OrderlyDifferentialPolynomial| . |CharacteristicNonZero|) 125556) ((|OrderlyDifferentialPolynomial| . |CharacteristicZero|) 125519) ((|XPolynomialRing| . |FreeModuleCat|) 125498) ((|OrderedFreeMonoid| . |OrderedSet|) T) ((|ThreeDimensionalViewport| . |SetCategory|) T) ((|UnivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 125447) ((|UnivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 125396) ((|UnivariateTaylorSeries| . |TrigonometricFunctionCategory|) 125345) ((|UnivariateTaylorSeries| . |TranscendentalFunctionCategory|) 125294) ((|UnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 125243) ((|StringTable| . |Dictionary|) 125179) ((|UnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 125128) ((|FreeMonoid| . |OrderedSet|) 125099) ((|UnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 125048) ((|UnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 124997) ((|UnivariatePuiseuxSeriesConstructor| . |SemiGroup|) T) ((|DoubleFloatMatrix| . |MatrixCategory|) 124926) ((|ComplexDoubleFloatMatrix| . |MatrixCategory|) 124829) ((|UnivariateLaurentSeries| . |TranscendentalFunctionCategory|) 124778) ((|UnivariateLaurentSeries| . |TrigonometricFunctionCategory|) 124727) ((|UnivariateLaurentSeries| . |ArcTrigonometricFunctionCategory|) 124676) ((|InnerFreeAbelianMonoid| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeries| . |ArcHyperbolicFunctionCategory|) 124625) ((|UnivariateFormalPowerSeries| . |TrigonometricFunctionCategory|) 124574) ((|UnivariateFormalPowerSeries| . |TranscendentalFunctionCategory|) 124523) ((|UnivariateLaurentSeriesConstructor| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |ArcHyperbolicFunctionCategory|) 124472) ((|AssociatedLieAlgebra| . |CoercibleTo|) 124433) ((|AssociatedJordanAlgebra| . |CoercibleTo|) 124394) ((|AffinePlane| . |BasicType|) T) ((|DoubleFloat| . |OrderedSet|) T) ((|Expression| . |LeftOreRing|) 124361) ((|ExponentialExpansion| . |LeftOreRing|) T) ((|UnivariateFormalPowerSeries| . |ArcTrigonometricFunctionCategory|) 124310) ((|SingleInteger| . |LeftModule|) 124297) ((|SparseUnivariatePolynomialExpressions| . |PartialDifferentialRing|) 124195) ((|SimpleAlgebraicExtension| . |FiniteFieldCategory|) 124157) ((|IndexedString| . |Collection|) 124132) ((|PAdicInteger| . |EuclideanDomain|) T) ((|ContinuedFraction| . |EntireRing|) T) ((|BalancedPAdicRational| . |FullyLinearlyExplicitRingOver|) 124091) ((|BalancedPAdicRational| . |FullyEvalableOver|) 124050) ((|PseudoAlgebraicClosureOfFiniteField| . |Field|) T) ((|NeitherSparseOrDensePowerSeries| . |Field|) T) ((|ExponentialExpansion| . |OrderedAbelianSemiGroup|) NIL) ((|ExponentialExpansion| . |OrderedAbelianGroup|) NIL) ((|Expression| . |Monoid|) 123832) ((|ExponentialExpansion| . |Monoid|) T) ((|InfClsPt| . |CoercibleTo|) 123806) ((|GeneralUnivariatePowerSeries| . |Field|) 123782) ((|FiniteFieldExtension| . |FiniteFieldCategory|) 123757) ((|FiniteFieldNormalBasisExtension| . |FiniteFieldCategory|) 123732) ((|FiniteFieldCyclicGroupExtension| . |FiniteFieldCategory|) 123707) ((|Expression| . |Group|) 123683) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianMonoid|) T) ((|MoebiusTransform| . |SemiGroup|) T) ((|ModuleOperator| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator1| . |BasicType|) T) ((|Pi| . |Module|) 123637) ((|AssociationList| . |ExtensibleLinearAggregate|) 123579) ((|BasicFunctions| . |SetCategory|) T) ((|Asp28| . |CoercibleTo|) 123553) ((|OrderedVariableList| . |BasicType|) T) ((|LaurentPolynomial| . |PartialDifferentialRing|) 123485) ((|XRecursivePolynomial| . |SetCategory|) T) ((|FreeModule1| . |SetCategory|) T) ((|U32Vector| . |Aggregate|) T) ((|U16Vector| . |LinearAggregate|) 123462) ((|U16Vector| . |FiniteLinearAggregate|) 123439) ((|Asp73| . |Type|) T) ((|RomanNumeral| . |OrderedSet|) T) ((|Polynomial| . |OrderedSet|) 123410) ((|BalancedPAdicRational| . |PartialDifferentialRing|) NIL) ((|NewSparseUnivariatePolynomial| . |PrincipalIdealDomain|) 123386) ((|ModuleMonomial| . |OrderedSet|) T) ((|IndexedExponents| . |SetCategory|) T) ((|IndexedBits| . |SetCategory|) T) ((|FiniteFieldExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 123336) ((|DistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 123286) ((|SplitHomogeneousDirectProduct| . |DifferentialExtension|) 123254) ((|HomogeneousDistributedMultivariatePolynomial| . |OrderedSet|) 123225) ((|String| . |OpenMath|) T) ((|SquareMatrix| . |RightModule|) 123209) ((|FreeNilpotentLie| . |NonAssociativeRng|) T) ((|MyUnivariatePolynomial| . |Evalable|) 123196) ((|MachineComplex| . |Type|) T) ((|FiniteFieldExtensionByPolynomial| . |IntegralDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |IntegralDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |IntegralDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |IntegralDomain|) 123082) ((|DistributedMultivariatePolynomial| . |IntegralDomain|) 122968) ((|SquareMatrix| . |BiModule|) 122947) ((|GenericNonAssociativeAlgebra| . |NonAssociativeAlgebra|) 122903) ((|OrdinaryWeightedPolynomials| . |RightModule|) 122860) ((|OrdinaryDifferentialRing| . |Algebra|) 122780) ((|MachineComplex| . |Patternable|) 122752) ((|MachineComplex| . |PatternMatchable|) 122731) ((|EqTable| . |Evalable|) 122491) ((|PrimeField| . |UniqueFactorizationDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |SemiGroup|) T) ((|OrdinaryWeightedPolynomials| . |BiModule|) 122443) ((|LieSquareMatrix| . |FullyRetractableTo|) 122427) ((|NeitherSparseOrDensePowerSeries| . |SemiGroup|) T) ((|MachineComplex| . |RetractableTo|) 122346) ((|Stream| . |EltableAggregate|) 122318) ((|RadixExpansion| . |GcdDomain|) T) ((|PrimeField| . |IntegralDomain|) T) ((|InnerPrimeField| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |SemiGroup|) T) ((|InnerFiniteField| . |PrincipalIdealDomain|) T) ((|PartialFraction| . |GcdDomain|) T) ((|DoubleFloatMatrix| . |CoercibleTo|) 122292) ((|ComplexDoubleFloatMatrix| . |CoercibleTo|) 122266) ((|Asp20| . |CoercibleTo|) 122240) ((|SingleInteger| . |LeftOreRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianMonoid|) T) ((|Library| . |Dictionary|) 122173) ((|NeitherSparseOrDensePowerSeries| . |AbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |AbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianGroup|) T) ((|XDistributedPolynomial| . |XFreeAlgebra|) 122152) ((|SingleInteger| . |Monoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |LeftModule|) 122126) ((|Equation| . |CoercibleTo|) 121761) ((|Result| . |Aggregate|) T) ((|OrderedDirectProduct| . |OrderedRing|) 121731) ((|InnerPAdicInteger| . |EuclideanDomain|) T) ((|Integer| . |EuclideanDomain|) T) ((|InnerAlgebraicNumber| . |EuclideanDomain|) T) ((|XRecursivePolynomial| . |Module|) 121688) ((|MachineComplex| . |FullyLinearlyExplicitRingOver|) 121660) ((|MachineComplex| . |FullyEvalableOver|) 121632) ((|Pi| . |CommutativeRing|) T) ((|FreeModule1| . |Module|) 121589) ((|MyUnivariatePolynomial| . |StepThrough|) 121559) ((|PAdicRational| . |OrderedSet|) NIL) ((|Integer| . |RealConstant|) T) ((|InnerAlgebraicNumber| . |RealConstant|) T) ((|ThreeSpace| . |CoercibleTo|) 121533) ((|SplitHomogeneousDirectProduct| . |DirectProductCategory|) 121512) ((|Database| . |BasicType|) T) ((|SparseTable| . |BasicType|) T) ((|Asp31| . |CoercibleTo|) 121486) ((|SquareMatrix| . |Ring|) T) ((|SymmetricPolynomial| . |Algebra|) 121330) ((|OrdSetInts| . |CoercibleTo|) 121304) ((|Integer| . |IntegerNumberSystem|) T) ((|MyUnivariatePolynomial| . |Algebra|) 121044) ((|LieSquareMatrix| . |Rng|) T) ((|MultivariatePolynomial| . |PolynomialCategory|) 120949) ((|SquareMatrix| . |DifferentialRing|) 120914) ((|SingletonAsOrderedSet| . |SetCategory|) T) ((|ResidueRing| . |AbelianSemiGroup|) T) ((|ResidueRing| . |AbelianGroup|) T) ((|RadicalFunctionField| . |RightModule|) 120842) ((|Permutation| . |BasicType|) T) ((|OrdinaryWeightedPolynomials| . |Ring|) T) ((|NottinghamGroup| . |SemiGroup|) T) ((|MachineComplex| . |PartialDifferentialRing|) NIL) ((|FiniteFieldExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120826) ((|FiniteFieldExtensionByPolynomial| . |Field|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120810) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Field|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120794) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Field|) T) ((|HexadecimalExpansion| . |BasicType|) T) ((|WeightedPolynomials| . |Algebra|) 120751) ((|IndexedMatrix| . |MatrixCategory|) 120679) ((|DecimalExpansion| . |BasicType|) T) ((|RealClosure| . |RetractableTo|) 120505) ((|RadicalFunctionField| . |BiModule|) 120388) ((|SparseUnivariateTaylorSeries| . |PowerSeriesCategory|) 120323) ((|SparseUnivariatePuiseuxSeries| . |PowerSeriesCategory|) 120256) ((|IndexedList| . |Collection|) 120240) ((|SimpleAlgebraicExtension| . |FiniteRankAlgebra|) 120219) ((|FiniteFieldNormalBasis| . |CoercibleTo|) 120193) ((|FreeAbelianGroup| . |AbelianGroup|) T) ((|FiniteField| . |RetractableTo|) 120162) ((|FreeAbelianGroup| . |AbelianSemiGroup|) T) ((|SparseUnivariateLaurentSeries| . |PowerSeriesCategory|) 120108) ((|SparseMultivariateTaylorSeries| . |PowerSeriesCategory|) 120061) ((|Asp42| . |CoercibleTo|) 120035) ((|MachineFloat| . |EuclideanDomain|) T) ((|Complex| . |OrderedSet|) 120006) ((|PrimeField| . |Field|) T) ((|Float| . |AbelianSemiGroup|) T) ((|Float| . |AbelianGroup|) T) ((|PrimeField| . |FiniteAlgebraicExtensionField|) 119993) ((|Asp7| . |CoercibleTo|) 119967) ((|MachineFloat| . |RealConstant|) T) ((|Magma| . |OrderedSet|) T) ((|UnivariatePuiseuxSeriesConstructor| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |CancellationAbelianMonoid|) T) ((|PendantTree| . |RecursiveAggregate|) 119951) ((|Operator| . |AbelianGroup|) T) ((|AlgebraicNumber| . |RetractableTo|) 119874) ((|Operator| . |AbelianSemiGroup|) T) ((|OppositeMonogenicLinearOperator| . |AbelianSemiGroup|) T) ((|OppositeMonogenicLinearOperator| . |AbelianGroup|) T) ((|XPolynomial| . |Rng|) T) ((|XPBWPolynomial| . |Rng|) T) ((|LinearOrdinaryDifferentialOperator2| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |EuclideanDomain|) 119850) ((|DesingTree| . |RecursiveAggregate|) 119834) ((|XPolynomialRing| . |RightModule|) 119818) ((|UnivariatePolynomial| . |OrderedSet|) 119789) ((|OrderedDirectProduct| . |FullyRetractableTo|) 119750) ((|BalancedBinaryTree| . |BinaryRecursiveAggregate|) 119734) ((|Any| . |SetCategory|) T) ((|Plot3D| . |CoercibleTo|) 119708) ((|PAdicRational| . |QuotientFieldCategory|) 119675) ((|OpenMathEncoding| . |BasicType|) T) ((|XPolynomialRing| . |BiModule|) 119654) ((|LinearOrdinaryDifferentialOperator1| . |Algebra|) 119611) ((|Interval| . |OrderedSet|) T) ((|FiniteFieldExtensionByPolynomial| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |SemiGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |SemiGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |SemiGroup|) T) ((|DistributedMultivariatePolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |EuclideanDomain|) 119587) ((|SparseTable| . |Evalable|) 119347) ((|LiePolynomial| . |AbelianMonoid|) T) ((|HomogeneousDirectProduct| . |DifferentialExtension|) 119315) ((|CliffordAlgebra| . |Rng|) T) ((|FiniteFieldExtensionByPolynomial| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianMonoid|) T) ((|BalancedPAdicRational| . |EuclideanDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|DistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|RadicalFunctionField| . |Ring|) T) ((|ModMonic| . |PolynomialFactorizationExplicit|) 119265) ((|RadicalFunctionField| . |DifferentialRing|) 119217) ((|RadicalFunctionField| . |DivisionRing|) T) ((|BalancedPAdicRational| . |RealConstant|) NIL) ((|PrimeField| . |SemiGroup|) T) ((|UnivariatePuiseuxSeries| . |GcdDomain|) 119193) ((|UnivariateLaurentSeries| . |GcdDomain|) 119169) ((|IndexedMatrix| . |CoercibleTo|) 119120) ((|ModMonic| . |LeftModule|) 119017) ((|Fraction| . |RightModule|) 118958) ((|PseudoAlgebraicClosureOfFiniteField| . |CancellationAbelianMonoid|) T) ((|PolynomialIdeals| . |CoercibleTo|) 118932) ((|PrimeField| . |AbelianMonoid|) T) ((|NeitherSparseOrDensePowerSeries| . |CancellationAbelianMonoid|) T) ((|HexadecimalExpansion| . |Evalable|) NIL) ((|GeneralUnivariatePowerSeries| . |CancellationAbelianMonoid|) T) ((|DecimalExpansion| . |Evalable|) NIL) ((|Fraction| . |BiModule|) 118841) ((|OrderedDirectProduct| . |Rng|) 118751) ((|Multiset| . |SetAggregate|) 118735) ((|UnivariatePuiseuxSeriesConstructor| . |HyperbolicFunctionCategory|) 118684) ((|UnivariateLaurentSeriesConstructor| . |HyperbolicFunctionCategory|) 118633) ((|CharacterClass| . |SetAggregate|) 118608) ((|Pi| . |EntireRing|) T) ((|XPolynomialRing| . |Ring|) T) ((|RoutinesTable| . |BasicType|) T) ((|IndexedBits| . |InnerEvalable|) NIL) ((|MakeCachableSet| . |BasicType|) T) ((|HomogeneousDirectProduct| . |DirectProductCategory|) 118587) ((|SparseUnivariatePolynomial| . |CharacteristicNonZero|) 118547) ((|SparseUnivariatePolynomial| . |CharacteristicZero|) 118510) ((|SparseMultivariatePolynomial| . |CharacteristicZero|) 118473) ((|SparseMultivariatePolynomial| . |CharacteristicNonZero|) 118433) ((|AssociatedLieAlgebra| . |RightModule|) 118417) ((|AssociatedJordanAlgebra| . |RightModule|) 118401) ((|SparseUnivariateTaylorSeries| . |UnivariateTaylorSeriesCategory|) 118385) ((|LieSquareMatrix| . |SetCategory|) T) ((|LieSquareMatrix| . |RectangularMatrixCategory|) 118303) ((|SparseUnivariateTaylorSeries| . |UnivariatePowerSeriesCategory|) 118264) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesConstructorCategory|) 118199) ((|HexadecimalExpansion| . |StepThrough|) T) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 118158) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 118142) ((|SparseUnivariateLaurentSeries| . |UnivariateLaurentSeriesConstructorCategory|) 118078) ((|DecimalExpansion| . |StepThrough|) T) ((|FiniteFieldCyclicGroup| . |PrincipalIdealDomain|) T) ((|OrderlyDifferentialVariable| . |DifferentialVariableCategory|) 118062) ((|AssociatedLieAlgebra| . |BiModule|) 118041) ((|AssociatedJordanAlgebra| . |BiModule|) 118020) ((|SparseUnivariateLaurentSeries| . |UnivariatePowerSeriesCategory|) 117992) ((|OrderedCompletion| . |Ring|) 117962) ((|SparseUnivariateLaurentSeries| . |UnivariateLaurentSeriesCategory|) 117946) ((|InnerFreeAbelianMonoid| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |ExpressionSpace|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |AbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianMonoid| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianMonoid|) T) ((|ModMonic| . |LeftOreRing|) 117841) ((|Fraction| . |Ring|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Rng|) T) ((|MachineComplex| . |EuclideanDomain|) T) ((|BinaryExpansion| . |OrderedRing|) T) ((|Fraction| . |DivisionRing|) T) ((|Fraction| . |DifferentialRing|) 117806) ((|ModMonic| . |Monoid|) T) ((|HexadecimalExpansion| . |Algebra|) 117740) ((|DecimalExpansion| . |Algebra|) 117674) ((|GeneralUnivariatePowerSeries| . |HyperbolicFunctionCategory|) 117623) ((|String| . |StringAggregate|) T) ((|SetOfMIntegersInOneToN| . |BasicType|) T) ((|MachineInteger| . |CoercibleTo|) 117597) ((|MachineInteger| . |ConvertibleTo|) 117478) ((|ModuleOperator| . |AbelianGroup|) T) ((|ModuleOperator| . |AbelianSemiGroup|) T) ((|CardinalNumber| . |CoercibleTo|) 117452) ((|BalancedPAdicInteger| . |CoercibleTo|) 117426) ((|Color| . |AbelianSemiGroup|) T) ((|XPolynomial| . |SetCategory|) T) ((|PAdicRationalConstructor| . |LinearlyExplicitRingOver|) 117342) ((|XPBWPolynomial| . |SetCategory|) T) ((|PolynomialRing| . |BasicType|) T) ((|MonoidRing| . |BasicType|) T) ((|ModularRing| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |BasicType|) T) ((|U16Vector| . |Aggregate|) T) ((|OrderlyDifferentialPolynomial| . |GcdDomain|) 117260) ((|AlgebraGivenByStructuralConstants| . |SetCategory|) T) ((|SequentialDifferentialVariable| . |OrderedSet|) T) ((|LiePolynomial| . |CancellationAbelianMonoid|) T) ((|RoutinesTable| . |Evalable|) 117066) ((|LieSquareMatrix| . |Module|) 117050) ((|EuclideanModularRing| . |Rng|) T) ((|FiniteFieldExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|DistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|MyExpression| . |Type|) T) ((|Factored| . |BasicType|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianMonoidRing|) 117011) ((|CliffordAlgebra| . |SetCategory|) T) ((|AssociationList| . |Dictionary|) 116953) ((|MyUnivariatePolynomial| . |DifferentialExtension|) 116937) ((|Quaternion| . |LeftModule|) 116861) ((|PrimitiveArray| . |OrderedSet|) 116832) ((|MyExpression| . |Patternable|) 116816) ((|MyExpression| . |PatternMatchable|) 116697) ((|DirectProduct| . |VectorSpace|) 116664) ((|RealClosure| . |EuclideanDomain|) T) ((|Equation| . |RightModule|) 116571) ((|PrimeField| . |CancellationAbelianMonoid|) T) ((|AlgebraicFunctionField| . |PrincipalIdealDomain|) T) ((|MyExpression| . |RetractableTo|) 116170) ((|HexadecimalExpansion| . |FullyPatternMatchable|) 116147) ((|HTMLFormat| . |CoercibleTo|) 116121) ((|FiniteField| . |EuclideanDomain|) T) ((|DecimalExpansion| . |FullyPatternMatchable|) 116098) ((|SimpleAlgebraicExtension| . |FullyRetractableTo|) 116082) ((|Equation| . |BiModule|) 115984) ((|PseudoAlgebraicClosureOfRationalNumber| . |UniqueFactorizationDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |UniqueFactorizationDomain|) T) ((|PAdicRationalConstructor| . |AbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |IntegralDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |IntegralDomain|) T) ((|FortranExpression| . |CoercibleTo|) 115958) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianMonoidRing|) 115848) ((|DoubleFloat| . |CharacteristicZero|) T) ((|ContinuedFraction| . |CoercibleTo|) 115822) ((|SplitHomogeneousDirectProduct| . |OrderedRing|) 115792) ((|None| . |CoercibleTo|) 115766) ((|KeyedAccessFile| . |DictionaryOperations|) 115702) ((|GeneralSparseTable| . |DictionaryOperations|) 115644) ((|XPolynomial| . |Module|) 115601) ((|AlgebraicNumber| . |EuclideanDomain|) T) ((|XPBWPolynomial| . |Module|) 115558) ((|Product| . |SetCategory|) T) ((|OrderedDirectProduct| . |SetCategory|) 115250) ((|Exit| . |BasicType|) T) ((|PendantTree| . |Type|) T) ((|MyExpression| . |FullyLinearlyExplicitRingOver|) 115218) ((|AlgebraicNumber| . |RealConstant|) T) ((|UnivariateLaurentSeriesConstructor| . |LinearlyExplicitRingOver|) 115088) ((|Matrix| . |BasicType|) 115058) ((|AlgebraGivenByStructuralConstants| . |Module|) 115042) ((|InnerTable| . |BasicType|) T) ((|Asp27| . |FortranMatrixCategory|) T) ((|DesingTree| . |Type|) T) ((|Asp27| . |FortranProgramCategory|) T) ((|AffineSpace| . |CoercibleTo|) 115016) ((|Localize| . |AbelianMonoid|) T) ((|LieSquareMatrix| . |NonAssociativeRng|) T) ((|Tuple| . |SetCategory|) 114986) ((|FiniteFieldNormalBasis| . |RightModule|) 114912) ((|ThreeDimensionalMatrix| . |SetCategory|) 114882) ((|RomanNumeral| . |CharacteristicZero|) T) ((|Polynomial| . |CharacteristicZero|) 114845) ((|Polynomial| . |CharacteristicNonZero|) 114805) ((|Octonion| . |BasicType|) T) ((|CliffordAlgebra| . |Module|) 114789) ((|HomogeneousDistributedMultivariatePolynomial| . |CharacteristicZero|) 114752) ((|HomogeneousDistributedMultivariatePolynomial| . |CharacteristicNonZero|) 114712) ((|FiniteFieldNormalBasis| . |BiModule|) 114591) ((|SimpleAlgebraicExtension| . |Rng|) T) ((|FreeAbelianGroup| . |OrderedSet|) 114562) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|UnivariateTaylorSeries| . |PowerSeriesCategory|) 114497) ((|UnivariatePuiseuxSeries| . |PowerSeriesCategory|) 114430) ((|UnivariateLaurentSeries| . |PowerSeriesCategory|) 114376) ((|LieExponentials| . |SetCategory|) T) ((|MyExpression| . |PartialDifferentialRing|) 114354) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductAbelianGroup| . |CancellationAbelianMonoid|) T) ((|EqTable| . |Dictionary|) 114296) ((|FiniteFieldExtension| . |Rng|) T) ((|FiniteFieldNormalBasisExtension| . |Rng|) T) ((|FiniteFieldCyclicGroupExtension| . |Rng|) T) ((|Equation| . |Ring|) 114216) ((|UnivariateFormalPowerSeries| . |PowerSeriesCategory|) 114151) ((|Float| . |OrderedSet|) T) ((|BinaryExpansion| . |Rng|) T) ((|Quaternion| . |Monoid|) T) ((|PAdicInteger| . |PrincipalIdealDomain|) T) ((|OrderedCompletion| . |OrderedCancellationAbelianMonoid|) 114121) ((|OrderedCompletion| . |OrderedAbelianMonoid|) 114091) ((|Factored| . |Evalable|) 114018) ((|GraphImage| . |BasicType|) T) ((|InnerSparseUnivariatePowerSeries| . |PowerSeriesCategory|) 113964) ((|ExponentialOfUnivariatePuiseuxSeries| . |SetCategory|) T) ((|Fraction| . |OrderedCancellationAbelianMonoid|) 113924) ((|Fraction| . |OrderedAbelianMonoid|) 113884) ((|IndexedBits| . |HomogeneousAggregate|) 113861) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |RetractableTo|) 113807) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianGroup|) T) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |Module|) 113736) ((|U32Matrix| . |BasicType|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Field|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Field|) T) ((|MachineFloat| . |FloatingPointSystem|) T) ((|WuWenTsunTriangularSet| . |Type|) T) ((|SplitHomogeneousDirectProduct| . |FullyRetractableTo|) 113697) ((|RadicalFunctionField| . |Finite|) NIL) ((|BalancedBinaryTree| . |Aggregate|) T) ((|Multiset| . |Type|) T) ((|AlgebraGivenByStructuralConstants| . |NonAssociativeRng|) T) ((|IndexedString| . |BasicType|) T) ((|Asp49| . |FortranFunctionCategory|) T) ((|Asp49| . |FortranProgramCategory|) T) ((|LinearOrdinaryDifferentialOperator1| . |LinearOrdinaryDifferentialOperatorCategory|) 113681) ((|CharacterClass| . |Type|) T) ((|PAdicRational| . |CharacteristicZero|) T) ((|PAdicRational| . |CharacteristicNonZero|) NIL) ((|UnivariateTaylorSeriesCZero| . |PartialDifferentialRing|) 113545) ((|FiniteFieldNormalBasis| . |Ring|) T) ((|Asp30| . |FortranMatrixCategory|) T) ((|Asp30| . |FortranProgramCategory|) T) ((|SuchThat| . |BasicType|) T) ((|LieSquareMatrix| . |InnerEvalable|) 113464) ((|Matrix| . |Evalable|) 113388) ((|PolynomialRing| . |Algebra|) 113232) ((|MonoidRing| . |Algebra|) 113189) ((|InnerTable| . |Evalable|) 112949) ((|Expression| . |Type|) T) ((|FiniteFieldNormalBasis| . |DifferentialRing|) T) ((|FiniteFieldNormalBasis| . |DivisionRing|) T) ((|ExponentialExpansion| . |Type|) T) ((|EuclideanModularRing| . |SetCategory|) T) ((|SymbolTable| . |CoercibleTo|) 112923) ((|ModularField| . |UniqueFactorizationDomain|) T) ((|Stream| . |LinearAggregate|) 112907) ((|TaylorSeries| . |IntegralDomain|) 112874) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianGroup|) T) ((|ModularField| . |IntegralDomain|) T) ((|Expression| . |Patternable|) 112858) ((|Expression| . |PatternMatchable|) 112739) ((|ExponentialExpansion| . |Patternable|) 112654) ((|ExponentialExpansion| . |PatternMatchable|) NIL) ((|Octonion| . |Evalable|) 112613) ((|NeitherSparseOrDensePowerSeries| . |AbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Module|) 112401) ((|NeitherSparseOrDensePowerSeries| . |AbelianGroup|) T) ((|FreeAbelianMonoid| . |FreeAbelianMonoidCategory|) 112362) ((|HyperellipticFiniteDivisor| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |AbelianSemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |AbelianGroup|) T) ((|Factored| . |Algebra|) 112336) ((|Expression| . |RetractableTo|) 111840) ((|DoubleFloat| . |TranscendentalFunctionCategory|) T) ((|DoubleFloat| . |TrigonometricFunctionCategory|) T) ((|Union| . |CoercibleTo|) 111814) ((|ExponentialExpansion| . |RetractableTo|) 111678) ((|PseudoAlgebraicClosureOfRationalNumber| . |SemiGroup|) T) ((|Record| . |SetCategory|) T) ((|Record| . |RecordCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |SemiGroup|) T) ((|OnePointCompletion| . |CoercibleTo|) 111652) ((|SplitHomogeneousDirectProduct| . |Rng|) 111562) ((|InnerPAdicInteger| . |PrincipalIdealDomain|) T) ((|Integer| . |OrderedIntegralDomain|) T) ((|Integer| . |PrincipalIdealDomain|) T) ((|InnerAlgebraicNumber| . |PrincipalIdealDomain|) T) ((|CartesianTensor| . |RetractableTo|) 111546) ((|DoubleFloat| . |ArcTrigonometricFunctionCategory|) T) ((|Asp41| . |FortranVectorFunctionCategory|) T) ((|Asp41| . |FortranProgramCategory|) T) ((|Enumeration| . |CoercibleTo|) 111520) ((|Complex| . |CharacteristicZero|) 111483) ((|Complex| . |CharacteristicNonZero|) 111401) ((|DoubleFloat| . |ArcHyperbolicFunctionCategory|) T) ((|AnonymousFunction| . |CoercibleTo|) 111375) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianMonoid|) T) ((|Pi| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |DifferentialExtension|) 111352) ((|Heap| . |PriorityQueueAggregate|) 111336) ((|HomogeneousDirectProduct| . |OrderedRing|) 111306) ((|DecimalExpansion| . |DifferentialExtension|) 111283) ((|Asp6| . |FortranVectorFunctionCategory|) T) ((|Asp6| . |FortranProgramCategory|) T) ((|SquareFreeRegularTriangularSet| . |Aggregate|) T) ((|OrderedDirectProduct| . |CommutativeRing|) 111249) ((|MultivariatePolynomial| . |BasicType|) T) ((|Reference| . |CoercibleTo|) 111200) ((|IndexedBits| . |Eltable|) 111165) ((|Expression| . |FullyLinearlyExplicitRingOver|) 111133) ((|ExponentialExpansion| . |FullyLinearlyExplicitRingOver|) 111048) ((|ExponentialExpansion| . |FullyEvalableOver|) 110963) ((|U32Matrix| . |Evalable|) NIL) ((|OrderlyDifferentialPolynomial| . |PolynomialCategory|) 110840) ((|Localize| . |CancellationAbelianMonoid|) T) ((|UnivariatePolynomial| . |CharacteristicNonZero|) 110800) ((|UnivariatePolynomial| . |CharacteristicZero|) 110763) ((|U32Vector| . |Type|) T) ((|SparseUnivariateTaylorSeries| . |BasicType|) T) ((|SparseUnivariatePuiseuxSeries| . |BasicType|) T) ((|SparseUnivariateLaurentSeries| . |BasicType|) T) ((|StringTable| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |BasicType|) T) ((|Dequeue| . |Aggregate|) T) ((|EuclideanModularRing| . |Module|) 110750) ((|StringTable| . |KeyedDictionary|) 110723) ((|IndexedString| . |Evalable|) NIL) ((|UnivariateTaylorSeries| . |UnivariateTaylorSeriesCategory|) 110707) ((|UnivariateTaylorSeries| . |UnivariatePowerSeriesCategory|) 110668) ((|Heap| . |SetCategory|) 110638) ((|UnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesConstructorCategory|) 110579) ((|FreeNilpotentLie| . |CoercibleTo|) 110553) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedSet|) T) ((|SparseTable| . |Dictionary|) 110495) ((|UnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 110454) ((|UnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 110438) ((|UnivariateLaurentSeries| . |UnivariateLaurentSeriesConstructorCategory|) 110380) ((|UnivariateLaurentSeries| . |UnivariatePowerSeriesCategory|) 110352) ((|UnivariateLaurentSeries| . |UnivariateLaurentSeriesCategory|) 110336) ((|UnivariateFormalPowerSeries| . |UnivariateTaylorSeriesCategory|) 110320) ((|UnivariateFormalPowerSeries| . |UnivariatePowerSeriesCategory|) 110281) ((|LocalAlgebra| . |CoercibleTo|) 110255) ((|SparseUnivariateTaylorSeries| . |ElementaryFunctionCategory|) 110204) ((|MachineFloat| . |PrincipalIdealDomain|) T) ((|SparseUnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 110153) ((|SparseUnivariateLaurentSeries| . |ElementaryFunctionCategory|) 110102) ((|SparseMultivariateTaylorSeries| . |ElementaryFunctionCategory|) 110051) ((|SimpleAlgebraicExtension| . |SetCategory|) T) ((|RightOpenIntervalRootCharacterization| . |SetCategory|) T) ((|AlgebraicNumber| . |ExpressionSpace|) T) ((|Expression| . |PartialDifferentialRing|) 110013) ((|ExponentialExpansion| . |PartialDifferentialRing|) NIL) ((|RightOpenIntervalRootCharacterization| . |RealRootCharacterizationCategory|) 109992) ((|SingleInteger| . |PatternMatchable|) 109969) ((|Octonion| . |Algebra|) 109953) ((|DifferentialSparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 109869) ((|DistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 109785) ((|MachineInteger| . |RightModule|) 109772) ((|InnerSparseUnivariatePowerSeries| . |UnivariatePowerSeriesCategory|) 109744) ((|SingleInteger| . |RetractableTo|) 109721) ((|ExponentialOfUnivariatePuiseuxSeries| . |CommutativeRing|) 109627) ((|FiniteFieldExtension| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtension| . |SetCategory|) T) ((|FiniteFieldCyclicGroupExtension| . |SetCategory|) T) ((|IndexedBits| . |OneDimensionalArrayAggregate|) 109604) ((|Set| . |Collection|) 109588) ((|MyExpression| . |EuclideanDomain|) 109555) ((|BinaryExpansion| . |SetCategory|) T) ((|BalancedPAdicInteger| . |RightModule|) 109542) ((|ModularField| . |Field|) T) ((|IndexedBits| . |IndexedAggregate|) 109507) ((|MachineInteger| . |BiModule|) 109492) ((|FortranTemplate| . |BasicType|) T) ((|SparseUnivariatePolynomialExpressions| . |PrincipalIdealDomain|) 109468) ((|AssociationList| . |StreamAggregate|) 109410) ((|BalancedPAdicInteger| . |BiModule|) 109395) ((|DoubleFloatVector| . |OrderedSet|) T) ((|ComplexDoubleFloatVector| . |OrderedSet|) 109343) ((|AssociatedLieAlgebra| . |Monad|) T) ((|AssociatedJordanAlgebra| . |Monad|) T) ((|OrderedDirectProduct| . |InnerEvalable|) 109262) ((|Result| . |Type|) T) ((|Point| . |Collection|) 109246) ((|IndexedList| . |BasicType|) 109183) ((|SequentialDifferentialPolynomial| . |UniqueFactorizationDomain|) 109133) ((|NewSparseUnivariatePolynomial| . |UniqueFactorizationDomain|) 109083) ((|NewSparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 109033) ((|Asp12| . |Type|) T) ((|Pi| . |CoercibleTo|) 108965) ((|Pi| . |ConvertibleTo|) 108834) ((|SparseUnivariatePolynomial| . |GcdDomain|) 108729) ((|String| . |SetCategory|) T) ((|SquareMatrix| . |LeftModule|) 108703) ((|SequentialDifferentialPolynomial| . |IntegralDomain|) 108589) ((|HomogeneousDirectProduct| . |FullyRetractableTo|) 108550) ((|LaurentPolynomial| . |PrincipalIdealDomain|) 108526) ((|GeneralDistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 108476) ((|SparseMultivariatePolynomial| . |GcdDomain|) 108394) ((|NewSparseUnivariatePolynomial| . |IntegralDomain|) 108257) ((|FortranProgram| . |CoercibleTo|) 108231) ((|NewSparseMultivariatePolynomial| . |IntegralDomain|) 108117) ((|MultivariatePolynomial| . |Evalable|) 108104) ((|ThreeDimensionalMatrix| . |InnerEvalable|) 108023) ((|LiePolynomial| . |AbelianSemiGroup|) T) ((|LiePolynomial| . |AbelianGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |IntegralDomain|) 107909) ((|BalancedPAdicRational| . |PrincipalIdealDomain|) T) ((|BalancedPAdicRational| . |OrderedIntegralDomain|) NIL) ((|FiniteFieldExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldExtensionByPolynomial| . |AbelianGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianGroup|) T) ((|Asp74| . |FortranMatrixFunctionCategory|) T) ((|Asp74| . |FortranProgramCategory|) T) ((|DistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|DistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|ThreeDimensionalViewport| . |CoercibleTo|) 107883) ((|TaylorSeries| . |SemiGroup|) T) ((|TaylorSeries| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |Evalable|) 107684) ((|SparseMultivariateTaylorSeries| . |Evalable|) 107671) ((|SimpleAlgebraicExtension| . |Module|) 107494) ((|OrdinaryWeightedPolynomials| . |LeftModule|) 107441) ((|Point| . |PointCategory|) 107425) ((|PrimeField| . |AbelianGroup|) T) ((|EuclideanModularRing| . |CommutativeRing|) T) ((|PrimeField| . |AbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |OrderedSet|) 107352) ((|PseudoAlgebraicClosureOfRationalNumber| . |CancellationAbelianMonoid|) T) ((|ModularField| . |SemiGroup|) T) ((|ModularField| . |AbelianMonoid|) T) ((|ListMultiDictionary| . |SetCategory|) 107322) ((|Library| . |KeyedDictionary|) 107292) ((|Library| . |SetCategory|) T) ((|InnerPrimeField| . |UniqueFactorizationDomain|) T) ((|InnerFiniteField| . |UniqueFactorizationDomain|) T) ((|InnerPrimeField| . |IntegralDomain|) T) ((|InnerFiniteField| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |Module|) 107233) ((|FiniteFieldNormalBasisExtension| . |Module|) 107174) ((|FiniteFieldCyclicGroupExtension| . |Module|) 107115) ((|FortranExpression| . |RightModule|) 107099) ((|ContinuedFraction| . |BiModule|) 106964) ((|ContinuedFraction| . |RightModule|) 106879) ((|BinaryExpansion| . |Module|) 106813) ((|FortranExpression| . |BiModule|) 106792) ((|e04ucfAnnaType| . |SetCategory|) T) ((|e04nafAnnaType| . |SetCategory|) T) ((|e04mbfAnnaType| . |SetCategory|) T) ((|e04jafAnnaType| . |SetCategory|) T) ((|MachineInteger| . |Ring|) T) ((|e04gcfAnnaType| . |SetCategory|) T) ((|e04fdfAnnaType| . |SetCategory|) T) ((|e04dgfAnnaType| . |SetCategory|) T) ((|d03fafAnnaType| . |SetCategory|) T) ((|d03eefAnnaType| . |SetCategory|) T) ((|d02ejfAnnaType| . |SetCategory|) T) ((|Complex| . |TrigonometricFunctionCategory|) 106743) ((|Complex| . |TranscendentalFunctionCategory|) 106694) ((|d02cjfAnnaType| . |SetCategory|) T) ((|d02bhfAnnaType| . |SetCategory|) T) ((|BalancedPAdicInteger| . |Ring|) T) ((|d02bbfAnnaType| . |SetCategory|) T) ((|d01TransformFunctionType| . |SetCategory|) T) ((|MachineInteger| . |DifferentialRing|) T) ((|d01gbfAnnaType| . |SetCategory|) T) ((|d01fcfAnnaType| . |SetCategory|) T) ((|d01asfAnnaType| . |SetCategory|) T) ((|d01aqfAnnaType| . |SetCategory|) T) ((|d01apfAnnaType| . |SetCategory|) T) ((|d01anfAnnaType| . |SetCategory|) T) ((|d01amfAnnaType| . |SetCategory|) T) ((|d01alfAnnaType| . |SetCategory|) T) ((|d01akfAnnaType| . |SetCategory|) T) ((|d01ajfAnnaType| . |SetCategory|) T) ((|DirectProduct| . |BasicType|) 106386) ((|Complex| . |ArcHyperbolicFunctionCategory|) 106337) ((|Complex| . |ArcTrigonometricFunctionCategory|) 106288) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |RetractableTo|) 106132) ((|HomogeneousDirectProduct| . |Rng|) 106042) ((|SquareMatrix| . |Aggregate|) T) ((|SplitHomogeneousDirectProduct| . |SetCategory|) 105734) ((|StochasticDifferential| . |BasicType|) T) ((|LieSquareMatrix| . |HomogeneousAggregate|) 105718) ((|Asp34| . |Type|) T) ((|BasicFunctions| . |CoercibleTo|) 105692) ((|XRecursivePolynomial| . |CoercibleTo|) 105666) ((|FreeModule1| . |CoercibleTo|) 105640) ((|MultivariatePolynomial| . |Algebra|) 105403) ((|Interval| . |TrigonometricFunctionCategory|) T) ((|Interval| . |TranscendentalFunctionCategory|) T) ((|IndexedExponents| . |CoercibleTo|) 105377) ((|IndexedList| . |Evalable|) 105301) ((|IndexedBits| . |CoercibleTo|) 105275) ((|IndexedBits| . |ConvertibleTo|) 105250) ((|SparseUnivariateLaurentSeries| . |StepThrough|) NIL) ((|RegularTriangularSet| . |RegularTriangularSetCategory|) 105219) ((|RegularTriangularSet| . |SetCategory|) T) ((|RadixExpansion| . |BasicType|) T) ((|Partition| . |BasicType|) T) ((|PartialFraction| . |BasicType|) T) ((|PoincareBirkhoffWittLyndonBasis| . |RetractableTo|) 105188) ((|SquareMatrix| . |Monoid|) T) ((|RadicalFunctionField| . |LeftModule|) 105116) ((|GeneralTriangularSet| . |SetCategory|) T) ((|GeneralPolynomialSet| . |SetCategory|) T) ((|IntegrationResult| . |AbelianMonoid|) T) ((|Interval| . |ArcHyperbolicFunctionCategory|) T) ((|Interval| . |ArcTrigonometricFunctionCategory|) T) ((|FourierSeries| . |BasicType|) T) ((|RoutinesTable| . |Dictionary|) 105049) ((|SparseUnivariateTaylorSeries| . |Algebra|) 104893) ((|OrdinaryWeightedPolynomials| . |Monoid|) T) ((|MachineComplex| . |PrincipalIdealDomain|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianSemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |Algebra|) 104681) ((|FortranExpression| . |Ring|) T) ((|SparseUnivariateLaurentSeries| . |Algebra|) 104396) ((|SimpleAlgebraicExtension| . |CommutativeRing|) T) ((|ContinuedFraction| . |Ring|) T) ((|SparseMultivariateTaylorSeries| . |Algebra|) 104240) ((|ModMonic| . |AbelianMonoidRing|) 104201) ((|FiniteFieldExtension| . |CommutativeRing|) T) ((|FiniteFieldNormalBasisExtension| . |CommutativeRing|) T) ((|InnerIndexedTwoDimensionalArray| . |TwoDimensionalArrayCategory|) 104175) ((|IndexedTwoDimensionalArray| . |TwoDimensionalArrayCategory|) 104077) ((|FiniteFieldNormalBasis| . |ExtensionField|) 104046) ((|DoubleFloat| . |GcdDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |EntireRing|) 103985) ((|FiniteFieldCyclicGroupExtension| . |CommutativeRing|) T) ((|ContinuedFraction| . |DivisionRing|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedSet|) 103854) ((|BinaryExpansion| . |CommutativeRing|) T) ((|PAdicRationalConstructor| . |QuotientFieldCategory|) 103838) ((|LinearOrdinaryDifferentialOperator| . |SemiGroup|) T) ((|InnerPrimeField| . |Field|) T) ((|InnerPrimeField| . |FiniteAlgebraicExtensionField|) 103825) ((|InnerFiniteField| . |FiniteAlgebraicExtensionField|) 103789) ((|InnerFiniteField| . |Field|) T) ((|Expression| . |EuclideanDomain|) 103756) ((|ExponentialExpansion| . |EuclideanDomain|) T) ((|IndexedVector| . |OrderedSet|) 103727) ((|SplitHomogeneousDirectProduct| . |Module|) 103656) ((|IndexedList| . |ExtensibleLinearAggregate|) 103640) ((|LinearOrdinaryDifferentialOperator| . |AbelianMonoid|) T) ((|Factored| . |DifferentialExtension|) 103624) ((|U16Matrix| . |BasicType|) T) ((|ExponentialExpansion| . |RealConstant|) NIL) ((|FiniteDivisor| . |AbelianMonoid|) T) ((|Divisor| . |AbelianMonoid|) T) ((|BalancedBinaryTree| . |RecursiveAggregate|) 103608) ((|AssociationList| . |AssociationListAggregate|) 103587) ((|Kernel| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |Finite|) T) ((|InnerAlgebraicNumber| . |AlgebraicallyClosedField|) T) ((|DirectProduct| . |Evalable|) 103511) ((|SequentialDifferentialPolynomial| . |SemiGroup|) T) ((|XPolynomialRing| . |LeftModule|) 103485) ((|NewSparseUnivariatePolynomial| . |SemiGroup|) T) ((|NewSparseMultivariatePolynomial| . |SemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |SemiGroup|) T) ((|RomanNumeral| . |GcdDomain|) T) ((|U8Matrix| . |SetCategory|) T) ((|Polynomial| . |GcdDomain|) 103403) ((|Bits| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |AbelianMonoid|) T) ((|OrdinaryDifferentialRing| . |Rng|) T) ((|NewSparseUnivariatePolynomial| . |AbelianMonoid|) T) ((|NewSparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |GcdDomain|) 103321) ((|StringTable| . |InnerEvalable|) 103005) ((|FreeModule1| . |FreeModuleCat|) 102984) ((|SymmetricPolynomial| . |FullyRetractableTo|) 102968) ((|GeneralModulePolynomial| . |AbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|MyUnivariatePolynomial| . |FullyRetractableTo|) 102952) ((|MyExpression| . |ExpressionSpace|) T) ((|Heap| . |InnerEvalable|) 102871) ((|RadicalFunctionField| . |LeftOreRing|) T) ((|EuclideanModularRing| . |EntireRing|) T) ((|SingletonAsOrderedSet| . |CoercibleTo|) 102845) ((|Fraction| . |PolynomialFactorizationExplicit|) 102795) ((|AntiSymm| . |SemiGroup|) T) ((|RealClosure| . |PrincipalIdealDomain|) T) ((|RadicalFunctionField| . |Monoid|) T) ((|ModMonic| . |PatternMatchable|) NIL) ((|InnerPrimeField| . |SemiGroup|) T) ((|InnerFiniteField| . |SemiGroup|) T) ((|OrderedCompletion| . |LeftModule|) 102759) ((|TaylorSeries| . |CancellationAbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |FullyPatternMatchable|) 102683) ((|RadixExpansion| . |Evalable|) NIL) ((|OrderedDirectProduct| . |HomogeneousAggregate|) 102667) ((|FiniteField| . |PrincipalIdealDomain|) T) ((|Stream| . |Aggregate|) T) ((|Fraction| . |LeftModule|) 102608) ((|AntiSymm| . |AbelianMonoid|) T) ((|ModularField| . |CancellationAbelianMonoid|) T) ((|ModMonic| . |RetractableTo|) 102418) ((|InnerPrimeField| . |AbelianMonoid|) T) ((|BinaryExpansion| . |InnerEvalable|) NIL) ((|InnerFiniteField| . |AbelianMonoid|) T) ((|Complex| . |FramedAlgebra|) 102366) ((|DoubleFloat| . |SpecialFunctionCategory|) T) ((|SplittingNode| . |SetCategory|) T) ((|XDistributedPolynomial| . |XAlgebra|) 102350) ((|MachineInteger| . |OrderedCancellationAbelianMonoid|) T) ((|MachineInteger| . |OrderedAbelianMonoid|) T) ((|Float| . |CharacteristicZero|) T) ((|SingleInteger| . |EuclideanDomain|) T) ((|UnivariateLaurentSeriesConstructor| . |QuotientFieldCategory|) 102317) ((|AlgebraicNumber| . |PrincipalIdealDomain|) T) ((|ThreeDimensionalMatrix| . |HomogeneousAggregate|) 102301) ((|DirectProductModule| . |VectorSpace|) 102268) ((|DirectProductMatrixModule| . |VectorSpace|) 102235) ((|Symbol| . |OrderedSet|) T) ((|SplitHomogeneousDirectProduct| . |CommutativeRing|) 102201) ((|SingleInteger| . |RealConstant|) T) ((|RegularChain| . |Aggregate|) T) ((|Operator| . |CharacteristicZero|) 102164) ((|Operator| . |CharacteristicNonZero|) 102124) ((|Multiset| . |BagAggregate|) 102108) ((|Kernel| . |CachableSet|) T) ((|HomogeneousDirectProduct| . |SetCategory|) 101800) ((|SymmetricPolynomial| . |Rng|) T) ((|PAdicRational| . |GcdDomain|) T) ((|Asp78| . |Type|) T) ((|DirectProduct| . |Algebra|) 101757) ((|CharacterClass| . |BagAggregate|) 101732) ((|Plcs| . |SetCategoryWithDegree|) T) ((|ModMonic| . |FullyLinearlyExplicitRingOver|) 101716) ((|MyUnivariatePolynomial| . |Rng|) T) ((|SingleInteger| . |IntegerNumberSystem|) T) ((|U16Matrix| . |Evalable|) NIL) ((|FreeNilpotentLie| . |RightModule|) 101700) ((|XPolynomialRing| . |Monoid|) T) ((|WeightedPolynomials| . |Rng|) T) ((|SparseUnivariatePolynomial| . |PolynomialCategory|) 101635) ((|Any| . |CoercibleTo|) 101609) ((|SparseMultivariatePolynomial| . |PolynomialCategory|) 101562) ((|LinearOrdinaryDifferentialOperator1| . |FullyRetractableTo|) 101546) ((|UnivariateTaylorSeries| . |BasicType|) T) ((|UnivariatePuiseuxSeries| . |BasicType|) T) ((|LocalAlgebra| . |RightModule|) 101530) ((|Localize| . |AbelianSemiGroup|) T) ((|Localize| . |AbelianGroup|) T) ((|String| . |InnerEvalable|) NIL) ((|UnivariateLaurentSeries| . |BasicType|) T) ((|U16Vector| . |Type|) T) ((|FreeNilpotentLie| . |BiModule|) 101509) ((|Dequeue| . |DequeueAggregate|) 101493) ((|UnivariateFormalPowerSeries| . |BasicType|) T) ((|RectangularMatrix| . |SetCategory|) T) ((|RadixExpansion| . |StepThrough|) T) ((|RectangularMatrix| . |RectangularMatrixCategory|) 101411) ((|OrderlyDifferentialVariable| . |SetCategory|) T) ((|FiniteFieldCyclicGroup| . |UniqueFactorizationDomain|) T) ((|AssociatedLieAlgebra| . |LeftModule|) 101395) ((|LocalAlgebra| . |BiModule|) 101374) ((|AssociatedJordanAlgebra| . |LeftModule|) 101358) ((|InnerTaylorSeries| . |BasicType|) T) ((|IntegrationResult| . |CancellationAbelianMonoid|) T) ((|InnerSparseUnivariatePowerSeries| . |BasicType|) T) ((|FramedModule| . |SetCategory|) T) ((|FreeModule| . |SetCategory|) T) ((|DenavitHartenbergMatrix| . |SetCategory|) 101328) ((|ListMultiDictionary| . |InnerEvalable|) 101247) ((|Library| . |InnerEvalable|) 100997) ((|OnePointCompletion| . |Ring|) 100967) ((|List| . |Collection|) 100951) ((|FiniteFieldCyclicGroup| . |IntegralDomain|) T) ((|ModMonic| . |PartialDifferentialRing|) 100849) ((|InnerTable| . |Dictionary|) 100791) ((|UnivariateTaylorSeries| . |ElementaryFunctionCategory|) 100740) ((|UnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 100689) ((|UnivariateLaurentSeries| . |ElementaryFunctionCategory|) 100638) ((|SimpleAlgebraicExtension| . |EntireRing|) 100572) ((|HexadecimalExpansion| . |OrderedRing|) T) ((|DeRhamComplex| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |ElementaryFunctionCategory|) 100521) ((|TaylorSeries| . |HyperbolicFunctionCategory|) 100470) ((|RadixExpansion| . |Algebra|) 100404) ((|DecimalExpansion| . |OrderedRing|) T) ((|Fraction| . |LeftOreRing|) T) ((|PartialFraction| . |Algebra|) 100345) ((|OrderedCompletion| . |OrderedAbelianSemiGroup|) 100315) ((|OrderedCompletion| . |OrderedAbelianGroup|) 100285) ((|OrderedCompletion| . |Monoid|) 100255) ((|FiniteFieldExtension| . |EntireRing|) T) ((|FiniteFieldNormalBasisExtension| . |EntireRing|) T) ((|FiniteFieldCyclicGroupExtension| . |EntireRing|) T) ((|Complex| . |GcdDomain|) 100156) ((|FourierSeries| . |Algebra|) 100140) ((|BinaryExpansion| . |EntireRing|) T) ((|DeRhamComplex| . |AbelianMonoid|) T) ((|Fraction| . |OrderedAbelianSemiGroup|) 100100) ((|Fraction| . |OrderedAbelianGroup|) 100060) ((|Fraction| . |Monoid|) T) ((|IndexedBits| . |EltableAggregate|) 100025) ((|Pi| . |RightModule|) 99979) ((|LinearOrdinaryDifferentialOperator| . |CancellationAbelianMonoid|) T) ((|SplitHomogeneousDirectProduct| . |InnerEvalable|) 99898) ((|FiniteDivisor| . |CancellationAbelianMonoid|) T) ((|Complex| . |FieldOfPrimeCharacteristic|) 99860) ((|Divisor| . |CancellationAbelianMonoid|) T) ((|HomogeneousDirectProduct| . |Module|) 99789) ((|OrderedDirectProduct| . |Eltable|) 99761) ((|Pi| . |BiModule|) 99688) ((|AffinePlane| . |AffineSpaceCategory|) 99672) ((|LinearOrdinaryDifferentialOperator1| . |Rng|) T) ((|UnivariatePolynomial| . |GcdDomain|) 99567) ((|SequentialDifferentialPolynomial| . |CancellationAbelianMonoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |OrderedSet|) 99538) ((|DistributedMultivariatePolynomial| . |OrderedSet|) 99509) ((|NewSparseUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|NewSparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|Interval| . |GcdDomain|) T) ((|RectangularMatrix| . |Module|) 99438) ((|LocalAlgebra| . |Ring|) T) ((|RegularTriangularSet| . |InnerEvalable|) 99357) ((|GeneralModulePolynomial| . |CancellationAbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|AssociationList| . |SetCategory|) T) ((|FreeModule| . |Module|) 99314) ((|OrdinaryDifferentialRing| . |SetCategory|) T) ((|GeneralTriangularSet| . |InnerEvalable|) 99233) ((|GeneralPolynomialSet| . |InnerEvalable|) 99152) ((|GenericNonAssociativeAlgebra| . |FiniteRankNonAssociativeAlgebra|) 99108) ((|AssociationList| . |KeyedDictionary|) 99087) ((|Expression| . |ExpressionSpace|) T) ((|LieSquareMatrix| . |CoercibleTo|) 99037) ((|OneDimensionalArray| . |OrderedSet|) 99008) ((|UnivariateLaurentSeries| . |Evalable|) 98827) ((|RadixExpansion| . |FullyPatternMatchable|) 98804) ((|OrderedDirectProduct| . |IndexedAggregate|) 98776) ((|IndexedFlexibleArray| . |OrderedSet|) 98747) ((|IndexedOneDimensionalArray| . |OrderedSet|) 98718) ((|AlgebraicFunctionField| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |RetractableTo|) 98562) ((|AntiSymm| . |CancellationAbelianMonoid|) T) ((|InnerPrimeField| . |CancellationAbelianMonoid|) T) ((|InnerFiniteField| . |CancellationAbelianMonoid|) T) ((|Equation| . |LeftModule|) 98386) ((|FiniteFieldCyclicGroup| . |FiniteAlgebraicExtensionField|) 98355) ((|FiniteFieldCyclicGroup| . |Field|) T) ((|FreeAbelianGroup| . |FreeAbelianMonoidCategory|) 98327) ((|ExponentialOfUnivariatePuiseuxSeries| . |Eltable|) 98312) ((|AlgebraicFunctionField| . |IntegralDomain|) T) ((|Float| . |TranscendentalFunctionCategory|) T) ((|Float| . |TrigonometricFunctionCategory|) T) ((|Result| . |TableAggregate|) 98282) ((|Table| . |DictionaryOperations|) 98224) ((|SparseUnivariateLaurentSeries| . |DifferentialExtension|) 98148) ((|Result| . |BagAggregate|) 98081) ((|FortranCode| . |SetCategory|) T) ((|Float| . |ArcTrigonometricFunctionCategory|) T) ((|Float| . |ArcHyperbolicFunctionCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianSemiGroup|) T) ((|Pi| . |Ring|) T) ((|InfinitlyClosePoint| . |InfinitlyClosePointCategory|) 98025) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianGroup|) T) ((|HashTable| . |DictionaryOperations|) 97967) ((|StringTable| . |HomogeneousAggregate|) 97890) ((|XRecursivePolynomial| . |RightModule|) 97874) ((|FreeModule1| . |RightModule|) 97858) ((|Pi| . |DivisionRing|) T) ((|OrderlyDifferentialPolynomial| . |BasicType|) T) ((|ModuleOperator| . |CharacteristicZero|) 97821) ((|ModuleOperator| . |CharacteristicNonZero|) 97781) ((|Heap| . |HomogeneousAggregate|) 97765) ((|XRecursivePolynomial| . |BiModule|) 97744) ((|HyperellipticFiniteDivisor| . |FiniteDivisorCategory|) 97713) ((|Quaternion| . |FullyLinearlyExplicitRingOver|) 97697) ((|IndexedDirectProductObject| . |SetCategory|) T) ((|HomogeneousDirectProduct| . |CommutativeRing|) 97663) ((|Quaternion| . |FullyEvalableOver|) 97647) ((|FractionalIdeal| . |BasicType|) T) ((|FreeModule1| . |BiModule|) 97626) ((|ElementaryFunctionsUnivariatePuiseuxSeries| . |PartialTranscendentalFunctions|) 97610) ((|ElementaryFunctionsUnivariateLaurentSeries| . |PartialTranscendentalFunctions|) 97594) ((|DoubleFloatMatrix| . |Aggregate|) T) ((|ComplexDoubleFloatMatrix| . |Aggregate|) T) ((|U8Matrix| . |InnerEvalable|) NIL) ((|XPolynomial| . |CoercibleTo|) 97568) ((|XPBWPolynomial| . |CoercibleTo|) 97542) ((|Bits| . |InnerEvalable|) NIL) ((|SparseUnivariatePolynomial| . |UnivariatePolynomialCategory|) 97526) ((|SparseUnivariateSkewPolynomial| . |UnivariateSkewPolynomialCategory|) 97510) ((|SymmetricPolynomial| . |SetCategory|) T) ((|BalancedBinaryTree| . |Type|) T) ((|Polynomial| . |PolynomialCategory|) 97451) ((|MyUnivariatePolynomial| . |SetCategory|) T) ((|OrdinaryDifferentialRing| . |Module|) 97371) ((|UnivariateLaurentSeries| . |StepThrough|) NIL) ((|HomogeneousDistributedMultivariatePolynomial| . |PolynomialCategory|) 97263) ((|RomanNumeral| . |CombinatorialFunctionCategory|) T) ((|TwoDimensionalArray| . |BasicType|) 97233) ((|AlgebraGivenByStructuralConstants| . |CoercibleTo|) 97207) ((|Asp4| . |CoercibleTo|) 97181) ((|FiniteFieldNormalBasis| . |LeftModule|) 97107) ((|WeightedPolynomials| . |SetCategory|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedSet|) T) ((|FiniteFieldCyclicGroup| . |SemiGroup|) T) ((|EqTable| . |SetCategory|) T) ((|Quaternion| . |PartialDifferentialRing|) 97039) ((|EqTable| . |KeyedDictionary|) 97018) ((|UnivariateTaylorSeries| . |Algebra|) 96862) ((|UnivariatePuiseuxSeries| . |Algebra|) 96650) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|UnivariateLaurentSeries| . |Algebra|) 96371) ((|HexadecimalExpansion| . |Rng|) T) ((|UnivariateFormalPowerSeries| . |Algebra|) 96215) ((|DecimalExpansion| . |Rng|) T) ((|FiniteFieldCyclicGroup| . |AbelianMonoid|) T) ((|CliffordAlgebra| . |CoercibleTo|) 96189) ((|OnePointCompletion| . |OrderedCancellationAbelianMonoid|) 96159) ((|OnePointCompletion| . |OrderedAbelianMonoid|) 96129) ((|MyExpression| . |PrincipalIdealDomain|) 96096) ((|InnerTaylorSeries| . |Algebra|) 96057) ((|InnerSparseUnivariatePowerSeries| . |Algebra|) 95901) ((|PAdicInteger| . |IntegralDomain|) T) ((|DeRhamComplex| . |CancellationAbelianMonoid|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |RadicalCategory|) 95850) ((|Asp50| . |CoercibleTo|) 95824) ((|ModMonic| . |EuclideanDomain|) 95800) ((|Equation| . |Monoid|) 95673) ((|OpenMathErrorKind| . |BasicType|) T) ((|OrderedVariableList| . |OrderedFinite|) T) ((|Equation| . |Group|) 95649) ((|XDistributedPolynomial| . |BasicType|) T) ((|AlgebraicFunctionField| . |Field|) T) ((|PAdicRationalConstructor| . |CharacteristicZero|) 95612) ((|AffinePlane| . |SetCategory|) T) ((|PAdicRationalConstructor| . |CharacteristicNonZero|) 95572) ((|String| . |HomogeneousAggregate|) 95547) ((|XRecursivePolynomial| . |Ring|) T) ((|HomogeneousDirectProduct| . |InnerEvalable|) 95466) ((|SquareFreeRegularTriangularSet| . |Type|) T) ((|Product| . |CoercibleTo|) 95440) ((|ListMultiDictionary| . |HomogeneousAggregate|) 95424) ((|Library| . |HomogeneousAggregate|) 95341) ((|OrderedDirectProduct| . |CoercibleTo|) 94990) ((|AlgebraicNumber| . |AlgebraicallyClosedField|) T) ((|SymmetricPolynomial| . |Module|) 94834) ((|LinearOrdinaryDifferentialOperator1| . |SetCategory|) T) ((|FortranTemplate| . |FileCategory|) 94799) ((|MyUnivariatePolynomial| . |Module|) 94539) ((|Set| . |BasicType|) T) ((|OrderlyDifferentialPolynomial| . |Evalable|) 94526) ((|OrderedVariableList| . |SetCategory|) T) ((|XPBWPolynomial| . |FreeModuleCat|) 94469) ((|RectangularMatrix| . |InnerEvalable|) 94388) ((|StringTable| . |Eltable|) 94361) ((|DirectProduct| . |DifferentialExtension|) 94329) ((|WeightedPolynomials| . |Module|) 94286) ((|OrdinaryDifferentialRing| . |CommutativeRing|) 94262) ((|FiniteFieldNormalBasis| . |LeftOreRing|) T) ((|DenavitHartenbergMatrix| . |InnerEvalable|) 94181) ((|LocalAlgebra| . |OrderedCancellationAbelianMonoid|) 94151) ((|LocalAlgebra| . |OrderedAbelianMonoid|) 94121) ((|Tuple| . |CoercibleTo|) 94040) ((|Dequeue| . |Type|) T) ((|ThreeDimensionalMatrix| . |CoercibleTo|) 93991) ((|Stream| . |RecursiveAggregate|) 93975) ((|FiniteFieldNormalBasis| . |Monoid|) T) ((|Point| . |BasicType|) 93912) ((|UnivariateLaurentSeries| . |FullyPatternMatchable|) 93842) ((|SplitHomogeneousDirectProduct| . |HomogeneousAggregate|) 93826) ((|TwoDimensionalArray| . |Evalable|) 93750) ((|FourierComponent| . |BasicType|) T) ((|TaylorSeries| . |AbelianGroup|) T) ((|TaylorSeries| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |SemiGroup|) T) ((|ModularField| . |AbelianGroup|) T) ((|LieExponentials| . |CoercibleTo|) 93724) ((|InnerFreeAbelianMonoid| . |FreeAbelianMonoidCategory|) 93703) ((|ModularField| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |Eltable|) NIL) ((|PositiveInteger| . |SemiGroup|) T) ((|AlgebraicFunctionField| . |AbelianMonoid|) T) ((|NonNegativeInteger| . |SemiGroup|) T) ((|Integer| . |UniqueFactorizationDomain|) T) ((|InnerAlgebraicNumber| . |UniqueFactorizationDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CoercibleTo|) 93677) ((|RadixExpansion| . |DifferentialExtension|) 93654) ((|Complex| . |ComplexCategory|) 93638) ((|InnerPAdicInteger| . |IntegralDomain|) T) ((|Integer| . |IntegralDomain|) T) ((|InnerAlgebraicNumber| . |IntegralDomain|) T) ((|NonNegativeInteger| . |AbelianMonoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |CharacteristicZero|) 93601) ((|StringTable| . |IndexedAggregate|) 93574) ((|UnivariatePuiseuxSeriesConstructor| . |CharacteristicNonZero|) 93534) ((|RegularTriangularSet| . |HomogeneousAggregate|) 93518) ((|UnivariateLaurentSeriesConstructor| . |CharacteristicNonZero|) 93405) ((|UnivariateLaurentSeriesConstructor| . |CharacteristicZero|) 93298) ((|XDistributedPolynomial| . |XPolynomialsCat|) 93277) ((|GeneralTriangularSet| . |HomogeneousAggregate|) 93261) ((|GeneralPolynomialSet| . |HomogeneousAggregate|) 93245) ((|IndexedMatrix| . |Aggregate|) T) ((|LinearOrdinaryDifferentialOperator1| . |Module|) 93202) ((|Localize| . |OrderedSet|) 93164) ((|SymmetricPolynomial| . |CommutativeRing|) 93093) ((|File| . |BasicType|) T) ((|DirectProduct| . |DirectProductCategory|) 93072) ((|DirectProductModule| . |BasicType|) T) ((|DirectProductMatrixModule| . |BasicType|) T) ((|UnivariatePolynomial| . |PolynomialCategory|) 93007) ((|BinaryFile| . |BasicType|) T) ((|DataList| . |OrderedSet|) 92978) ((|OrderlyDifferentialPolynomial| . |Algebra|) 92741) ((|MyUnivariatePolynomial| . |CommutativeRing|) 92571) ((|AssociationList| . |InnerEvalable|) 92279) ((|String| . |Eltable|) 92242) ((|Database| . |SetCategory|) T) ((|SparseTable| . |SetCategory|) T) ((|Places| . |BasicType|) T) ((|SparseTable| . |KeyedDictionary|) 92221) ((|IntegrationResult| . |AbelianSemiGroup|) T) ((|IntegrationResult| . |AbelianGroup|) T) ((|Set| . |Evalable|) 92145) ((|PolynomialRing| . |FullyRetractableTo|) 92129) ((|MachineFloat| . |UniqueFactorizationDomain|) T) ((|Library| . |Eltable|) 92099) ((|SequentialDifferentialPolynomial| . |LinearlyExplicitRingOver|) 92015) ((|NewSparseUnivariatePolynomial| . |LinearlyExplicitRingOver|) 91931) ((|NewSparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 91847) ((|FiniteFieldCyclicGroup| . |CancellationAbelianMonoid|) T) ((|EuclideanModularRing| . |CoercibleTo|) 91821) ((|Places| . |PlacesCategory|) 91764) ((|MachineFloat| . |IntegralDomain|) T) ((|Permutation| . |SetCategory|) T) ((|PAdicInteger| . |SemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 91680) ((|Permutation| . |PermutationCategory|) 91664) ((|PseudoAlgebraicClosureOfFiniteField| . |PseudoAlgebraicClosureOfFiniteFieldCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|Point| . |Evalable|) 91588) ((|Float| . |GcdDomain|) T) ((|PAdicInteger| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |CharacteristicNonZero|) T) ((|MachineInteger| . |LeftModule|) 91575) ((|PseudoAlgebraicClosureOfFiniteField| . |CharacteristicZero|) 91538) ((|DecimalExpansion| . |SetCategory|) T) ((|Expression| . |PrincipalIdealDomain|) 91505) ((|ExponentialExpansion| . |PrincipalIdealDomain|) T) ((|ExponentialExpansion| . |OrderedIntegralDomain|) NIL) ((|FreeNilpotentLie| . |Monad|) T) ((|NeitherSparseOrDensePowerSeries| . |CharacteristicNonZero|) 91465) ((|NeitherSparseOrDensePowerSeries| . |CharacteristicZero|) 91428) ((|U8Matrix| . |HomogeneousAggregate|) 91405) ((|BalancedPAdicInteger| . |LeftModule|) 91392) ((|GeneralUnivariatePowerSeries| . |CharacteristicNonZero|) 91352) ((|Factored| . |FullyRetractableTo|) 91336) ((|GeneralUnivariatePowerSeries| . |CharacteristicZero|) 91299) ((|Bits| . |HomogeneousAggregate|) 91276) ((|SparseUnivariatePolynomialExpressions| . |UniqueFactorizationDomain|) 91226) ((|Record| . |CoercibleTo|) 91200) ((|String| . |OneDimensionalArrayAggregate|) 91175) ((|SparseUnivariatePolynomialExpressions| . |IntegralDomain|) 91038) ((|String| . |IndexedAggregate|) 91001) ((|LinearOrdinaryDifferentialOperator| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator| . |AbelianSemiGroup|) T) ((|IndexedString| . |StringAggregate|) T) ((|SplitHomogeneousDirectProduct| . |Eltable|) 90973) ((|FiniteDivisor| . |AbelianSemiGroup|) T) ((|FiniteDivisor| . |AbelianGroup|) T) ((|Divisor| . |AbelianSemiGroup|) T) ((|Divisor| . |AbelianGroup|) T) ((|InnerAlgebraicNumber| . |Field|) T) ((|XDistributedPolynomial| . |Algebra|) 90930) ((|SquareMatrix| . |Type|) T) ((|Library| . |IndexedAggregate|) 90900) ((|SequentialDifferentialPolynomial| . |AbelianSemiGroup|) T) ((|SequentialDifferentialPolynomial| . |AbelianGroup|) T) ((|PolynomialRing| . |Rng|) T) ((|MyUnivariatePolynomial| . |InnerEvalable|) 90810) ((|IndexedExponents| . |OrderedAbelianMonoid|) T) ((|IndexedExponents| . |OrderedCancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |UniqueFactorizationDomain|) T) ((|DirichletRing| . |BasicType|) T) ((|LaurentPolynomial| . |IntegralDomain|) T) ((|NewSparseUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|NewSparseUnivariatePolynomial| . |AbelianGroup|) T) ((|NewSparseMultivariatePolynomial| . |AbelianGroup|) T) ((|NewSparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|MonoidRing| . |Rng|) T) ((|ModularRing| . |Rng|) T) ((|LieSquareMatrix| . |RightModule|) 90794) ((|GeneralModulePolynomial| . |AbelianSemiGroup|) T) ((|BalancedPAdicRational| . |IntegralDomain|) T) ((|GeneralModulePolynomial| . |AbelianGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|SquareMatrix| . |RetractableTo|) 90638) ((|OrdinaryDifferentialRing| . |EntireRing|) 90614) ((|MyExpression| . |FunctionSpace|) 90598) ((|OpenMathEncoding| . |SetCategory|) T) ((|XPolynomial| . |RightModule|) 90582) ((|XPBWPolynomial| . |RightModule|) 90566) ((|LieSquareMatrix| . |BiModule|) 90545) ((|EqTable| . |InnerEvalable|) 90253) ((|UnivariatePuiseuxSeriesConstructor| . |TranscendentalFunctionCategory|) 90202) ((|UnivariatePuiseuxSeriesConstructor| . |TrigonometricFunctionCategory|) 90151) ((|UniversalSegment| . |BasicType|) 90121) ((|DirectProductModule| . |Evalable|) 90045) ((|DirectProductMatrixModule| . |Evalable|) 89969) ((|UnivariateLaurentSeries| . |DifferentialExtension|) 89899) ((|StringTable| . |ConvertibleTo|) NIL) ((|StringTable| . |CoercibleTo|) 89873) ((|UnivariateLaurentSeriesConstructor| . |TranscendentalFunctionCategory|) 89822) ((|UnivariateLaurentSeriesConstructor| . |TrigonometricFunctionCategory|) 89771) ((|SquareMatrix| . |FullyLinearlyExplicitRingOver|) 89755) ((|SingleInteger| . |OrderedIntegralDomain|) T) ((|SingleInteger| . |PrincipalIdealDomain|) T) ((|SplitHomogeneousDirectProduct| . |IndexedAggregate|) 89727) ((|SimpleAlgebraicExtension| . |ConvertibleTo|) 89711) ((|SimpleAlgebraicExtension| . |CoercibleTo|) 89685) ((|RightOpenIntervalRootCharacterization| . |CoercibleTo|) 89659) ((|InfinitlyClosePoint| . |BasicType|) T) ((|Heap| . |CoercibleTo|) 89610) ((|OrderedDirectProduct| . |EltableAggregate|) 89582) ((|KeyedAccessFile| . |Collection|) 89518) ((|Factored| . |Rng|) T) ((|HexadecimalExpansion| . |Module|) 89452) ((|HomogeneousDirectProduct| . |HomogeneousAggregate|) 89436) ((|FlexibleArray| . |OrderedSet|) 89407) ((|FortranExpression| . |LeftModule|) 89381) ((|AntiSymm| . |AbelianGroup|) T) ((|AntiSymm| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |Module|) 89315) ((|Complex| . |MonogenicAlgebra|) 89263) ((|ContinuedFraction| . |LeftModule|) 89178) ((|InnerPrimeField| . |AbelianGroup|) T) ((|InnerPrimeField| . |AbelianSemiGroup|) T) ((|InnerFiniteField| . |AbelianSemiGroup|) T) ((|InnerFiniteField| . |AbelianGroup|) T) ((|GeneralSparseTable| . |Collection|) 89120) ((|MachineInteger| . |LeftOreRing|) T) ((|QuadraticForm| . |BasicType|) T) ((|OutputForm| . |BasicType|) T) ((|Octonion| . |FullyRetractableTo|) 89076) ((|AlgebraicFunctionField| . |CancellationAbelianMonoid|) T) ((|d03fafAnnaType| . |PartialDifferentialEquationsSolverCategory|) T) ((|MachineFloat| . |Field|) T) ((|MachineInteger| . |OrderedAbelianSemiGroup|) T) ((|MachineInteger| . |OrderedAbelianGroup|) T) ((|InnerPAdicInteger| . |SemiGroup|) T) ((|Integer| . |SemiGroup|) T) ((|BalancedPAdicInteger| . |LeftOreRing|) T) ((|InnerAlgebraicNumber| . |SemiGroup|) T) ((|MachineInteger| . |Monoid|) T) ((|FiniteFieldExtension| . |CoercibleTo|) 89050) ((|FiniteFieldNormalBasisExtension| . |CoercibleTo|) 89024) ((|FiniteFieldCyclicGroupExtension| . |CoercibleTo|) 88998) ((|Asp24| . |FortranFunctionCategory|) T) ((|Asp24| . |FortranProgramCategory|) T) ((|BinaryExpansion| . |ConvertibleTo|) 88899) ((|BinaryExpansion| . |CoercibleTo|) 88873) ((|d03eefAnnaType| . |PartialDifferentialEquationsSolverCategory|) T) ((|PrimitiveArray| . |Collection|) 88857) ((|UnivariatePuiseuxSeriesConstructor| . |ArcTrigonometricFunctionCategory|) 88806) ((|NonNegativeInteger| . |CancellationAbelianMonoid|) T) ((|CardinalNumber| . |Monoid|) T) ((|BalancedPAdicInteger| . |Monoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |ArcHyperbolicFunctionCategory|) 88755) ((|RectangularMatrix| . |HomogeneousAggregate|) 88739) ((|InnerPAdicInteger| . |AbelianMonoid|) T) ((|Integer| . |AbelianMonoid|) T) ((|InnerAlgebraicNumber| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |ArcTrigonometricFunctionCategory|) 88688) ((|UnivariateLaurentSeriesConstructor| . |ArcHyperbolicFunctionCategory|) 88637) ((|SparseUnivariatePolynomial| . |BasicType|) T) ((|SparseMultivariatePolynomial| . |BasicType|) T) ((|SparseUnivariateSkewPolynomial| . |BasicType|) T) ((|DenavitHartenbergMatrix| . |HomogeneousAggregate|) 88621) ((|XPolynomial| . |BiModule|) 88600) ((|XPBWPolynomial| . |BiModule|) 88579) ((|AlgebraGivenByStructuralConstants| . |RightModule|) 88563) ((|UnivariatePolynomial| . |UnivariatePolynomialCategory|) 88547) ((|UnivariateSkewPolynomial| . |UnivariateSkewPolynomialCategory|) 88531) ((|SymmetricPolynomial| . |EntireRing|) 88498) ((|Bits| . |Eltable|) 88463) ((|SquareMatrix| . |PartialDifferentialRing|) 88395) ((|AlgebraGivenByStructuralConstants| . |BiModule|) 88374) ((|MyUnivariatePolynomial| . |EntireRing|) 88237) ((|XPolynomial| . |Ring|) T) ((|LieSquareMatrix| . |Ring|) T) ((|SparseUnivariateLaurentSeries| . |OrderedRing|) NIL) ((|String| . |ConvertibleTo|) NIL) ((|String| . |CoercibleTo|) 88211) ((|RoutinesTable| . |KeyedDictionary|) 88181) ((|RoutinesTable| . |SetCategory|) T) ((|Asp35| . |FortranVectorFunctionCategory|) T) ((|Asp35| . |FortranProgramCategory|) T) ((|LieSquareMatrix| . |DifferentialRing|) 88146) ((|CliffordAlgebra| . |RightModule|) 88130) ((|Interval| . |IntervalCategory|) 88114) ((|FiniteFieldExtensionByPolynomial| . |CharacteristicZero|) 88077) ((|FiniteFieldExtensionByPolynomial| . |CharacteristicNonZero|) 88008) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CharacteristicZero|) 87971) ((|MakeCachableSet| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CharacteristicNonZero|) 87902) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CharacteristicZero|) 87865) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CharacteristicNonZero|) 87796) ((|DifferentialSparseMultivariatePolynomial| . |CharacteristicNonZero|) 87756) ((|DifferentialSparseMultivariatePolynomial| . |CharacteristicZero|) 87719) ((|DirectProductModule| . |Algebra|) 87676) ((|DistributedMultivariatePolynomial| . |CharacteristicZero|) 87639) ((|BalancedPAdicRational| . |Field|) T) ((|DistributedMultivariatePolynomial| . |CharacteristicNonZero|) 87599) ((|DirectProductMatrixModule| . |Algebra|) 87556) ((|CliffordAlgebra| . |BiModule|) 87535) ((|RadicalFunctionField| . |RetractableTo|) 87340) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|MachineComplex| . |UniqueFactorizationDomain|) T) ((|Octonion| . |Rng|) T) ((|MachineFloat| . |SemiGroup|) T) ((|XPBWPolynomial| . |Ring|) T) ((|SparseUnivariatePolynomialExpressions| . |SemiGroup|) T) ((|Stream| . |Type|) T) ((|RadicalFunctionField| . |FullyLinearlyExplicitRingOver|) 87311) ((|PrimeField| . |CharacteristicNonZero|) T) ((|PrimeField| . |CharacteristicZero|) 87277) ((|PAdicInteger| . |CancellationAbelianMonoid|) T) ((|OrderedDirectProduct| . |RightModule|) 87147) ((|MachineFloat| . |AbelianMonoid|) T) ((|MachineComplex| . |IntegralDomain|) T) ((|ListMultiDictionary| . |CoercibleTo|) 87098) ((|ListMultiDictionary| . |ConvertibleTo|) 87034) ((|Library| . |ConvertibleTo|) NIL) ((|Library| . |CoercibleTo|) 87008) ((|HexadecimalExpansion| . |CommutativeRing|) T) ((|DeRhamComplex| . |AbelianGroup|) T) ((|ContinuedFraction| . |LeftOreRing|) T) ((|DeRhamComplex| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |CommutativeRing|) T) ((|GeneralUnivariatePowerSeries| . |TrigonometricFunctionCategory|) 86957) ((|GeneralUnivariatePowerSeries| . |TranscendentalFunctionCategory|) 86906) ((|e04ucfAnnaType| . |CoercibleTo|) 86880) ((|e04nafAnnaType| . |CoercibleTo|) 86854) ((|e04mbfAnnaType| . |CoercibleTo|) 86828) ((|e04jafAnnaType| . |CoercibleTo|) 86802) ((|e04gcfAnnaType| . |CoercibleTo|) 86776) ((|IndexedBits| . |LinearAggregate|) 86753) ((|e04fdfAnnaType| . |CoercibleTo|) 86727) ((|FortranExpression| . |Monoid|) T) ((|e04dgfAnnaType| . |CoercibleTo|) 86701) ((|Bits| . |OneDimensionalArrayAggregate|) 86678) ((|ContinuedFraction| . |Monoid|) T) ((|IndexedBits| . |FiniteLinearAggregate|) 86655) ((|d03fafAnnaType| . |CoercibleTo|) 86629) ((|IndexedList| . |StreamAggregate|) 86613) ((|IndexedBits| . |BitAggregate|) T) ((|Bits| . |IndexedAggregate|) 86578) ((|d03eefAnnaType| . |CoercibleTo|) 86552) ((|GeneralUnivariatePowerSeries| . |ArcHyperbolicFunctionCategory|) 86501) ((|GeneralUnivariatePowerSeries| . |ArcTrigonometricFunctionCategory|) 86450) ((|d02ejfAnnaType| . |CoercibleTo|) 86424) ((|d02cjfAnnaType| . |CoercibleTo|) 86398) ((|d02bhfAnnaType| . |CoercibleTo|) 86372) ((|d02bbfAnnaType| . |CoercibleTo|) 86346) ((|d01TransformFunctionType| . |CoercibleTo|) 86320) ((|d01gbfAnnaType| . |CoercibleTo|) 86294) ((|d01fcfAnnaType| . |CoercibleTo|) 86268) ((|d01asfAnnaType| . |CoercibleTo|) 86242) ((|d01aqfAnnaType| . |CoercibleTo|) 86216) ((|d01apfAnnaType| . |CoercibleTo|) 86190) ((|d01anfAnnaType| . |CoercibleTo|) 86164) ((|InputForm| . |SExpressionCategory|) 86088) ((|d01amfAnnaType| . |CoercibleTo|) 86062) ((|d01alfAnnaType| . |CoercibleTo|) 86036) ((|AssociationList| . |HomogeneousAggregate|) 85965) ((|d01akfAnnaType| . |CoercibleTo|) 85939) ((|d01ajfAnnaType| . |CoercibleTo|) 85913) ((|SparseUnivariatePolynomialExpressions| . |AbelianMonoid|) T) ((|OrderedDirectProduct| . |BiModule|) 85776) ((|List| . |BasicType|) 85713) ((|HomogeneousDirectProduct| . |Eltable|) 85685) ((|SplitHomogeneousDirectProduct| . |CoercibleTo|) 85334) ((|SetOfMIntegersInOneToN| . |SetCategory|) T) ((|RegularChain| . |Type|) T) ((|LaurentPolynomial| . |SemiGroup|) T) ((|XPolynomialRing| . |RetractableTo|) 85318) ((|SparseUnivariatePolynomial| . |Evalable|) 85305) ((|SparseMultivariatePolynomial| . |Evalable|) 85292) ((|BalancedPAdicRational| . |SemiGroup|) T) ((|U8Matrix| . |MatrixCategory|) 85243) ((|OrderedFreeMonoid| . |BasicType|) T) ((|LaurentPolynomial| . |AbelianMonoid|) T) ((|SparseTable| . |InnerEvalable|) 84951) ((|FreeMonoid| . |BasicType|) T) ((|FreeAbelianMonoid| . |BasicType|) T) ((|RadicalFunctionField| . |PartialDifferentialRing|) 84870) ((|PolynomialRing| . |SetCategory|) T) ((|CliffordAlgebra| . |Ring|) T) ((|MultivariatePolynomial| . |FullyRetractableTo|) 84854) ((|BalancedPAdicRational| . |AbelianMonoid|) T) ((|MonoidRing| . |SetCategory|) T) ((|ModularRing| . |SetCategory|) T) ((|MakeCachableSet| . |CachableSet|) T) ((|GenericNonAssociativeAlgebra| . |SetCategory|) T) ((|Expression| . |FunctionSpace|) 84838) ((|Fraction| . |Type|) T) ((|RegularTriangularSet| . |ConvertibleTo|) 84774) ((|RegularTriangularSet| . |CoercibleTo|) 84726) ((|RealClosure| . |UniqueFactorizationDomain|) T) ((|DoubleFloat| . |BasicType|) T) ((|DirichletRing| . |Algebra|) 84646) ((|OrderlyDifferentialPolynomial| . |DifferentialExtension|) 84630) ((|RealClosure| . |IntegralDomain|) T) ((|OnePointCompletion| . |LeftModule|) 84594) ((|FiniteField| . |UniqueFactorizationDomain|) T) ((|GeneralTriangularSet| . |CoercibleTo|) 84546) ((|GeneralTriangularSet| . |ConvertibleTo|) 84482) ((|GeneralPolynomialSet| . |ConvertibleTo|) 84418) ((|GeneralPolynomialSet| . |CoercibleTo|) 84370) ((|Fraction| . |Patternable|) 84354) ((|ExponentialOfUnivariatePuiseuxSeries| . |RightModule|) 84136) ((|Fraction| . |PatternMatchable|) 84017) ((|OrderedCompletion| . |RetractableTo|) 83861) ((|HexadecimalExpansion| . |InnerEvalable|) NIL) ((|HomogeneousDirectProduct| . |IndexedAggregate|) 83833) ((|FiniteField| . |IntegralDomain|) T) ((|DecimalExpansion| . |InnerEvalable|) NIL) ((|PAdicRationalConstructor| . |GcdDomain|) T) ((|Factored| . |SetCategory|) T) ((|Fraction| . |RetractableTo|) 83635) ((|ExponentialOfUnivariatePuiseuxSeries| . |BiModule|) 83385) ((|MachineComplex| . |Field|) T) ((|DoubleFloat| . |ElementaryFunctionCategory|) T) ((|AlgebraicNumber| . |UniqueFactorizationDomain|) T) ((|OrderedDirectProduct| . |Ring|) 83295) ((|InnerPAdicInteger| . |CancellationAbelianMonoid|) T) ((|Integer| . |CancellationAbelianMonoid|) T) ((|InnerAlgebraicNumber| . |CancellationAbelianMonoid|) T) ((|AlgebraicNumber| . |IntegralDomain|) T) ((|StringTable| . |EltableAggregate|) 83268) ((|SparseUnivariatePolynomial| . |StepThrough|) 83238) ((|Expression| . |AlgebraicallyClosedField|) 83205) ((|RomanNumeral| . |BasicType|) T) ((|OrderedDirectProduct| . |DifferentialRing|) 83142) ((|DirectProduct| . |OrderedRing|) 83112) ((|Polynomial| . |BasicType|) T) ((|ModuleMonomial| . |BasicType|) T) ((|EqTable| . |HomogeneousAggregate|) 83041) ((|HomogeneousDistributedMultivariatePolynomial| . |BasicType|) T) ((|MultivariatePolynomial| . |Rng|) T) ((|Kernel| . |CoercibleTo|) 83015) ((|Kernel| . |ConvertibleTo|) 82793) ((|Fraction| . |FullyLinearlyExplicitRingOver|) 82777) ((|Fraction| . |FullyEvalableOver|) 82761) ((|SparseUnivariatePolynomial| . |Algebra|) 82501) ((|SparseMultivariatePolynomial| . |Algebra|) 82264) ((|SparseUnivariateSkewPolynomial| . |Algebra|) 82221) ((|FreeNilpotentLie| . |LeftModule|) 82205) ((|List| . |Evalable|) 82129) ((|U8Matrix| . |CoercibleTo|) 82103) ((|PolynomialRing| . |Module|) 81947) ((|MonoidRing| . |Module|) 81904) ((|Dequeue| . |BagAggregate|) 81888) ((|AssociationList| . |Eltable|) 81800) ((|LocalAlgebra| . |LeftModule|) 81774) ((|Exit| . |SetCategory|) T) ((|EuclideanModularRing| . |RightModule|) 81761) ((|Bits| . |CoercibleTo|) 81735) ((|Bits| . |ConvertibleTo|) 81710) ((|GenericNonAssociativeAlgebra| . |Module|) 81666) ((|OrderlyDifferentialPolynomial| . |DifferentialPolynomialCategory|) 81532) ((|Matrix| . |SetCategory|) 81502) ((|InnerTable| . |SetCategory|) T) ((|SparseUnivariateTaylorSeries| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |Rng|) T) ((|EuclideanModularRing| . |BiModule|) 81487) ((|SparseUnivariateLaurentSeries| . |Rng|) T) ((|SparseMultivariateTaylorSeries| . |Rng|) T) ((|InnerTable| . |KeyedDictionary|) 81466) ((|RadixExpansion| . |OrderedRing|) T) ((|DenavitHartenbergMatrix| . |MatrixCategory|) 81418) ((|MachineComplex| . |SemiGroup|) T) ((|TaylorSeries| . |MultivariateTaylorSeriesCategory|) 81391) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |ProjectiveSpaceCategory|) 81335) ((|ExponentialOfUnivariatePuiseuxSeries| . |Ring|) T) ((|FiniteFieldCyclicGroup| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroup| . |AbelianGroup|) T) ((|Fraction| . |PartialDifferentialRing|) 81267) ((|Asp28| . |Type|) T) ((|OnePointCompletion| . |OrderedAbelianSemiGroup|) 81237) ((|Factored| . |Module|) 81211) ((|Octonion| . |SetCategory|) T) ((|OnePointCompletion| . |OrderedAbelianGroup|) 81181) ((|MachineFloat| . |CancellationAbelianMonoid|) T) ((|ModMonic| . |PrincipalIdealDomain|) 81157) ((|MachineComplex| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |EntireRing|) T) ((|OnePointCompletion| . |Monoid|) 81127) ((|ExponentialOfUnivariatePuiseuxSeries| . |DifferentialRing|) 81062) ((|ExponentialOfUnivariatePuiseuxSeries| . |DivisionRing|) 81038) ((|DecimalExpansion| . |EntireRing|) T) ((|RealClosure| . |Field|) T) ((|UnivariatePuiseuxSeriesConstructor| . |GcdDomain|) 81014) ((|UnivariateLaurentSeriesConstructor| . |GcdDomain|) 80990) ((|FiniteField| . |FiniteAlgebraicExtensionField|) 80959) ((|FiniteField| . |Field|) T) ((|SplittingNode| . |CoercibleTo|) 80933) ((|AssociationList| . |UnaryRecursiveAggregate|) 80875) ((|PAdicRational| . |BasicType|) T) ((|List| . |ExtensibleLinearAggregate|) 80859) ((|MachineFloat| . |RealNumberSystem|) T) ((|Pi| . |LeftModule|) 80813) ((|GraphImage| . |SetCategory|) T) ((|AssociationList| . |IndexedAggregate|) 80725) ((|String| . |EltableAggregate|) 80688) ((|SparseUnivariatePolynomialExpressions| . |CancellationAbelianMonoid|) T) ((|AlgebraicFunctionField| . |LinearlyExplicitRingOver|) 80578) ((|AlgebraicNumber| . |Field|) T) ((|SimpleFortranProgram| . |CoercibleTo|) 80552) ((|SequentialDifferentialPolynomial| . |OrderedSet|) 80523) ((|Library| . |EltableAggregate|) 80493) ((|U32Matrix| . |SetCategory|) T) ((|Polynomial| . |Evalable|) 80480) ((|NewSparseUnivariatePolynomial| . |OrderedSet|) 80451) ((|NewSparseMultivariatePolynomial| . |OrderedSet|) 80422) ((|GeneralDistributedMultivariatePolynomial| . |OrderedSet|) 80393) ((|HomogeneousDirectProduct| . |CoercibleTo|) 80042) ((|DirectProduct| . |FullyRetractableTo|) 80003) ((|DoubleFloatMatrix| . |Type|) T) ((|ComplexDoubleFloatMatrix| . |Type|) T) ((|DoubleFloatVector| . |Collection|) 79976) ((|ComplexDoubleFloatVector| . |Collection|) 79937) ((|Asp20| . |Type|) T) ((|MyUnivariatePolynomial| . |Eltable|) 79840) ((|LaurentPolynomial| . |CancellationAbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Evalable|) 79827) ((|RoutinesTable| . |InnerEvalable|) 79577) ((|EuclideanModularRing| . |Ring|) T) ((|BalancedPAdicRational| . |CancellationAbelianMonoid|) T) ((|GenericNonAssociativeAlgebra| . |NonAssociativeRng|) T) ((|PolynomialRing| . |CommutativeRing|) 79506) ((|SuchThat| . |SetCategory|) T) ((|SplitHomogeneousDirectProduct| . |EltableAggregate|) 79478) ((|SimpleAlgebraicExtension| . |RightModule|) 79360) ((|LocalAlgebra| . |OrderedAbelianSemiGroup|) 79330) ((|IndexedString| . |SetCategory|) T) ((|LocalAlgebra| . |OrderedAbelianGroup|) 79300) ((|LocalAlgebra| . |Monoid|) T) ((|EqTable| . |Eltable|) 79279) ((|Equation| . |Type|) T) ((|RectangularMatrix| . |CoercibleTo|) 79229) ((|RectangularMatrix| . |ConvertibleTo|) 79165) ((|RealClosure| . |SemiGroup|) T) ((|Complex| . |BasicType|) T) ((|ExtAlgBasis| . |OrderedSet|) T) ((|Set| . |Dictionary|) 79149) ((|OrderlyDifferentialVariable| . |CoercibleTo|) 79123) ((|SimpleAlgebraicExtension| . |BiModule|) 78973) ((|RadicalFunctionField| . |EuclideanDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |GcdDomain|) T) ((|Octonion| . |Module|) 78957) ((|FiniteFieldExtension| . |RightModule|) 78898) ((|FiniteField| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |RightModule|) 78839) ((|FramedModule| . |CoercibleTo|) 78813) ((|FreeModule| . |CoercibleTo|) 78787) ((|FiniteFieldCyclicGroupExtension| . |RightModule|) 78728) ((|DenavitHartenbergMatrix| . |CoercibleTo|) 78679) ((|RealClosure| . |AbelianMonoid|) T) ((|NeitherSparseOrDensePowerSeries| . |GcdDomain|) T) ((|BinaryExpansion| . |RightModule|) 78613) ((|NumericalPDEProblem| . |BasicType|) T) ((|NumericalOptimizationProblem| . |BasicType|) T) ((|NumericalODEProblem| . |BasicType|) T) ((|NumericalIntegrationProblem| . |BasicType|) T) ((|Magma| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |GcdDomain|) 78589) ((|Factored| . |CommutativeRing|) T) ((|FiniteFieldExtension| . |BiModule|) 78498) ((|FiniteFieldNormalBasisExtension| . |BiModule|) 78407) ((|FiniteFieldCyclicGroupExtension| . |BiModule|) 78316) ((|DirectProductModule| . |DifferentialExtension|) 78284) ((|DirectProductMatrixModule| . |DifferentialExtension|) 78252) ((|FiniteField| . |AbelianMonoid|) T) ((|Asp31| . |Type|) T) ((|DoubleFloat| . |Algebra|) 78206) ((|BinaryExpansion| . |BiModule|) 78101) ((|AlgebraicFunctionField| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |AbelianGroup|) T) ((|LieSquareMatrix| . |Monad|) T) ((|Complex| . |ElementaryFunctionCategory|) 78052) ((|PseudoAlgebraicClosureOfFiniteField| . |FieldOfPrimeCharacteristic|) T) ((|AlgebraicNumber| . |SemiGroup|) T) ((|PositiveInteger| . |AbelianSemiGroup|) T) ((|NonNegativeInteger| . |AbelianSemiGroup|) T) ((|SparseTable| . |HomogeneousAggregate|) 77981) ((|Pi| . |LeftOreRing|) T) ((|HyperellipticFiniteDivisor| . |SetCategory|) T) ((|XRecursivePolynomial| . |LeftModule|) 77955) ((|UnivariatePolynomial| . |BasicType|) T) ((|UnivariateSkewPolynomial| . |BasicType|) T) ((|DirectProduct| . |Rng|) 77865) ((|RomanNumeral| . |StepThrough|) T) ((|Product| . |OrderedAbelianMonoid|) 77776) ((|FreeModule1| . |LeftModule|) 77760) ((|AlgebraicNumber| . |AbelianMonoid|) T) ((|Product| . |OrderedCancellationAbelianMonoid|) 77671) ((|OrderedDirectProduct| . |OrderedCancellationAbelianMonoid|) 77595) ((|OrderedDirectProduct| . |OrderedAbelianMonoid|) 77519) ((|EqTable| . |IndexedAggregate|) 77498) ((|Pi| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |HyperbolicFunctionCategory|) 77449) ((|Interval| . |BasicType|) T) ((|StochasticDifferential| . |Rng|) T) ((|PAdicRational| . |Evalable|) 77357) ((|LinearOrdinaryDifferentialOperator1| . |Eltable|) 77336) ((|Boolean| . |Logic|) T) ((|Asp42| . |Type|) T) ((|RomanNumeral| . |Algebra|) 77323) ((|LiePolynomial| . |FreeLieAlgebra|) 77302) ((|Polynomial| . |Algebra|) 77065) ((|MultivariatePolynomial| . |SetCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Algebra|) 76828) ((|Asp7| . |Type|) T) ((|Interval| . |ElementaryFunctionCategory|) T) ((|UnivariateLaurentSeries| . |OrderedRing|) NIL) ((|SparseUnivariateTaylorSeries| . |SetCategory|) T) ((|SparseUnivariatePuiseuxSeries| . |SetCategory|) T) ((|SparseUnivariateLaurentSeries| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |RetractableTo|) 76797) ((|SimpleAlgebraicExtension| . |Ring|) T) ((|RadixExpansion| . |Rng|) T) ((|AssociationList| . |CoercibleTo|) 76771) ((|AssociationList| . |ConvertibleTo|) NIL) ((|PartialFraction| . |Rng|) T) ((|OrdinaryDifferentialRing| . |CoercibleTo|) 76745) ((|Stack| . |BasicType|) 76715) ((|SimpleAlgebraicExtension| . |DivisionRing|) 76649) ((|FourierSeries| . |Rng|) T) ((|FiniteFieldExtension| . |Ring|) T) ((|FiniteFieldNormalBasisExtension| . |Ring|) T) ((|File| . |FileCategory|) 76620) ((|FiniteFieldCyclicGroupExtension| . |Ring|) T) ((|DirectProductModule| . |DirectProductCategory|) 76599) ((|DirectProductMatrixModule| . |DirectProductCategory|) 76578) ((|BinaryFile| . |FileCategory|) 76536) ((|SimpleAlgebraicExtension| . |DifferentialRing|) 76430) ((|SparseMultivariateTaylorSeries| . |SetCategory|) T) ((|Equation| . |PartialDifferentialRing|) 76362) ((|BinaryExpansion| . |Ring|) T) ((|MyExpression| . |UniqueFactorizationDomain|) 76329) ((|MachineComplex| . |CancellationAbelianMonoid|) T) ((|Factored| . |InnerEvalable|) 76125) ((|FiniteFieldExtension| . |DifferentialRing|) 76100) ((|FiniteFieldExtension| . |DivisionRing|) T) ((|AlgebraGivenByStructuralConstants| . |Monad|) T) ((|FiniteFieldNormalBasisExtension| . |DifferentialRing|) 76075) ((|FiniteFieldNormalBasisExtension| . |DivisionRing|) T) ((|FiniteFieldCyclicGroupExtension| . |DifferentialRing|) 76050) ((|FiniteFieldCyclicGroupExtension| . |DivisionRing|) T) ((|MyExpression| . |IntegralDomain|) T) ((|Complex| . |Evalable|) 76009) ((|BinaryExpansion| . |DivisionRing|) T) ((|BinaryExpansion| . |DifferentialRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedAbelianMonoid|) T) ((|PAdicInteger| . |AbelianGroup|) T) ((|PAdicInteger| . |AbelianSemiGroup|) T) ((|Fraction| . |EuclideanDomain|) T) ((|IndexedBits| . |Aggregate|) T) ((|Bits| . |EltableAggregate|) 75974) ((|SplitHomogeneousDirectProduct| . |RightModule|) 75844) ((|PAdicRational| . |StepThrough|) NIL) ((|PseudoAlgebraicClosureOfRationalNumber| . |PseudoAlgebraicClosureOfRationalNumberCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfRationalNumberCategory|) T) ((|FortranCode| . |CoercibleTo|) 75818) ((|Fraction| . |RealConstant|) 75787) ((|SplitHomogeneousDirectProduct| . |BiModule|) 75650) ((|PseudoAlgebraicClosureOfRationalNumber| . |CharacteristicNonZero|) 75590) ((|PseudoAlgebraicClosureOfRationalNumber| . |CharacteristicZero|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CharacteristicZero|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CharacteristicNonZero|) 75530) ((|FortranTemplate| . |SetCategory|) T) ((|XRecursivePolynomial| . |Monoid|) T) ((|Asp19| . |CoercibleTo|) 75504) ((|PAdicRational| . |Algebra|) 75428) ((|IndexedMatrix| . |Type|) T) ((|IndexedVector| . |Collection|) 75412) ((|IndexedDirectProductObject| . |CoercibleTo|) 75386) ((|UnivariatePolynomial| . |Evalable|) 75373) ((|MultivariatePolynomial| . |Module|) 75136) ((|IndexedExponents| . |OrderedAbelianMonoidSup|) T) ((|IndexedExponents| . |OrderedAbelianSemiGroup|) T) ((|Integer| . |LinearlyExplicitRingOver|) 75113) ((|InnerAlgebraicNumber| . |LinearlyExplicitRingOver|) 75057) ((|FiniteFieldExtensionByPolynomial| . |GcdDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |GcdDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |GcdDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |GcdDomain|) 74975) ((|IndexedList| . |SetCategory|) 74912) ((|DistributedMultivariatePolynomial| . |GcdDomain|) 74830) ((|SparseTable| . |Eltable|) 74809) ((|SymmetricPolynomial| . |CoercibleTo|) 74783) ((|Matrix| . |InnerEvalable|) 74702) ((|PolynomialRing| . |EntireRing|) 74669) ((|InnerTable| . |InnerEvalable|) 74377) ((|MyUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|MyUnivariatePolynomial| . |CoercibleTo|) 74351) ((|WeightedPolynomials| . |CoercibleTo|) 74325) ((|SparseUnivariatePolynomial| . |DifferentialExtension|) 74309) ((|Complex| . |StepThrough|) 74271) ((|UnivariateTaylorSeriesCZero| . |IntegralDomain|) 74238) ((|SparseUnivariateTaylorSeries| . |Module|) 74082) ((|SparseUnivariatePuiseuxSeries| . |Module|) 73870) ((|Pattern| . |BasicType|) T) ((|SparseUnivariateLaurentSeries| . |Module|) 73585) ((|SparseMultivariateTaylorSeries| . |Module|) 73429) ((|Stream| . |LazyStreamAggregate|) 73413) ((|FiniteFieldExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73344) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73275) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73206) ((|RealClosure| . |CancellationAbelianMonoid|) T) ((|Octonion| . |InnerEvalable|) 73095) ((|EqTable| . |ConvertibleTo|) NIL) ((|EqTable| . |CoercibleTo|) 73069) ((|PrimeField| . |GcdDomain|) T) ((|Product| . |Finite|) 73014) ((|OrderedDirectProduct| . |Finite|) 72989) ((|IndexedDirectProductOrderedAbelianMonoid| . |IndexedDirectProductCategory|) 72968) ((|IndexedDirectProductAbelianMonoid| . |IndexedDirectProductCategory|) 72947) ((|HexadecimalExpansion| . |Eltable|) NIL) ((|HomogeneousDirectProduct| . |EltableAggregate|) 72919) ((|Factored| . |EntireRing|) T) ((|FiniteField| . |CancellationAbelianMonoid|) T) ((|DecimalExpansion| . |Eltable|) NIL) ((|MachineComplex| . |HyperbolicFunctionCategory|) NIL) ((|Automorphism| . |SemiGroup|) T) ((|Complex| . |Algebra|) 72677) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |IntegralDomain|) T) ((|UnivariatePuiseuxSeriesConstructor| . |PowerSeriesCategory|) 72610) ((|Stack| . |Evalable|) 72534) ((|UnivariateLaurentSeriesConstructor| . |PowerSeriesCategory|) 72480) ((|PrimeField| . |FieldOfPrimeCharacteristic|) T) ((|SplitHomogeneousDirectProduct| . |Ring|) 72390) ((|SparseTable| . |IndexedAggregate|) 72369) ((|MyExpression| . |Field|) 72336) ((|NeitherSparseOrDensePowerSeries| . |Collection|) 72277) ((|Boolean| . |OrderedSet|) T) ((|RoutinesTable| . |HomogeneousAggregate|) 72194) ((|InnerPAdicInteger| . |AbelianGroup|) T) ((|InnerPAdicInteger| . |AbelianSemiGroup|) T) ((|Integer| . |AbelianGroup|) T) ((|Integer| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |AbelianGroup|) T) ((|UnivariatePolynomial| . |StepThrough|) 72164) ((|SplitHomogeneousDirectProduct| . |DifferentialRing|) 72101) ((|AlgebraicNumber| . |CancellationAbelianMonoid|) T) ((|AffinePlane| . |CoercibleTo|) 72075) ((|ProjectiveSpace| . |SetCategoryWithDegree|) T) ((|TextFile| . |BasicType|) T) ((|DirectProduct| . |SetCategory|) 71767) ((|PAdicRational| . |FullyPatternMatchable|) 71734) ((|SequentialDifferentialVariable| . |BasicType|) T) ((|RewriteRule| . |BasicType|) T) ((|U32Matrix| . |InnerEvalable|) NIL) ((|KeyedAccessFile| . |BasicType|) T) ((|GeneralSparseTable| . |BasicType|) T) ((|UnivariatePolynomial| . |Algebra|) 71474) ((|StochasticDifferential| . |SetCategory|) T) ((|UnivariateSkewPolynomial| . |Algebra|) 71431) ((|SparseUnivariatePolynomialExpressions| . |LinearlyExplicitRingOver|) 71347) ((|MultivariatePolynomial| . |CommutativeRing|) 71200) ((|LinearOrdinaryDifferentialOperator1| . |CoercibleTo|) 71174) ((|Interval| . |Algebra|) 71161) ((|PrimitiveArray| . |BasicType|) 71098) ((|OrderedVariableList| . |CoercibleTo|) 71072) ((|OrderedVariableList| . |ConvertibleTo|) 70966) ((|IndexedString| . |InnerEvalable|) NIL) ((|UnivariateTaylorSeries| . |Rng|) T) ((|UnivariatePuiseuxSeries| . |Rng|) T) ((|UnivariateLaurentSeries| . |Rng|) T) ((|UnivariateFormalPowerSeries| . |Rng|) T) ((|IntegerMod| . |SemiGroup|) T) ((|TaylorSeries| . |CharacteristicZero|) 70929) ((|SparseUnivariateTaylorSeries| . |CommutativeRing|) 70858) ((|InnerTaylorSeries| . |Rng|) T) ((|InnerSparseUnivariatePowerSeries| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |CommutativeRing|) 70764) ((|SparseUnivariateLaurentSeries| . |CommutativeRing|) 70670) ((|SparseMultivariateTaylorSeries| . |CommutativeRing|) 70599) ((|RadixExpansion| . |SetCategory|) T) ((|Partition| . |SetCategory|) T) ((|PartialFraction| . |SetCategory|) T) ((|Octonion| . |OctonionCategory|) 70583) ((|NeitherSparseOrDensePowerSeries| . |LocalPowerSeriesCategory|) 70567) ((|NeitherSparseOrDensePowerSeries| . |PowerSeriesCategory|) 70513) ((|MyExpression| . |SemiGroup|) T) ((|MachineFloat| . |AbelianSemiGroup|) T) ((|MachineFloat| . |AbelianGroup|) T) ((|BalancedPAdicRational| . |LinearlyExplicitRingOver|) 70472) ((|MachineInteger| . |PatternMatchable|) 70449) ((|FourierSeries| . |SetCategory|) T) ((|Expression| . |UniqueFactorizationDomain|) 70416) ((|ExponentialExpansion| . |UniqueFactorizationDomain|) T) ((|Complex| . |FullyPatternMatchable|) 70400) ((|TaylorSeries| . |CharacteristicNonZero|) 70360) ((|GeneralUnivariatePowerSeries| . |PowerSeriesCategory|) 70293) ((|Asp33| . |CoercibleTo|) 70267) ((|MyExpression| . |AbelianMonoid|) T) ((|BinaryExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|BinaryExpansion| . |OrderedAbelianMonoid|) T) ((|Expression| . |IntegralDomain|) 70234) ((|MachineInteger| . |RetractableTo|) 70211) ((|ExponentialExpansion| . |IntegralDomain|) T) ((|IntegerMod| . |AbelianMonoid|) T) ((|CardinalNumber| . |RetractableTo|) 70177) ((|HomogeneousDirectProduct| . |RightModule|) 70047) ((|AssociationList| . |EltableAggregate|) 69959) ((|SparseUnivariatePolynomialExpressions| . |AbelianSemiGroup|) T) ((|SparseUnivariatePolynomialExpressions| . |AbelianGroup|) T) ((|DirectProduct| . |Module|) 69888) ((|HomogeneousDirectProduct| . |BiModule|) 69751) ((|SegmentBinding| . |BasicType|) 69721) ((|ResidueRing| . |BasicType|) T) ((|StochasticDifferential| . |Module|) 69690) ((|List| . |OpenMath|) 69663) ((|U16Matrix| . |SetCategory|) T) ((|MultivariatePolynomial| . |InnerEvalable|) 69567) ((|RectangularMatrix| . |RightModule|) 69551) ((|LaurentPolynomial| . |AbelianGroup|) T) ((|LaurentPolynomial| . |AbelianSemiGroup|) T) ((|RoutinesTable| . |Eltable|) 69521) ((|FreeGroup| . |BasicType|) T) ((|FreeAbelianGroup| . |BasicType|) T) ((|LieSquareMatrix| . |LeftModule|) 69495) ((|FreeModule| . |RightModule|) 69479) ((|RectangularMatrix| . |BiModule|) 69458) ((|OrderlyDifferentialPolynomial| . |FullyRetractableTo|) 69442) ((|BalancedPAdicRational| . |AbelianSemiGroup|) T) ((|Asp9| . |CoercibleTo|) 69416) ((|BalancedPAdicRational| . |AbelianGroup|) T) ((|KeyedAccessFile| . |Evalable|) 69158) ((|GeneralSparseTable| . |Evalable|) 68918) ((|UnivariateTaylorSeriesCZero| . |SemiGroup|) T) ((|SparseTable| . |ConvertibleTo|) NIL) ((|FreeModule| . |BiModule|) 68897) ((|Float| . |BasicType|) T) ((|Database| . |CoercibleTo|) 68871) ((|SparseTable| . |CoercibleTo|) 68845) ((|RadixExpansion| . |Module|) 68779) ((|SparseUnivariateLaurentSeries| . |InnerEvalable|) 68309) ((|PartialFraction| . |Module|) 68250) ((|SparseMultivariateTaylorSeries| . |InnerEvalable|) 68220) ((|FiniteFieldNormalBasis| . |EuclideanDomain|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianMonoid|) T) ((|Table| . |Collection|) 68162) ((|PrimitiveArray| . |Evalable|) 68086) ((|Operator| . |BasicType|) T) ((|FourierSeries| . |Module|) 68070) ((|DoubleFloat| . |OpenMath|) T) ((|OppositeMonogenicLinearOperator| . |BasicType|) T) ((|OpenMathError| . |BasicType|) T) ((|HashTable| . |Collection|) 68012) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePuiseuxSeriesConstructorCategory|) 67991) ((|SingleInteger| . |UniqueFactorizationDomain|) T) ((|FortranExpression| . |RetractableTo|) 67954) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePowerSeriesCategory|) 67913) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePuiseuxSeriesCategory|) 67897) ((|UnivariateLaurentSeriesConstructor| . |UnivariateLaurentSeriesConstructorCategory|) 67876) ((|Asp55| . |CoercibleTo|) 67850) ((|Permutation| . |CoercibleTo|) 67824) ((|UnivariateLaurentSeriesConstructor| . |UnivariatePowerSeriesCategory|) 67796) ((|SingleInteger| . |IntegralDomain|) T) ((|PositiveInteger| . |OrderedSet|) T) ((|NonNegativeInteger| . |OrderedSet|) T) ((|HexadecimalExpansion| . |ConvertibleTo|) 67697) ((|HexadecimalExpansion| . |CoercibleTo|) 67671) ((|Float| . |ElementaryFunctionCategory|) T) ((|LyndonWord| . |OrderedSet|) T) ((|UnivariateLaurentSeriesConstructor| . |UnivariateLaurentSeriesCategory|) 67655) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |SemiGroup|) T) ((|DecimalExpansion| . |ConvertibleTo|) 67556) ((|DecimalExpansion| . |CoercibleTo|) 67530) ((|RoutinesTable| . |IndexedAggregate|) 67500) ((|OneDimensionalArray| . |Collection|) 67484) ((|IndexedFlexibleArray| . |Collection|) 67468) ((|IndexedOneDimensionalArray| . |Collection|) 67452) ((|FiniteFieldExtension| . |ExtensionField|) 67436) ((|FiniteFieldNormalBasisExtension| . |ExtensionField|) 67420) ((|FiniteFieldCyclicGroupExtension| . |ExtensionField|) 67404) ((|Expression| . |Field|) 67371) ((|ExponentialExpansion| . |Field|) T) ((|HomogeneousDirectProduct| . |Ring|) 67281) ((|MachineComplex| . |LinearlyExplicitRingOver|) 67253) ((|XPolynomial| . |LeftModule|) 67227) ((|XPBWPolynomial| . |LeftModule|) 67201) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianMonoid|) T) ((|Matrix| . |HomogeneousAggregate|) 67185) ((|Asp1| . |CoercibleTo|) 67159) ((|SplitHomogeneousDirectProduct| . |OrderedCancellationAbelianMonoid|) 67083) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianMonoid|) 67007) ((|InnerTable| . |HomogeneousAggregate|) 66936) ((|LieSquareMatrix| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |DifferentialRing|) 66873) ((|EqTable| . |EltableAggregate|) 66852) ((|DirectProduct| . |CommutativeRing|) 66818) ((|PseudoAlgebraicClosureOfFiniteField| . |VectorSpace|) 66802) ((|OrderlyDifferentialPolynomial| . |Rng|) T) ((|AlgebraGivenByStructuralConstants| . |LeftModule|) 66751) ((|SimpleAlgebraicExtension| . |Finite|) 66684) ((|MultivariatePolynomial| . |EntireRing|) 66570) ((|IndexedList| . |InnerEvalable|) 66489) ((|OrdinaryDifferentialRing| . |RightModule|) 66426) ((|SequentialDifferentialPolynomial| . |CharacteristicNonZero|) 66386) ((|FiniteFieldExtension| . |Finite|) 66361) ((|FiniteFieldNormalBasisExtension| . |Finite|) 66336) ((|FiniteFieldCyclicGroupExtension| . |Finite|) 66311) ((|SequentialDifferentialPolynomial| . |CharacteristicZero|) 66274) ((|PAdicRational| . |DifferentialExtension|) 66241) ((|OrdinaryDifferentialRing| . |BiModule|) 66151) ((|NewSparseUnivariatePolynomial| . |CharacteristicNonZero|) 66111) ((|NewSparseUnivariatePolynomial| . |CharacteristicZero|) 66074) ((|DifferentialSparseMultivariatePolynomial| . |PolynomialCategory|) 66027) ((|DirectProductModule| . |OrderedRing|) 65997) ((|DistributedMultivariatePolynomial| . |PolynomialCategory|) 65900) ((|DirectProductMatrixModule| . |OrderedRing|) 65870) ((|NewSparseMultivariatePolynomial| . |CharacteristicNonZero|) 65830) ((|NewSparseMultivariatePolynomial| . |CharacteristicZero|) 65793) ((|CliffordAlgebra| . |LeftModule|) 65767) ((|GeneralDistributedMultivariatePolynomial| . |CharacteristicZero|) 65730) ((|GeneralDistributedMultivariatePolynomial| . |CharacteristicNonZero|) 65690) ((|LieSquareMatrix| . |Monoid|) T) ((|OpenMathEncoding| . |CoercibleTo|) 65664) ((|UnivariateTaylorSeries| . |SetCategory|) T) ((|UnivariatePuiseuxSeries| . |SetCategory|) T) ((|UnivariateLaurentSeries| . |SetCategory|) T) ((|UnivariateFormalPowerSeries| . |SetCategory|) T) ((|TaylorSeries| . |TrigonometricFunctionCategory|) 65613) ((|TaylorSeries| . |TranscendentalFunctionCategory|) 65562) ((|SparseUnivariateTaylorSeries| . |EntireRing|) 65529) ((|SparseUnivariatePuiseuxSeries| . |EntireRing|) 65468) ((|SparseUnivariateLaurentSeries| . |EntireRing|) 65407) ((|SparseMultivariateTaylorSeries| . |EntireRing|) 65374) ((|FortranExpression| . |PartialDifferentialRing|) 65352) ((|RadixExpansion| . |CommutativeRing|) T) ((|PartialFraction| . |CommutativeRing|) T) ((|NeitherSparseOrDensePowerSeries| . |UnivariatePowerSeriesCategory|) 65324) ((|InnerTaylorSeries| . |SetCategory|) T) ((|InnerSparseUnivariatePowerSeries| . |SetCategory|) T) ((|MachineComplex| . |AbelianGroup|) T) ((|MachineComplex| . |AbelianSemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |UnivariatePuiseuxSeriesCategory|) 65308) ((|GeneralUnivariatePowerSeries| . |UnivariatePowerSeriesCategory|) 65267) ((|Factored| . |Eltable|) 65185) ((|Expression| . |SemiGroup|) 64967) ((|ExponentialExpansion| . |SemiGroup|) T) ((|TaylorSeries| . |ArcHyperbolicFunctionCategory|) 64916) ((|TaylorSeries| . |ArcTrigonometricFunctionCategory|) 64865) ((|Asp77| . |CoercibleTo|) 64839) ((|ArrayStack| . |BasicType|) 64809) ((|IntegerMod| . |CancellationAbelianMonoid|) T) ((|U32Matrix| . |HomogeneousAggregate|) 64786) ((|MyExpression| . |CancellationAbelianMonoid|) T) ((|InnerPrimeField| . |CharacteristicNonZero|) T) ((|InnerPrimeField| . |CharacteristicZero|) 64752) ((|InnerFiniteField| . |CharacteristicZero|) 64718) ((|InnerFiniteField| . |CharacteristicNonZero|) T) ((|Expression| . |AbelianMonoid|) 64486) ((|AlgebraicFunctionField| . |FunctionFieldCategory|) 64460) ((|ExponentialExpansion| . |AbelianMonoid|) T) ((|String| . |LinearAggregate|) 64435) ((|OrderedDirectProduct| . |LeftModule|) 64249) ((|XDistributedPolynomial| . |Rng|) T) ((|String| . |FiniteLinearAggregate|) 64224) ((|Complex| . |DifferentialExtension|) 64208) ((|IndexedString| . |HomogeneousAggregate|) 64183) ((|DirectProduct| . |InnerEvalable|) 64102) ((|XPolynomial| . |Monoid|) T) ((|XPBWPolynomial| . |Monoid|) T) ((|SymmetricPolynomial| . |RightModule|) 63935) ((|MyUnivariatePolynomial| . |RightModule|) 63669) ((|SymmetricPolynomial| . |BiModule|) 63470) ((|OrdinaryDifferentialRing| . |Ring|) T) ((|MyUnivariatePolynomial| . |BiModule|) 63172) ((|InnerFreeAbelianMonoid| . |BasicType|) T) ((|AlgebraicNumber| . |LinearlyExplicitRingOver|) 63116) ((|IndexedDirectProductOrderedAbelianMonoid| . |BasicType|) T) ((|IndexedDirectProductAbelianMonoid| . |BasicType|) T) ((|WeightedPolynomials| . |RightModule|) 63073) ((|ResidueRing| . |Algebra|) 63057) ((|OrdinaryDifferentialRing| . |DifferentialRing|) T) ((|OrdinaryDifferentialRing| . |DivisionRing|) 63033) ((|InnerTable| . |Eltable|) 63012) ((|WeightedPolynomials| . |BiModule|) 62964) ((|UnivariatePolynomial| . |DifferentialExtension|) 62948) ((|UnivariateTaylorSeries| . |Module|) 62792) ((|UnivariatePuiseuxSeries| . |Module|) 62580) ((|RoutinesTable| . |ConvertibleTo|) NIL) ((|RoutinesTable| . |CoercibleTo|) 62554) ((|UnivariateLaurentSeries| . |Module|) 62275) ((|UnivariateFormalPowerSeries| . |Module|) 62119) ((|RadicalFunctionField| . |PrincipalIdealDomain|) T) ((|MakeCachableSet| . |CoercibleTo|) 62080) ((|CliffordAlgebra| . |Monoid|) T) ((|UnivariateTaylorSeriesCZero| . |CancellationAbelianMonoid|) T) ((|U8Vector| . |OrderedSet|) T) ((|SplitHomogeneousDirectProduct| . |Finite|) 62055) ((|RadixExpansion| . |InnerEvalable|) NIL) ((|DirectProductModule| . |FullyRetractableTo|) 62016) ((|DirectProductMatrixModule| . |FullyRetractableTo|) 61977) ((|RealClosure| . |AbelianSemiGroup|) T) ((|RealClosure| . |AbelianGroup|) T) ((|InnerTaylorSeries| . |Module|) 61938) ((|InnerSparseUnivariatePowerSeries| . |Module|) 61782) ((|Octonion| . |Eltable|) 61735) ((|BinaryTournament| . |BasicType|) 61705) ((|OnePointCompletion| . |RetractableTo|) 61549) ((|Complex| . |OpenMath|) 61522) ((|ExponentialOfUnivariatePuiseuxSeries| . |LeftModule|) 61391) ((|OrderedDirectProduct| . |Aggregate|) T) ((|ModuleOperator| . |BasicType|) T) ((|SingleInteger| . |SemiGroup|) T) ((|Reference| . |Type|) T) ((|Float| . |Algebra|) 61345) ((|FiniteField| . |AbelianSemiGroup|) T) ((|FiniteField| . |AbelianGroup|) T) ((|DoubleFloatVector| . |BasicType|) T) ((|Commutator| . |BasicType|) T) ((|Color| . |BasicType|) T) ((|ComplexDoubleFloatVector| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |VectorSpace|) 61329) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |VectorSpace|) 61313) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |VectorSpace|) 61297) ((|PseudoAlgebraicClosureOfRationalNumber| . |GcdDomain|) T) ((|Complex| . |FiniteFieldCategory|) 61259) ((|Integer| . |OrderedSet|) T) ((|InnerAlgebraicNumber| . |OrderedSet|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |GcdDomain|) T) ((|SingleInteger| . |AbelianMonoid|) T) ((|Asp80| . |CoercibleTo|) 61233) ((|MachineInteger| . |EuclideanDomain|) T) ((|Operator| . |Algebra|) 61190) ((|OppositeMonogenicLinearOperator| . |Algebra|) 61147) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CancellationAbelianMonoid|) T) ((|SparseTable| . |EltableAggregate|) 61126) ((|Product| . |Monoid|) 61014) ((|Product| . |OrderedAbelianMonoidSup|) 60925) ((|Product| . |OrderedAbelianSemiGroup|) 60836) ((|OrderedDirectProduct| . |OrderedAbelianGroup|) 60806) ((|BalancedPAdicInteger| . |EuclideanDomain|) T) ((|ArrayStack| . |Evalable|) 60730) ((|ThreeDimensionalMatrix| . |Aggregate|) T) ((|InnerTable| . |IndexedAggregate|) 60709) ((|AlgebraicNumber| . |AbelianSemiGroup|) T) ((|AlgebraicNumber| . |AbelianGroup|) T) ((|OrderedDirectProduct| . |OrderedAbelianSemiGroup|) 60633) ((|OrderedDirectProduct| . |OrderedAbelianMonoidSup|) 60591) ((|MachineInteger| . |RealConstant|) T) ((|LinearOrdinaryDifferentialOperator1| . |RightModule|) 60575) ((|Product| . |Group|) 60522) ((|OrderedDirectProduct| . |Monoid|) 60408) ((|PrimeField| . |VectorSpace|) 60395) ((|Divisor| . |FreeAbelianMonoidCategory|) 60367) ((|PseudoAlgebraicClosureOfRationalNumber| . |FieldOfPrimeCharacteristic|) 60307) ((|HomogeneousDirectProduct| . |OrderedCancellationAbelianMonoid|) 60231) ((|HomogeneousDirectProduct| . |OrderedAbelianMonoid|) 60155) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |FieldOfPrimeCharacteristic|) 60095) ((|SymmetricPolynomial| . |Ring|) T) ((|U16Matrix| . |InnerEvalable|) NIL) ((|MyUnivariatePolynomial| . |Ring|) T) ((|LinearOrdinaryDifferentialOperator1| . |BiModule|) 60074) ((|SymmetricPolynomial| . |FiniteAbelianMonoidRing|) 60044) ((|Tree| . |BasicType|) 60014) ((|SetOfMIntegersInOneToN| . |CoercibleTo|) 59988) ((|MachineInteger| . |IntegerNumberSystem|) T) ((|MyUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 59949) ((|OrderlyDifferentialPolynomial| . |SetCategory|) T) ((|MyUnivariatePolynomial| . |DifferentialRing|) T) ((|WeightedPolynomials| . |Ring|) T) ((|FractionalIdeal| . |SetCategory|) T) ((|DirectProductModule| . |Rng|) 59859) ((|DirectProductMatrixModule| . |Rng|) 59769) ((|EuclideanModularRing| . |LeftModule|) 59756) ((|IndexedString| . |Eltable|) 59719) ((|Matrix| . |MatrixCategory|) 59671) ((|UnivariateTaylorSeries| . |CommutativeRing|) 59600) ((|PolynomialRing| . |CoercibleTo|) 59574) ((|PAdicRationalConstructor| . |BasicType|) T) ((|MonoidRing| . |CoercibleTo|) 59548) ((|ModularRing| . |CoercibleTo|) 59522) ((|UnivariatePuiseuxSeries| . |CommutativeRing|) 59428) ((|UnivariateLaurentSeries| . |CommutativeRing|) 59334) ((|UnivariateFormalPowerSeries| . |CommutativeRing|) 59263) ((|MachineFloat| . |OrderedSet|) T) ((|RadixExpansion| . |EntireRing|) T) ((|GenericNonAssociativeAlgebra| . |CoercibleTo|) 59237) ((|LieExponentials| . |Monoid|) T) ((|TwoDimensionalArray| . |SetCategory|) 59207) ((|DataList| . |Collection|) 59191) ((|PartialFraction| . |EntireRing|) T) ((|RealClosure| . |RealClosedField|) T) ((|LieExponentials| . |Group|) T) ((|ModMonic| . |UniqueFactorizationDomain|) 59141) ((|ExponentialOfUnivariatePuiseuxSeries| . |LeftOreRing|) 59117) ((|UnivariateTaylorSeriesCZero| . |HyperbolicFunctionCategory|) 59066) ((|InnerTaylorSeries| . |CommutativeRing|) 59033) ((|InnerSparseUnivariatePowerSeries| . |CommutativeRing|) 58962) ((|Vector| . |OrderedSet|) 58933) ((|ModMonic| . |IntegralDomain|) 58796) ((|Fraction| . |PrincipalIdealDomain|) T) ((|Fraction| . |OrderedIntegralDomain|) 58756) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedAbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Monoid|) T) ((|Factored| . |CoercibleTo|) 58730) ((|Factored| . |ConvertibleTo|) 58576) ((|List| . |StreamAggregate|) 58560) ((|Bits| . |LinearAggregate|) 58537) ((|ContinuedFraction| . |EuclideanDomain|) T) ((|BinaryTournament| . |Evalable|) 58461) ((|Bits| . |FiniteLinearAggregate|) 58438) ((|FortranProgram| . |Type|) T) ((|Expression| . |CancellationAbelianMonoid|) 58240) ((|ExponentialExpansion| . |CancellationAbelianMonoid|) T) ((|Asp29| . |FortranProgramCategory|) T) ((|Bits| . |BitAggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |OrderedSet|) 58211) ((|IndexedList| . |HomogeneousAggregate|) 58195) ((|LinearOrdinaryDifferentialOperator2| . |SemiGroup|) T) ((|IndexedString| . |OneDimensionalArrayAggregate|) 58170) ((|DoubleFloatVector| . |Evalable|) NIL) ((|Asp10| . |FortranVectorFunctionCategory|) T) ((|ComplexDoubleFloatVector| . |Evalable|) NIL) ((|Asp10| . |FortranProgramCategory|) T) ((|OpenMathErrorKind| . |SetCategory|) T) ((|IndexedString| . |IndexedAggregate|) 58133) ((|Pi| . |RetractableTo|) 58077) ((|LinearOrdinaryDifferentialOperator1| . |Ring|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianMonoid|) T) ((|XDistributedPolynomial| . |SetCategory|) T) ((|OrderlyDifferentialPolynomial| . |Module|) 57840) ((|U32Matrix| . |MatrixCategory|) 57789) ((|BasicStochasticDifferential| . |OrderedSet|) T) ((|BalancedPAdicRational| . |OrderedSet|) NIL) ((|SparseUnivariatePolynomial| . |FullyRetractableTo|) 57773) ((|SparseMultivariatePolynomial| . |FullyRetractableTo|) 57757) ((|SparseUnivariateSkewPolynomial| . |FullyRetractableTo|) 57741) ((|DirichletRing| . |Rng|) T) ((|EuclideanModularRing| . |LeftOreRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |BasicType|) T) ((|UnivariateLaurentSeries| . |InnerEvalable|) 57313) ((|Tree| . |Evalable|) 57237) ((|Exit| . |CoercibleTo|) 57211) ((|UnivariateLaurentSeriesConstructor| . |BasicType|) T) ((|Set| . |SetCategory|) T) ((|SparseUnivariateTaylorSeries| . |Eltable|) 57196) ((|SparseUnivariatePuiseuxSeries| . |Eltable|) 57181) ((|EuclideanModularRing| . |Monoid|) T) ((|BinaryExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|Matrix| . |CoercibleTo|) 57132) ((|Matrix| . |ConvertibleTo|) 57068) ((|SimpleAlgebraicExtension| . |LeftModule|) 56950) ((|InfiniteTuple| . |CoercibleTo|) 56924) ((|InnerTable| . |ConvertibleTo|) NIL) ((|InnerTable| . |CoercibleTo|) 56898) ((|SparseUnivariateLaurentSeries| . |Eltable|) 56638) ((|HexadecimalExpansion| . |RightModule|) 56572) ((|ModularField| . |GcdDomain|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |IndexedDirectProductCategory|) 56551) ((|IndexedDirectProductAbelianGroup| . |IndexedDirectProductCategory|) 56530) ((|DecimalExpansion| . |RightModule|) 56464) ((|FiniteFieldExtension| . |LeftModule|) 56405) ((|FiniteFieldNormalBasisExtension| . |LeftModule|) 56346) ((|DoubleFloat| . |OrderedRing|) T) ((|FiniteFieldCyclicGroupExtension| . |LeftModule|) 56287) ((|IndexedVector| . |BasicType|) 56224) ((|HomogeneousDirectProduct| . |Finite|) 56199) ((|BinaryExpansion| . |LeftModule|) 56133) ((|HexadecimalExpansion| . |BiModule|) 56028) ((|DirectProduct| . |HomogeneousAggregate|) 56012) ((|FiniteFieldCyclicGroup| . |CharacteristicZero|) 55978) ((|FiniteFieldCyclicGroup| . |CharacteristicNonZero|) T) ((|Complex| . |FiniteRankAlgebra|) 55926) ((|Point| . |VectorCategory|) 55910) ((|DecimalExpansion| . |BiModule|) 55805) ((|PAdicRationalConstructor| . |Evalable|) 55764) ((|Point| . |SetCategory|) 55701) ((|Octonion| . |ConvertibleTo|) 55637) ((|Octonion| . |CoercibleTo|) 55611) ((|MoebiusTransform| . |BasicType|) T) ((|FourierComponent| . |SetCategory|) T) ((|SingleInteger| . |CancellationAbelianMonoid|) T) ((|ModuleOperator| . |Algebra|) 55568) ((|Expression| . |HyperbolicFunctionCategory|) 55535) ((|IndexedBits| . |Type|) T) ((|UnivariatePuiseuxSeriesConstructor| . |ElementaryFunctionCategory|) 55484) ((|UnivariateLaurentSeriesConstructor| . |ElementaryFunctionCategory|) 55433) ((|FlexibleArray| . |Collection|) 55417) ((|RoutinesTable| . |EltableAggregate|) 55387) ((|XDistributedPolynomial| . |Module|) 55344) ((|StringTable| . |Aggregate|) T) ((|XRecursivePolynomial| . |RetractableTo|) 55306) ((|MyExpression| . |LinearlyExplicitRingOver|) 55178) ((|GraphImage| . |CoercibleTo|) 55152) ((|Heap| . |Aggregate|) T) ((|FreeModule1| . |RetractableTo|) 55136) ((|SparseUnivariatePolynomial| . |Rng|) T) ((|SparseMultivariatePolynomial| . |Rng|) T) ((|SparseUnivariateSkewPolynomial| . |Rng|) T) ((|RomanNumeral| . |OrderedRing|) T) ((|OrderlyDifferentialPolynomial| . |CommutativeRing|) 54989) ((|IndexedList| . |Eltable|) 54961) ((|U32Matrix| . |CoercibleTo|) 54935) ((|IntegerMod| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeries| . |EntireRing|) 54902) ((|UnivariatePuiseuxSeries| . |EntireRing|) 54841) ((|BalancedPAdicRational| . |QuotientFieldCategory|) 54800) ((|PseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|UnivariateLaurentSeries| . |EntireRing|) 54739) ((|NeitherSparseOrDensePowerSeries| . |BasicType|) T) ((|UnivariateFormalPowerSeries| . |EntireRing|) 54706) ((|TextFile| . |FileCategory|) 54671) ((|SparseUnivariateTaylorSeries| . |RadicalCategory|) 54620) ((|SparseUnivariatePuiseuxSeries| . |RadicalCategory|) 54569) ((|SequentialDifferentialVariable| . |DifferentialVariableCategory|) 54553) ((|GeneralUnivariatePowerSeries| . |BasicType|) T) ((|File| . |SetCategory|) T) ((|DirectProductModule| . |SetCategory|) T) ((|DirectProductMatrixModule| . |SetCategory|) T) ((|SparseUnivariateLaurentSeries| . |RadicalCategory|) 54502) ((|BinaryFile| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |RadicalCategory|) 54451) ((|PAdicRationalConstructor| . |StepThrough|) 54421) ((|SimpleAlgebraicExtension| . |LeftOreRing|) 54355) ((|KeyedAccessFile| . |FileCategory|) 54278) ((|SimpleAlgebraicExtension| . |Monoid|) T) ((|KeyedAccessFile| . |Dictionary|) 54214) ((|IndexedString| . |CoercibleTo|) 54188) ((|IndexedString| . |ConvertibleTo|) NIL) ((|MachineComplex| . |OrderedSet|) T) ((|GeneralSparseTable| . |Dictionary|) 54130) ((|HexadecimalExpansion| . |Ring|) T) ((|Places| . |SetCategory|) T) ((|Asp8| . |FortranVectorCategory|) T) ((|Asp8| . |FortranProgramCategory|) T) ((|DecimalExpansion| . |Ring|) T) ((|FiniteFieldExtension| . |LeftOreRing|) T) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|FiniteFieldNormalBasisExtension| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtension| . |LeftOreRing|) T) ((|ModMonic| . |SemiGroup|) T) ((|InnerTaylorSeries| . |EntireRing|) 54097) ((|InnerSparseUnivariatePowerSeries| . |EntireRing|) 54064) ((|BinaryExpansion| . |LeftOreRing|) T) ((|HexadecimalExpansion| . |DivisionRing|) T) ((|HexadecimalExpansion| . |DifferentialRing|) T) ((|SuchThat| . |CoercibleTo|) 54038) ((|PAdicRationalConstructor| . |Algebra|) 53979) ((|DecimalExpansion| . |DivisionRing|) T) ((|DecimalExpansion| . |DifferentialRing|) T) ((|MyExpression| . |AbelianSemiGroup|) T) ((|MyExpression| . |AbelianGroup|) T) ((|FiniteFieldExtension| . |Monoid|) T) ((|FiniteFieldNormalBasisExtension| . |Monoid|) T) ((|FiniteFieldCyclicGroupExtension| . |Monoid|) T) ((|BinaryExpansion| . |OrderedAbelianSemiGroup|) T) ((|BinaryExpansion| . |OrderedAbelianGroup|) T) ((|IndexedList| . |UnaryRecursiveAggregate|) 53963) ((|BinaryExpansion| . |Monoid|) T) ((|ModMonic| . |AbelianMonoid|) T) ((|U16Matrix| . |HomogeneousAggregate|) 53940) ((|GeneralUnivariatePowerSeries| . |ElementaryFunctionCategory|) 53889) ((|IntegerMod| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |Evalable|) 53819) ((|Symbol| . |BasicType|) T) ((|AlgebraicFunctionField| . |CharacteristicNonZero|) 53766) ((|AlgebraicFunctionField| . |CharacteristicZero|) 53716) ((|IndexedList| . |IndexedAggregate|) 53688) ((|SplitHomogeneousDirectProduct| . |LeftModule|) 53502) ((|IndexedVector| . |Evalable|) 53426) ((|AssociationList| . |LinearAggregate|) 53368) ((|AssociationList| . |ListAggregate|) 53310) ((|AssociationList| . |FiniteLinearAggregate|) 53252) ((|String| . |Aggregate|) T) ((|PAdicRational| . |OrderedRing|) NIL) ((|LinearOrdinaryDifferentialOperator2| . |CancellationAbelianMonoid|) T) ((|HyperellipticFiniteDivisor| . |CoercibleTo|) 53226) ((|DirectProduct| . |Eltable|) 53198) ((|ListMultiDictionary| . |Aggregate|) T) ((|Library| . |Aggregate|) T) ((|SequentialDifferentialPolynomial| . |GcdDomain|) 53116) ((|OrderlyDifferentialPolynomial| . |InnerEvalable|) 52891) ((|NewSparseUnivariatePolynomial| . |GcdDomain|) 52786) ((|NewSparseMultivariatePolynomial| . |GcdDomain|) 52704) ((|NottinghamGroup| . |BasicType|) T) ((|GeneralDistributedMultivariatePolynomial| . |GcdDomain|) 52622) ((|Polynomial| . |FullyRetractableTo|) 52606) ((|MultivariatePolynomial| . |CoercibleTo|) 52580) ((|DirectProductModule| . |Module|) 52509) ((|DirectProductMatrixModule| . |Module|) 52438) ((|MultivariatePolynomial| . |ConvertibleTo|) 52216) ((|HomogeneousDistributedMultivariatePolynomial| . |FullyRetractableTo|) 52200) ((|FortranExpression| . |ExpressionSpace|) T) ((|DirichletRing| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |PrincipalIdealDomain|) T) ((|Queue| . |BasicType|) 52170) ((|RealClosure| . |OrderedSet|) T) ((|TwoDimensionalArray| . |InnerEvalable|) 52089) ((|UnivariateTaylorSeriesCZero| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |StepThrough|) 52030) ((|RadixExpansion| . |Eltable|) NIL) ((|DoubleFloat| . |Rng|) T) ((|Float| . |OpenMath|) T) ((|SplitHomogeneousDirectProduct| . |Aggregate|) T) ((|NeitherSparseOrDensePowerSeries| . |Evalable|) 51860) ((|InnerPrimeField| . |GcdDomain|) T) ((|InnerFiniteField| . |GcdDomain|) T) ((|UniversalSegment| . |SegmentCategory|) 51844) ((|UniversalSegment| . |SetCategory|) 51814) ((|DirectProduct| . |IndexedAggregate|) 51786) ((|UniversalSegment| . |SegmentExpansionCategory|) 51731) ((|SparseUnivariateTaylorSeries| . |CoercibleTo|) 51705) ((|SparseUnivariatePuiseuxSeries| . |CoercibleTo|) 51679) ((|SparseUnivariateLaurentSeries| . |CoercibleTo|) 51653) ((|SparseUnivariateLaurentSeries| . |ConvertibleTo|) NIL) ((|SparseMultivariateTaylorSeries| . |CoercibleTo|) 51627) ((|PAdicRationalConstructor| . |FullyPatternMatchable|) 51611) ((|InfinitlyClosePoint| . |SetCategory|) T) ((|InputForm| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Algebra|) 51399) ((|UnivariateLaurentSeriesConstructor| . |Algebra|) 51157) ((|PAdicInteger| . |CharacteristicZero|) T) ((|InnerPrimeField| . |FieldOfPrimeCharacteristic|) T) ((|AlgebraicNumber| . |OrderedSet|) T) ((|InnerFiniteField| . |FieldOfPrimeCharacteristic|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianGroup|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianSemiGroup|) T) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianGroup|) 51127) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianSemiGroup|) 51051) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianMonoidSup|) 51009) ((|QuadraticForm| . |SetCategory|) T) ((|RegularTriangularSet| . |Aggregate|) T) ((|OutputForm| . |SetCategory|) T) ((|Variable| . |BasicType|) T) ((|SplitHomogeneousDirectProduct| . |Monoid|) 50895) ((|LiePolynomial| . |BasicType|) T) ((|InnerTable| . |EltableAggregate|) 50874) ((|Table| . |BasicType|) T) ((|GeneralTriangularSet| . |Aggregate|) T) ((|GeneralPolynomialSet| . |Aggregate|) T) ((|FiniteFieldExtensionByPolynomial| . |BasicType|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |BasicType|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |BasicType|) T) ((|DifferentialSparseMultivariatePolynomial| . |BasicType|) T) ((|DistributedMultivariatePolynomial| . |BasicType|) T) ((|Pi| . |EuclideanDomain|) T) ((|RomanNumeral| . |Rng|) T) ((|Polynomial| . |Rng|) T) ((|Expression| . |LinearlyExplicitRingOver|) 50746) ((|ExponentialExpansion| . |LinearlyExplicitRingOver|) 50661) ((|HomogeneousDistributedMultivariatePolynomial| . |Rng|) T) ((|HashTable| . |BasicType|) T) ((|FortranTemplate| . |CoercibleTo|) 50635) ((|SparseUnivariatePolynomial| . |SetCategory|) T) ((|SparseMultivariatePolynomial| . |SetCategory|) T) ((|SparseUnivariateSkewPolynomial| . |SetCategory|) T) ((|SplittingTree| . |BasicType|) T) ((|OrderlyDifferentialPolynomial| . |EntireRing|) 50521) ((|PolynomialRing| . |RightModule|) 50354) ((|Pi| . |RealConstant|) T) ((|MonoidRing| . |RightModule|) 50311) ((|Stack| . |StackAggregate|) 50295) ((|Set| . |InnerEvalable|) 50214) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |RightModule|) 50170) ((|PolynomialRing| . |BiModule|) 49971) ((|PseudoAlgebraicClosureOfRationalNumber| . |VectorSpace|) 49935) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |VectorSpace|) 49848) ((|PrimeField| . |BasicType|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |StepThrough|) T) ((|MonoidRing| . |BiModule|) 49800) ((|DirichletRing| . |Module|) 49720) ((|OneDimensionalArray| . |BasicType|) 49657) ((|IndexedList| . |ConvertibleTo|) 49593) ((|IndexedList| . |CoercibleTo|) 49511) ((|InnerIndexedTwoDimensionalArray| . |BasicType|) 49481) ((|IndexedFlexibleArray| . |BasicType|) 49418) ((|IndexedTwoDimensionalArray| . |BasicType|) 49388) ((|IndexedOneDimensionalArray| . |BasicType|) 49325) ((|GenericNonAssociativeAlgebra| . |BiModule|) 49248) ((|DirectProductModule| . |CommutativeRing|) 49214) ((|DirectProductMatrixModule| . |CommutativeRing|) 49180) ((|Factored| . |RightModule|) 49154) ((|TaylorSeries| . |PowerSeriesCategory|) 49095) ((|Quaternion| . |SemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Algebra|) 49049) ((|NeitherSparseOrDensePowerSeries| . |Algebra|) 48963) ((|Point| . |InnerEvalable|) 48882) ((|HexadecimalExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |Algebra|) 48670) ((|Factored| . |BiModule|) 48637) ((|HexadecimalExpansion| . |OrderedAbelianMonoid|) T) ((|Queue| . |Evalable|) 48561) ((|DecimalExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|DecimalExpansion| . |OrderedAbelianMonoid|) T) ((|Quaternion| . |AbelianMonoid|) T) ((|ModMonic| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |FullyPatternMatchable|) 48528) ((|U8Matrix| . |Aggregate|) T) ((|Expression| . |AbelianSemiGroup|) 48296) ((|Complex| . |FullyRetractableTo|) 48280) ((|Expression| . |AbelianGroup|) 48082) ((|ExponentialExpansion| . |AbelianSemiGroup|) T) ((|ExponentialExpansion| . |AbelianGroup|) T) ((|OrderedVariableList| . |Finite|) T) ((|Bits| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |LeftModule|) 47896) ((|PAdicRational| . |Rng|) T) ((|IndexedString| . |EltableAggregate|) 47859) ((|InnerPAdicInteger| . |CharacteristicZero|) T) ((|Integer| . |CharacteristicZero|) T) ((|InnerAlgebraicNumber| . |CharacteristicZero|) T) ((|SparseUnivariatePolynomial| . |Module|) 47599) ((|SparseMultivariatePolynomial| . |Module|) 47362) ((|SingleInteger| . |LinearlyExplicitRingOver|) 47339) ((|SparseUnivariateSkewPolynomial| . |Module|) 47296) ((|LieSquareMatrix| . |Type|) T) ((|Mapping| . |BasicType|) T) ((|DirectProduct| . |CoercibleTo|) 46945) ((|UnivariatePolynomial| . |FullyRetractableTo|) 46929) ((|U16Matrix| . |MatrixCategory|) 46878) ((|Table| . |Evalable|) 46638) ((|PolynomialRing| . |Ring|) T) ((|MonoidRing| . |Ring|) T) ((|ModularRing| . |Ring|) T) ((|List| . |SetCategory|) 46575) ((|RectangularMatrix| . |LeftModule|) 46559) ((|UnivariateSkewPolynomial| . |FullyRetractableTo|) 46543) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |BasicType|) T) ((|IndexedDirectProductAbelianGroup| . |BasicType|) T) ((|DistributedMultivariatePolynomial| . |Evalable|) 46530) ((|DifferentialSparseMultivariatePolynomial| . |Evalable|) 46517) ((|StochasticDifferential| . |CoercibleTo|) 46491) ((|PolynomialRing| . |FiniteAbelianMonoidRing|) 46470) ((|FreeModule| . |LeftModule|) 46454) ((|HashTable| . |Evalable|) 46214) ((|DirectProductModule| . |InnerEvalable|) 46133) ((|LieSquareMatrix| . |RetractableTo|) 45977) ((|DirectProductMatrixModule| . |InnerEvalable|) 45896) ((|SplittingTree| . |Evalable|) 45786) ((|DirichletRing| . |CommutativeRing|) 45752) ((|OrderedFreeMonoid| . |SetCategory|) T) ((|Octonion| . |RightModule|) 45736) ((|UnivariateTaylorSeries| . |Eltable|) 45721) ((|UnivariatePuiseuxSeries| . |Eltable|) 45706) ((|UnivariateLaurentSeries| . |Eltable|) 45470) ((|UnivariateFormalPowerSeries| . |Eltable|) 45455) ((|FreeMonoid| . |SetCategory|) T) ((|FreeAbelianMonoid| . |SetCategory|) T) ((|Factored| . |Ring|) T) ((|Complex| . |Rng|) T) ((|OneDimensionalArray| . |Evalable|) 45379) ((|Octonion| . |BiModule|) 45358) ((|InnerSparseUnivariatePowerSeries| . |Eltable|) 45343) ((|InnerIndexedTwoDimensionalArray| . |Evalable|) 45267) ((|IndexedFlexibleArray| . |Evalable|) 45191) ((|IndexedTwoDimensionalArray| . |Evalable|) 45115) ((|IndexedOneDimensionalArray| . |Evalable|) 45039) ((|Factored| . |DifferentialRing|) 45004) ((|HomogeneousDirectProduct| . |Aggregate|) T) ((|RadixExpansion| . |ConvertibleTo|) 44905) ((|DoubleFloat| . |SetCategory|) T) ((|RadixExpansion| . |CoercibleTo|) 44879) ((|Partition| . |CoercibleTo|) 44853) ((|Partition| . |ConvertibleTo|) 44821) ((|PartialFraction| . |CoercibleTo|) 44795) ((|MachineFloat| . |CharacteristicZero|) T) ((|MachineInteger| . |PrincipalIdealDomain|) T) ((|MachineInteger| . |OrderedIntegralDomain|) T) ((|FourierSeries| . |CoercibleTo|) 44769) ((|SingleInteger| . |AbelianGroup|) T) ((|SingleInteger| . |AbelianSemiGroup|) T) ((|LieSquareMatrix| . |FullyLinearlyExplicitRingOver|) 44753) ((|BalancedPAdicInteger| . |PrincipalIdealDomain|) T) ((|PAdicRationalConstructor| . |DifferentialExtension|) 44737) ((|Asp4| . |Type|) T) ((|BinaryTournament| . |BinaryTreeCategory|) 44721) ((|RectangularMatrix| . |Aggregate|) T) ((|XPolynomial| . |RetractableTo|) 44677) ((|XPBWPolynomial| . |RetractableTo|) 44590) ((|UnivariatePolynomial| . |Rng|) T) ((|SparseUnivariatePolynomialExpressions| . |CharacteristicNonZero|) 44550) ((|SparseUnivariatePolynomialExpressions| . |CharacteristicZero|) 44513) ((|UnivariateSkewPolynomial| . |Rng|) T) ((|HomogeneousDirectProduct| . |OrderedAbelianGroup|) 44483) ((|FiniteFieldExtensionByPolynomial| . |StepThrough|) 44458) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |StepThrough|) 44433) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |StepThrough|) 44408) ((|HomogeneousDirectProduct| . |OrderedAbelianSemiGroup|) 44332) ((|HomogeneousDirectProduct| . |OrderedAbelianMonoidSup|) 44290) ((|DenavitHartenbergMatrix| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Monoid|) 44176) ((|TwoDimensionalArray| . |HomogeneousAggregate|) 44160) ((|Interval| . |Rng|) T) ((|U16Matrix| . |CoercibleTo|) 44134) ((|SparseUnivariatePolynomial| . |CommutativeRing|) 43964) ((|SparseMultivariatePolynomial| . |CommutativeRing|) 43817) ((|RomanNumeral| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |PolynomialCategory|) 43688) ((|Polynomial| . |SetCategory|) T) ((|OrdinaryDifferentialRing| . |LeftModule|) 43625) ((|NewSparseUnivariatePolynomial| . |PolynomialCategory|) 43560) ((|ModuleMonomial| . |SetCategory|) T) ((|NewSparseMultivariatePolynomial| . |PolynomialCategory|) 43513) ((|IndexedFlexibleArray| . |ExtensibleLinearAggregate|) 43497) ((|LieSquareMatrix| . |PartialDifferentialRing|) 43429) ((|HomogeneousDistributedMultivariatePolynomial| . |SetCategory|) T) ((|GeneralDistributedMultivariatePolynomial| . |PolynomialCategory|) 43379) ((|Asp50| . |Type|) T) ((|FiniteFieldExtensionByPolynomial| . |Algebra|) 43333) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Algebra|) 43287) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Algebra|) 43241) ((|DifferentialSparseMultivariatePolynomial| . |Algebra|) 43004) ((|DistributedMultivariatePolynomial| . |Algebra|) 42767) ((|PrimeField| . |StepThrough|) T) ((|LaurentPolynomial| . |CharacteristicZero|) 42730) ((|LaurentPolynomial| . |CharacteristicNonZero|) 42690) ((|BalancedPAdicRational| . |CharacteristicZero|) T) ((|BalancedPAdicRational| . |CharacteristicNonZero|) NIL) ((|FramedModule| . |Monoid|) T) ((|Octonion| . |Ring|) T) ((|FiniteFieldCyclicGroup| . |GcdDomain|) T) ((|UnivariateTaylorSeries| . |RadicalCategory|) 42639) ((|UnivariatePuiseuxSeries| . |RadicalCategory|) 42588) ((|UnivariateLaurentSeries| . |RadicalCategory|) 42537) ((|UnivariateFormalPowerSeries| . |RadicalCategory|) 42486) ((|PrimeField| . |Algebra|) 42440) ((|DoubleFloat| . |Module|) 42394) ((|MyExpression| . |OrderedSet|) T) ((|AlgebraicFunctionField| . |FramedAlgebra|) 42360) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianMonoidRing|) 42319) ((|Quaternion| . |CancellationAbelianMonoid|) T) ((|OrderedDirectProduct| . |Type|) T) ((|ContinuedFraction| . |PrincipalIdealDomain|) T) ((|FiniteFieldCyclicGroup| . |FieldOfPrimeCharacteristic|) T) ((|IndexedList| . |EltableAggregate|) 42291) ((|AssociationList| . |Aggregate|) T) ((|OrderedDirectProduct| . |RetractableTo|) 42042) ((|MyUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 41992) ((|Localize| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianSemiGroup|) T) ((|Set| . |HomogeneousAggregate|) 41976) ((|UnivariateLaurentSeriesConstructor| . |DifferentialExtension|) 41943) ((|ThreeDimensionalMatrix| . |Type|) T) ((|DataList| . |BasicType|) 41880) ((|PAdicRational| . |SetCategory|) T) ((|SymmetricPolynomial| . |LeftModule|) 41777) ((|RomanNumeral| . |Module|) 41764) ((|MultivariatePolynomial| . |RightModule|) 41521) ((|SparseUnivariatePolynomial| . |InnerEvalable|) 41431) ((|Polynomial| . |Module|) 41194) ((|SparseMultivariatePolynomial| . |InnerEvalable|) 41146) ((|MyUnivariatePolynomial| . |LeftModule|) 41043) ((|HomogeneousDistributedMultivariatePolynomial| . |Module|) 40806) ((|Asp27| . |CoercibleTo|) 40780) ((|MultivariatePolynomial| . |BiModule|) 40505) ((|OrdinaryDifferentialRing| . |LeftOreRing|) 40481) ((|Point| . |HomogeneousAggregate|) 40465) ((|WeightedPolynomials| . |LeftModule|) 40412) ((|SparseUnivariateTaylorSeries| . |RightModule|) 40245) ((|OrdinaryDifferentialRing| . |Monoid|) T) ((|SparseUnivariatePuiseuxSeries| . |RightModule|) 40027) ((|SparseUnivariateLaurentSeries| . |RightModule|) 39736) ((|DirichletRing| . |EntireRing|) 39702) ((|SparseMultivariateTaylorSeries| . |RightModule|) 39535) ((|RadicalFunctionField| . |UniqueFactorizationDomain|) T) ((|Segment| . |BasicType|) 39505) ((|OrderedDirectProduct| . |FullyLinearlyExplicitRingOver|) 39473) ((|RadicalFunctionField| . |IntegralDomain|) T) ((|SparseUnivariateTaylorSeries| . |BiModule|) 39274) ((|SparseUnivariatePuiseuxSeries| . |BiModule|) 39024) ((|SparseUnivariateLaurentSeries| . |BiModule|) 38653) ((|SparseMultivariateTaylorSeries| . |BiModule|) 38454) ((|SExpressionOf| . |SExpressionCategory|) 38418) ((|Float| . |OrderedRing|) T) ((|UnivariateTaylorSeries| . |CoercibleTo|) 38392) ((|UnivariatePuiseuxSeries| . |CoercibleTo|) 38366) ((|UnivariateLaurentSeries| . |CoercibleTo|) 38340) ((|UnivariateLaurentSeries| . |ConvertibleTo|) NIL) ((|UnivariateFormalPowerSeries| . |CoercibleTo|) 38314) ((|DirectProduct| . |EltableAggregate|) 38286) ((|AlgebraicFunctionField| . |GcdDomain|) T) ((|DoubleFloat| . |CommutativeRing|) T) ((|Complex| . |SetCategory|) T) ((|MachineComplex| . |CharacteristicZero|) T) ((|MachineComplex| . |CharacteristicNonZero|) NIL) ((|InnerTaylorSeries| . |CoercibleTo|) 38260) ((|InnerSparseUnivariatePowerSeries| . |CoercibleTo|) 38234) ((|NumericalPDEProblem| . |SetCategory|) T) ((|NumericalOptimizationProblem| . |SetCategory|) T) ((|NumericalODEProblem| . |SetCategory|) T) ((|NumericalIntegrationProblem| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |UnivariateSkewPolynomialCategory|) 38218) ((|Magma| . |SetCategory|) T) ((|OrderedDirectProduct| . |PartialDifferentialRing|) 38122) ((|SparseUnivariatePolynomialExpressions| . |TranscendentalFunctionCategory|) 38073) ((|SparseUnivariatePolynomialExpressions| . |TrigonometricFunctionCategory|) 38024) ((|AlgebraicFunctionField| . |FieldOfPrimeCharacteristic|) NIL) ((|SingleInteger| . |Logic|) T) ((|PAdicRational| . |Module|) 37948) ((|DirectProductModule| . |HomogeneousAggregate|) 37932) ((|DirectProductMatrixModule| . |HomogeneousAggregate|) 37916) ((|ModMonic| . |LinearlyExplicitRingOver|) 37832) ((|LinearOrdinaryDifferentialOperator1| . |LeftModule|) 37806) ((|EqTable| . |Aggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |ArcTrigonometricFunctionCategory|) 37757) ((|SparseUnivariatePolynomialExpressions| . |ArcHyperbolicFunctionCategory|) 37708) ((|MultivariatePolynomial| . |Ring|) T) ((|InnerPrimeField| . |VectorSpace|) 37695) ((|InnerFiniteField| . |VectorSpace|) 37659) ((|UnivariatePolynomial| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |EntireRing|) 37522) ((|SparseMultivariatePolynomial| . |EntireRing|) 37408) ((|RomanNumeral| . |CommutativeRing|) T) ((|MyUnivariatePolynomial| . |LeftOreRing|) 37303) ((|UnivariateSkewPolynomial| . |SetCategory|) T) ((|Polynomial| . |CommutativeRing|) 37156) ((|NewSparseUnivariatePolynomial| . |UnivariatePolynomialCategory|) 37140) ((|List| . |InnerEvalable|) 37059) ((|Asp49| . |CoercibleTo|) 37033) ((|MultivariatePolynomial| . |FiniteAbelianMonoidRing|) 36967) ((|SymmetricPolynomial| . |Monoid|) T) ((|Interval| . |SetCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |CommutativeRing|) 36820) ((|MyUnivariatePolynomial| . |Monoid|) T) ((|DataList| . |Evalable|) 36744) ((|SquareMatrix| . |SemiGroup|) T) ((|Asp30| . |CoercibleTo|) 36718) ((|WeightedPolynomials| . |Monoid|) T) ((|SparseUnivariateTaylorSeries| . |Ring|) T) ((|SparseUnivariatePuiseuxSeries| . |Ring|) T) ((|FlexibleArray| . |BasicType|) 36655) ((|SparseUnivariateLaurentSeries| . |Ring|) T) ((|SquareMatrix| . |AbelianMonoid|) T) ((|SparseMultivariateTaylorSeries| . |Ring|) T) ((|ArrayStack| . |StackAggregate|) 36639) ((|OrdinaryWeightedPolynomials| . |SemiGroup|) T) ((|SparseUnivariateTaylorSeries| . |DifferentialRing|) 36576) ((|SparseUnivariatePuiseuxSeries| . |DivisionRing|) 36552) ((|SparseUnivariatePuiseuxSeries| . |DifferentialRing|) 36487) ((|SparseUnivariateLaurentSeries| . |DifferentialRing|) 36324) ((|SparseUnivariateLaurentSeries| . |DivisionRing|) 36300) ((|ExponentialOfUnivariatePuiseuxSeries| . |PartialDifferentialRing|) 36162) ((|PseudoAlgebraicClosureOfRationalNumber| . |BasicType|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |BasicType|) T) ((|OrdinaryWeightedPolynomials| . |AbelianMonoid|) T) ((|Complex| . |Module|) 35920) ((|SetOfMIntegersInOneToN| . |Finite|) T) ((|Fraction| . |UniqueFactorizationDomain|) T) ((|RealClosure| . |CharacteristicZero|) T) ((|RadicalFunctionField| . |Field|) T) ((|Point| . |Eltable|) 35892) ((|PAdicInteger| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |FiniteFieldCategory|) T) ((|Expression| . |OrderedSet|) T) ((|ExponentialExpansion| . |OrderedSet|) NIL) ((|Palette| . |BasicType|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |InfinitlyClosePointCategory|) 35419) ((|ModMonic| . |AbelianSemiGroup|) T) ((|Fraction| . |IntegralDomain|) T) ((|ModMonic| . |AbelianGroup|) T) ((|FiniteField| . |CharacteristicZero|) 35385) ((|FiniteField| . |CharacteristicNonZero|) T) ((|Stack| . |SetCategory|) 35355) ((|GenericNonAssociativeAlgebra| . |Monad|) T) ((|Asp41| . |CoercibleTo|) 35329) ((|BasicOperator| . |OrderedSet|) T) ((|DataList| . |ExtensibleLinearAggregate|) 35313) ((|DirectProduct| . |RightModule|) 35183) ((|Asp6| . |CoercibleTo|) 35157) ((|MonoidRing| . |Finite|) 35102) ((|Symbol| . |OpenMath|) T) ((|Multiset| . |DictionaryOperations|) 35086) ((|UnivariatePolynomial| . |Module|) 34826) ((|StringTable| . |Type|) T) ((|CharacterClass| . |DictionaryOperations|) 34801) ((|DirectProduct| . |BiModule|) 34664) ((|StochasticDifferential| . |RightModule|) 34633) ((|AlgebraicNumber| . |CharacteristicZero|) T) ((|PAdicRational| . |CommutativeRing|) T) ((|UnivariateSkewPolynomial| . |Module|) 34590) ((|Heap| . |Type|) T) ((|Polynomial| . |InnerEvalable|) 34530) ((|LinearOrdinaryDifferentialOperator1| . |Monoid|) T) ((|Interval| . |Module|) 34517) ((|StochasticDifferential| . |BiModule|) 34466) ((|ResidueRing| . |Rng|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |InnerEvalable|) 34370) ((|Point| . |OneDimensionalArrayAggregate|) 34354) ((|Point| . |IndexedAggregate|) 34326) ((|OrderlyDifferentialPolynomial| . |ConvertibleTo|) NIL) ((|OrderlyDifferentialPolynomial| . |CoercibleTo|) 34300) ((|RadixExpansion| . |RightModule|) 34234) ((|FractionalIdeal| . |CoercibleTo|) 34208) ((|DirectProductModule| . |Eltable|) 34180) ((|DirectProductMatrixModule| . |Eltable|) 34152) ((|HexadecimalExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|Expression| . |AlgebraicallyClosedFunctionSpace|) 34110) ((|BinaryExpansion| . |Type|) T) ((|RadicalFunctionField| . |SemiGroup|) T) ((|DecimalExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|PartialFraction| . |RightModule|) 34051) ((|U32Vector| . |OrderedSet|) T) ((|SimpleAlgebraicExtension| . |RetractableTo|) 33895) ((|RadixExpansion| . |BiModule|) 33790) ((|Multiset| . |MultiDictionary|) 33774) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialExtension|) 33758) ((|FourierSeries| . |RightModule|) 33742) ((|Float| . |Rng|) T) ((|RadicalFunctionField| . |AbelianMonoid|) T) ((|PartialFraction| . |BiModule|) 33651) ((|MachineComplex| . |TrigonometricFunctionCategory|) NIL) ((|HexadecimalExpansion| . |LeftModule|) 33585) ((|BinaryExpansion| . |Patternable|) 33562) ((|BinaryExpansion| . |PatternMatchable|) 33539) ((|MachineComplex| . |TranscendentalFunctionCategory|) NIL) ((|DecimalExpansion| . |LeftModule|) 33473) ((|FiniteFieldExtension| . |RetractableTo|) 33457) ((|FiniteFieldNormalBasisExtension| . |RetractableTo|) 33441) ((|FlexibleArray| . |Evalable|) 33365) ((|FiniteFieldCyclicGroupExtension| . |RetractableTo|) 33349) ((|DoubleFloat| . |EntireRing|) T) ((|FourierSeries| . |BiModule|) 33328) ((|TwoDimensionalArray| . |CoercibleTo|) 33279) ((|Complex| . |CommutativeRing|) T) ((|SingleInteger| . |OrderedSet|) T) ((|BinaryExpansion| . |RetractableTo|) 33223) ((|Pattern| . |SetCategory|) T) ((|Operator| . |Rng|) T) ((|OppositeMonogenicLinearOperator| . |Rng|) T) ((|MachineComplex| . |ArcHyperbolicFunctionCategory|) NIL) ((|MachineComplex| . |ArcTrigonometricFunctionCategory|) NIL) ((|ExponentialExpansion| . |QuotientFieldCategory|) 33138) ((|InnerPAdicInteger| . |GcdDomain|) T) ((|Integer| . |GcdDomain|) T) ((|InnerAlgebraicNumber| . |GcdDomain|) T) ((|Fraction| . |Field|) T) ((|DirectProduct| . |Ring|) 33048) ((|SparseTable| . |Aggregate|) T) ((|Plcs| . |BasicType|) T) ((|Pi| . |PrincipalIdealDomain|) T) ((|Quaternion| . |LinearlyExplicitRingOver|) 32964) ((|DirectProductModule| . |IndexedAggregate|) 32936) ((|DirectProductMatrixModule| . |IndexedAggregate|) 32908) ((|SimpleAlgebraicExtension| . |FullyLinearlyExplicitRingOver|) 32892) ((|PAdicRational| . |InnerEvalable|) 32662) ((|DirectProduct| . |DifferentialRing|) 32599) ((|String| . |Type|) T) ((|OpenMathErrorKind| . |CoercibleTo|) 32573) ((|ProjectiveSpace| . |ProjectiveSpaceCategory|) 32557) ((|XPolynomialRing| . |SemiGroup|) T) ((|XDistributedPolynomial| . |CoercibleTo|) 32531) ((|UnivariatePolynomial| . |CommutativeRing|) 32361) ((|BinaryExpansion| . |FullyLinearlyExplicitRingOver|) 32338) ((|BinaryExpansion| . |FullyEvalableOver|) 32315) ((|RomanNumeral| . |EntireRing|) T) ((|Polynomial| . |EntireRing|) 32201) ((|Octonion| . |Finite|) 32176) ((|Plcs| . |PlacesCategory|) 32155) ((|ListMultiDictionary| . |Type|) T) ((|Library| . |Type|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |EntireRing|) 32041) ((|Interval| . |CommutativeRing|) T) ((|FlexibleArray| . |ExtensibleLinearAggregate|) 32025) ((|XPolynomialRing| . |AbelianMonoid|) T) ((|TaylorSeries| . |BasicType|) T) ((|TextFile| . |SetCategory|) T) ((|SequentialDifferentialVariable| . |SetCategory|) T) ((|RewriteRule| . |SetCategory|) T) ((|Asp74| . |CoercibleTo|) 31999) ((|ModularField| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |FiniteFieldCategory|) 31974) ((|KeyedAccessFile| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FiniteFieldCategory|) 31949) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FiniteFieldCategory|) 31924) ((|Table| . |Dictionary|) 31866) ((|GeneralSparseTable| . |SetCategory|) T) ((|DirichletRing| . |Eltable|) 31830) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialPolynomialCategory|) 31778) ((|SquareMatrix| . |CancellationAbelianMonoid|) T) ((|KeyedAccessFile| . |KeyedDictionary|) 31751) ((|SimpleAlgebraicExtension| . |PartialDifferentialRing|) 31654) ((|RadixExpansion| . |Ring|) T) ((|PartialFraction| . |Ring|) T) ((|GeneralSparseTable| . |KeyedDictionary|) 31633) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianMonoid|) NIL) ((|SparseUnivariateLaurentSeries| . |OrderedCancellationAbelianMonoid|) NIL) ((|Set| . |ConvertibleTo|) 31569) ((|Set| . |CoercibleTo|) 31543) ((|HashTable| . |Dictionary|) 31485) ((|RadixExpansion| . |DivisionRing|) T) ((|RadixExpansion| . |DifferentialRing|) T) ((|PrimitiveArray| . |SetCategory|) 31422) ((|FourierSeries| . |Ring|) T) ((|PartialFraction| . |DivisionRing|) T) ((|OrdinaryWeightedPolynomials| . |CancellationAbelianMonoid|) T) ((|MachineFloat| . |GcdDomain|) T) ((|HexadecimalExpansion| . |LeftOreRing|) T) ((|OrderedCompletion| . |SemiGroup|) 31392) ((|BinaryExpansion| . |PartialDifferentialRing|) NIL) ((|TaylorSeries| . |ElementaryFunctionCategory|) 31341) ((|DecimalExpansion| . |LeftOreRing|) T) ((|PAdicRationalConstructor| . |OrderedRing|) 31301) ((|SplitHomogeneousDirectProduct| . |Type|) T) ((|Permutation| . |Monoid|) T) ((|Complex| . |InnerEvalable|) 31190) ((|Quaternion| . |AbelianSemiGroup|) T) ((|Permutation| . |Group|) T) ((|Fraction| . |SemiGroup|) T) ((|HexadecimalExpansion| . |OrderedAbelianSemiGroup|) T) ((|HexadecimalExpansion| . |OrderedAbelianGroup|) T) ((|PrimeField| . |FiniteFieldCategory|) T) ((|HexadecimalExpansion| . |Monoid|) T) ((|DecimalExpansion| . |OrderedAbelianSemiGroup|) T) ((|DecimalExpansion| . |OrderedAbelianGroup|) T) ((|Quaternion| . |AbelianGroup|) T) ((|DecimalExpansion| . |Monoid|) T) ((|OrderedCompletion| . |AbelianMonoid|) 31125) ((|ExponentialOfUnivariatePuiseuxSeries| . |EuclideanDomain|) 31101) ((|Result| . |DictionaryOperations|) 31034) ((|Fraction| . |AbelianMonoid|) T) ((|Point| . |ConvertibleTo|) 30970) ((|Point| . |CoercibleTo|) 30888) ((|List| . |HomogeneousAggregate|) 30872) ((|AssociationList| . |RecursiveAggregate|) 30814) ((|PseudoAlgebraicClosureOfRationalNumber| . |Algebra|) 30768) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Algebra|) 30722) ((|SparseUnivariatePolynomialExpressions| . |GcdDomain|) 30617) ((|FourierComponent| . |CoercibleTo|) 30591) ((|SplitHomogeneousDirectProduct| . |RetractableTo|) 30342) ((|IndexedString| . |LinearAggregate|) 30317) ((|IndexedString| . |FiniteLinearAggregate|) 30292) ((|FiniteFieldCyclicGroup| . |VectorSpace|) 30261) ((|RegularTriangularSet| . |Type|) T) ((|PAdicRational| . |EntireRing|) T) ((|UnivariatePolynomial| . |InnerEvalable|) 30171) ((|GeneralTriangularSet| . |Type|) T) ((|GeneralPolynomialSet| . |Type|) T) ((|IntegrationResult| . |BasicType|) T) ((|SparseUnivariatePolynomial| . |Eltable|) 30074) ((|LaurentPolynomial| . |GcdDomain|) 30050) ((|Queue| . |QueueAggregate|) 30034) ((|XDistributedPolynomial| . |FreeModuleCat|) 29991) ((|BalancedPAdicRational| . |GcdDomain|) T) ((|TexFormat| . |BasicType|) T) ((|SegmentBinding| . |SetCategory|) 29961) ((|ResidueRing| . |SetCategory|) T) ((|PoincareBirkhoffWittLyndonBasis| . |OrderedSet|) T) ((|UnivariateTaylorSeries| . |RightModule|) 29794) ((|FiniteFieldNormalBasis| . |UniqueFactorizationDomain|) T) ((|UnivariatePuiseuxSeries| . |RightModule|) 29576) ((|SplitHomogeneousDirectProduct| . |FullyLinearlyExplicitRingOver|) 29544) ((|UnivariateLaurentSeries| . |RightModule|) 29259) ((|UnivariateFormalPowerSeries| . |RightModule|) 29092) ((|UnivariateTaylorSeries| . |BiModule|) 28893) ((|UnivariatePuiseuxSeries| . |BiModule|) 28643) ((|UnivariateLaurentSeries| . |BiModule|) 28284) ((|UnivariateFormalPowerSeries| . |BiModule|) 28085) ((|TaylorSeries| . |Evalable|) 28072) ((|FiniteFieldNormalBasis| . |IntegralDomain|) T) ((|File| . |CoercibleTo|) 28046) ((|EuclideanModularRing| . |EuclideanDomain|) T) ((|InnerTaylorSeries| . |RightModule|) 28007) ((|InnerSparseUnivariatePowerSeries| . |RightModule|) 27840) ((|FreeGroup| . |SetCategory|) T) ((|FreeAbelianGroup| . |SetCategory|) T) ((|DirectProductModule| . |CoercibleTo|) 27790) ((|DirectProductMatrixModule| . |CoercibleTo|) 27740) ((|RadicalFunctionField| . |CancellationAbelianMonoid|) T) ((|BinaryFile| . |CoercibleTo|) 27714) ((|AssociatedLieAlgebra| . |AbelianMonoid|) T) ((|MachineComplex| . |FramedAlgebra|) 27638) ((|AssociatedJordanAlgebra| . |AbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator| . |BasicType|) T) ((|InnerTaylorSeries| . |BiModule|) 27597) ((|InnerSparseUnivariatePowerSeries| . |BiModule|) 27398) ((|Float| . |SetCategory|) T) ((|FiniteDivisor| . |BasicType|) T) ((|Complex| . |EntireRing|) 27267) ((|Divisor| . |BasicType|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedRing|) 27198) ((|Places| . |CoercibleTo|) 27172) ((|ModuleOperator| . |Rng|) T) ((|Stack| . |InnerEvalable|) 27091) ((|SplitHomogeneousDirectProduct| . |PartialDifferentialRing|) 26995) ((|Operator| . |SetCategory|) T) ((|OppositeMonogenicLinearOperator| . |SetCategory|) T) ((|OpenMathError| . |SetCategory|) T) ((|AttributeButtons| . |BasicType|) T) ((|Character| . |OrderedSet|) T) ((|MyExpression| . |CharacteristicZero|) 26958) ((|MyExpression| . |CharacteristicNonZero|) 26918) ((|Kernel| . |Patternable|) 26902) ((|U8Matrix| . |Type|) T) ((|U8Vector| . |Collection|) 26879) ((|Bits| . |Type|) T) ((|SequentialDifferentialPolynomial| . |BasicType|) T) ((|RoutinesTable| . |Aggregate|) T) ((|NewSparseUnivariatePolynomial| . |BasicType|) T) ((|NewSparseMultivariatePolynomial| . |BasicType|) T) ((|GeneralModulePolynomial| . |BasicType|) T) ((|GeneralDistributedMultivariatePolynomial| . |BasicType|) T) ((|DirectProduct| . |OrderedCancellationAbelianMonoid|) 26803) ((|DirectProduct| . |OrderedAbelianMonoid|) 26727) ((|NeitherSparseOrDensePowerSeries| . |StreamAggregate|) 26668) ((|ListMonoidOps| . |BasicType|) T) ((|UnivariatePolynomial| . |EntireRing|) 26531) ((|LiePolynomial| . |LieAlgebra|) 26515) ((|List| . |Eltable|) 26487) ((|ResidueRing| . |Module|) 26471) ((|Interval| . |EntireRing|) T) ((|PolynomialRing| . |LeftModule|) 26368) ((|XPolynomialRing| . |CancellationAbelianMonoid|) T) ((|MonoidRing| . |LeftModule|) 26315) ((|ModularRing| . |LeftModule|) 26302) ((|ExtAlgBasis| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |LeftModule|) 26195) ((|AntiSymm| . |BasicType|) T) ((|InnerPrimeField| . |BasicType|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|InnerFiniteField| . |BasicType|) T) ((|UnivariateTaylorSeries| . |Ring|) T) ((|UnivariatePuiseuxSeries| . |Ring|) T) ((|UnivariateLaurentSeries| . |Ring|) T) ((|UnivariateFormalPowerSeries| . |Ring|) T) ((|UnivariateTaylorSeries| . |DifferentialRing|) 26132) ((|UnivariatePuiseuxSeries| . |DivisionRing|) 26108) ((|FreeAbelianGroup| . |Module|) 26085) ((|UnivariatePuiseuxSeries| . |DifferentialRing|) 26020) ((|UnivariateLaurentSeries| . |DifferentialRing|) 25863) ((|UnivariateLaurentSeries| . |DivisionRing|) 25839) ((|UnivariateFormalPowerSeries| . |DifferentialRing|) 25776) ((|TaylorSeries| . |Algebra|) 25620) ((|RadixExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|InnerTaylorSeries| . |Ring|) T) ((|InnerSparseUnivariatePowerSeries| . |Ring|) T) ((|RadixExpansion| . |OrderedAbelianMonoid|) T) ((|Partition| . |OrderedCancellationAbelianMonoid|) T) ((|Partition| . |OrderedAbelianMonoid|) T) ((|DirichletRing| . |CoercibleTo|) 25594) ((|PAdicRationalConstructor| . |Rng|) T) ((|PAdicInteger| . |PAdicIntegerCategory|) 25578) ((|MachineComplex| . |GcdDomain|) T) ((|Float| . |Module|) 25532) ((|Factored| . |LeftModule|) 25506) ((|ModMonic| . |OrderedSet|) 25477) ((|ModularField| . |Algebra|) 25431) ((|InnerSparseUnivariatePowerSeries| . |DifferentialRing|) 25379) ((|AlgebraicFunctionField| . |MonogenicAlgebra|) 25345) ((|FiniteFieldNormalBasis| . |FiniteAlgebraicExtensionField|) 25314) ((|FiniteFieldNormalBasis| . |Field|) T) ((|UnivariateTaylorSeriesCZero| . |CharacteristicNonZero|) 25274) ((|UnivariateTaylorSeriesCZero| . |CharacteristicZero|) 25237) ((|SimpleAlgebraicExtension| . |EuclideanDomain|) 25171) ((|Equation| . |SemiGroup|) 25017) ((|SimpleFortranProgram| . |Type|) T) ((|SubSpaceComponentProperty| . |BasicType|) T) ((|UniversalSegment| . |CoercibleTo|) 24968) ((|OrderedCompletion| . |CancellationAbelianMonoid|) 24903) ((|List| . |UnaryRecursiveAggregate|) 24887) ((|Operator| . |Module|) 24844) ((|OppositeMonogenicLinearOperator| . |Module|) 24801) ((|HomogeneousDirectProduct| . |Type|) T) ((|FiniteFieldExtension| . |EuclideanDomain|) T) ((|FiniteFieldNormalBasisExtension| . |EuclideanDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |EuclideanDomain|) T) ((|List| . |IndexedAggregate|) 24773) ((|Fraction| . |CancellationAbelianMonoid|) T) ((|IndexedList| . |ListAggregate|) 24757) ((|BinaryExpansion| . |EuclideanDomain|) T) ((|Equation| . |AbelianMonoid|) 24591) ((|IndexedList| . |LinearAggregate|) 24575) ((|MachineComplex| . |FieldOfPrimeCharacteristic|) NIL) ((|IndexedList| . |FiniteLinearAggregate|) 24559) ((|InfinitlyClosePoint| . |CoercibleTo|) 24533) ((|ArrayStack| . |SetCategory|) 24503) ((|BinaryExpansion| . |RealConstant|) T) ((|Integer| . |CombinatorialFunctionCategory|) T) ((|Vector| . |Collection|) 24487) ((|HomogeneousDirectProduct| . |RetractableTo|) 24238) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CharacteristicNonZero|) 24160) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CharacteristicZero|) 24085) ((|RectangularMatrix| . |Type|) T) ((|QuadraticForm| . |CoercibleTo|) 24059) ((|OutputForm| . |CoercibleTo|) 24033) ((|OrderlyDifferentialPolynomial| . |RightModule|) 23790) ((|SequentialDifferentialPolynomial| . |Evalable|) 23777) ((|DenavitHartenbergMatrix| . |Type|) T) ((|NewSparseUnivariatePolynomial| . |Evalable|) 23764) ((|NewSparseMultivariatePolynomial| . |Evalable|) 23751) ((|OrderlyDifferentialPolynomial| . |BiModule|) 23476) ((|GeneralDistributedMultivariatePolynomial| . |Evalable|) 23463) ((|SparseUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|SparseUnivariatePolynomial| . |CoercibleTo|) 23437) ((|SparseMultivariatePolynomial| . |CoercibleTo|) 23411) ((|SparseMultivariatePolynomial| . |ConvertibleTo|) 23018) ((|ResidueRing| . |CommutativeRing|) T) ((|SparseUnivariateSkewPolynomial| . |CoercibleTo|) 22992) ((|Point| . |EltableAggregate|) 22964) ((|KeyedAccessFile| . |InnerEvalable|) 22648) ((|OrderlyDifferentialVariable| . |RetractableTo|) 22632) ((|GeneralSparseTable| . |InnerEvalable|) 22340) ((|PolynomialRing| . |Monoid|) T) ((|MonoidRing| . |Monoid|) T) ((|ModularRing| . |Monoid|) T) ((|FiniteFieldNormalBasis| . |SemiGroup|) T) ((|TheSymbolTable| . |CoercibleTo|) 22314) ((|DeRhamComplex| . |BasicType|) T) ((|HomogeneousDirectProduct| . |FullyLinearlyExplicitRingOver|) 22282) ((|InnerFreeAbelianMonoid| . |SetCategory|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |SetCategory|) T) ((|IndexedDirectProductAbelianMonoid| . |SetCategory|) T) ((|Octonion| . |LeftModule|) 22256) ((|RealClosure| . |GcdDomain|) T) ((|PrimitiveArray| . |InnerEvalable|) 22175) ((|FiniteFieldNormalBasis| . |AbelianMonoid|) T) ((|U16Vector| . |OrderedSet|) T) ((|AssociatedLieAlgebra| . |CancellationAbelianMonoid|) T) ((|AssociatedJordanAlgebra| . |CancellationAbelianMonoid|) T) ((|Factored| . |LeftOreRing|) 22099) ((|FiniteField| . |GcdDomain|) T) ((|DirectProduct| . |Finite|) 22074) ((|Float| . |CommutativeRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Rng|) T) ((|UnivariateLaurentSeriesConstructor| . |Rng|) T) ((|DoubleFloat| . |RadicalCategory|) T) ((|ProjectivePlane| . |SetCategoryWithDegree|) T) ((|MachineFloat| . |FortranMachineTypeCategory|) T) ((|Factored| . |Monoid|) T) ((|MachineInteger| . |UniqueFactorizationDomain|) T) ((|SquareMatrix| . |LinearlyExplicitRingOver|) 21990) ((|XDistributedPolynomial| . |RightModule|) 21974) ((|InnerPAdicInteger| . |PAdicIntegerCategory|) 21958) ((|StringTable| . |TableAggregate|) 21931) ((|ModuleOperator| . |SetCategory|) T) ((|MachineInteger| . |IntegralDomain|) T) ((|BinaryTournament| . |SetCategory|) 21901) ((|HomogeneousDirectProduct| . |PartialDifferentialRing|) 21805) ((|DoubleFloatVector| . |VectorCategory|) 21778) ((|DoubleFloatVector| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |VectorCategory|) 21739) ((|Commutator| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |Algebra|) 21696) ((|FiniteField| . |FieldOfPrimeCharacteristic|) T) ((|Expression| . |CharacteristicZero|) 21659) ((|Expression| . |CharacteristicNonZero|) 21619) ((|BalancedPAdicInteger| . |IntegralDomain|) T) ((|ExponentialExpansion| . |CharacteristicZero|) 21513) ((|ExponentialExpansion| . |CharacteristicNonZero|) 21404) ((|AlgebraicNumber| . |GcdDomain|) T) ((|Color| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |SetCategory|) T) ((|StringTable| . |BagAggregate|) 21340) ((|SparseUnivariatePolynomialExpressions| . |PolynomialCategory|) 21275) ((|NewSparseUnivariatePolynomial| . |StepThrough|) 21245) ((|Matrix| . |Aggregate|) T) ((|XDistributedPolynomial| . |BiModule|) 21224) ((|InnerTable| . |Aggregate|) T) ((|Heap| . |BagAggregate|) 21208) ((|DirectProductModule| . |EltableAggregate|) 21180) ((|DirectProductMatrixModule| . |EltableAggregate|) 21152) ((|PAdicRational| . |Eltable|) 21037) ((|AssociationList| . |Type|) T) ((|OrderlyDifferentialPolynomial| . |Ring|) T) ((|SymmetricPolynomial| . |AbelianMonoidRing|) 21007) ((|OrderlyDifferentialPolynomial| . |FiniteAbelianMonoidRing|) 20927) ((|SequentialDifferentialPolynomial| . |Algebra|) 20690) ((|OrderlyDifferentialPolynomial| . |DifferentialRing|) 20655) ((|NewSparseUnivariatePolynomial| . |Algebra|) 20395) ((|NewSparseMultivariatePolynomial| . |Algebra|) 20158) ((|MyUnivariatePolynomial| . |AbelianMonoidRing|) 20119) ((|GeneralDistributedMultivariatePolynomial| . |Algebra|) 19882) ((|List| . |ConvertibleTo|) 19818) ((|List| . |CoercibleTo|) 19736) ((|InnerPrimeField| . |StepThrough|) T) ((|InnerFiniteField| . |StepThrough|) T) ((|Stack| . |HomogeneousAggregate|) 19720) ((|Tree| . |SetCategory|) 19690) ((|SquareMatrix| . |AbelianSemiGroup|) T) ((|SquareMatrix| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Rng|) T) ((|NeitherSparseOrDensePowerSeries| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |TrigonometricFunctionCategory|) 19639) ((|UnivariateTaylorSeriesCZero| . |TranscendentalFunctionCategory|) 19588) ((|GeneralUnivariatePowerSeries| . |Rng|) T) ((|UnivariateLaurentSeries| . |OrderedAbelianMonoid|) NIL) ((|UnivariateLaurentSeries| . |OrderedCancellationAbelianMonoid|) NIL) ((|Quaternion| . |OrderedSet|) 19559) ((|OrderedFreeMonoid| . |CoercibleTo|) 19533) ((|OrdinaryWeightedPolynomials| . |AbelianGroup|) T) ((|OrdinaryWeightedPolynomials| . |AbelianSemiGroup|) T) ((|Octonion| . |Monoid|) T) ((|InfClsPt| . |SetCategoryWithDegree|) T) ((|ContinuedFraction| . |UniqueFactorizationDomain|) T) ((|InnerPrimeField| . |Algebra|) 19487) ((|InnerFiniteField| . |Algebra|) 19441) ((|FreeMonoid| . |CoercibleTo|) 19415) ((|FreeAbelianMonoid| . |CoercibleTo|) 19389) ((|Complex| . |Eltable|) 19342) ((|UnivariateTaylorSeriesCZero| . |ArcHyperbolicFunctionCategory|) 19291) ((|UnivariateTaylorSeriesCZero| . |ArcTrigonometricFunctionCategory|) 19240) ((|Asp19| . |Type|) T) ((|Boolean| . |BasicType|) T) ((|PAdicRationalConstructor| . |SetCategory|) T) ((|ContinuedFraction| . |IntegralDomain|) T) ((|ModuleOperator| . |Module|) 19197) ((|Equation| . |CancellationAbelianMonoid|) 19031) ((|DoubleFloat| . |CoercibleTo|) 19005) ((|DoubleFloat| . |ConvertibleTo|) 18908) ((|U32Matrix| . |Aggregate|) T) ((|RadicalFunctionField| . |LinearlyExplicitRingOver|) 18798) ((|XDistributedPolynomial| . |Ring|) T) ((|SingleInteger| . |CharacteristicZero|) T) ((|Library| . |TableAggregate|) 18768) ((|MultivariatePolynomial| . |PolynomialFactorizationExplicit|) 18718) ((|IndexedString| . |Aggregate|) T) ((|ListMultiDictionary| . |BagAggregate|) 18702) ((|Library| . |BagAggregate|) 18635) ((|MyUnivariatePolynomial| . |PatternMatchable|) NIL) ((|UnivariatePolynomial| . |Eltable|) 18538) ((|MultivariatePolynomial| . |LeftModule|) 18435) ((|EqTable| . |Type|) T) ((|SymmetricPolynomial| . |RetractableTo|) 18279) ((|MyUnivariatePolynomial| . |RetractableTo|) 18089) ((|SparseUnivariateLaurentSeries| . |PolynomialFactorizationExplicit|) NIL) ((|RomanNumeral| . |ConvertibleTo|) 17970) ((|RomanNumeral| . |CoercibleTo|) 17944) ((|FiniteFieldCyclicGroup| . |BasicType|) T) ((|DirectProductModule| . |RightModule|) 17814) ((|DirectProductMatrixModule| . |RightModule|) 17684) ((|ScriptFormulaFormat| . |BasicType|) T) ((|Polynomial| . |CoercibleTo|) 17658) ((|Polynomial| . |ConvertibleTo|) 17436) ((|ModuleMonomial| . |CoercibleTo|) 17410) ((|WuWenTsunTriangularSet| . |TriangularSetCategory|) 17379) ((|HomogeneousDistributedMultivariatePolynomial| . |CoercibleTo|) 17353) ((|HomogeneousDistributedMultivariatePolynomial| . |ConvertibleTo|) 17131) ((|DifferentialSparseMultivariatePolynomial| . |FullyRetractableTo|) 17115) ((|DistributedMultivariatePolynomial| . |FullyRetractableTo|) 17099) ((|DirectProductModule| . |BiModule|) 16962) ((|DirectProductMatrixModule| . |BiModule|) 16825) ((|SparseUnivariateTaylorSeries| . |LeftModule|) 16722) ((|SparseUnivariatePuiseuxSeries| . |LeftModule|) 16591) ((|SparseUnivariateLaurentSeries| . |LeftModule|) 16387) ((|SparseMultivariateTaylorSeries| . |LeftModule|) 16284) ((|FiniteFieldNormalBasis| . |CancellationAbelianMonoid|) T) ((|Asp73| . |FortranVectorFunctionCategory|) T) ((|Asp73| . |FortranProgramCategory|) T) ((|RadicalFunctionField| . |AbelianSemiGroup|) T) ((|RadicalFunctionField| . |AbelianGroup|) T) ((|PAdicRationalConstructor| . |Module|) 16225) ((|Float| . |EntireRing|) T) ((|Complex| . |RadicalCategory|) 16137) ((|MyUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 16121) ((|MachineComplex| . |FortranMachineTypeCategory|) T) ((|Quaternion| . |QuaternionCategory|) 16105) ((|MachineInteger| . |SemiGroup|) T) ((|MachineComplex| . |ComplexCategory|) 16077) ((|UnivariatePuiseuxSeriesConstructor| . |SetCategory|) T) ((|UnivariateLaurentSeriesConstructor| . |SetCategory|) T) ((|Expression| . |TranscendentalFunctionCategory|) 16044) ((|Expression| . |TrigonometricFunctionCategory|) 16011) ((|SubSpace| . |BasicType|) T) ((|Expression| . |PrimitiveFunctionCategory|) 15978) ((|CardinalNumber| . |SemiGroup|) T) ((|BalancedPAdicInteger| . |SemiGroup|) T) ((|IndexedVector| . |VectorCategory|) 15962) ((|MachineInteger| . |AbelianMonoid|) T) ((|IndexedVector| . |SetCategory|) 15899) ((|ArrayStack| . |InnerEvalable|) 15818) ((|ContinuedFraction| . |Field|) T) ((|SparseUnivariatePolynomialExpressions| . |UnivariatePolynomialCategory|) 15802) ((|Expression| . |ArcTrigonometricFunctionCategory|) 15769) ((|Expression| . |ArcHyperbolicFunctionCategory|) 15736) ((|KeyedAccessFile| . |HomogeneousAggregate|) 15659) ((|CardinalNumber| . |AbelianMonoid|) T) ((|BalancedPAdicInteger| . |AbelianMonoid|) T) ((|MoebiusTransform| . |SetCategory|) T) ((|GeneralSparseTable| . |HomogeneousAggregate|) 15588) ((|Fraction| . |LinearlyExplicitRingOver|) 15504) ((|LinearOrdinaryDifferentialOperator1| . |RetractableTo|) 15348) ((|MyUnivariatePolynomial| . |PartialDifferentialRing|) 15246) ((|PrimitiveArray| . |HomogeneousAggregate|) 15230) ((|MultivariatePolynomial| . |LeftOreRing|) 15148) ((|FiniteFieldExtensionByPolynomial| . |Rng|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Rng|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Rng|) T) ((|DifferentialSparseMultivariatePolynomial| . |Rng|) T) ((|DistributedMultivariatePolynomial| . |Rng|) T) ((|PAdicRational| . |ConvertibleTo|) NIL) ((|PAdicRational| . |CoercibleTo|) 15122) ((|XPolynomialRing| . |AbelianGroup|) T) ((|Interval| . |RadicalCategory|) T) ((|MultivariatePolynomial| . |Monoid|) T) ((|XPolynomialRing| . |AbelianSemiGroup|) T) ((|DirectProductModule| . |Ring|) 15032) ((|DirectProductMatrixModule| . |Ring|) 14942) ((|DirichletRing| . |RightModule|) 14862) ((|Asp33| . |Type|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|DirectProductModule| . |DifferentialRing|) 14799) ((|DirectProductMatrixModule| . |DifferentialRing|) 14736) ((|DirichletRing| . |BiModule|) 14649) ((|AlgebraicFunctionField| . |BasicType|) T) ((|PrimeField| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |LeftOreRing|) 14625) ((|SparseUnivariateLaurentSeries| . |LeftOreRing|) 14601) ((|SparseUnivariateTaylorSeries| . |Monoid|) T) ((|SparseUnivariatePuiseuxSeries| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianGroup|) NIL) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianSemiGroup|) NIL) ((|SparseMultivariateTaylorSeries| . |Monoid|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |PlacesCategory|) 14464) ((|PseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PositiveInteger| . |BasicType|) T) ((|NeitherSparseOrDensePowerSeries| . |SetCategory|) T) ((|NonNegativeInteger| . |BasicType|) T) ((|LyndonWord| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |SetCategory|) T) ((|FortranExpression| . |SemiGroup|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Module|) 14252) ((|ContinuedFraction| . |SemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 14228) ((|MyExpression| . |GcdDomain|) 14195) ((|PAdicRationalConstructor| . |CommutativeRing|) T) ((|UnivariateLaurentSeriesConstructor| . |Module|) 13953) ((|OrderedCompletion| . |AbelianGroup|) 13888) ((|OrderedCompletion| . |AbelianSemiGroup|) 13823) ((|DataList| . |StreamAggregate|) 13807) ((|BinaryTournament| . |InnerEvalable|) 13726) ((|Fraction| . |AbelianSemiGroup|) T) ((|Fraction| . |AbelianGroup|) T) ((|FortranExpression| . |AbelianMonoid|) T) ((|Complex| . |ConvertibleTo|) 13346) ((|Complex| . |CoercibleTo|) 13320) ((|ContinuedFraction| . |AbelianMonoid|) T) ((|List| . |EltableAggregate|) 13292) ((|DoubleFloatVector| . |InnerEvalable|) NIL) ((|ComplexDoubleFloatVector| . |InnerEvalable|) NIL) ((|IndexedList| . |Aggregate|) T) ((|NumericalPDEProblem| . |CoercibleTo|) 13266) ((|Asp9| . |Type|) T) ((|NumericalOptimizationProblem| . |CoercibleTo|) 13240) ((|NumericalODEProblem| . |CoercibleTo|) 13214) ((|NumericalIntegrationProblem| . |CoercibleTo|) 13188) ((|Magma| . |CoercibleTo|) 13162) ((|DirectProduct| . |LeftModule|) 12976) ((|Symbol| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |RightModule|) 12710) ((|SparseTable| . |Type|) T) ((|SparseMultivariatePolynomial| . |RightModule|) 12467) ((|SparseUnivariateSkewPolynomial| . |RightModule|) 12451) ((|StochasticDifferential| . |LeftModule|) 12420) ((|SparseUnivariatePolynomial| . |BiModule|) 12122) ((|SparseMultivariatePolynomial| . |BiModule|) 11847) ((|SparseUnivariateSkewPolynomial| . |BiModule|) 11826) ((|UnivariatePolynomial| . |ConvertibleTo|) NIL) ((|UnivariatePolynomial| . |CoercibleTo|) 11800) ((|FiniteFieldCyclicGroup| . |StepThrough|) T) ((|UnivariateSkewPolynomial| . |CoercibleTo|) 11774) ((|RewriteRule| . |Eltable|) 11753) ((|DirichletRing| . |Ring|) T) ((|Asp55| . |Type|) T) ((|RadixExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|KeyedAccessFile| . |Eltable|) 11726) ((|Tree| . |InnerEvalable|) 11645) ((|HexadecimalExpansion| . |Type|) T) ((|Interval| . |CoercibleTo|) 11619) ((|GeneralSparseTable| . |Eltable|) 11598) ((|SequentialDifferentialPolynomial| . |DifferentialExtension|) 11582) ((|RadixExpansion| . |LeftModule|) 11516) ((|DecimalExpansion| . |Type|) T) ((|PrimitiveArray| . |Eltable|) 11488) ((|PartialFraction| . |LeftModule|) 11429) ((|EuclideanModularRing| . |PrincipalIdealDomain|) T) ((|OrdinaryDifferentialRing| . |EuclideanDomain|) 11405) ((|PAdicInteger| . |BasicType|) T) ((|NewSparseUnivariatePolynomial| . |DifferentialExtension|) 11389) ((|NottinghamGroup| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Module|) 11330) ((|NeitherSparseOrDensePowerSeries| . |Module|) 11244) ((|AssociatedLieAlgebra| . |AbelianGroup|) T) ((|AssociatedLieAlgebra| . |AbelianSemiGroup|) T) ((|AssociatedJordanAlgebra| . |AbelianGroup|) T) ((|FiniteFieldCyclicGroup| . |Algebra|) 11198) ((|MachineComplex| . |MonogenicAlgebra|) 11122) ((|HexadecimalExpansion| . |Patternable|) 11099) ((|HexadecimalExpansion| . |PatternMatchable|) 11076) ((|GeneralUnivariatePowerSeries| . |Module|) 10864) ((|DecimalExpansion| . |Patternable|) 10841) ((|Asp1| . |Type|) T) ((|DecimalExpansion| . |PatternMatchable|) 10818) ((|AssociatedJordanAlgebra| . |AbelianSemiGroup|) T) ((|FourierSeries| . |LeftModule|) 10792) ((|HexadecimalExpansion| . |RetractableTo|) 10736) ((|PAdicRationalConstructor| . |InnerEvalable|) 10625) ((|DecimalExpansion| . |RetractableTo|) 10569) ((|DirectProduct| . |Aggregate|) T) ((|Queue| . |SetCategory|) 10539) ((|UnivariatePuiseuxSeriesConstructor| . |CommutativeRing|) 10445) ((|UnivariateLaurentSeriesConstructor| . |CommutativeRing|) 10351) ((|ModMonic| . |CharacteristicNonZero|) 10311) ((|ModMonic| . |CharacteristicZero|) 10274) ((|MachineInteger| . |CancellationAbelianMonoid|) T) ((|CartesianTensor| . |GradedAlgebra|) 10235) ((|GuessOptionFunctions0| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator| . |LinearOrdinaryDifferentialOperatorCategory|) 10219) ((|Stack| . |CoercibleTo|) 10170) ((|BalancedPAdicInteger| . |CancellationAbelianMonoid|) T) ((|Pi| . |UniqueFactorizationDomain|) T) ((|KeyedAccessFile| . |IndexedAggregate|) 10143) ((|GeneralSparseTable| . |IndexedAggregate|) 10122) ((|FiniteDivisor| . |FiniteDivisorCategory|) 10091) ((|InputForm| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |Ring|) T) ((|Pi| . |IntegralDomain|) T) ((|Divisor| . |DivisorCategory|) 10075) ((|SparseMultivariatePolynomial| . |Ring|) T) ((|SparseUnivariateSkewPolynomial| . |Ring|) T) ((|DirectProduct| . |OrderedAbelianGroup|) 10045) ((|DirectProduct| . |OrderedAbelianSemiGroup|) 9969) ((|DirectProduct| . |OrderedAbelianMonoidSup|) 9927) ((|SparseUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 9888) ((|DirectProduct| . |Monoid|) 9774) ((|PrimitiveArray| . |OneDimensionalArrayAggregate|) 9758) ((|HexadecimalExpansion| . |FullyLinearlyExplicitRingOver|) 9735) ((|HexadecimalExpansion| . |FullyEvalableOver|) 9712) ((|SparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 9670) ((|FiniteField| . |VectorSpace|) 9639) ((|DecimalExpansion| . |FullyLinearlyExplicitRingOver|) 9616) ((|DecimalExpansion| . |FullyEvalableOver|) 9593) ((|PrimitiveArray| . |IndexedAggregate|) 9565) ((|SparseUnivariatePolynomial| . |DifferentialRing|) T) ((|LiePolynomial| . |SetCategory|) T) ((|Variable| . |SetCategory|) T) ((|Table| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |DifferentialPolynomialCategory|) 9425) ((|FiniteFieldExtensionByPolynomial| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |SetCategory|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |SetCategory|) T) ((|DistributedMultivariatePolynomial| . |SetCategory|) T) ((|Asp77| . |Type|) T) ((|BinaryTree| . |BasicType|) 9395) ((|BinarySearchTree| . |BasicType|) 9365) ((|MyUnivariatePolynomial| . |EuclideanDomain|) 9341) ((|Table| . |KeyedDictionary|) 9320) ((|U8Vector| . |BasicType|) T) ((|SplittingTree| . |SetCategory|) T) ((|HashTable| . |SetCategory|) T) ((|SimpleAlgebraicExtension| . |PrincipalIdealDomain|) 9254) ((|RadixExpansion| . |OrderedAbelianSemiGroup|) T) ((|HashTable| . |KeyedDictionary|) 9233) ((|DirectProductModule| . |OrderedCancellationAbelianMonoid|) 9157) ((|DirectProductModule| . |OrderedAbelianMonoid|) 9081) ((|DirectProductMatrixModule| . |OrderedCancellationAbelianMonoid|) 9005) ((|AlgebraicFunctionField| . |StepThrough|) NIL) ((|DirectProductMatrixModule| . |OrderedAbelianMonoid|) 8929) ((|RadixExpansion| . |OrderedAbelianGroup|) T) ((|RadixExpansion| . |LeftOreRing|) T) ((|RadixExpansion| . |Monoid|) T) ((|Partition| . |OrderedAbelianSemiGroup|) T) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PartialFraction| . |LeftOreRing|) T) ((|PartialFraction| . |Monoid|) T) ((|PrimeField| . |SetCategory|) T) ((|PAdicRationalConstructor| . |EntireRing|) T) ((|ArrayStack| . |HomogeneousAggregate|) 8913) ((|HexadecimalExpansion| . |PartialDifferentialRing|) NIL) ((|PseudoAlgebraicClosureOfFiniteField| . |CommutativeRing|) T) ((|DoubleFloat| . |RightModule|) 8867) ((|OnePointCompletion| . |SemiGroup|) 8837) ((|DecimalExpansion| . |PartialDifferentialRing|) NIL) ((|NeitherSparseOrDensePowerSeries| . |CommutativeRing|) T) ((|OneDimensionalArray| . |SetCategory|) 8774) ((|InnerIndexedTwoDimensionalArray| . |SetCategory|) 8744) ((|IndexedFlexibleArray| . |SetCategory|) 8681) ((|IndexedTwoDimensionalArray| . |SetCategory|) 8651) ((|IndexedOneDimensionalArray| . |SetCategory|) 8588) ((|InnerPAdicInteger| . |BasicType|) T) ((|Integer| . |BasicType|) T) ((|InnerAlgebraicNumber| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |CommutativeRing|) 8494) ((|FiniteFieldExtension| . |PrincipalIdealDomain|) T) ((|FiniteFieldNormalBasisExtension| . |PrincipalIdealDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |PrincipalIdealDomain|) T) ((|DoubleFloat| . |BiModule|) 8421) ((|OnePointCompletion| . |AbelianMonoid|) 8356) ((|FourierSeries| . |Monoid|) T) ((|BinaryExpansion| . |PrincipalIdealDomain|) T) ((|AlgebraicFunctionField| . |Algebra|) 8284) ((|BinaryExpansion| . |OrderedIntegralDomain|) T) ((|InnerPrimeField| . |FiniteFieldCategory|) T) ((|InnerFiniteField| . |FiniteFieldCategory|) T) ((|UnivariateLaurentSeriesConstructor| . |InnerEvalable|) 8115) ((|Expression| . |GcdDomain|) 8082) ((|ExponentialExpansion| . |GcdDomain|) T) ((|U16Matrix| . |Aggregate|) T) ((|Operator| . |Eltable|) 8061) ((|FortranExpression| . |CancellationAbelianMonoid|) T) ((|ContinuedFraction| . |CancellationAbelianMonoid|) T) ((|Equation| . |AbelianSemiGroup|) 7861) ((|Equation| . |AbelianGroup|) 7695) ((|AssociationList| . |TableAggregate|) 7674) ((|Asp24| . |CoercibleTo|) 7648) ((|Pattern| . |CoercibleTo|) 7622) ((|IndexedVector| . |InnerEvalable|) 7541) ((|AssociationList| . |BagAggregate|) 7483) ((|Set| . |FiniteSetAggregate|) 7467) ((|Set| . |Finite|) 7442) ((|RoutinesTable| . |Type|) T) ((|RomanNumeral| . |RightModule|) 7429) ((|Polynomial| . |RightModule|) 7186) ((|HomogeneousDistributedMultivariatePolynomial| . |RightModule|) 6943) ((|LiePolynomial| . |Module|) 6927) ((|RomanNumeral| . |BiModule|) 6912) ((|Polynomial| . |BiModule|) 6637) ((|Pi| . |Field|) T) ((|FiniteFieldExtensionByPolynomial| . |Module|) 6578) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Module|) 6519) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Module|) 6460) ((|DifferentialSparseMultivariatePolynomial| . |Module|) 6223) ((|DistributedMultivariatePolynomial| . |Module|) 5986) ((|TwoDimensionalViewport| . |BasicType|) T) ((|Vector| . |BasicType|) 5923) ((|Point| . |LinearAggregate|) 5907) ((|UnivariateTaylorSeries| . |LeftModule|) 5804) ((|HomogeneousDistributedMultivariatePolynomial| . |BiModule|) 5529) ((|UnivariatePuiseuxSeries| . |LeftModule|) 5398) ((|UnivariateLaurentSeries| . |LeftModule|) 5200) ((|UnivariateLaurentSeries| . |PolynomialFactorizationExplicit|) NIL) ((|Point| . |FiniteLinearAggregate|) 5184) ((|UnivariateFormalPowerSeries| . |LeftModule|) 5081) ((|Asp35| . |CoercibleTo|) 5055) ((|PolynomialRing| . |AbelianMonoidRing|) 5034) ((|LocalAlgebra| . |SemiGroup|) T) ((|Mapping| . |SetCategory|) T) ((|MathMLFormat| . |BasicType|) T) ((|MachineFloat| . |BasicType|) T) ((|TextFile| . |CoercibleTo|) 5008) ((|SequentialDifferentialVariable| . |CoercibleTo|) 4982) ((|RewriteRule| . |CoercibleTo|) 4956) ((|PrimeField| . |Module|) 4910) ((|BinaryTournament| . |HomogeneousAggregate|) 4894) ((|NeitherSparseOrDensePowerSeries| . |InnerEvalable|) 4676) ((|LocalAlgebra| . |AbelianMonoid|) T) ((|FreeNilpotentLie| . |AbelianMonoid|) T) ((|KeyedAccessFile| . |CoercibleTo|) 4650) ((|Asp80| . |Type|) T) ((|KeyedAccessFile| . |ConvertibleTo|) NIL) ((|GeneralSparseTable| . |ConvertibleTo|) NIL) ((|GeneralSparseTable| . |CoercibleTo|) 4624) ((|FiniteFieldNormalBasis| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasis| . |AbelianGroup|) T) ((|DoubleFloatVector| . |HomogeneousAggregate|) 4597) ((|BinaryTree| . |Evalable|) 4521) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |SetCategory|) T) ((|IndexedDirectProductAbelianGroup| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |HomogeneousAggregate|) 4482) ((|BinarySearchTree| . |Evalable|) 4406) ((|InnerTaylorSeries| . |LeftModule|) 4393) ((|DoubleFloatMatrix| . |TwoDimensionalArrayCategory|) 4322) ((|ComplexDoubleFloatMatrix| . |TwoDimensionalArrayCategory|) 4225) ((|DoubleFloat| . |Ring|) T) ((|InnerSparseUnivariatePowerSeries| . |LeftModule|) 4122) ((|U8Vector| . |Evalable|) NIL) ((|Float| . |RadicalCategory|) T) ((|DoubleFloat| . |DivisionRing|) T) ((|DoubleFloat| . |DifferentialRing|) T) ((|SparseUnivariatePolynomialExpressions| . |BasicType|) T) ((|PrimitiveArray| . |ConvertibleTo|) 4058) ((|PrimitiveArray| . |CoercibleTo|) 3976) ((|PAdicInteger| . |Algebra|) 3963) ((|UnivariatePuiseuxSeriesConstructor| . |EntireRing|) 3902) ((|UnivariateLaurentSeriesConstructor| . |EntireRing|) 3841) ((|SingleInteger| . |GcdDomain|) T) ((|IndexCard| . |OrderedSet|) T) ((|Expression| . |SpecialFunctionCategory|) 3808) ((|Quaternion| . |CharacteristicZero|) 3771) ((|Quaternion| . |CharacteristicNonZero|) 3731) ((|MyExpression| . |CombinatorialOpsCategory|) T) ((|MyExpression| . |CombinatorialFunctionCategory|) T) ((|InnerAlgebraicNumber| . |Evalable|) 3718) ((|EqTable| . |TableAggregate|) 3697) ((|Pi| . |SemiGroup|) T) ((|PAdicRational| . |RightModule|) 3621) ((|LaurentPolynomial| . |BasicType|) T) ((|Tree| . |HomogeneousAggregate|) 3605) ((|DirectProductModule| . |Finite|) 3580) ((|DirectProductMatrixModule| . |Finite|) 3555) ((|SparseUnivariatePolynomialExpressions| . |ElementaryFunctionCategory|) 3506) ((|RomanNumeral| . |Ring|) T) ((|EqTable| . |BagAggregate|) 3448) ((|BasicStochasticDifferential| . |BasicType|) T) ((|BalancedPAdicRational| . |BasicType|) T) ((|AffineSpace| . |SetCategoryWithDegree|) T) ((|Polynomial| . |Ring|) T) ((|PAdicRational| . |BiModule|) 3323) ((|Pi| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Ring|) T) ((|RomanNumeral| . |DifferentialRing|) T) ((|Polynomial| . |FiniteAbelianMonoidRing|) 3275) ((|HomogeneousDistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 3196) ((|FiniteFieldExtensionByPolynomial| . |CommutativeRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CommutativeRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CommutativeRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |CommutativeRing|) 3049) ((|DistributedMultivariatePolynomial| . |CommutativeRing|) 2902) ((|PolynomialRing| . |RetractableTo|) 2746) ((|MonoidRing| . |RetractableTo|) 2717) ((|SExpressionOf| . |BasicType|) T) ((|SegmentBinding| . |CoercibleTo|) 2668) ((|ResidueRing| . |CoercibleTo|) 2642) ((|UnivariatePuiseuxSeries| . |LeftOreRing|) 2618) ((|UnivariateLaurentSeries| . |LeftOreRing|) 2594) ((|UnivariateTaylorSeriesCZero| . |PowerSeriesCategory|) 2529) ((|UnivariateTaylorSeries| . |Monoid|) T) ((|UnivariatePuiseuxSeries| . |Monoid|) T) ((|UnivariateLaurentSeries| . |Monoid|) T) ((|UnivariateLaurentSeries| . |OrderedAbelianGroup|) NIL) ((|UnivariateLaurentSeries| . |OrderedAbelianSemiGroup|) NIL) ((|PseudoAlgebraicClosureOfFiniteField| . |EntireRing|) T) ((|Complex| . |RightModule|) 2411) ((|PrimeField| . |CommutativeRing|) T) ((|NeitherSparseOrDensePowerSeries| . |EntireRing|) T) ((|UnivariateFormalPowerSeries| . |Monoid|) T) ((|WuWenTsunTriangularSet| . |Collection|) 2395) ((|RadicalFunctionField| . |FunctionFieldCategory|) 2369) ((|Queue| . |InnerEvalable|) 2288) ((|OrderedCompletion| . |OrderedSet|) 2258) ((|Integer| . |StepThrough|) T) ((|GeneralUnivariatePowerSeries| . |EntireRing|) 2197) ((|InnerTaylorSeries| . |Monoid|) T) ((|FreeGroup| . |CoercibleTo|) 2171) ((|FreeAbelianGroup| . |CoercibleTo|) 2145) ((|Factored| . |RetractableTo|) 1989) ((|InnerSparseUnivariatePowerSeries| . |Monoid|) T) ((|Fraction| . |OrderedSet|) 1916) ((|Complex| . |BiModule|) 1766) ((|PseudoAlgebraicClosureOfRationalNumber| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Rng|) T) ((|OnePointCompletion| . |CancellationAbelianMonoid|) 1701) ((|Multiset| . |Collection|) 1685) ((|Vector| . |Evalable|) 1609) ((|HexadecimalExpansion| . |EuclideanDomain|) T) ((|Float| . |CoercibleTo|) 1559) ((|IndexedList| . |RecursiveAggregate|) 1543) ((|Float| . |ConvertibleTo|) 1427) ((|DecimalExpansion| . |EuclideanDomain|) T) ((|CharacterClass| . |Collection|) 1402) ((|ModuleOperator| . |Eltable|) 1381) ((|SparseUnivariatePolynomialExpressions| . |Evalable|) 1368) ((|HexadecimalExpansion| . |RealConstant|) T) ((|InnerPAdicInteger| . |Algebra|) 1355) ((|Integer| . |Algebra|) 1342) ((|InnerAlgebraicNumber| . |Algebra|) 1296) ((|DoubleFloatVector| . |Eltable|) 1257) ((|ComplexDoubleFloatVector| . |Eltable|) 1206) ((|DecimalExpansion| . |RealConstant|) T) ((|PAdicRational| . |Ring|) T) ((|Operator| . |CoercibleTo|) 1180) ((|OppositeMonogenicLinearOperator| . |CoercibleTo|) 1154) ((|OpenMathError| . |CoercibleTo|) 1128) ((|OrderlyDifferentialPolynomial| . |PolynomialFactorizationExplicit|) 1078) ((|XRecursivePolynomial| . |SemiGroup|) T) ((|UnivariatePolynomial| . |RightModule|) 812) ((|UnivariateSkewPolynomial| . |RightModule|) 796) ((|PAdicRational| . |DivisionRing|) T) ((|PAdicRational| . |DifferentialRing|) NIL) ((|Matrix| . |Type|) T) ((|XRecursivePolynomial| . |AbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |LeftModule|) 693) ((|InnerTable| . |Type|) T) ((|Factored| . |FullyEvalableOver|) 677) ((|Interval| . |RightModule|) 664) ((|UnivariatePolynomial| . |BiModule|) 366) ((|MachineInteger| . |LinearlyExplicitRingOver|) 343) ((|UnivariateSkewPolynomial| . |BiModule|) 322) ((|FreeModule1| . |AbelianMonoid|) T) ((|Table| . |InnerEvalable|) 30)) 
\ No newline at end of file
+(((|Localize| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |InnerEvalable|) 224176) ((|DistributedMultivariatePolynomial| . |InnerEvalable|) 224080) ((|Interval| . |BiModule|) 224065) ((|IndexedExponents| . |AbelianMonoid|) T) ((|DataList| . |SetCategory|) 224002) ((|BalancedPAdicRational| . |Evalable|) 223886) ((|HashTable| . |InnerEvalable|) 223594) ((|MachineComplex| . |BasicType|) T) ((|SplittingTree| . |InnerEvalable|) 223456) ((|FreeNilpotentLie| . |CancellationAbelianMonoid|) T) ((|WuWenTsunTriangularSet| . |PolynomialSetCategory|) 223425) ((|DoubleFloatVector| . |OneDimensionalArrayAggregate|) 223398) ((|ComplexDoubleFloatVector| . |OneDimensionalArrayAggregate|) 223359) ((|IndexedVector| . |HomogeneousAggregate|) 223343) ((|OrderedFreeMonoid| . |OrderedMonoid|) T) ((|LocalAlgebra| . |CancellationAbelianMonoid|) T) ((|IndexedMatrix| . |TwoDimensionalArrayCategory|) 223271) ((|DoubleFloatVector| . |IndexedAggregate|) 223232) ((|ComplexDoubleFloatVector| . |IndexedAggregate|) 223181) ((|OneDimensionalArray| . |InnerEvalable|) 223100) ((|InnerIndexedTwoDimensionalArray| . |InnerEvalable|) 223019) ((|Factored| . |PartialDifferentialRing|) 222951) ((|Complex| . |Ring|) T) ((|IndexedFlexibleArray| . |InnerEvalable|) 222870) ((|IndexedTwoDimensionalArray| . |InnerEvalable|) 222789) ((|IndexedOneDimensionalArray| . |InnerEvalable|) 222708) ((|Octonion| . |RetractableTo|) 222385) ((|MachineFloat| . |Algebra|) 222339) ((|FiniteFieldCyclicGroup| . |FiniteFieldCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |StepThrough|) 222309) ((|Segment| . |SegmentCategory|) 222293) ((|Segment| . |SetCategory|) 222263) ((|Complex| . |DivisionRing|) 222197) ((|Complex| . |DifferentialRing|) 222120) ((|Segment| . |SegmentExpansionCategory|) 222067) ((|PAdicRationalConstructor| . |Eltable|) 222020) ((|DoubleFloat| . |OrderedCancellationAbelianMonoid|) T) ((|DoubleFloat| . |OrderedAbelianMonoid|) T) ((|MachineComplex| . |ElementaryFunctionCategory|) NIL) ((|SparseTable| . |TableAggregate|) 221999) ((|Fraction| . |QuotientFieldCategory|) 221983) ((|ProjectiveSpace| . |BasicType|) T) ((|MachineInteger| . |AbelianGroup|) T) ((|MachineInteger| . |AbelianSemiGroup|) T) ((|XDistributedPolynomial| . |LeftModule|) 221957) ((|U32Vector| . |Collection|) 221934) ((|U32Matrix| . |Type|) T) ((|SparseUnivariatePolynomialExpressions| . |Algebra|) 221674) ((|Expression| . |CombinatorialOpsCategory|) 221641) ((|Expression| . |CombinatorialFunctionCategory|) 221608) ((|SparseTable| . |BagAggregate|) 221550) ((|CardinalNumber| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |DifferentialExtension|) 221521) ((|BalancedPAdicInteger| . |AbelianGroup|) T) ((|BalancedPAdicInteger| . |AbelianSemiGroup|) T) ((|KeyedAccessFile| . |EltableAggregate|) 221494) ((|GeneralSparseTable| . |EltableAggregate|) 221473) ((|UnivariatePolynomial| . |Ring|) T) ((|UnivariateSkewPolynomial| . |Ring|) T) ((|Octonion| . |FullyEvalableOver|) 221457) ((|BalancedPAdicRational| . |StepThrough|) NIL) ((|ArrayStack| . |CoercibleTo|) 221408) ((|Pi| . |CancellationAbelianMonoid|) T) ((|UnivariatePolynomial| . |FiniteAbelianMonoidRing|) 221369) ((|IndexedString| . |Type|) T) ((|OrderlyDifferentialPolynomial| . |LeftOreRing|) 221287) ((|Interval| . |Ring|) T) ((|UnivariatePolynomial| . |DifferentialRing|) T) ((|Localize| . |Module|) 221271) ((|PrimitiveArray| . |EltableAggregate|) 221243) ((|NeitherSparseOrDensePowerSeries| . |HomogeneousAggregate|) 221184) ((|TwoDimensionalArray| . |Aggregate|) T) ((|RomanNumeral| . |OrderedCancellationAbelianMonoid|) T) ((|RomanNumeral| . |OrderedAbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |Monoid|) T) ((|MultivariatePolynomial| . |AbelianMonoidRing|) 221118) ((|LaurentPolynomial| . |Algebra|) 221105) ((|FiniteFieldExtensionByPolynomial| . |EntireRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |EntireRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |EntireRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |EntireRing|) 220991) ((|DistributedMultivariatePolynomial| . |EntireRing|) 220877) ((|RealClosure| . |BasicType|) T) ((|FractionalIdeal| . |Monoid|) T) ((|BalancedPAdicRational| . |Algebra|) 220793) ((|FractionalIdeal| . |Group|) T) ((|FiniteField| . |BasicType|) T) ((|TaylorSeries| . |Rng|) T) ((|ModularField| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |UnivariateTaylorSeriesCategory|) 220777) ((|UnivariateTaylorSeriesCZero| . |UnivariatePowerSeriesCategory|) 220738) ((|SparseUnivariateTaylorSeries| . |AbelianMonoidRing|) 220699) ((|SparseUnivariatePuiseuxSeries| . |AbelianMonoidRing|) 220658) ((|SparseUnivariateLaurentSeries| . |AbelianMonoidRing|) 220630) ((|Result| . |Collection|) 220563) ((|PrimeField| . |EntireRing|) T) ((|SparseMultivariateTaylorSeries| . |AbelianMonoidRing|) 220521) ((|MachineComplex| . |Evalable|) NIL) ((|InnerFreeAbelianMonoid| . |CoercibleTo|) 220495) ((|IndexedDirectProductOrderedAbelianMonoid| . |CoercibleTo|) 220469) ((|IndexedDirectProductAbelianMonoid| . |CoercibleTo|) 220443) ((|FlexibleArray| . |SetCategory|) 220380) ((|BlowUpWithHamburgerNoether| . |BasicType|) T) ((|ModMonic| . |GcdDomain|) 220275) ((|AlgebraicNumber| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Eltable|) 220260) ((|UnivariateLaurentSeriesConstructor| . |Eltable|) 220172) ((|List| . |ListAggregate|) 220156) ((|List| . |LinearAggregate|) 220140) ((|FortranExpression| . |AbelianGroup|) T) ((|FortranExpression| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |FiniteFieldCategory|) NIL) ((|PseudoAlgebraicClosureOfRationalNumber| . |SetCategory|) T) ((|ContinuedFraction| . |AbelianGroup|) T) ((|ContinuedFraction| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |SetCategory|) T) ((|List| . |FiniteLinearAggregate|) 220124) ((|IndexedVector| . |Eltable|) 220096) ((|FileName| . |BasicType|) T) ((|SingleInteger| . |CombinatorialFunctionCategory|) T) ((|BinaryTournament| . |CoercibleTo|) 220047) ((|Palette| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |FullyRetractableTo|) 220031) ((|ModuleOperator| . |CoercibleTo|) 220005) ((|XDistributedPolynomial| . |Monoid|) T) ((|DoubleFloatVector| . |CoercibleTo|) 219979) ((|DoubleFloatVector| . |ConvertibleTo|) 219954) ((|Color| . |CoercibleTo|) 219928) ((|ComplexDoubleFloatVector| . |CoercibleTo|) 219902) ((|ComplexDoubleFloatVector| . |ConvertibleTo|) 219815) ((|Commutator| . |CoercibleTo|) 219789) ((|Set| . |Aggregate|) T) ((|BlowUpWithHamburgerNoether| . |BlowUpMethodCategory|) T) ((|PAdicRational| . |OrderedCancellationAbelianMonoid|) NIL) ((|PAdicRational| . |OrderedAbelianMonoid|) NIL) ((|OrdSetInts| . |OrderedSet|) T) ((|MultivariatePolynomial| . |PatternMatchable|) NIL) ((|XRecursivePolynomial| . |CancellationAbelianMonoid|) T) ((|FreeModule1| . |CancellationAbelianMonoid|) T) ((|PermutationGroup| . |BasicType|) T) ((|MultivariatePolynomial| . |RetractableTo|) 219596) ((|IndexedExponents| . |CancellationAbelianMonoid|) T) ((|SequentialDifferentialPolynomial| . |FullyRetractableTo|) 219580) ((|Queue| . |HomogeneousAggregate|) 219564) ((|BalancedPAdicRational| . |FullyPatternMatchable|) 219523) ((|SparseUnivariateLaurentSeries| . |Type|) 219499) ((|NewSparseUnivariatePolynomial| . |FullyRetractableTo|) 219483) ((|NewSparseMultivariatePolynomial| . |FullyRetractableTo|) 219467) ((|Point| . |Aggregate|) T) ((|MachineComplex| . |StepThrough|) NIL) ((|DirectProductModule| . |LeftModule|) 219268) ((|DirectProductMatrixModule| . |LeftModule|) 219056) ((|OrdinaryDifferentialRing| . |PrincipalIdealDomain|) 219032) ((|GeneralDistributedMultivariatePolynomial| . |FullyRetractableTo|) 219016) ((|IndexedVector| . |OneDimensionalArrayAggregate|) 219000) ((|SquareFreeRegularTriangularSet| . |TriangularSetCategory|) 218969) ((|SparseUnivariateLaurentSeries| . |PatternMatchable|) NIL) ((|SparseUnivariateLaurentSeries| . |Patternable|) 218893) ((|IndexedVector| . |IndexedAggregate|) 218865) ((|Tree| . |CoercibleTo|) 218816) ((|Switch| . |CoercibleTo|) 218790) ((|Asp12| . |FortranProgramCategory|) T) ((|SparseUnivariatePuiseuxSeries| . |RetractableTo|) 218674) ((|SparseUnivariateLaurentSeries| . |RetractableTo|) 218615) ((|NeitherSparseOrDensePowerSeries| . |Eltable|) 218532) ((|MachineComplex| . |Algebra|) 218461) ((|GeneralUnivariatePowerSeries| . |Eltable|) 218446) ((|MultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 218430) ((|PseudoAlgebraicClosureOfRationalNumber| . |Module|) 218384) ((|LinearOrdinaryDifferentialOperator| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Module|) 218287) ((|UnivariatePuiseuxSeriesConstructor| . |RadicalCategory|) 218236) ((|UnivariateLaurentSeriesConstructor| . |RadicalCategory|) 218185) ((|RoutinesTable| . |TableAggregate|) 218155) ((|PAdicRationalConstructor| . |ConvertibleTo|) 217843) ((|PAdicRationalConstructor| . |CoercibleTo|) 217817) ((|Table| . |HomogeneousAggregate|) 217746) ((|Factored| . |RealConstant|) 217715) ((|AlgebraicNumber| . |Evalable|) 217702) ((|RoutinesTable| . |BagAggregate|) 217635) ((|HashTable| . |HomogeneousAggregate|) 217564) ((|IndexedList| . |Type|) T) ((|SplittingTree| . |HomogeneousAggregate|) 217525) ((|SparseUnivariateLaurentSeries| . |FullyEvalableOver|) 217449) ((|SparseUnivariateLaurentSeries| . |FullyLinearlyExplicitRingOver|) 217373) ((|FortranType| . |BasicType|) T) ((|SequentialDifferentialPolynomial| . |Rng|) T) ((|DirectProductModule| . |Aggregate|) T) ((|DirectProductMatrixModule| . |Aggregate|) T) ((|NeitherSparseOrDensePowerSeries| . |UnaryRecursiveAggregate|) 217314) ((|NewSparseUnivariatePolynomial| . |Rng|) T) ((|NewSparseMultivariatePolynomial| . |Rng|) T) ((|MultivariatePolynomial| . |PartialDifferentialRing|) 217274) ((|GeneralDistributedMultivariatePolynomial| . |Rng|) T) ((|NeitherSparseOrDensePowerSeries| . |IndexedAggregate|) 217203) ((|OneDimensionalArray| . |HomogeneousAggregate|) 217187) ((|ResidueRing| . |RightModule|) 217161) ((|Plcs| . |SetCategory|) T) ((|InnerIndexedTwoDimensionalArray| . |HomogeneousAggregate|) 217145) ((|IndexedFlexibleArray| . |HomogeneousAggregate|) 217129) ((|IndexedTwoDimensionalArray| . |HomogeneousAggregate|) 217113) ((|IndexedOneDimensionalArray| . |HomogeneousAggregate|) 217097) ((|MyUnivariatePolynomial| . |PrincipalIdealDomain|) 217073) ((|DataList| . |InnerEvalable|) 216992) ((|ResidueRing| . |BiModule|) 216959) ((|SparseUnivariateTaylorSeries| . |PartialDifferentialRing|) 216823) ((|DirichletRing| . |LeftModule|) 216770) ((|LieSquareMatrix| . |SemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |PartialDifferentialRing|) 216632) ((|SparseUnivariateLaurentSeries| . |PartialDifferentialRing|) 216378) ((|SparseMultivariateTaylorSeries| . |PartialDifferentialRing|) 216362) ((|FiniteField| . |StepThrough|) T) ((|FreeAbelianGroup| . |RightModule|) 216339) ((|DirectProductModule| . |OrderedAbelianGroup|) 216309) ((|DirectProductModule| . |OrderedAbelianSemiGroup|) 216233) ((|DirectProductModule| . |OrderedAbelianMonoidSup|) 216191) ((|DirectProductMatrixModule| . |OrderedAbelianGroup|) 216161) ((|DirectProductMatrixModule| . |OrderedAbelianSemiGroup|) 216085) ((|DirectProductMatrixModule| . |OrderedAbelianMonoidSup|) 216043) ((|AntiSymm| . |Rng|) T) ((|DirectProductModule| . |Monoid|) 215929) ((|DirectProductMatrixModule| . |Monoid|) 215815) ((|TaylorSeries| . |SetCategory|) T) ((|LieSquareMatrix| . |AbelianMonoid|) T) ((|InnerPrimeField| . |Rng|) T) ((|InnerFiniteField| . |Rng|) T) ((|Float| . |RightModule|) 215769) ((|FreeAbelianGroup| . |BiModule|) 215734) ((|Asp34| . |FortranMatrixCategory|) T) ((|Asp34| . |FortranProgramCategory|) T) ((|RealClosure| . |Algebra|) 215655) ((|MachineComplex| . |FullyPatternMatchable|) 215627) ((|Automorphism| . |BasicType|) T) ((|ModularField| . |SetCategory|) T) ((|RadicalFunctionField| . |CharacteristicNonZero|) 215574) ((|Float| . |BiModule|) 215501) ((|ExponentialOfUnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 215477) ((|GeneralUnivariatePowerSeries| . |RadicalCategory|) 215426) ((|FiniteField| . |Algebra|) 215380) ((|AlgebraicFunctionField| . |FiniteRankAlgebra|) 215346) ((|RadicalFunctionField| . |CharacteristicZero|) 215296) ((|BinaryTree| . |BinaryTreeCategory|) 215280) ((|BinarySearchTree| . |BinaryTreeCategory|) 215264) ((|Operator| . |RightModule|) 215221) ((|OnePointCompletion| . |AbelianGroup|) 215156) ((|OppositeMonogenicLinearOperator| . |RightModule|) 215140) ((|OnePointCompletion| . |AbelianSemiGroup|) 215075) ((|ExponentialOfUnivariatePuiseuxSeries| . |IntegralDomain|) 215014) ((|Integer| . |OpenMath|) T) ((|DirectProduct| . |Type|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |CommutativeRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CommutativeRing|) T) ((|Operator| . |BiModule|) 214966) ((|OppositeMonogenicLinearOperator| . |BiModule|) 214945) ((|UnivariatePuiseuxSeriesConstructor| . |CoercibleTo|) 214919) ((|UnivariateLaurentSeriesConstructor| . |CoercibleTo|) 214893) ((|UnivariateLaurentSeriesConstructor| . |ConvertibleTo|) 214436) ((|SparseUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 214386) ((|SparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 214336) ((|AlgebraicNumber| . |Algebra|) 214290) ((|XPolynomial| . |SemiGroup|) T) ((|IndexedVector| . |CoercibleTo|) 214208) ((|IndexedVector| . |ConvertibleTo|) 214144) ((|XPBWPolynomial| . |SemiGroup|) T) ((|DirectProduct| . |RetractableTo|) 213895) ((|SparseUnivariatePolynomial| . |LeftModule|) 213792) ((|SparseMultivariatePolynomial| . |LeftModule|) 213689) ((|MoebiusTransform| . |CoercibleTo|) 213663) ((|SparseUnivariateSkewPolynomial| . |LeftModule|) 213637) ((|XPolynomial| . |AbelianMonoid|) T) ((|XPBWPolynomial| . |AbelianMonoid|) T) ((|SparseUnivariatePolynomialExpressions| . |DifferentialExtension|) 213621) ((|ResidueRing| . |Ring|) T) ((|Table| . |Eltable|) 213600) ((|Complex| . |Finite|) 213533) ((|RadixExpansion| . |Type|) T) ((|AlgebraGivenByStructuralConstants| . |AbelianMonoid|) T) ((|IntegerMod| . |BasicType|) T) ((|TaylorSeries| . |Module|) 213377) ((|HashTable| . |Eltable|) 213356) ((|IntegrationResult| . |SetCategory|) T) ((|TexFormat| . |SetCategory|) T) ((|SquareFreeRegularTriangularSet| . |SquareFreeRegularTriangularSetCategory|) 213325) ((|SExpression| . |SExpressionCategory|) 213249) ((|FreeNilpotentLie| . |AbelianGroup|) T) ((|FreeNilpotentLie| . |AbelianSemiGroup|) T) ((|CliffordAlgebra| . |SemiGroup|) T) ((|RadixExpansion| . |RetractableTo|) 213193) ((|RadixExpansion| . |Patternable|) 213170) ((|RadixExpansion| . |PatternMatchable|) 213147) ((|MyExpression| . |BasicType|) T) ((|DirichletRing| . |Monoid|) T) ((|LaurentPolynomial| . |DifferentialExtension|) 213131) ((|LocalAlgebra| . |AbelianGroup|) T) ((|EuclideanModularRing| . |IntegralDomain|) T) ((|LocalAlgebra| . |AbelianSemiGroup|) T) ((|ModularField| . |Module|) 213085) ((|Float| . |Ring|) T) ((|DirectProduct| . |FullyLinearlyExplicitRingOver|) 213053) ((|DoubleFloatVector| . |EltableAggregate|) 213014) ((|ComplexDoubleFloatVector| . |EltableAggregate|) 212963) ((|DeRhamComplex| . |Rng|) T) ((|BalancedPAdicRational| . |DifferentialExtension|) 212922) ((|OneDimensionalArray| . |Eltable|) 212894) ((|CliffordAlgebra| . |AbelianMonoid|) T) ((|IndexedFlexibleArray| . |Eltable|) 212866) ((|FlexibleArray| . |InnerEvalable|) 212785) ((|IndexedOneDimensionalArray| . |Eltable|) 212757) ((|Float| . |DivisionRing|) T) ((|Float| . |DifferentialRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 212731) ((|Operator| . |Ring|) T) ((|OppositeMonogenicLinearOperator| . |Ring|) T) ((|NeitherSparseOrDensePowerSeries| . |CoercibleTo|) 212705) ((|NeitherSparseOrDensePowerSeries| . |ConvertibleTo|) NIL) ((|ModMonic| . |PolynomialCategory|) 212640) ((|MachineInteger| . |OrderedSet|) T) ((|GeneralUnivariatePowerSeries| . |CoercibleTo|) 212614) ((|OppositeMonogenicLinearOperator| . |DifferentialRing|) 212579) ((|CardinalNumber| . |OrderedSet|) T) ((|U16Matrix| . |Type|) T) ((|LinearOrdinaryDifferentialOperator| . |SetCategory|) T) ((|Table| . |IndexedAggregate|) 212558) ((|InnerTable| . |TableAggregate|) 212537) ((|FiniteDivisor| . |SetCategory|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Field|) 212513) ((|Fraction| . |CharacteristicZero|) 212476) ((|Fraction| . |CharacteristicNonZero|) 212436) ((|U16Vector| . |Collection|) 212413) ((|Divisor| . |SetCategory|) T) ((|Product| . |SemiGroup|) 212301) ((|DirectProduct| . |PartialDifferentialRing|) 212205) ((|OrderedDirectProduct| . |SemiGroup|) 212091) ((|LinearOrdinaryDifferentialOperator2| . |UnivariateSkewPolynomialCategory|) 212075) ((|HashTable| . |IndexedAggregate|) 212054) ((|InnerTable| . |BagAggregate|) 211996) ((|RadixExpansion| . |FullyLinearlyExplicitRingOver|) 211973) ((|RadixExpansion| . |FullyEvalableOver|) 211950) ((|Symbol| . |CoercibleTo|) 211924) ((|SparseUnivariatePolynomial| . |LeftOreRing|) 211819) ((|AttributeButtons| . |SetCategory|) T) ((|Product| . |AbelianMonoid|) 211499) ((|Pi| . |AbelianGroup|) T) ((|Pi| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |AbelianMonoid|) 211302) ((|SparseMultivariatePolynomial| . |LeftOreRing|) 211220) ((|OneDimensionalArray| . |OneDimensionalArrayAggregate|) 211204) ((|Symbol| . |ConvertibleTo|) 211098) ((|SparseUnivariatePolynomial| . |Monoid|) T) ((|SparseMultivariatePolynomial| . |Monoid|) T) ((|IndexedFlexibleArray| . |OneDimensionalArrayAggregate|) 211082) ((|IndexedOneDimensionalArray| . |OneDimensionalArrayAggregate|) 211066) ((|OneDimensionalArray| . |IndexedAggregate|) 211038) ((|SequentialDifferentialPolynomial| . |SetCategory|) T) ((|PendantTree| . |BasicType|) 211008) ((|SparseUnivariateSkewPolynomial| . |Monoid|) T) ((|NewSparseUnivariatePolynomial| . |SetCategory|) T) ((|IndexedFlexibleArray| . |IndexedAggregate|) 210980) ((|IndexedOneDimensionalArray| . |IndexedAggregate|) 210952) ((|NewSparseMultivariatePolynomial| . |SetCategory|) T) ((|NewSparseMultivariatePolynomial| . |RecursivePolynomialCategory|) 210905) ((|GeneralModulePolynomial| . |SetCategory|) T) ((|GeneralDistributedMultivariatePolynomial| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |BasicType|) T) ((|IntegrationResult| . |Module|) 210869) ((|DesingTree| . |BasicType|) 210839) ((|ListMonoidOps| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |ElementaryFunctionCategory|) 210788) ((|UnivariateTaylorSeries| . |AbelianMonoidRing|) 210749) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |BasicType|) T) ((|UnivariatePuiseuxSeries| . |AbelianMonoidRing|) 210708) ((|RadixExpansion| . |PartialDifferentialRing|) NIL) ((|UnivariateLaurentSeries| . |AbelianMonoidRing|) 210680) ((|LieExponentials| . |SemiGroup|) T) ((|LieSquareMatrix| . |CancellationAbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |AbelianMonoidRing|) 210641) ((|TaylorSeries| . |CommutativeRing|) 210570) ((|SparseUnivariatePuiseuxSeries| . |EuclideanDomain|) 210546) ((|SparseUnivariateLaurentSeries| . |EuclideanDomain|) 210522) ((|SimpleAlgebraicExtension| . |UniqueFactorizationDomain|) 210456) ((|ExtAlgBasis| . |SetCategory|) T) ((|Asp78| . |FortranVectorFunctionCategory|) T) ((|Asp78| . |FortranProgramCategory|) T) ((|SimpleAlgebraicExtension| . |IntegralDomain|) 210390) ((|NottinghamGroup| . |CoercibleTo|) 210364) ((|AntiSymm| . |SetCategory|) T) ((|ModularField| . |CommutativeRing|) T) ((|InnerSparseUnivariatePowerSeries| . |AbelianMonoidRing|) 210336) ((|DoubleFloat| . |LeftModule|) 210290) ((|InnerPrimeField| . |SetCategory|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|InnerFiniteField| . |SetCategory|) T) ((|FiniteFieldExtension| . |UniqueFactorizationDomain|) T) ((|FiniteFieldNormalBasisExtension| . |UniqueFactorizationDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |UniqueFactorizationDomain|) T) ((|HexadecimalExpansion| . |OrderedIntegralDomain|) T) ((|HexadecimalExpansion| . |PrincipalIdealDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |SemiGroup|) T) ((|BinaryExpansion| . |UniqueFactorizationDomain|) T) ((|MyExpression| . |Evalable|) 210277) ((|FortranExpression| . |OrderedSet|) T) ((|DecimalExpansion| . |PrincipalIdealDomain|) T) ((|DecimalExpansion| . |OrderedIntegralDomain|) T) ((|ModuleOperator| . |RightModule|) 210234) ((|FiniteFieldExtension| . |IntegralDomain|) T) ((|FiniteFieldNormalBasisExtension| . |IntegralDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |IntegralDomain|) T) ((|BinaryExpansion| . |IntegralDomain|) T) ((|SparseUnivariateLaurentSeries| . |RealConstant|) NIL) ((|LinearOrdinaryDifferentialOperator| . |Module|) 210191) ((|PseudoAlgebraicClosureOfRationalNumber| . |EntireRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |EntireRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|Asp27| . |Type|) T) ((|Queue| . |CoercibleTo|) 210142) ((|MachineComplex| . |DifferentialExtension|) 210114) ((|Divisor| . |Module|) 210091) ((|ModuleOperator| . |BiModule|) 210043) ((|List| . |Aggregate|) T) ((|DataList| . |HomogeneousAggregate|) 210027) ((|Set| . |SetAggregate|) 210011) ((|SubSpaceComponentProperty| . |SetCategory|) T) ((|Polynomial| . |PolynomialFactorizationExplicit|) 209961) ((|HomogeneousDistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 209911) ((|XRecursivePolynomial| . |AbelianGroup|) T) ((|XRecursivePolynomial| . |AbelianSemiGroup|) T) ((|XPolynomial| . |CancellationAbelianMonoid|) T) ((|XPBWPolynomial| . |CancellationAbelianMonoid|) T) ((|SequentialDifferentialPolynomial| . |Module|) 209674) ((|RomanNumeral| . |LeftModule|) 209661) ((|Polynomial| . |LeftModule|) 209558) ((|NewSparseUnivariatePolynomial| . |Module|) 209298) ((|InputForm| . |CoercibleTo|) 209272) ((|InputForm| . |ConvertibleTo|) 209245) ((|NewSparseMultivariatePolynomial| . |Module|) 209008) ((|WuWenTsunTriangularSet| . |BasicType|) T) ((|Ruleset| . |BasicType|) T) ((|FreeModule1| . |AbelianSemiGroup|) T) ((|FreeModule1| . |AbelianGroup|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |LeftModule|) 208905) ((|GeneralModulePolynomial| . |Module|) 208876) ((|GeneralDistributedMultivariatePolynomial| . |Module|) 208639) ((|QuasiAlgebraicSet| . |BasicType|) T) ((|Multiset| . |BasicType|) T) ((|IntegerMod| . |StepThrough|) T) ((|Variable| . |CoercibleTo|) 208594) ((|IndexedExponents| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeries| . |Type|) 208570) ((|UnivariatePuiseuxSeries| . |RetractableTo|) 208466) ((|UnivariateLaurentSeries| . |PatternMatchable|) NIL) ((|UnivariateLaurentSeries| . |Patternable|) 208396) ((|CharacterClass| . |BasicType|) T) ((|AlgebraGivenByStructuralConstants| . |CancellationAbelianMonoid|) T) ((|Table| . |ConvertibleTo|) NIL) ((|Table| . |CoercibleTo|) 208370) ((|SquareMatrix| . |SquareMatrixCategory|) 208293) ((|FiniteFieldCyclicGroup| . |Rng|) T) ((|LiePolynomial| . |CoercibleTo|) 208267) ((|EuclideanModularRing| . |SemiGroup|) T) ((|FiniteFieldExtensionByPolynomial| . |CoercibleTo|) 208241) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CoercibleTo|) 208215) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CoercibleTo|) 208189) ((|DifferentialSparseMultivariatePolynomial| . |ConvertibleTo|) 207796) ((|DifferentialSparseMultivariatePolynomial| . |CoercibleTo|) 207770) ((|DistributedMultivariatePolynomial| . |CoercibleTo|) 207744) ((|DistributedMultivariatePolynomial| . |ConvertibleTo|) 207522) ((|RegularChain| . |TriangularSetCategory|) 207357) ((|PendantTree| . |Evalable|) 207281) ((|UnivariateLaurentSeries| . |RetractableTo|) 207228) ((|TaylorSeries| . |InnerEvalable|) 207192) ((|SplittingTree| . |CoercibleTo|) 207166) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 207140) ((|OrderedFreeMonoid| . |Monoid|) T) ((|InnerPrimeField| . |Module|) 207094) ((|IndexedVector| . |EltableAggregate|) 207066) ((|InnerFiniteField| . |Module|) 206987) ((|HashTable| . |ConvertibleTo|) NIL) ((|HashTable| . |CoercibleTo|) 206961) ((|Expression| . |BasicType|) T) ((|DesingTree| . |Evalable|) 206885) ((|ExponentialExpansion| . |BasicType|) T) ((|EuclideanModularRing| . |AbelianMonoid|) T) ((|CliffordAlgebra| . |CancellationAbelianMonoid|) T) ((|PrimeField| . |CoercibleTo|) 206859) ((|PrimeField| . |ConvertibleTo|) 206836) ((|FreeMonoid| . |Monoid|) T) ((|PAdicRationalConstructor| . |RightModule|) 206777) ((|PAdicRationalConstructor| . |BiModule|) 206686) ((|DoubleFloat| . |LeftOreRing|) T) ((|MyExpression| . |Algebra|) 206574) ((|CartesianTensor| . |BasicType|) T) ((|BasicOperator| . |BasicType|) T) ((|ModMonic| . |UnivariatePolynomialCategory|) 206558) ((|ModuleOperator| . |Ring|) T) ((|MachineComplex| . |FiniteFieldCategory|) NIL) ((|InnerIndexedTwoDimensionalArray| . |CoercibleTo|) 206509) ((|Float| . |OrderedCancellationAbelianMonoid|) T) ((|DeRhamComplex| . |SetCategory|) T) ((|Float| . |OrderedAbelianMonoid|) T) ((|DoubleFloat| . |OrderedAbelianSemiGroup|) T) ((|DoubleFloat| . |OrderedAbelianGroup|) T) ((|OneDimensionalArray| . |ConvertibleTo|) 206445) ((|OneDimensionalArray| . |CoercibleTo|) 206363) ((|DoubleFloat| . |Monoid|) T) ((|IndexedFlexibleArray| . |ConvertibleTo|) 206299) ((|IndexedFlexibleArray| . |CoercibleTo|) 206217) ((|IndexedTwoDimensionalArray| . |CoercibleTo|) 206168) ((|IndexedOneDimensionalArray| . |ConvertibleTo|) 206104) ((|IndexedOneDimensionalArray| . |CoercibleTo|) 206022) ((|SimpleAlgebraicExtension| . |Field|) 205956) ((|AlgebraicFunctionField| . |FullyRetractableTo|) 205927) ((|Asp49| . |Type|) T) ((|BlowUpWithQuadTrans| . |BasicType|) T) ((|ProjectivePlane| . |ProjectiveSpaceCategory|) 205911) ((|PAdicRational| . |PolynomialFactorizationExplicit|) NIL) ((|FiniteFieldExtension| . |FiniteAlgebraicExtensionField|) 205895) ((|FiniteFieldExtension| . |Field|) T) ((|FiniteFieldNormalBasisExtension| . |FiniteAlgebraicExtensionField|) 205879) ((|FiniteFieldNormalBasisExtension| . |Field|) T) ((|FiniteFieldCyclicGroupExtension| . |FiniteAlgebraicExtensionField|) 205863) ((|FiniteFieldCyclicGroupExtension| . |Field|) T) ((|Expression| . |ElementaryFunctionCategory|) 205830) ((|BinaryExpansion| . |Field|) T) ((|Asp30| . |Type|) T) ((|UnivariateLaurentSeries| . |FullyEvalableOver|) 205760) ((|PAdicRational| . |LeftModule|) 205684) ((|UnivariateLaurentSeries| . |FullyLinearlyExplicitRingOver|) 205614) ((|Product| . |CancellationAbelianMonoid|) 205362) ((|OrderedDirectProduct| . |CancellationAbelianMonoid|) 205165) ((|RomanNumeral| . |LeftOreRing|) T) ((|PrimitiveArray| . |LinearAggregate|) 205149) ((|Polynomial| . |LeftOreRing|) 205067) ((|SequentialDifferentialPolynomial| . |CommutativeRing|) 204920) ((|RomanNumeral| . |OrderedAbelianSemiGroup|) T) ((|RomanNumeral| . |OrderedAbelianGroup|) T) ((|PrimitiveArray| . |FiniteLinearAggregate|) 204904) ((|BlowUpWithQuadTrans| . |BlowUpMethodCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |LeftOreRing|) 204822) ((|NeitherSparseOrDensePowerSeries| . |EltableAggregate|) 204751) ((|NewSparseUnivariatePolynomial| . |CommutativeRing|) 204581) ((|NewSparseMultivariatePolynomial| . |CommutativeRing|) 204434) ((|OrderlyDifferentialPolynomial| . |AbelianMonoidRing|) 204354) ((|RomanNumeral| . |Monoid|) T) ((|FlexibleArray| . |HomogeneousAggregate|) 204338) ((|Polynomial| . |Monoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |CommutativeRing|) 204191) ((|DataList| . |Eltable|) 204163) ((|HomogeneousDistributedMultivariatePolynomial| . |Monoid|) T) ((|WuWenTsunTriangularSet| . |Evalable|) 204087) ((|UnivariateTaylorSeriesCZero| . |Algebra|) 203931) ((|UnivariateTaylorSeries| . |PartialDifferentialRing|) 203795) ((|UnivariatePuiseuxSeries| . |PartialDifferentialRing|) 203657) ((|UnivariatePuiseuxSeriesConstructor| . |RightModule|) 203439) ((|UnivariateLaurentSeries| . |PartialDifferentialRing|) 203191) ((|UnivariateLaurentSeriesConstructor| . |RightModule|) 202943) ((|UnivariateFormalPowerSeries| . |PartialDifferentialRing|) 202807) ((|U32Vector| . |BasicType|) T) ((|TaylorSeries| . |EntireRing|) 202774) ((|SquareFreeRegularTriangularSet| . |Collection|) 202758) ((|RuleCalled| . |BasicType|) T) ((|Plot| . |PlottablePlaneCurveCategory|) T) ((|Multiset| . |Evalable|) 202682) ((|Asp41| . |Type|) T) ((|Complex| . |PolynomialFactorizationExplicit|) 202593) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|LiePolynomial| . |FreeModuleCat|) 202557) ((|PlaneAlgebraicCurvePlot| . |PlottablePlaneCurveCategory|) T) ((|Mapping| . |CoercibleTo|) 202531) ((|SingleInteger| . |BasicType|) T) ((|SimpleAlgebraicExtension| . |AbelianMonoid|) T) ((|AntiSymm| . |LeftAlgebra|) 202515) ((|SimpleAlgebraicExtension| . |SemiGroup|) T) ((|RadicalFunctionField| . |FramedAlgebra|) 202481) ((|InnerSparseUnivariatePowerSeries| . |PartialDifferentialRing|) 202356) ((|FunctionCalled| . |BasicType|) T) ((|CharacterClass| . |Evalable|) NIL) ((|PAdicRationalConstructor| . |Ring|) T) ((|OnePointCompletion| . |OrderedSet|) 202326) ((|Asp6| . |Type|) T) ((|ModularField| . |EntireRing|) T) ((|AlgebraicFunctionField| . |Rng|) T) ((|InnerPrimeField| . |CommutativeRing|) T) ((|InnerFiniteField| . |CommutativeRing|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |CoercibleTo|) 202300) ((|Complex| . |LeftModule|) 202182) ((|IndexedDirectProductAbelianGroup| . |CoercibleTo|) 202156) ((|FiniteFieldNormalBasis| . |CharacteristicZero|) 202122) ((|FiniteFieldNormalBasis| . |CharacteristicNonZero|) T) ((|FiniteFieldExtension| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |SemiGroup|) T) ((|FiniteFieldCyclicGroupExtension| . |SemiGroup|) T) ((|RadixExpansion| . |EuclideanDomain|) T) ((|PartialFraction| . |EuclideanDomain|) T) ((|PAdicRationalConstructor| . |DivisionRing|) T) ((|BinaryExpansion| . |SemiGroup|) T) ((|PAdicRationalConstructor| . |DifferentialRing|) 202087) ((|MyExpression| . |FullyPatternMatchable|) 202071) ((|UnivariatePuiseuxSeriesConstructor| . |BiModule|) 201821) ((|UnivariateLaurentSeriesConstructor| . |BiModule|) 201536) ((|DataList| . |UnaryRecursiveAggregate|) 201520) ((|Integer| . |OrderedRing|) T) ((|FiniteFieldExtension| . |AbelianMonoid|) T) ((|FiniteField| . |FiniteFieldCategory|) T) ((|Expression| . |Evalable|) 201507) ((|ExponentialExpansion| . |Evalable|) 201259) ((|FiniteFieldNormalBasisExtension| . |AbelianMonoid|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtension| . |AbelianMonoid|) T) ((|RadixExpansion| . |RealConstant|) T) ((|BinaryExpansion| . |AbelianMonoid|) T) ((|DataList| . |IndexedAggregate|) 201231) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Algebra|) 200987) ((|UnivariatePolynomial| . |PolynomialFactorizationExplicit|) 200937) ((|Boolean| . |SetCategory|) T) ((|PAdicRational| . |LeftOreRing|) T) ((|Result| . |BasicType|) T) ((|UnivariatePolynomial| . |LeftModule|) 200834) ((|PAdicRational| . |OrderedAbelianSemiGroup|) NIL) ((|UnivariateSkewPolynomial| . |LeftModule|) 200808) ((|PAdicRational| . |OrderedAbelianGroup|) NIL) ((|OrderlyDifferentialPolynomial| . |PatternMatchable|) NIL) ((|PAdicRational| . |Monoid|) T) ((|SequentialDifferentialPolynomial| . |InnerEvalable|) 200577) ((|NewSparseUnivariatePolynomial| . |InnerEvalable|) 200487) ((|NewSparseMultivariatePolynomial| . |InnerEvalable|) 200439) ((|Interval| . |LeftModule|) 200426) ((|OrderlyDifferentialPolynomial| . |RetractableTo|) 200143) ((|GeneralDistributedMultivariatePolynomial| . |InnerEvalable|) 200047) ((|FileName| . |FileNameCategory|) T) ((|TwoDimensionalArray| . |Type|) T) ((|LocalAlgebra| . |OrderedSet|) 200017) ((|IndexedBits| . |Logic|) T) ((|SquareFreeRegularTriangularSet| . |PolynomialSetCategory|) 199986) ((|PseudoAlgebraicClosureOfFiniteField| . |RightModule|) 199927) ((|NeitherSparseOrDensePowerSeries| . |RightModule|) 199868) ((|RadicalFunctionField| . |GcdDomain|) T) ((|MachineFloat| . |OrderedRing|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedAbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |RightModule|) 199650) ((|FiniteFieldCyclicGroup| . |SetCategory|) T) ((|ExponentialExpansion| . |StepThrough|) NIL) ((|EuclideanModularRing| . |CancellationAbelianMonoid|) T) ((|ScriptFormulaFormat| . |SetCategory|) T) ((|PAdicInteger| . |Rng|) T) ((|MachineComplex| . |FiniteRankAlgebra|) 199574) ((|PseudoAlgebraicClosureOfFiniteField| . |BiModule|) 199483) ((|NeitherSparseOrDensePowerSeries| . |BiModule|) 199392) ((|DeRhamComplex| . |LeftAlgebra|) 199361) ((|Complex| . |LeftOreRing|) 199262) ((|FlexibleArray| . |Eltable|) 199234) ((|U32Vector| . |Evalable|) NIL) ((|GeneralUnivariatePowerSeries| . |BiModule|) 198984) ((|UnivariatePuiseuxSeriesConstructor| . |Ring|) T) ((|UnivariateLaurentSeriesConstructor| . |Ring|) T) ((|OrderlyDifferentialPolynomial| . |FullyLinearlyExplicitRingOver|) 198968) ((|Complex| . |Monoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |DivisionRing|) 198944) ((|UnivariatePuiseuxSeriesConstructor| . |DifferentialRing|) 198879) ((|UnivariateLaurentSeriesConstructor| . |DifferentialRing|) 198759) ((|UnivariateLaurentSeriesConstructor| . |DivisionRing|) 198735) ((|RadicalFunctionField| . |FieldOfPrimeCharacteristic|) NIL) ((|LieSquareMatrix| . |LinearlyExplicitRingOver|) 198651) ((|Expression| . |Algebra|) 198513) ((|ExponentialExpansion| . |Algebra|) 198385) ((|Asp29| . |CoercibleTo|) 198359) ((|ExponentialOfUnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 198308) ((|Table| . |EltableAggregate|) 198287) ((|SplitHomogeneousDirectProduct| . |SemiGroup|) 198173) ((|Asp74| . |Type|) T) ((|Asp10| . |CoercibleTo|) 198147) ((|HashTable| . |EltableAggregate|) 198126) ((|XDistributedPolynomial| . |RetractableTo|) 198088) ((|SubSpace| . |SetCategory|) T) ((|SplitHomogeneousDirectProduct| . |AbelianMonoid|) 197891) ((|UnivariatePolynomial| . |LeftOreRing|) 197786) ((|OrderlyDifferentialPolynomial| . |PartialDifferentialRing|) 197667) ((|UnivariatePolynomial| . |Monoid|) T) ((|Set| . |Type|) T) ((|SequentialDifferentialPolynomial| . |EntireRing|) 197553) ((|PoincareBirkhoffWittLyndonBasis| . |BasicType|) T) ((|NewSparseUnivariatePolynomial| . |EntireRing|) 197416) ((|Interval| . |LeftOreRing|) T) ((|FlexibleArray| . |OneDimensionalArrayAggregate|) 197400) ((|OneDimensionalArray| . |EltableAggregate|) 197372) ((|NewSparseMultivariatePolynomial| . |EntireRing|) 197258) ((|UnivariateSkewPolynomial| . |Monoid|) T) ((|BalancedPAdicRational| . |OrderedRing|) NIL) ((|IndexedFlexibleArray| . |EltableAggregate|) 197230) ((|FlexibleArray| . |IndexedAggregate|) 197202) ((|IndexedOneDimensionalArray| . |EltableAggregate|) 197174) ((|GeneralDistributedMultivariatePolynomial| . |EntireRing|) 197060) ((|Result| . |Evalable|) 196866) ((|Interval| . |Monoid|) T) ((|Localize| . |CoercibleTo|) 196840) ((|DataList| . |ConvertibleTo|) 196776) ((|DataList| . |CoercibleTo|) 196694) ((|Stack| . |Aggregate|) T) ((|Point| . |Type|) T) ((|FiniteFieldCyclicGroup| . |Module|) 196620) ((|PseudoAlgebraicClosureOfFiniteField| . |Ring|) T) ((|NeitherSparseOrDensePowerSeries| . |Ring|) T) ((|LieSquareMatrix| . |AbelianSemiGroup|) T) ((|LieSquareMatrix| . |AbelianGroup|) T) ((|SingleInteger| . |StepThrough|) T) ((|GeneralUnivariatePowerSeries| . |Ring|) T) ((|AssociatedLieAlgebra| . |FramedNonAssociativeAlgebra|) 196560) ((|AssociatedJordanAlgebra| . |FramedNonAssociativeAlgebra|) 196500) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |DifferentialRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |DivisionRing|) T) ((|NeitherSparseOrDensePowerSeries| . |DifferentialRing|) 196448) ((|NeitherSparseOrDensePowerSeries| . |DivisionRing|) T) ((|InnerPrimeField| . |EntireRing|) T) ((|InnerFiniteField| . |EntireRing|) T) ((|UnivariatePuiseuxSeries| . |EuclideanDomain|) 196424) ((|GeneralUnivariatePowerSeries| . |DifferentialRing|) 196359) ((|GeneralUnivariatePowerSeries| . |DivisionRing|) 196335) ((|UnivariateLaurentSeries| . |EuclideanDomain|) 196311) ((|SimpleAlgebraicExtension| . |CancellationAbelianMonoid|) T) ((|PAdicRationalConstructor| . |OrderedCancellationAbelianMonoid|) 196271) ((|Character| . |BasicType|) T) ((|AlgebraicFunctionField| . |SetCategory|) T) ((|PAdicRationalConstructor| . |OrderedAbelianMonoid|) 196231) ((|List| . |RecursiveAggregate|) 196215) ((|InnerPAdicInteger| . |Rng|) T) ((|Integer| . |Rng|) T) ((|InnerAlgebraicNumber| . |Rng|) T) ((|Fraction| . |GcdDomain|) T) ((|FiniteFieldExtension| . |CancellationAbelianMonoid|) T) ((|Expression| . |FullyPatternMatchable|) 196199) ((|ExponentialExpansion| . |FullyPatternMatchable|) 196114) ((|FiniteFieldNormalBasisExtension| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtension| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeries| . |RealConstant|) NIL) ((|Segment| . |CoercibleTo|) 196065) ((|BinaryExpansion| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |Algebra|) 196052) ((|PositiveInteger| . |SetCategory|) T) ((|NonNegativeInteger| . |SetCategory|) T) ((|LyndonWord| . |SetCategory|) T) ((|MachineInteger| . |CharacteristicZero|) T) ((|SparseUnivariatePolynomialExpressions| . |FullyRetractableTo|) 196036) ((|BalancedPAdicInteger| . |CharacteristicZero|) T) ((|XPolynomial| . |AbelianGroup|) T) ((|XPolynomial| . |AbelianSemiGroup|) T) ((|XPBWPolynomial| . |AbelianGroup|) T) ((|XPBWPolynomial| . |AbelianSemiGroup|) T) ((|LiePolynomial| . |RightModule|) 196020) ((|IndexedExponents| . |OrderedSet|) T) ((|IndexedBits| . |OrderedSet|) T) ((|FiniteFieldExtensionByPolynomial| . |RightModule|) 195961) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |RightModule|) 195902) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |RightModule|) 195843) ((|DirectProductModule| . |Type|) T) ((|DirectProductMatrixModule| . |Type|) T) ((|DifferentialSparseMultivariatePolynomial| . |RightModule|) 195600) ((|DistributedMultivariatePolynomial| . |RightModule|) 195357) ((|LiePolynomial| . |BiModule|) 195336) ((|FiniteFieldExtensionByPolynomial| . |BiModule|) 195245) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |BiModule|) 195154) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |BiModule|) 195063) ((|DifferentialSparseMultivariatePolynomial| . |BiModule|) 194788) ((|DistributedMultivariatePolynomial| . |BiModule|) 194513) ((|OrdinaryDifferentialRing| . |UniqueFactorizationDomain|) 194489) ((|LaurentPolynomial| . |FullyRetractableTo|) 194473) ((|AlgebraGivenByStructuralConstants| . |AbelianGroup|) T) ((|AlgebraGivenByStructuralConstants| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |LinearlyExplicitRingOver|) 194345) ((|OrdinaryDifferentialRing| . |IntegralDomain|) 194321) ((|DirectProductModule| . |RetractableTo|) 194072) ((|DirectProductMatrixModule| . |RetractableTo|) 193823) ((|BinaryTournament| . |BinaryRecursiveAggregate|) 193807) ((|PrimeField| . |RightModule|) 193761) ((|MachineFloat| . |Rng|) T) ((|ModMonic| . |BasicType|) T) ((|DoubleFloatVector| . |LinearAggregate|) 193734) ((|ComplexDoubleFloatVector| . |LinearAggregate|) 193695) ((|FiniteFieldCyclicGroup| . |CommutativeRing|) T) ((|DoubleFloatVector| . |FiniteLinearAggregate|) 193668) ((|ComplexDoubleFloatVector| . |FiniteLinearAggregate|) 193629) ((|CliffordAlgebra| . |AbelianGroup|) T) ((|CliffordAlgebra| . |AbelianSemiGroup|) T) ((|Asp8| . |CoercibleTo|) 193603) ((|PrimeField| . |BiModule|) 193530) ((|AlgebraicFunctionField| . |Module|) 193458) ((|PAdicInteger| . |SetCategory|) T) ((|FlexibleArray| . |ConvertibleTo|) 193394) ((|FlexibleArray| . |CoercibleTo|) 193312) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianMonoid|) 193243) ((|SparseUnivariatePolynomialExpressions| . |Rng|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedCancellationAbelianMonoid|) 193174) ((|DirectProductModule| . |FullyLinearlyExplicitRingOver|) 193142) ((|DirectProductMatrixModule| . |FullyLinearlyExplicitRingOver|) 193110) ((|PseudoAlgebraicClosureOfRationalNumber| . |CoercibleTo|) 193084) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CoercibleTo|) 193058) ((|LinearOrdinaryDifferentialOperator2| . |Algebra|) 193015) ((|KeyedAccessFile| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |SemiGroup|) 192901) ((|GeneralSparseTable| . |Aggregate|) T) ((|SplitHomogeneousDirectProduct| . |CancellationAbelianMonoid|) 192704) ((|SymmetricPolynomial| . |IntegralDomain|) 192671) ((|Product| . |AbelianSemiGroup|) 192351) ((|Palette| . |CoercibleTo|) 192325) ((|Product| . |AbelianGroup|) 192258) ((|OrderedDirectProduct| . |AbelianGroup|) 192145) ((|OrderedDirectProduct| . |AbelianSemiGroup|) 191914) ((|SparseUnivariatePolynomial| . |AbelianMonoidRing|) 191875) ((|LaurentPolynomial| . |Rng|) T) ((|SparseMultivariatePolynomial| . |AbelianMonoidRing|) 191833) ((|GuessOptionFunctions0| . |SetCategory|) T) ((|FiniteFieldExtensionByPolynomial| . |Ring|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Ring|) T) ((|HomogeneousDirectProduct| . |AbelianMonoid|) 191636) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Ring|) T) ((|DifferentialSparseMultivariatePolynomial| . |Ring|) T) ((|DistributedMultivariatePolynomial| . |Ring|) T) ((|ResidueRing| . |LeftModule|) 191610) ((|BalancedPAdicRational| . |Rng|) T) ((|PrimitiveArray| . |Aggregate|) T) ((|MyUnivariatePolynomial| . |UniqueFactorizationDomain|) 191560) ((|FiniteFieldExtensionByPolynomial| . |DifferentialRing|) 191535) ((|FiniteFieldExtensionByPolynomial| . |DivisionRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |DifferentialRing|) 191510) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |DivisionRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |DifferentialRing|) 191485) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |DivisionRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 191443) ((|DistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 191375) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialRing|) 191340) ((|Stream| . |Collection|) 191324) ((|MyUnivariatePolynomial| . |IntegralDomain|) 191187) ((|DirectProductModule| . |PartialDifferentialRing|) 191091) ((|DirectProductMatrixModule| . |PartialDifferentialRing|) 190995) ((|SingletonAsOrderedSet| . |OrderedSet|) T) ((|UniversalSegment| . |Type|) T) ((|FramedModule| . |SemiGroup|) T) ((|U16Vector| . |BasicType|) T) ((|RectangularMatrix| . |AbelianMonoid|) T) ((|PrimeField| . |Ring|) T) ((|FreeAbelianGroup| . |LeftModule|) 190972) ((|RealClosure| . |OrderedRing|) T) ((|TaylorSeries| . |RadicalCategory|) 190921) ((|SparseUnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 190897) ((|SparseUnivariateLaurentSeries| . |PrincipalIdealDomain|) 190873) ((|PrimeField| . |DivisionRing|) T) ((|OrdinaryDifferentialRing| . |Field|) 190849) ((|FreeModule| . |AbelianMonoid|) T) ((|BinaryTree| . |SetCategory|) 190819) ((|BinarySearchTree| . |SetCategory|) 190789) ((|PrimeField| . |DifferentialRing|) T) ((|SparseUnivariateLaurentSeries| . |OrderedIntegralDomain|) NIL) ((|Float| . |LeftModule|) 190743) ((|PAdicInteger| . |Module|) 190730) ((|U8Vector| . |SetCategory|) T) ((|RegularChain| . |Collection|) 190649) ((|AlgebraicFunctionField| . |CommutativeRing|) T) ((|MachineComplex| . |FullyRetractableTo|) 190621) ((|ModMonic| . |Evalable|) 190608) ((|Operator| . |LeftModule|) 190555) ((|OppositeMonogenicLinearOperator| . |LeftModule|) 190529) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator| . |Eltable|) 190508) ((|InnerPAdicInteger| . |SetCategory|) T) ((|Integer| . |SetCategory|) T) ((|InnerAlgebraicNumber| . |SetCategory|) T) ((|DataList| . |EltableAggregate|) 190480) ((|ExponentialExpansion| . |DifferentialExtension|) 190395) ((|SparseUnivariatePolynomial| . |PatternMatchable|) NIL) ((|SparseMultivariatePolynomial| . |PatternMatchable|) 190174) ((|SparseUnivariatePolynomial| . |RetractableTo|) 189984) ((|SparseMultivariatePolynomial| . |RetractableTo|) 189815) ((|SparseUnivariateSkewPolynomial| . |RetractableTo|) 189659) ((|NewSparseUnivariatePolynomial| . |Eltable|) 189562) ((|Plcs| . |CoercibleTo|) 189536) ((|OrdinaryDifferentialRing| . |SemiGroup|) T) ((|ResidueRing| . |Monoid|) T) ((|IndexedVector| . |LinearAggregate|) 189520) ((|RegularChain| . |PolynomialSetCategory|) 189355) ((|Quaternion| . |BasicType|) T) ((|OrdinaryDifferentialRing| . |AbelianMonoid|) T) ((|ModMonic| . |StepThrough|) 189325) ((|MachineComplex| . |Rng|) T) ((|IndexedVector| . |FiniteLinearAggregate|) 189309) ((|FiniteFieldNormalBasis| . |GcdDomain|) T) ((|FiniteFieldCyclicGroup| . |EntireRing|) T) ((|TwoDimensionalViewport| . |SetCategory|) T) ((|GuessOption| . |BasicType|) T) ((|FullPartialFractionExpansion| . |BasicType|) T) ((|EuclideanModularRing| . |AbelianGroup|) T) ((|EuclideanModularRing| . |AbelianSemiGroup|) T) ((|FreeGroup| . |Monoid|) T) ((|Float| . |LeftOreRing|) T) ((|MathMLFormat| . |SetCategory|) T) ((|MachineFloat| . |SetCategory|) T) ((|FreeGroup| . |Group|) T) ((|U16Vector| . |Evalable|) NIL) ((|TaylorSeries| . |CoercibleTo|) 189283) ((|SparseUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 189267) ((|SparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 189251) ((|RealClosure| . |FullyRetractableTo|) 189202) ((|CharacterClass| . |Dictionary|) 189177) ((|Float| . |OrderedAbelianSemiGroup|) T) ((|Float| . |OrderedAbelianGroup|) T) ((|PAdicInteger| . |CommutativeRing|) T) ((|Float| . |Monoid|) T) ((|ModularField| . |CoercibleTo|) 189151) ((|ModMonic| . |Algebra|) 188891) ((|Vector| . |VectorCategory|) 188875) ((|FiniteFieldNormalBasis| . |FieldOfPrimeCharacteristic|) T) ((|Vector| . |SetCategory|) 188812) ((|InnerPAdicInteger| . |Module|) 188799) ((|Integer| . |Module|) 188786) ((|InnerAlgebraicNumber| . |Module|) 188740) ((|PseudoAlgebraicClosureOfFiniteField| . |ExtensionField|) 188724) ((|Expression| . |LiouvillianFunctionCategory|) 188691) ((|Operator| . |Monoid|) T) ((|OppositeMonogenicLinearOperator| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |SetCategory|) T) ((|List| . |Type|) T) ((|SimpleAlgebraicExtension| . |LinearlyExplicitRingOver|) 188607) ((|SparseUnivariatePolynomial| . |PartialDifferentialRing|) 188505) ((|SparseMultivariatePolynomial| . |PartialDifferentialRing|) 188489) ((|Localize| . |RightModule|) 188473) ((|BinaryExpansion| . |LinearlyExplicitRingOver|) 188450) ((|HomogeneousDirectProduct| . |CancellationAbelianMonoid|) 188253) ((|NeitherSparseOrDensePowerSeries| . |LinearAggregate|) 188194) ((|SymmetricPolynomial| . |SemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Finite|) T) ((|Polynomial| . |AbelianMonoidRing|) 188146) ((|MyUnivariatePolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |SetCategory|) T) ((|Localize| . |BiModule|) 188125) ((|FlexibleArray| . |EltableAggregate|) 188097) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianMonoidRing|) 188018) ((|SymmetricPolynomial| . |AbelianMonoid|) T) ((|BasicStochasticDifferential| . |SetCategory|) T) ((|BalancedPAdicRational| . |SetCategory|) T) ((|BalancedBinaryTree| . |BasicType|) 187988) ((|MyUnivariatePolynomial| . |AbelianMonoid|) T) ((|WeightedPolynomials| . |SemiGroup|) T) ((|RectangularMatrix| . |CancellationAbelianMonoid|) T) ((|RealClosure| . |Rng|) T) ((|OrderedFreeMonoid| . |RetractableTo|) 187972) ((|RadicalFunctionField| . |MonogenicAlgebra|) 187938) ((|WeightedPolynomials| . |AbelianMonoid|) T) ((|MachineFloat| . |Module|) 187892) ((|IntegrationResult| . |CoercibleTo|) 187866) ((|FreeMonoid| . |RetractableTo|) 187850) ((|FiniteField| . |Rng|) T) ((|FreeModule| . |CancellationAbelianMonoid|) T) ((|FreeAbelianMonoid| . |RetractableTo|) 187834) ((|DoubleFloat| . |PatternMatchable|) 187813) ((|RadixExpansion| . |PrincipalIdealDomain|) T) ((|ArrayStack| . |Aggregate|) T) ((|RadixExpansion| . |OrderedIntegralDomain|) T) ((|PartialFraction| . |PrincipalIdealDomain|) T) ((|HexadecimalExpansion| . |UniqueFactorizationDomain|) T) ((|TexFormat| . |CoercibleTo|) 187787) ((|SExpressionOf| . |SetCategory|) T) ((|DecimalExpansion| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |Evalable|) 187746) ((|DoubleFloat| . |RetractableTo|) 187690) ((|AlgebraicFunctionField| . |EntireRing|) T) ((|SimpleAlgebraicExtension| . |AbelianGroup|) T) ((|SimpleAlgebraicExtension| . |AbelianSemiGroup|) T) ((|SingleInteger| . |OpenMath|) T) ((|HexadecimalExpansion| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |AbelianGroup|) T) ((|FiniteFieldNormalBasisExtension| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |AbelianGroup|) T) ((|ModuleOperator| . |LeftModule|) 187637) ((|FiniteFieldCyclicGroupExtension| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroupExtension| . |AbelianGroup|) T) ((|BinaryExpansion| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |AbelianGroup|) T) ((|AlgebraicNumber| . |Rng|) T) ((|SparseUnivariatePolynomialExpressions| . |Module|) 187377) ((|InnerPAdicInteger| . |CommutativeRing|) T) ((|Integer| . |CommutativeRing|) T) ((|InnerAlgebraicNumber| . |CommutativeRing|) T) ((|LinearOrdinaryDifferentialOperator| . |CoercibleTo|) 187351) ((|Multiset| . |MultisetAggregate|) 187335) ((|FiniteDivisor| . |CoercibleTo|) 187309) ((|Divisor| . |CoercibleTo|) 187283) ((|Asp28| . |FortranMatrixCategory|) T) ((|Asp28| . |FortranProgramCategory|) T) ((|Set| . |BagAggregate|) 187267) ((|RomanNumeral| . |PatternMatchable|) 187244) ((|Polynomial| . |PatternMatchable|) 187125) ((|LinearOrdinaryDifferentialOperator1| . |SemiGroup|) T) ((|LaurentPolynomial| . |Module|) 187112) ((|HomogeneousDistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|SquareFreeRegularTriangularSet| . |BasicType|) T) ((|RomanNumeral| . |RetractableTo|) 187089) ((|AttributeButtons| . |CoercibleTo|) 187063) ((|Pi| . |CharacteristicZero|) T) ((|Polynomial| . |RetractableTo|) 186888) ((|BalancedPAdicRational| . |Module|) 186804) ((|LinearOrdinaryDifferentialOperator1| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |RetractableTo|) 186611) ((|SequentialDifferentialPolynomial| . |ConvertibleTo|) NIL) ((|SequentialDifferentialPolynomial| . |CoercibleTo|) 186585) ((|NewSparseUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|NewSparseUnivariatePolynomial| . |CoercibleTo|) 186515) ((|NewSparseMultivariatePolynomial| . |ConvertibleTo|) 185954) ((|NewSparseMultivariatePolynomial| . |CoercibleTo|) 185813) ((|SplitHomogeneousDirectProduct| . |LinearlyExplicitRingOver|) 185685) ((|GeneralModulePolynomial| . |CoercibleTo|) 185659) ((|GeneralDistributedMultivariatePolynomial| . |CoercibleTo|) 185633) ((|GeneralDistributedMultivariatePolynomial| . |ConvertibleTo|) 185411) ((|Result| . |Dictionary|) 185344) ((|BinaryTournament| . |Aggregate|) T) ((|OrdinaryDifferentialRing| . |CancellationAbelianMonoid|) T) ((|PAdicRationalConstructor| . |PolynomialFactorizationExplicit|) 185294) ((|ListMonoidOps| . |CoercibleTo|) 185268) ((|FiniteFieldExtensionByPolynomial| . |ExtensionField|) 185252) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |ExtensionField|) 185236) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |ExtensionField|) 185220) ((|BinaryTree| . |InnerEvalable|) 185139) ((|BinarySearchTree| . |InnerEvalable|) 185058) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedCancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedAbelianSemiGroup|) T) ((|BalancedBinaryTree| . |Evalable|) 184982) ((|Dequeue| . |BasicType|) 184952) ((|DoubleFloatVector| . |Aggregate|) T) ((|ComplexDoubleFloatVector| . |Aggregate|) T) ((|MachineComplex| . |SetCategory|) T) ((|MachineFloat| . |CommutativeRing|) T) ((|U8Vector| . |InnerEvalable|) NIL) ((|PAdicRationalConstructor| . |LeftModule|) 184893) ((|Quaternion| . |Algebra|) 184827) ((|Asp20| . |FortranMatrixFunctionCategory|) T) ((|ExtAlgBasis| . |CoercibleTo|) 184801) ((|Asp20| . |FortranProgramCategory|) T) ((|Polynomial| . |FullyLinearlyExplicitRingOver|) 184785) ((|PAdicInteger| . |EntireRing|) T) ((|AntiSymm| . |CoercibleTo|) 184759) ((|PseudoAlgebraicClosureOfRationalNumber| . |RightModule|) 184713) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |RightModule|) 184616) ((|InnerPrimeField| . |CoercibleTo|) 184590) ((|InnerPrimeField| . |ConvertibleTo|) 184567) ((|HomogeneousDistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 184551) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 184525) ((|InnerFiniteField| . |CoercibleTo|) 184499) ((|PrimeField| . |ExtensionField|) 184486) ((|PAdicRational| . |Type|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |BiModule|) 184413) ((|MachineInteger| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |BiModule|) 184246) ((|InnerAlgebraicNumber| . |InnerEvalable|) 184208) ((|HexadecimalExpansion| . |Field|) T) ((|FiniteFieldExtensionByPolynomial| . |Finite|) 184183) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Finite|) 184158) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Finite|) 184133) ((|DecimalExpansion| . |Field|) T) ((|ModuleOperator| . |Monoid|) T) ((|BalancedPAdicInteger| . |GcdDomain|) T) ((|SparseUnivariatePolynomialExpressions| . |CommutativeRing|) 183963) ((|XPolynomialRing| . |XAlgebra|) 183947) ((|PAdicRational| . |Patternable|) 183914) ((|PAdicRational| . |PatternMatchable|) NIL) ((|Product| . |OrderedSet|) 183758) ((|OrderedDirectProduct| . |OrderedSet|) 183682) ((|LinearOrdinaryDifferentialOperator2| . |LinearOrdinaryDifferentialOperatorCategory|) 183666) ((|Tree| . |Aggregate|) T) ((|SubSpaceComponentProperty| . |CoercibleTo|) 183640) ((|SplitHomogeneousDirectProduct| . |AbelianGroup|) 183527) ((|SplitHomogeneousDirectProduct| . |AbelianSemiGroup|) 183296) ((|ProjectiveSpace| . |SetCategory|) T) ((|PAdicRational| . |RetractableTo|) 183263) ((|Polynomial| . |PartialDifferentialRing|) 183241) ((|UnivariatePolynomial| . |AbelianMonoidRing|) 183202) ((|PrimeField| . |Finite|) T) ((|OneDimensionalArray| . |LinearAggregate|) 183186) ((|IndexedFlexibleArray| . |LinearAggregate|) 183170) ((|HomogeneousDistributedMultivariatePolynomial| . |PartialDifferentialRing|) 183130) ((|Asp31| . |FortranVectorFunctionCategory|) T) ((|Asp31| . |FortranProgramCategory|) T) ((|IndexedOneDimensionalArray| . |LinearAggregate|) 183114) ((|OneDimensionalArray| . |FiniteLinearAggregate|) 183098) ((|LaurentPolynomial| . |CommutativeRing|) T) ((|IndexedFlexibleArray| . |FiniteLinearAggregate|) 183082) ((|IndexedOneDimensionalArray| . |FiniteLinearAggregate|) 183066) ((|OppositeMonogenicLinearOperator| . |MonogenicLinearOperator|) 183050) ((|SparseUnivariatePolynomial| . |EuclideanDomain|) 183026) ((|SymmetricPolynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |CommutativeRing|) T) ((|MyUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|SquareFreeRegularTriangularSet| . |Evalable|) 182950) ((|Complex| . |Type|) T) ((|AssociatedLieAlgebra| . |NonAssociativeAlgebra|) 182934) ((|AssociatedJordanAlgebra| . |NonAssociativeAlgebra|) 182918) ((|WeightedPolynomials| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 182894) ((|UnivariateLaurentSeries| . |PrincipalIdealDomain|) 182870) ((|UnivariateLaurentSeries| . |OrderedIntegralDomain|) NIL) ((|MachineComplex| . |Module|) 182799) ((|UnivariateLaurentSeriesConstructor| . |PolynomialFactorizationExplicit|) 182720) ((|RealClosure| . |SetCategory|) T) ((|PAdicRational| . |FullyLinearlyExplicitRingOver|) 182687) ((|PAdicRational| . |FullyEvalableOver|) 182654) ((|Permutation| . |SemiGroup|) T) ((|Complex| . |Patternable|) 182638) ((|Complex| . |PatternMatchable|) 182519) ((|Vector| . |InnerEvalable|) 182438) ((|PAdicRationalConstructor| . |LeftOreRing|) T) ((|HexadecimalExpansion| . |SemiGroup|) T) ((|FiniteField| . |SetCategory|) T) ((|DecimalExpansion| . |SemiGroup|) T) ((|Asp42| . |FortranVectorFunctionCategory|) T) ((|Asp42| . |FortranProgramCategory|) T) ((|UnivariatePuiseuxSeriesConstructor| . |LeftModule|) 182307) ((|Complex| . |RetractableTo|) 182151) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedSet|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Ring|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Ring|) T) ((|UnivariateLaurentSeriesConstructor| . |LeftModule|) 181990) ((|PAdicRationalConstructor| . |OrderedAbelianSemiGroup|) 181950) ((|PAdicRationalConstructor| . |OrderedAbelianGroup|) 181910) ((|XRecursivePolynomial| . |XFreeAlgebra|) 181889) ((|PAdicRationalConstructor| . |Monoid|) T) ((|HexadecimalExpansion| . |AbelianMonoid|) T) ((|DeRhamComplex| . |CoercibleTo|) 181863) ((|ContinuedFraction| . |GcdDomain|) T) ((|Dequeue| . |Evalable|) 181787) ((|Asp7| . |FortranVectorFunctionCategory|) T) ((|Asp7| . |FortranProgramCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |DivisionRing|) T) ((|DecimalExpansion| . |AbelianMonoid|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |DivisionRing|) T) ((|MyExpression| . |FullyRetractableTo|) 181771) ((|InfClsPt| . |InfinitlyClosePointCategory|) 181535) ((|InnerPAdicInteger| . |EntireRing|) T) ((|Integer| . |EntireRing|) T) ((|Magma| . |RetractableTo|) 181519) ((|InnerAlgebraicNumber| . |EntireRing|) T) ((|SparseUnivariatePolynomialExpressions| . |InnerEvalable|) 181429) ((|CartesianTensor| . |GradedModule|) 181347) ((|BlowUpWithHamburgerNoether| . |SetCategory|) T) ((|AlgebraicNumber| . |SetCategory|) T) ((|ModMonic| . |DifferentialExtension|) 181331) ((|PAdicRational| . |PartialDifferentialRing|) NIL) ((|UnivariatePolynomial| . |PatternMatchable|) NIL) ((|PatternMatchResult| . |BasicType|) T) ((|PatternMatchListResult| . |BasicType|) T) ((|FileName| . |SetCategory|) T) ((|Complex| . |FullyLinearlyExplicitRingOver|) 181315) ((|Complex| . |FullyEvalableOver|) 181299) ((|UnivariatePolynomial| . |RetractableTo|) 181109) ((|UnivariateSkewPolynomial| . |RetractableTo|) 180953) ((|SquareMatrix| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator1| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |InnerEvalable|) 180667) ((|Localize| . |OrderedAbelianMonoid|) 180629) ((|Localize| . |OrderedCancellationAbelianMonoid|) 180591) ((|Interval| . |RetractableTo|) 180568) ((|Equation| . |VectorSpace|) 180535) ((|OrdinaryWeightedPolynomials| . |BasicType|) T) ((|PolynomialRing| . |IntegralDomain|) 180502) ((|TaylorSeries| . |RightModule|) 180335) ((|HomogeneousDirectProduct| . |LinearlyExplicitRingOver|) 180207) ((|PermutationGroup| . |SetCategory|) T) ((|RealClosure| . |Module|) 180128) ((|ModularField| . |RightModule|) 180082) ((|PseudoAlgebraicClosureOfFiniteField| . |LeftModule|) 180023) ((|NeitherSparseOrDensePowerSeries| . |LeftModule|) 179964) ((|IndexedVector| . |Aggregate|) T) ((|Stack| . |Type|) T) ((|TaylorSeries| . |BiModule|) 179765) ((|GeneralUnivariatePowerSeries| . |LeftModule|) 179634) ((|FiniteField| . |Module|) 179560) ((|Complex| . |PartialDifferentialRing|) 179492) ((|MachineFloat| . |EntireRing|) T) ((|MyExpression| . |Rng|) T) ((|MachineComplex| . |CommutativeRing|) T) ((|ModularField| . |BiModule|) 179419) ((|IntegerMod| . |Rng|) T) ((|UnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 179403) ((|Factored| . |UniqueFactorizationDomain|) 179359) ((|ExponentialExpansion| . |OrderedRing|) NIL) ((|UnivariatePuiseuxSeriesConstructor| . |LeftOreRing|) 179335) ((|UnivariateLaurentSeriesConstructor| . |LeftOreRing|) 179311) ((|Factored| . |IntegralDomain|) T) ((|DoubleFloat| . |EuclideanDomain|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianGroup|) 179242) ((|UnivariateLaurentSeriesConstructor| . |OrderedAbelianSemiGroup|) 179173) ((|AffinePlane| . |SetCategoryWithDegree|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Monoid|) T) ((|UnivariateLaurentSeriesConstructor| . |Monoid|) T) ((|AlgebraicNumber| . |Module|) 179127) ((|SparseUnivariatePolynomialExpressions| . |EntireRing|) 178990) ((|DoubleFloat| . |RealConstant|) T) ((|FiniteFieldNormalBasis| . |VectorSpace|) 178959) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |FullyRetractableTo|) 178905) ((|MoebiusTransform| . |Monoid|) T) ((|UnivariatePolynomial| . |PartialDifferentialRing|) 178803) ((|Boolean| . |CoercibleTo|) 178777) ((|Boolean| . |ConvertibleTo|) 178752) ((|MoebiusTransform| . |Group|) T) ((|HomogeneousDirectProduct| . |AbelianGroup|) 178639) ((|BinaryTree| . |HomogeneousAggregate|) 178623) ((|BinarySearchTree| . |HomogeneousAggregate|) 178607) ((|HomogeneousDirectProduct| . |AbelianSemiGroup|) 178376) ((|LaurentPolynomial| . |EntireRing|) T) ((|NeitherSparseOrDensePowerSeries| . |Aggregate|) T) ((|U8Vector| . |HomogeneousAggregate|) 178353) ((|IntegrationResult| . |RightModule|) 178317) ((|U8Matrix| . |TwoDimensionalArrayCategory|) 178268) ((|FortranType| . |SetCategory|) T) ((|RomanNumeral| . |EuclideanDomain|) T) ((|BalancedPAdicRational| . |EntireRing|) T) ((|SExpression| . |BasicType|) T) ((|RadicalFunctionField| . |BasicType|) T) ((|IntegrationResult| . |BiModule|) 178207) ((|UnivariateTaylorSeriesCZero| . |Rng|) T) ((|SquareMatrix| . |Evalable|) 178131) ((|TaylorSeries| . |Ring|) T) ((|RomanNumeral| . |RealConstant|) T) ((|Asp24| . |Type|) T) ((|RectangularMatrix| . |AbelianSemiGroup|) T) ((|RectangularMatrix| . |AbelianGroup|) T) ((|ModularField| . |Ring|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |LeftOreRing|) T) ((|NeitherSparseOrDensePowerSeries| . |LeftOreRing|) T) ((|FreeModule| . |AbelianGroup|) T) ((|FreeModule| . |AbelianSemiGroup|) T) ((|MachineComplex| . |InnerEvalable|) NIL) ((|RealClosure| . |CommutativeRing|) T) ((|GeneralUnivariatePowerSeries| . |LeftOreRing|) 178107) ((|ModularField| . |DivisionRing|) T) ((|RomanNumeral| . |IntegerNumberSystem|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Monoid|) T) ((|NeitherSparseOrDensePowerSeries| . |Monoid|) T) ((|IndexCard| . |BasicType|) T) ((|FiniteField| . |CommutativeRing|) T) ((|FiniteFieldCyclicGroup| . |CoercibleTo|) 178081) ((|ScriptFormulaFormat| . |CoercibleTo|) 178055) ((|GeneralUnivariatePowerSeries| . |Monoid|) T) ((|SingleInteger| . |OrderedRing|) T) ((|Pattern| . |RetractableTo|) 178020) ((|BinaryExpansion| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator| . |RightModule|) 178004) ((|HexadecimalExpansion| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Rng|) T) ((|DecimalExpansion| . |CancellationAbelianMonoid|) T) ((|Divisor| . |RightModule|) 177981) ((|Stream| . |BasicType|) 177951) ((|Automorphism| . |SetCategory|) T) ((|DataList| . |ListAggregate|) 177935) ((|DataList| . |LinearAggregate|) 177919) ((|LinearOrdinaryDifferentialOperator| . |BiModule|) 177898) ((|Expression| . |FullyRetractableTo|) 177882) ((|DataList| . |FiniteLinearAggregate|) 177866) ((|StringTable| . |DictionaryOperations|) 177802) ((|Quaternion| . |DifferentialExtension|) 177786) ((|Divisor| . |BiModule|) 177751) ((|Asp35| . |Type|) T) ((|AlgebraicNumber| . |CommutativeRing|) T) ((|MachineInteger| . |FortranMachineTypeCategory|) T) ((|MachineInteger| . |CombinatorialFunctionCategory|) T) ((|XPolynomialRing| . |BasicType|) T) ((|SequentialDifferentialPolynomial| . |RightModule|) 177508) ((|DifferentialSparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 177458) ((|DistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 177408) ((|NewSparseUnivariatePolynomial| . |RightModule|) 177142) ((|NewSparseMultivariatePolynomial| . |RightModule|) 176899) ((|KeyedAccessFile| . |Type|) T) ((|SubSpace| . |CoercibleTo|) 176873) ((|SequentialDifferentialPolynomial| . |BiModule|) 176598) ((|RegularChain| . |BasicType|) T) ((|GeneralSparseTable| . |Type|) T) ((|GeneralModulePolynomial| . |RightModule|) 176569) ((|GeneralDistributedMultivariatePolynomial| . |RightModule|) 176326) ((|LiePolynomial| . |LeftModule|) 176310) ((|PAdicRational| . |EuclideanDomain|) T) ((|NewSparseUnivariatePolynomial| . |BiModule|) 176012) ((|NewSparseMultivariatePolynomial| . |BiModule|) 175737) ((|FiniteFieldExtensionByPolynomial| . |LeftModule|) 175678) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |LeftModule|) 175619) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |LeftModule|) 175560) ((|DifferentialSparseMultivariatePolynomial| . |LeftModule|) 175457) ((|DistributedMultivariatePolynomial| . |LeftModule|) 175354) ((|String| . |OrderedSet|) T) ((|GeneralModulePolynomial| . |BiModule|) 175315) ((|GeneralDistributedMultivariatePolynomial| . |BiModule|) 175040) ((|SequentialDifferentialVariable| . |RetractableTo|) 175024) ((|RewriteRule| . |RetractableTo|) 174995) ((|Queue| . |Aggregate|) T) ((|PrimitiveArray| . |Type|) T) ((|BinaryTournament| . |RecursiveAggregate|) 174979) ((|PolynomialRing| . |SemiGroup|) T) ((|PAdicRational| . |RealConstant|) NIL) ((|MonoidRing| . |SemiGroup|) T) ((|ModularRing| . |SemiGroup|) T) ((|Vector| . |HomogeneousAggregate|) 174963) ((|SquareMatrix| . |Algebra|) 174908) ((|PolynomialRing| . |AbelianMonoid|) T) ((|PrimeField| . |LeftModule|) 174862) ((|OrderedCompletion| . |BasicType|) T) ((|OrdinaryDifferentialRing| . |AbelianGroup|) T) ((|OrdinaryDifferentialRing| . |AbelianSemiGroup|) T) ((|MonoidRing| . |AbelianMonoid|) T) ((|ModularRing| . |AbelianMonoid|) T) ((|Bits| . |Logic|) T) ((|NottinghamGroup| . |Monoid|) T) ((|InnerPrimeField| . |RightModule|) 174816) ((|InnerFiniteField| . |RightModule|) 174737) ((|DenavitHartenbergMatrix| . |TwoDimensionalArrayCategory|) 174689) ((|GenericNonAssociativeAlgebra| . |AbelianMonoid|) T) ((|Fraction| . |BasicType|) T) ((|DrawOption| . |BasicType|) T) ((|NottinghamGroup| . |Group|) T) ((|ProjectivePlane| . |BasicType|) T) ((|MachineComplex| . |EntireRing|) T) ((|OrdinaryWeightedPolynomials| . |Algebra|) 174646) ((|U8Vector| . |Eltable|) 174611) ((|InnerPrimeField| . |BiModule|) 174538) ((|InnerFiniteField| . |BiModule|) 174407) ((|MyUnivariatePolynomial| . |LinearlyExplicitRingOver|) 174323) ((|Factored| . |SemiGroup|) T) ((|Expression| . |Rng|) 174155) ((|ExponentialExpansion| . |Rng|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 174129) ((|MyExpression| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |Ring|) T) ((|IntegerMod| . |SetCategory|) T) ((|Complex| . |EuclideanDomain|) 174030) ((|Factored| . |AbelianMonoid|) T) ((|AlgebraicFunctionField| . |CoercibleTo|) 174004) ((|AlgebraicFunctionField| . |ConvertibleTo|) 173988) ((|BinaryExpansion| . |QuotientFieldCategory|) 173965) ((|BalancedPAdicInteger| . |PAdicIntegerCategory|) 173949) ((|AlgebraicNumber| . |InnerEvalable|) 173911) ((|Tree| . |RecursiveAggregate|) 173895) ((|Table| . |Aggregate|) T) ((|PositiveInteger| . |CoercibleTo|) 173869) ((|SplitHomogeneousDirectProduct| . |OrderedSet|) 173793) ((|NonNegativeInteger| . |CoercibleTo|) 173767) ((|LyndonWord| . |CoercibleTo|) 173741) ((|UnivariatePolynomial| . |EuclideanDomain|) 173717) ((|U8Vector| . |OneDimensionalArrayAggregate|) 173694) ((|U8Vector| . |IndexedAggregate|) 173659) ((|Stream| . |Evalable|) 173583) ((|SegmentBinding| . |Type|) T) ((|HashTable| . |Aggregate|) T) ((|SequentialDifferentialPolynomial| . |Ring|) T) ((|Pi| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |ExtensionField|) 173547) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |ExtensionField|) 173460) ((|SplittingTree| . |Aggregate|) T) ((|NewSparseUnivariatePolynomial| . |Ring|) T) ((|NewSparseMultivariatePolynomial| . |Ring|) T) ((|ListMultiDictionary| . |DictionaryOperations|) 173444) ((|Library| . |DictionaryOperations|) 173377) ((|SymmetricPolynomial| . |AbelianGroup|) T) ((|SymmetricPolynomial| . |AbelianSemiGroup|) T) ((|SequentialDifferentialPolynomial| . |FiniteAbelianMonoidRing|) 173294) ((|SequentialDifferentialPolynomial| . |DifferentialRing|) 173259) ((|NewSparseUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 173220) ((|NewSparseUnivariatePolynomial| . |DifferentialRing|) T) ((|GeneralDistributedMultivariatePolynomial| . |Ring|) T) ((|NewSparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 173178) ((|MultivariatePolynomial| . |UniqueFactorizationDomain|) 173128) ((|FiniteFieldExtensionByPolynomial| . |LeftOreRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |LeftOreRing|) T) ((|FlexibleArray| . |LinearAggregate|) 173112) ((|DifferentialSparseMultivariatePolynomial| . |LeftOreRing|) 173030) ((|DistributedMultivariatePolynomial| . |LeftOreRing|) 172948) ((|OneDimensionalArray| . |Aggregate|) T) ((|InnerIndexedTwoDimensionalArray| . |Aggregate|) T) ((|IndexedFlexibleArray| . |Aggregate|) T) ((|GeneralDistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 172927) ((|FlexibleArray| . |FiniteLinearAggregate|) 172911) ((|IndexedTwoDimensionalArray| . |Aggregate|) T) ((|IndexedOneDimensionalArray| . |Aggregate|) T) ((|RadicalFunctionField| . |StepThrough|) NIL) ((|MultivariatePolynomial| . |IntegralDomain|) 172797) ((|AssociatedLieAlgebra| . |BasicType|) T) ((|AssociatedJordanAlgebra| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |Monoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Monoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Monoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |Monoid|) T) ((|DistributedMultivariatePolynomial| . |Monoid|) T) ((|MyUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|MyUnivariatePolynomial| . |AbelianGroup|) T) ((|WeightedPolynomials| . |AbelianGroup|) T) ((|RegularChain| . |Evalable|) 172561) ((|WeightedPolynomials| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeriesCZero| . |SetCategory|) T) ((|PendantTree| . |SetCategory|) 172531) ((|AntiSymm| . |Ring|) T) ((|SparseUnivariateTaylorSeries| . |IntegralDomain|) 172498) ((|SparseUnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 172474) ((|SparseUnivariatePuiseuxSeries| . |IntegralDomain|) 172413) ((|SparseUnivariateLaurentSeries| . |UniqueFactorizationDomain|) 172389) ((|PrimeField| . |LeftOreRing|) T) ((|InnerPrimeField| . |Ring|) T) ((|InnerFiniteField| . |Ring|) T) ((|InfClsPt| . |BasicType|) T) ((|RealClosure| . |EntireRing|) T) ((|FreeGroup| . |RetractableTo|) 172373) ((|FreeAbelianGroup| . |RetractableTo|) 172357) ((|DesingTree| . |SetCategory|) 172327) ((|Float| . |PatternMatchable|) 172306) ((|SparseUnivariateLaurentSeries| . |IntegralDomain|) 172245) ((|SparseMultivariateTaylorSeries| . |IntegralDomain|) 172212) ((|RadicalFunctionField| . |Algebra|) 172140) ((|Octonion| . |SemiGroup|) T) ((|PrimeField| . |Monoid|) T) ((|InnerPrimeField| . |DivisionRing|) T) ((|InnerPrimeField| . |DifferentialRing|) T) ((|InnerFiniteField| . |DifferentialRing|) T) ((|InnerFiniteField| . |DivisionRing|) T) ((|MyExpression| . |Module|) 172028) ((|FiniteField| . |EntireRing|) T) ((|ListMultiDictionary| . |MultiDictionary|) 172012) ((|Float| . |RetractableTo|) 171956) ((|DesingTree| . |DesingTreeCategory|) 171940) ((|SingleInteger| . |Rng|) T) ((|BalancedBinaryTree| . |BinaryTreeCategory|) 171924) ((|Octonion| . |AbelianMonoid|) T) ((|XPolynomial| . |XFreeAlgebra|) 171897) ((|XPBWPolynomial| . |XFreeAlgebra|) 171876) ((|Vector| . |Eltable|) 171848) ((|Fraction| . |Evalable|) 171807) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |SetCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |Eltable|) 171710) ((|PAdicInteger| . |CoercibleTo|) 171684) ((|Operator| . |RetractableTo|) 171642) ((|d01TransformFunctionType| . |NumericalIntegrationCategory|) T) ((|d01gbfAnnaType| . |NumericalIntegrationCategory|) T) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |AffineSpaceCategory|) 171586) ((|d01fcfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01asfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01aqfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01apfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01anfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01amfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01alfAnnaType| . |NumericalIntegrationCategory|) T) ((|d01akfAnnaType| . |NumericalIntegrationCategory|) T) ((|InnerAlgebraicNumber| . |RadicalCategory|) T) ((|e04ucfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04nafAnnaType| . |NumericalOptimizationCategory|) T) ((|e04mbfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04jafAnnaType| . |NumericalOptimizationCategory|) T) ((|AlgebraicNumber| . |EntireRing|) T) ((|e04gcfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04fdfAnnaType| . |NumericalOptimizationCategory|) T) ((|e04dgfAnnaType| . |NumericalOptimizationCategory|) T) ((|d01ajfAnnaType| . |NumericalIntegrationCategory|) T) ((|Kernel| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator2| . |FullyRetractableTo|) 171570) ((|Bits| . |OrderedSet|) T) ((|LinearOrdinaryDifferentialOperator1| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator1| . |AbelianSemiGroup|) T) ((|GuessOptionFunctions0| . |CoercibleTo|) 171544) ((|XPolynomialRing| . |Algebra|) 171501) ((|Vector| . |OneDimensionalArrayAggregate|) 171485) ((|BalancedPAdicRational| . |Eltable|) 171338) ((|DoubleFloatMatrix| . |BasicType|) T) ((|ComplexDoubleFloatMatrix| . |BasicType|) T) ((|Vector| . |IndexedAggregate|) 171310) ((|WuWenTsunTriangularSet| . |SetCategory|) T) ((|UnivariateTaylorSeriesCZero| . |Module|) 171154) ((|Ruleset| . |SetCategory|) T) ((|QuasiAlgebraicSet| . |SetCategory|) T) ((|PolynomialRing| . |CancellationAbelianMonoid|) T) ((|Multiset| . |SetCategory|) T) ((|MonoidRing| . |CancellationAbelianMonoid|) T) ((|ModularRing| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianMonoidSup|) T) ((|Fraction| . |StepThrough|) 171124) ((|GenericNonAssociativeAlgebra| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedAbelianSemiGroup|) T) ((|DeRhamComplex| . |Ring|) T) ((|Equation| . |BasicType|) 170821) ((|CharacterClass| . |SetCategory|) T) ((|MachineFloat| . |RadicalCategory|) T) ((|ArrayStack| . |Type|) T) ((|BinaryTree| . |CoercibleTo|) 170772) ((|BinarySearchTree| . |CoercibleTo|) 170723) ((|MyExpression| . |CommutativeRing|) T) ((|IntegerMod| . |CommutativeRing|) T) ((|U8Vector| . |ConvertibleTo|) 170698) ((|U8Vector| . |CoercibleTo|) 170672) ((|SparseUnivariatePuiseuxSeries| . |Field|) 170648) ((|SparseUnivariateLaurentSeries| . |Field|) 170624) ((|Expression| . |SetCategory|) T) ((|Factored| . |CancellationAbelianMonoid|) T) ((|ExponentialExpansion| . |SetCategory|) T) ((|Fraction| . |Algebra|) 170565) ((|ThreeSpace| . |BasicType|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Module|) 170321) ((|LinearOrdinaryDifferentialOperator2| . |Rng|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CharacteristicNonZero|) 170281) ((|ExponentialOfUnivariatePuiseuxSeries| . |CharacteristicZero|) 170244) ((|CartesianTensor| . |SetCategory|) T) ((|BasicOperator| . |SetCategory|) T) ((|OrdSetInts| . |BasicType|) T) ((|InnerPAdicInteger| . |CoercibleTo|) 170218) ((|Integer| . |ConvertibleTo|) 170080) ((|Integer| . |CoercibleTo|) 170054) ((|InnerAlgebraicNumber| . |CoercibleTo|) 170028) ((|InnerAlgebraicNumber| . |ConvertibleTo|) 169953) ((|HyperellipticFiniteDivisor| . |AbelianMonoid|) T) ((|HomogeneousDirectProduct| . |OrderedSet|) 169877) ((|BlowUpWithQuadTrans| . |SetCategory|) T) ((|HexadecimalExpansion| . |LinearlyExplicitRingOver|) 169854) ((|NeitherSparseOrDensePowerSeries| . |RecursiveAggregate|) 169795) ((|DecimalExpansion| . |LinearlyExplicitRingOver|) 169772) ((|DoubleFloat| . |FloatingPointSystem|) T) ((|Localize| . |LeftModule|) 169756) ((|SparseUnivariatePolynomial| . |PrincipalIdealDomain|) 169732) ((|MultivariatePolynomial| . |SemiGroup|) T) ((|FiniteFieldNormalBasis| . |BasicType|) T) ((|OrderlyDifferentialVariable| . |OrderedSet|) T) ((|MultivariatePolynomial| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |RightModule|) 169658) ((|String| . |StringCategory|) T) ((|Stack| . |BagAggregate|) 169642) ((|UnivariateTaylorSeriesCZero| . |CommutativeRing|) 169571) ((|SparseUnivariateTaylorSeries| . |SemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |SemiGroup|) T) ((|SparseUnivariateLaurentSeries| . |SemiGroup|) T) ((|SparseMultivariateTaylorSeries| . |SemiGroup|) T) ((|InnerFreeAbelianMonoid| . |RetractableTo|) 169555) ((|FiniteFieldCyclicGroup| . |BiModule|) 169434) ((|DoubleFloatMatrix| . |Evalable|) NIL) ((|ComplexDoubleFloatMatrix| . |Evalable|) NIL) ((|RadixExpansion| . |UniqueFactorizationDomain|) T) ((|BinaryTournament| . |Type|) T) ((|PartialFraction| . |UniqueFactorizationDomain|) T) ((|TwoDimensionalViewport| . |CoercibleTo|) 169408) ((|U32Vector| . |SetCategory|) T) ((|MachineComplex| . |Eltable|) NIL) ((|SparseUnivariateTaylorSeries| . |AbelianMonoid|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |AbelianMonoid|) T) ((|SquareMatrix| . |DifferentialExtension|) 169392) ((|SparseMultivariateTaylorSeries| . |AbelianMonoid|) T) ((|RuleCalled| . |SetCategory|) T) ((|RadixExpansion| . |IntegralDomain|) T) ((|PartialFraction| . |IntegralDomain|) T) ((|Octonion| . |CancellationAbelianMonoid|) T) ((|DoubleFloatVector| . |Type|) T) ((|ComplexDoubleFloatVector| . |Type|) T) ((|MyExpression| . |InnerEvalable|) 169354) ((|MathMLFormat| . |CoercibleTo|) 169328) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|Expression| . |Module|) 169190) ((|ExponentialExpansion| . |Module|) 169062) ((|MachineFloat| . |CoercibleTo|) 169036) ((|MachineFloat| . |ConvertibleTo|) 168961) ((|Fraction| . |FullyPatternMatchable|) 168945) ((|FunctionCalled| . |SetCategory|) T) ((|HexadecimalExpansion| . |AbelianSemiGroup|) T) ((|HexadecimalExpansion| . |AbelianGroup|) T) ((|SingleInteger| . |SetCategory|) T) ((|DecimalExpansion| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |AbelianGroup|) T) ((|ModMonic| . |FullyRetractableTo|) 168929) ((|ModuleOperator| . |RetractableTo|) 168887) ((|Vector| . |CoercibleTo|) 168805) ((|Vector| . |ConvertibleTo|) 168741) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CommutativeRing|) T) ((|DataList| . |Aggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |ConvertibleTo|) NIL) ((|SparseUnivariatePolynomialExpressions| . |CoercibleTo|) 168715) ((|Plot3D| . |PlottableSpaceCurveCategory|) T) ((|Tree| . |Type|) T) ((|Localize| . |OrderedAbelianGroup|) 168677) ((|Localize| . |OrderedAbelianSemiGroup|) 168639) ((|FortranProgram| . |FortranProgramCategory|) T) ((|IndexedMatrix| . |BasicType|) 168609) ((|Result| . |SetCategory|) T) ((|Dequeue| . |QueueAggregate|) 168593) ((|PolynomialIdeals| . |BasicType|) T) ((|LaurentPolynomial| . |CoercibleTo|) 168567) ((|AssociationList| . |OrderedSet|) NIL) ((|LaurentPolynomial| . |ConvertibleTo|) 168538) ((|Result| . |KeyedDictionary|) 168508) ((|PendantTree| . |InnerEvalable|) 168427) ((|FiniteFieldCyclicGroup| . |Ring|) T) ((|BasicStochasticDifferential| . |CoercibleTo|) 168401) ((|BalancedPAdicRational| . |ConvertibleTo|) NIL) ((|BalancedPAdicRational| . |CoercibleTo|) 168375) ((|PAdicRationalConstructor| . |Type|) T) ((|LieSquareMatrix| . |FramedNonAssociativeAlgebra|) 168359) ((|LieSquareMatrix| . |SquareMatrixCategory|) 168282) ((|DesingTree| . |InnerEvalable|) 168201) ((|IndexedBits| . |Collection|) 168178) ((|FiniteFieldCyclicGroup| . |DifferentialRing|) T) ((|FiniteFieldCyclicGroup| . |DivisionRing|) T) ((|AlgebraicFunctionField| . |RightModule|) 168106) ((|PAdicRationalConstructor| . |Patternable|) 168090) ((|PAdicRationalConstructor| . |PatternMatchable|) 167971) ((|ModMonic| . |Rng|) T) ((|MachineComplex| . |RadicalCategory|) NIL) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianMonoidRing|) 167930) ((|UnivariateLaurentSeriesConstructor| . |AbelianMonoidRing|) 167902) ((|SplittingTree| . |RecursiveAggregate|) 167863) ((|SingleInteger| . |Module|) 167850) ((|SExpressionOf| . |CoercibleTo|) 167824) ((|PAdicRationalConstructor| . |RetractableTo|) 167626) ((|DoubleFloat| . |PrincipalIdealDomain|) T) ((|AlgebraicFunctionField| . |BiModule|) 167509) ((|MyExpression| . |EntireRing|) T) ((|SimpleAlgebraicExtension| . |CharacteristicZero|) 167472) ((|SimpleAlgebraicExtension| . |CharacteristicNonZero|) 167390) ((|RadixExpansion| . |Field|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |LeftModule|) 167344) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |LeftModule|) 167247) ((|ExponentialOfUnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 167196) ((|Float| . |EuclideanDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 167145) ((|Expression| . |CommutativeRing|) 167112) ((|ExponentialExpansion| . |CommutativeRing|) T) ((|RadicalFunctionField| . |DifferentialExtension|) 167083) ((|PartialFraction| . |Field|) T) ((|InnerPrimeField| . |ExtensionField|) 167070) ((|InnerFiniteField| . |ExtensionField|) 167034) ((|FiniteFieldExtension| . |CharacteristicZero|) 166997) ((|FiniteFieldExtension| . |CharacteristicNonZero|) 166928) ((|FiniteFieldNormalBasisExtension| . |CharacteristicZero|) 166891) ((|FiniteFieldNormalBasisExtension| . |CharacteristicNonZero|) 166822) ((|KeyedAccessFile| . |TableAggregate|) 166795) ((|FiniteFieldCyclicGroupExtension| . |CharacteristicZero|) 166758) ((|FiniteFieldCyclicGroupExtension| . |CharacteristicNonZero|) 166689) ((|ExponentialOfUnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 166638) ((|GeneralSparseTable| . |TableAggregate|) 166617) ((|Enumeration| . |EnumerationCategory|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 166566) ((|Float| . |RealConstant|) T) ((|BinaryExpansion| . |CharacteristicZero|) T) ((|BinaryExpansion| . |CharacteristicNonZero|) NIL) ((|AssociationList| . |DictionaryOperations|) 166508) ((|LinearOrdinaryDifferentialOperator2| . |SetCategory|) T) ((|KeyedAccessFile| . |BagAggregate|) 166444) ((|HyperellipticFiniteDivisor| . |CancellationAbelianMonoid|) T) ((|GeneralSparseTable| . |BagAggregate|) 166386) ((|DirectProduct| . |SemiGroup|) 166272) ((|StochasticDifferential| . |SemiGroup|) T) ((|PAdicRationalConstructor| . |FullyLinearlyExplicitRingOver|) 166256) ((|PAdicRationalConstructor| . |FullyEvalableOver|) 166240) ((|DirectProduct| . |AbelianMonoid|) 166043) ((|RomanNumeral| . |PrincipalIdealDomain|) T) ((|RomanNumeral| . |OrderedIntegralDomain|) T) ((|InnerPrimeField| . |Finite|) T) ((|InnerFiniteField| . |Finite|) T) ((|MyUnivariatePolynomial| . |OrderedSet|) 166014) ((|U8Vector| . |EltableAggregate|) 165979) ((|FiniteFieldNormalBasis| . |StepThrough|) T) ((|FlexibleArray| . |Aggregate|) T) ((|AlgebraGivenByStructuralConstants| . |FramedNonAssociativeAlgebra|) 165963) ((|StochasticDifferential| . |AbelianMonoid|) T) ((|FreeNilpotentLie| . |NonAssociativeAlgebra|) 165947) ((|WuWenTsunTriangularSet| . |InnerEvalable|) 165866) ((|MultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|UnivariateTaylorSeriesCZero| . |EntireRing|) 165833) ((|UnivariateTaylorSeries| . |IntegralDomain|) 165800) ((|UnivariatePuiseuxSeries| . |UniqueFactorizationDomain|) 165776) ((|UnivariatePuiseuxSeries| . |IntegralDomain|) 165715) ((|UnivariateLaurentSeries| . |UniqueFactorizationDomain|) 165691) ((|UnivariateLaurentSeries| . |IntegralDomain|) 165630) ((|Multiset| . |InnerEvalable|) 165549) ((|UnivariateLaurentSeriesConstructor| . |Type|) 165525) ((|UnivariateLaurentSeriesConstructor| . |PatternMatchable|) 165348) ((|PoincareBirkhoffWittLyndonBasis| . |SetCategory|) T) ((|Character| . |OrderedFinite|) T) ((|UnivariateLaurentSeriesConstructor| . |Patternable|) 165315) ((|UnivariateFormalPowerSeries| . |IntegralDomain|) 165282) ((|SparseUnivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|IndexedMatrix| . |Evalable|) 165206) ((|SparseUnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|CharacterClass| . |InnerEvalable|) NIL) ((|SparseUnivariateLaurentSeries| . |CancellationAbelianMonoid|) T) ((|SparseMultivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|RealClosure| . |RadicalCategory|) T) ((|RadixExpansion| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasis| . |Algebra|) 165160) ((|RadixExpansion| . |SemiGroup|) T) ((|PartialFraction| . |SemiGroup|) T) ((|Asp73| . |CoercibleTo|) 165134) ((|AlgebraicFunctionField| . |Ring|) T) ((|PAdicInteger| . |RightModule|) 165121) ((|PAdicRationalConstructor| . |PartialDifferentialRing|) 165053) ((|NeitherSparseOrDensePowerSeries| . |AbelianMonoidRing|) 165025) ((|MachineInteger| . |BasicType|) T) ((|RadicalFunctionField| . |FiniteFieldCategory|) NIL) ((|IndexedVector| . |Type|) T) ((|Partition| . |AbelianMonoid|) T) ((|PartialFraction| . |AbelianMonoid|) T) ((|PAdicInteger| . |BiModule|) 165010) ((|FourierSeries| . |SemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |AbelianMonoidRing|) 164969) ((|CardinalNumber| . |BasicType|) T) ((|AlgebraicFunctionField| . |DifferentialRing|) 164921) ((|AlgebraicFunctionField| . |DivisionRing|) T) ((|BalancedPAdicInteger| . |BasicType|) T) ((|InnerTaylorSeries| . |IntegralDomain|) 164888) ((|InnerSparseUnivariatePowerSeries| . |IntegralDomain|) 164855) ((|MachineComplex| . |CoercibleTo|) 164829) ((|MachineComplex| . |ConvertibleTo|) 164674) ((|Expression| . |InnerEvalable|) 164636) ((|ExponentialExpansion| . |InnerEvalable|) 164042) ((|PseudoAlgebraicClosureOfRationalNumber| . |LeftOreRing|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |LeftOreRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |RetractableTo|) 164026) ((|UnivariateLaurentSeriesConstructor| . |RetractableTo|) 163741) ((|Quaternion| . |FullyRetractableTo|) 163725) ((|FourierSeries| . |AbelianMonoid|) T) ((|SingleInteger| . |CommutativeRing|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Monoid|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Monoid|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |EntireRing|) T) ((|LinearOrdinaryDifferentialOperator2| . |Module|) 163682) ((|Character| . |SetCategory|) T) ((|AlgebraicNumber| . |RadicalCategory|) T) ((|Fraction| . |DifferentialExtension|) 163666) ((|EqTable| . |DictionaryOperations|) 163608) ((|SimpleCell| . |CoercibleTo|) 163582) ((|PAdicRational| . |PrincipalIdealDomain|) T) ((|PAdicRational| . |OrderedIntegralDomain|) NIL) ((|ProjectiveSpace| . |CoercibleTo|) 163556) ((|OrderedVariableList| . |OrderedSet|) T) ((|UnivariateLaurentSeriesConstructor| . |FullyEvalableOver|) 163523) ((|UnivariateLaurentSeriesConstructor| . |FullyLinearlyExplicitRingOver|) 163490) ((|Dequeue| . |StackAggregate|) 163474) ((|NeitherSparseOrDensePowerSeries| . |Type|) T) ((|Vector| . |EltableAggregate|) 163446) ((|HTMLFormat| . |BasicType|) T) ((|TaylorSeries| . |LeftModule|) 163343) ((|PolynomialRing| . |AbelianGroup|) T) ((|PolynomialRing| . |AbelianSemiGroup|) T) ((|MonoidRing| . |AbelianGroup|) T) ((|MonoidRing| . |AbelianSemiGroup|) T) ((|ModularRing| . |AbelianGroup|) T) ((|ModularRing| . |AbelianSemiGroup|) T) ((|ModularField| . |LeftModule|) 163297) ((|GenericNonAssociativeAlgebra| . |AbelianGroup|) T) ((|GenericNonAssociativeAlgebra| . |AbelianSemiGroup|) T) ((|FortranExpression| . |BasicType|) T) ((|ContinuedFraction| . |BasicType|) T) ((|Quaternion| . |Rng|) T) ((|PAdicInteger| . |Ring|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |RetractableTo|) 163281) ((|None| . |BasicType|) T) ((|U32Vector| . |InnerEvalable|) NIL) ((|UnivariatePuiseuxSeries| . |Field|) 163257) ((|UnivariatePuiseuxSeriesConstructor| . |PartialDifferentialRing|) 163119) ((|UnivariateLaurentSeries| . |Field|) 163095) ((|UnivariateLaurentSeriesConstructor| . |PartialDifferentialRing|) 162884) ((|RealClosure| . |CoercibleTo|) 162858) ((|Fraction| . |OpenMath|) 162788) ((|SparseUnivariateTaylorSeries| . |HyperbolicFunctionCategory|) 162737) ((|Complex| . |PrincipalIdealDomain|) 162638) ((|SparseUnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 162587) ((|SparseUnivariateLaurentSeries| . |HyperbolicFunctionCategory|) 162536) ((|ModMonic| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |HyperbolicFunctionCategory|) 162485) ((|InnerPAdicInteger| . |RightModule|) 162472) ((|Integer| . |RightModule|) 162459) ((|InnerAlgebraicNumber| . |RightModule|) 162413) ((|Expression| . |EntireRing|) 162380) ((|ExponentialExpansion| . |EntireRing|) T) ((|FiniteField| . |CoercibleTo|) 162354) ((|Factored| . |AbelianSemiGroup|) T) ((|Factored| . |AbelianGroup|) T) ((|Automorphism| . |Eltable|) 162333) ((|InnerPAdicInteger| . |BiModule|) 162318) ((|Integer| . |BiModule|) 162303) ((|InnerAlgebraicNumber| . |BiModule|) 162230) ((|Symbol| . |PatternMatchable|) 162189) ((|AffineSpace| . |BasicType|) T) ((|PendantTree| . |HomogeneousAggregate|) 162173) ((|BlowUpWithHamburgerNoether| . |CoercibleTo|) 162147) ((|AlgebraicNumber| . |CoercibleTo|) 162121) ((|AlgebraicNumber| . |ConvertibleTo|) 162046) ((|DesingTree| . |HomogeneousAggregate|) 162030) ((|DirectProduct| . |CancellationAbelianMonoid|) 161833) ((|UnivariatePolynomial| . |PrincipalIdealDomain|) 161809) ((|OrderlyDifferentialPolynomial| . |UniqueFactorizationDomain|) 161759) ((|Result| . |InnerEvalable|) 161509) ((|StochasticDifferential| . |CancellationAbelianMonoid|) T) ((|FileName| . |CoercibleTo|) 161483) ((|OrderlyDifferentialPolynomial| . |IntegralDomain|) 161369) ((|IntegrationResult| . |LeftModule|) 161333) ((|DifferentialSparseMultivariatePolynomial| . |AbelianMonoidRing|) 161291) ((|DistributedMultivariatePolynomial| . |AbelianMonoidRing|) 161223) ((|IndexedExponents| . |IndexedDirectProductCategory|) 161184) ((|Queue| . |Type|) T) ((|UnivariateTaylorSeries| . |AbelianMonoid|) T) ((|UnivariateTaylorSeries| . |SemiGroup|) T) ((|UnivariatePuiseuxSeries| . |SemiGroup|) T) ((|MachineFloat| . |RightModule|) 161138) ((|NeitherSparseOrDensePowerSeries| . |PartialDifferentialRing|) 161013) ((|UnivariatePuiseuxSeries| . |AbelianMonoid|) T) ((|UnivariateLaurentSeries| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |SemiGroup|) T) ((|RadicalFunctionField| . |FiniteRankAlgebra|) 160979) ((|ModularField| . |LeftOreRing|) T) ((|Boolean| . |Finite|) T) ((|GeneralUnivariatePowerSeries| . |PartialDifferentialRing|) 160841) ((|UnivariateLaurentSeries| . |AbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |AbelianMonoid|) T) ((|PermutationGroup| . |CoercibleTo|) 160815) ((|ArrayStack| . |BagAggregate|) 160799) ((|TaylorSeries| . |Monoid|) T) ((|Permutation| . |OrderedSet|) 160741) ((|MachineInteger| . |StepThrough|) T) ((|MachineFloat| . |BiModule|) 160668) ((|U16Vector| . |SetCategory|) T) ((|InnerTaylorSeries| . |SemiGroup|) T) ((|InnerSparseUnivariatePowerSeries| . |SemiGroup|) T) ((|ModMonic| . |Module|) 160408) ((|ModularField| . |Monoid|) T) ((|SingleInteger| . |EntireRing|) T) ((|RadixExpansion| . |CancellationAbelianMonoid|) T) ((|HexadecimalExpansion| . |OrderedSet|) T) ((|Partition| . |CancellationAbelianMonoid|) T) ((|PartialFraction| . |CancellationAbelianMonoid|) T) ((|Octonion| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |OrderedSet|) T) ((|Octonion| . |AbelianGroup|) T) ((|InnerPAdicInteger| . |Ring|) T) ((|Integer| . |Ring|) T) ((|InnerAlgebraicNumber| . |Ring|) T) ((|InnerTaylorSeries| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |ExtensionField|) 160377) ((|ExponentialOfUnivariatePuiseuxSeries| . |GcdDomain|) 160353) ((|FortranExpression| . |Evalable|) 160340) ((|InnerSparseUnivariatePowerSeries| . |AbelianMonoid|) T) ((|FourierSeries| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator| . |LeftModule|) 160314) ((|SparseUnivariatePolynomialExpressions| . |RightModule|) 160048) ((|DataList| . |RecursiveAggregate|) 160032) ((|PAdicRationalConstructor| . |EuclideanDomain|) T) ((|XRecursivePolynomial| . |XAlgebra|) 160016) ((|NonNegativeInteger| . |OrderedAbelianMonoid|) T) ((|NonNegativeInteger| . |OrderedCancellationAbelianMonoid|) T) ((|MachineInteger| . |Algebra|) 160003) ((|Divisor| . |LeftModule|) 159980) ((|Integer| . |DifferentialRing|) T) ((|InnerAlgebraicNumber| . |DivisionRing|) T) ((|InnerAlgebraicNumber| . |DifferentialRing|) T) ((|SparseUnivariatePolynomialExpressions| . |BiModule|) 159682) ((|SparseTable| . |DictionaryOperations|) 159624) ((|SequentialDifferentialPolynomial| . |PolynomialFactorizationExplicit|) 159574) ((|BalancedPAdicInteger| . |Algebra|) 159561) ((|d02ejfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02cjfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02bhfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|d02bbfAnnaType| . |OrdinaryDifferentialEquationsSolverCategory|) T) ((|PAdicRationalConstructor| . |RealConstant|) 159530) ((|WuWenTsunTriangularSet| . |HomogeneousAggregate|) 159514) ((|NewSparseUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 159464) ((|NewSparseMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 159414) ((|Table| . |Type|) T) ((|GeneralDistributedMultivariatePolynomial| . |PolynomialFactorizationExplicit|) 159364) ((|Multiset| . |HomogeneousAggregate|) 159348) ((|SequentialDifferentialPolynomial| . |LeftModule|) 159245) ((|NewSparseUnivariatePolynomial| . |LeftModule|) 159142) ((|LaurentPolynomial| . |RightModule|) 159129) ((|HashTable| . |Type|) T) ((|FiniteFieldCyclicGroup| . |Finite|) T) ((|CharacterClass| . |HomogeneousAggregate|) 159104) ((|NewSparseMultivariatePolynomial| . |LeftModule|) 159001) ((|SplittingTree| . |Type|) T) ((|GeneralModulePolynomial| . |LeftModule|) 158972) ((|DifferentialSparseMultivariatePolynomial| . |PatternMatchable|) 158751) ((|DistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|BalancedPAdicRational| . |RightModule|) 158667) ((|GeneralDistributedMultivariatePolynomial| . |LeftModule|) 158564) ((|LiePolynomial| . |RetractableTo|) 158533) ((|LaurentPolynomial| . |BiModule|) 158518) ((|FiniteFieldExtensionByPolynomial| . |RetractableTo|) 158502) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |RetractableTo|) 158486) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |RetractableTo|) 158470) ((|DifferentialSparseMultivariatePolynomial| . |RetractableTo|) 158237) ((|DistributedMultivariatePolynomial| . |RetractableTo|) 158044) ((|BalancedPAdicRational| . |BiModule|) 157903) ((|OneDimensionalArray| . |Type|) T) ((|InnerIndexedTwoDimensionalArray| . |Type|) T) ((|IndexedFlexibleArray| . |Type|) T) ((|IndexedTwoDimensionalArray| . |Type|) T) ((|IndexedOneDimensionalArray| . |Type|) T) ((|FortranType| . |CoercibleTo|) 157877) ((|FortranScalarType| . |CoercibleTo|) 157851) ((|Union| . |BasicType|) T) ((|RegularTriangularSet| . |TriangularSetCategory|) 157820) ((|OnePointCompletion| . |BasicType|) T) ((|Matrix| . |TwoDimensionalArrayCategory|) 157772) ((|MachineFloat| . |Ring|) T) ((|AntiSymm| . |LeftModule|) 157746) ((|EuclideanModularRing| . |GcdDomain|) T) ((|GeneralTriangularSet| . |TriangularSetCategory|) 157715) ((|UnivariateTaylorSeriesCZero| . |Eltable|) 157700) ((|Enumeration| . |BasicType|) T) ((|InnerPrimeField| . |LeftModule|) 157654) ((|InnerFiniteField| . |LeftModule|) 157575) ((|AnonymousFunction| . |BasicType|) T) ((|PrimeField| . |RetractableTo|) 157562) ((|MachineFloat| . |DivisionRing|) T) ((|SimpleAlgebraicExtension| . |FramedAlgebra|) 157541) ((|MultivariatePolynomial| . |LinearlyExplicitRingOver|) 157457) ((|Quaternion| . |SetCategory|) T) ((|ModMonic| . |CommutativeRing|) 157287) ((|HexadecimalExpansion| . |QuotientFieldCategory|) 157264) ((|GuessOption| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 157248) ((|DistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 157232) ((|FullPartialFractionExpansion| . |SetCategory|) T) ((|SparseUnivariatePolynomialExpressions| . |Ring|) T) ((|FortranExpression| . |Algebra|) 157216) ((|Reference| . |BasicType|) 157186) ((|DecimalExpansion| . |QuotientFieldCategory|) 157163) ((|ContinuedFraction| . |Algebra|) 157078) ((|UnivariatePuiseuxSeriesConstructor| . |EuclideanDomain|) 157054) ((|UnivariateLaurentSeriesConstructor| . |EuclideanDomain|) 157030) ((|SparseUnivariatePolynomialExpressions| . |FiniteAbelianMonoidRing|) 156991) ((|LinearOrdinaryDifferentialOperator| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |DifferentialRing|) T) ((|Automorphism| . |CoercibleTo|) 156965) ((|SparseUnivariateLaurentSeries| . |LinearlyExplicitRingOver|) 156889) ((|HyperellipticFiniteDivisor| . |AbelianSemiGroup|) T) ((|HyperellipticFiniteDivisor| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |RealConstant|) 156829) ((|SequentialDifferentialPolynomial| . |LeftOreRing|) 156747) ((|LaurentPolynomial| . |Ring|) T) ((|Float| . |FloatingPointSystem|) T) ((|NewSparseUnivariatePolynomial| . |LeftOreRing|) 156642) ((|NewSparseMultivariatePolynomial| . |LeftOreRing|) 156560) ((|FreeNilpotentLie| . |BasicType|) T) ((|DifferentialSparseMultivariatePolynomial| . |PartialDifferentialRing|) 156479) ((|DistributedMultivariatePolynomial| . |PartialDifferentialRing|) 156439) ((|BalancedPAdicRational| . |Ring|) T) ((|GeneralDistributedMultivariatePolynomial| . |LeftOreRing|) 156357) ((|OrderlyDifferentialPolynomial| . |SemiGroup|) T) ((|SequentialDifferentialPolynomial| . |Monoid|) T) ((|LaurentPolynomial| . |DifferentialRing|) 156322) ((|LocalAlgebra| . |BasicType|) T) ((|U32Vector| . |HomogeneousAggregate|) 156299) ((|NewSparseUnivariatePolynomial| . |Monoid|) T) ((|NewSparseMultivariatePolynomial| . |Monoid|) T) ((|U32Matrix| . |TwoDimensionalArrayCategory|) 156248) ((|FractionalIdeal| . |SemiGroup|) T) ((|BalancedPAdicRational| . |DivisionRing|) T) ((|AlgebraicFunctionField| . |Finite|) NIL) ((|BalancedPAdicRational| . |DifferentialRing|) NIL) ((|GeneralDistributedMultivariatePolynomial| . |Monoid|) T) ((|OrderlyDifferentialPolynomial| . |AbelianMonoid|) T) ((|MultivariatePolynomial| . |AbelianSemiGroup|) T) ((|MultivariatePolynomial| . |AbelianGroup|) T) ((|MakeCachableSet| . |OrderedSet|) T) ((|Ruleset| . |Eltable|) 156227) ((|Asp4| . |FortranFunctionCategory|) T) ((|Asp4| . |FortranProgramCategory|) T) ((|UnivariateTaylorSeriesCZero| . |RadicalCategory|) 156176) ((|UnivariateTaylorSeries| . |CancellationAbelianMonoid|) T) ((|UnivariatePuiseuxSeries| . |CancellationAbelianMonoid|) T) ((|MachineComplex| . |RightModule|) 156105) ((|UnivariateLaurentSeries| . |CancellationAbelianMonoid|) T) ((|UnivariateFormalPowerSeries| . |CancellationAbelianMonoid|) T) ((|SparseUnivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|Stream| . |StreamAggregate|) 156089) ((|SquareMatrix| . |FullyRetractableTo|) 156073) ((|InnerPrimeField| . |LeftOreRing|) T) ((|AssociatedLieAlgebra| . |FiniteRankNonAssociativeAlgebra|) 155954) ((|AssociatedJordanAlgebra| . |FiniteRankNonAssociativeAlgebra|) 155835) ((|InnerFiniteField| . |LeftOreRing|) T) ((|BalancedBinaryTree| . |SetCategory|) 155805) ((|SparseUnivariateTaylorSeries| . |AbelianGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|Quaternion| . |Module|) 155739) ((|DeRhamComplex| . |LeftModule|) 155698) ((|MachineComplex| . |BiModule|) 155583) ((|AntiSymm| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |AbelianGroup|) T) ((|FiniteFieldNormalBasis| . |FiniteFieldCategory|) T) ((|SparseUnivariateLaurentSeries| . |AbelianSemiGroup|) T) ((|SimpleAlgebraicExtension| . |GcdDomain|) 155517) ((|SparseMultivariateTaylorSeries| . |AbelianGroup|) T) ((|ModMonic| . |InnerEvalable|) 155427) ((|InnerPrimeField| . |Monoid|) T) ((|InnerFiniteField| . |Monoid|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |EuclideanDomain|) T) ((|SparseMultivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|NeitherSparseOrDensePowerSeries| . |EuclideanDomain|) T) ((|InnerTaylorSeries| . |CancellationAbelianMonoid|) T) ((|InnerSparseUnivariatePowerSeries| . |CancellationAbelianMonoid|) T) ((|FiniteFieldExtension| . |GcdDomain|) T) ((|FiniteFieldNormalBasisExtension| . |GcdDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |GcdDomain|) T) ((|GeneralUnivariatePowerSeries| . |EuclideanDomain|) 155403) ((|ExponentialExpansion| . |Eltable|) 155080) ((|BinaryExpansion| . |GcdDomain|) T) ((|Asp50| . |FortranVectorFunctionCategory|) T) ((|Asp50| . |FortranProgramCategory|) T) ((|Pi| . |BasicType|) T) ((|MyExpression| . |ConvertibleTo|) 154858) ((|MyExpression| . |CoercibleTo|) 154832) ((|IntegerMod| . |CoercibleTo|) 154806) ((|IntegerMod| . |ConvertibleTo|) 154783) ((|SimpleAlgebraicExtension| . |FieldOfPrimeCharacteristic|) 154745) ((|Result| . |HomogeneousAggregate|) 154662) ((|Integer| . |OrderedCancellationAbelianMonoid|) T) ((|Integer| . |OrderedAbelianMonoid|) T) ((|RoutinesTable| . |DictionaryOperations|) 154595) ((|FiniteFieldExtension| . |FieldOfPrimeCharacteristic|) 154526) ((|FiniteFieldNormalBasisExtension| . |FieldOfPrimeCharacteristic|) 154457) ((|FiniteFieldCyclicGroupExtension| . |FieldOfPrimeCharacteristic|) 154388) ((|XDistributedPolynomial| . |SemiGroup|) T) ((|XDistributedPolynomial| . |AbelianMonoid|) T) ((|ThreeDimensionalViewport| . |BasicType|) T) ((|SquareMatrix| . |Rng|) T) ((|LieSquareMatrix| . |NonAssociativeAlgebra|) 154372) ((|SymmetricPolynomial| . |CharacteristicNonZero|) 154332) ((|SymmetricPolynomial| . |CharacteristicZero|) 154295) ((|SquareFreeRegularTriangularSet| . |SetCategory|) T) ((|SquareFreeRegularTriangularSet| . |RegularTriangularSetCategory|) 154264) ((|Asp29| . |Type|) T) ((|RealClosure| . |RightModule|) 154185) ((|OrdinaryWeightedPolynomials| . |Rng|) T) ((|MyUnivariatePolynomial| . |CharacteristicNonZero|) 154145) ((|MyUnivariatePolynomial| . |CharacteristicZero|) 154108) ((|DirectProduct| . |LinearlyExplicitRingOver|) 153980) ((|MachineComplex| . |Ring|) T) ((|DirichletRing| . |IntegralDomain|) 153946) ((|FiniteField| . |RightModule|) 153872) ((|Asp10| . |Type|) T) ((|RealClosure| . |BiModule|) 153749) ((|PendantTree| . |CoercibleTo|) 153700) ((|MachineComplex| . |DivisionRing|) T) ((|MachineComplex| . |DifferentialRing|) NIL) ((|U16Vector| . |InnerEvalable|) NIL) ((|OrderedCompletion| . |OrderedRing|) 153670) ((|MachineFloat| . |OrderedCancellationAbelianMonoid|) T) ((|MachineFloat| . |OrderedAbelianMonoid|) T) ((|UnivariateTaylorSeriesCZero| . |CoercibleTo|) 153644) ((|U32Vector| . |Eltable|) 153609) ((|RadicalFunctionField| . |FullyRetractableTo|) 153580) ((|FiniteField| . |BiModule|) 153459) ((|DesingTree| . |CoercibleTo|) 153410) ((|Float| . |PrincipalIdealDomain|) T) ((|Fraction| . |OrderedRing|) 153370) ((|ModMonic| . |EntireRing|) 153233) ((|DeRhamComplex| . |Monoid|) T) ((|UnivariateTaylorSeries| . |HyperbolicFunctionCategory|) 153182) ((|UnivariatePuiseuxSeries| . |HyperbolicFunctionCategory|) 153131) ((|UnivariateLaurentSeries| . |HyperbolicFunctionCategory|) 153080) ((|UnivariateFormalPowerSeries| . |HyperbolicFunctionCategory|) 153029) ((|Expression| . |RadicalCategory|) 152996) ((|Dequeue| . |SetCategory|) 152966) ((|ExponentialOfUnivariatePuiseuxSeries| . |PowerSeriesCategory|) 152899) ((|BasicFunctions| . |BasicType|) T) ((|AlgebraicNumber| . |RightModule|) 152853) ((|XRecursivePolynomial| . |BasicType|) T) ((|FreeModule1| . |BasicType|) T) ((|AlgebraicNumber| . |BiModule|) 152780) ((|RadixExpansion| . |LinearlyExplicitRingOver|) 152757) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CoercibleTo|) 152731) ((|IndexedExponents| . |BasicType|) T) ((|IndexedBits| . |BasicType|) T) ((|ThreeSpace| . |ThreeSpaceCategory|) 152715) ((|CliffordAlgebra| . |VectorSpace|) 152699) ((|DataList| . |Type|) T) ((|U32Vector| . |OneDimensionalArrayAggregate|) 152676) ((|NeitherSparseOrDensePowerSeries| . |LazyStreamAggregate|) 152617) ((|SparseUnivariatePolynomial| . |UniqueFactorizationDomain|) 152567) ((|SparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 152517) ((|DirectProduct| . |AbelianGroup|) 152404) ((|DirectProduct| . |AbelianSemiGroup|) 152173) ((|BinaryTree| . |BinaryRecursiveAggregate|) 152157) ((|BinarySearchTree| . |BinaryRecursiveAggregate|) 152141) ((|U8Vector| . |LinearAggregate|) 152118) ((|AlgebraGivenByStructuralConstants| . |NonAssociativeAlgebra|) 152102) ((|U32Vector| . |IndexedAggregate|) 152067) ((|SparseUnivariatePolynomial| . |IntegralDomain|) 151930) ((|SparseMultivariatePolynomial| . |IntegralDomain|) 151816) ((|U8Vector| . |FiniteLinearAggregate|) 151793) ((|Result| . |Eltable|) 151763) ((|StochasticDifferential| . |AbelianSemiGroup|) T) ((|StochasticDifferential| . |AbelianGroup|) T) ((|OrderlyDifferentialPolynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |OrderedCancellationAbelianMonoid|) NIL) ((|BalancedPAdicRational| . |OrderedAbelianMonoid|) NIL) ((|FiniteFieldExtensionByPolynomial| . |EuclideanDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |EuclideanDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |EuclideanDomain|) T) ((|Segment| . |Type|) T) ((|DirectProductModule| . |SemiGroup|) 151649) ((|DirectProductMatrixModule| . |SemiGroup|) 151535) ((|RealClosure| . |Ring|) T) ((|RadicalFunctionField| . |Rng|) T) ((|FiniteFieldCyclicGroup| . |LeftModule|) 151461) ((|LocalAlgebra| . |Algebra|) 151445) ((|WuWenTsunTriangularSet| . |CoercibleTo|) 151397) ((|WuWenTsunTriangularSet| . |ConvertibleTo|) 151333) ((|Ruleset| . |CoercibleTo|) 151307) ((|RealClosure| . |DivisionRing|) T) ((|FiniteField| . |Ring|) T) ((|OrderedDirectProduct| . |VectorSpace|) 151274) ((|DirectProductModule| . |AbelianMonoid|) T) ((|DirectProductMatrixModule| . |AbelianMonoid|) T) ((|QuasiAlgebraicSet| . |CoercibleTo|) 151248) ((|Multiset| . |ConvertibleTo|) 151184) ((|Multiset| . |CoercibleTo|) 151158) ((|Octonion| . |OrderedSet|) 151129) ((|Quaternion| . |InnerEvalable|) 151018) ((|FiniteField| . |DifferentialRing|) T) ((|FiniteField| . |DivisionRing|) T) ((|StringTable| . |Collection|) 150954) ((|RadixExpansion| . |AbelianSemiGroup|) T) ((|CharacterClass| . |CoercibleTo|) 150928) ((|CharacterClass| . |ConvertibleTo|) 150875) ((|PrimeField| . |EuclideanDomain|) T) ((|RadixExpansion| . |AbelianGroup|) T) ((|Partition| . |AbelianSemiGroup|) T) ((|PartialFraction| . |AbelianGroup|) T) ((|PartialFraction| . |AbelianSemiGroup|) T) ((|FourierSeries| . |AbelianGroup|) T) ((|FourierSeries| . |AbelianSemiGroup|) T) ((|OrderedCompletion| . |FullyRetractableTo|) 150859) ((|AlgebraicNumber| . |Ring|) T) ((|XPolynomial| . |XAlgebra|) 150843) ((|XPBWPolynomial| . |XAlgebra|) 150827) ((|Result| . |IndexedAggregate|) 150797) ((|Expression| . |ConvertibleTo|) 150575) ((|Expression| . |CoercibleTo|) 150549) ((|ExponentialExpansion| . |ConvertibleTo|) NIL) ((|ExponentialExpansion| . |CoercibleTo|) 150523) ((|AlgebraicNumber| . |DivisionRing|) T) ((|AlgebraicNumber| . |DifferentialRing|) T) ((|LinearOrdinaryDifferentialOperator2| . |Eltable|) 150484) ((|InnerTable| . |DictionaryOperations|) 150426) ((|CartesianTensor| . |CoercibleTo|) 150400) ((|BasicOperator| . |CoercibleTo|) 150374) ((|Pi| . |Algebra|) 150328) ((|XRecursivePolynomial| . |XPolynomialsCat|) 150307) ((|XDistributedPolynomial| . |CancellationAbelianMonoid|) T) ((|XPolynomialRing| . |Rng|) T) ((|SingletonAsOrderedSet| . |BasicType|) T) ((|BlowUpWithQuadTrans| . |CoercibleTo|) 150281) ((|Asp8| . |Type|) T) ((|IndexedBits| . |Evalable|) NIL) ((|Queue| . |BagAggregate|) 150265) ((|PatternMatchResult| . |SetCategory|) T) ((|PatternMatchListResult| . |SetCategory|) T) ((|Vector| . |LinearAggregate|) 150249) ((|Vector| . |FiniteLinearAggregate|) 150233) ((|FlexibleArray| . |Type|) T) ((|IndexedString| . |OrderedSet|) T) ((|DirichletRing| . |SemiGroup|) T) ((|SquareMatrix| . |SetCategory|) T) ((|SquareMatrix| . |RectangularMatrixCategory|) 150151) ((|FiniteFieldCyclicGroup| . |LeftOreRing|) T) ((|BalancedBinaryTree| . |InnerEvalable|) 150070) ((|Plot| . |CoercibleTo|) 150044) ((|DirichletRing| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |Monoid|) T) ((|PlaneAlgebraicCurvePlot| . |CoercibleTo|) 150018) ((|OrdinaryWeightedPolynomials| . |SetCategory|) T) ((|OrderedCompletion| . |Rng|) 149988) ((|AlgebraicFunctionField| . |LeftModule|) 149916) ((|DoubleFloat| . |UniqueFactorizationDomain|) T) ((|Fraction| . |Rng|) T) ((|String| . |Collection|) 149891) ((|Quaternion| . |EntireRing|) 149834) ((|DoubleFloat| . |IntegralDomain|) T) ((|U32Vector| . |ConvertibleTo|) 149809) ((|ExponentialOfUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 149793) ((|ExponentialOfUnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 149752) ((|U32Vector| . |CoercibleTo|) 149726) ((|Table| . |TableAggregate|) 149705) ((|RuleCalled| . |CoercibleTo|) 149679) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |CoercibleTo|) 149653) ((|PseudoAlgebraicClosureOfRationalNumber| . |RetractableTo|) 149597) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |RetractableTo|) 149490) ((|ListMultiDictionary| . |Collection|) 149474) ((|Library| . |Collection|) 149407) ((|Table| . |BagAggregate|) 149349) ((|HashTable| . |TableAggregate|) 149328) ((|HexadecimalExpansion| . |CharacteristicZero|) T) ((|HexadecimalExpansion| . |CharacteristicNonZero|) NIL) ((|SingleInteger| . |ConvertibleTo|) 149209) ((|FunctionCalled| . |CoercibleTo|) 149183) ((|DecimalExpansion| . |CharacteristicZero|) T) ((|DecimalExpansion| . |CharacteristicNonZero|) NIL) ((|SingleInteger| . |CoercibleTo|) 149157) ((|Any| . |BasicType|) T) ((|UnivariateLaurentSeries| . |LinearlyExplicitRingOver|) 149087) ((|HashTable| . |BagAggregate|) 149029) ((|QuadraticForm| . |AbelianMonoid|) T) ((|XRecursivePolynomial| . |Algebra|) 148986) ((|SparseUnivariatePolynomial| . |SemiGroup|) T) ((|SparseMultivariatePolynomial| . |SemiGroup|) T) ((|RomanNumeral| . |UniqueFactorizationDomain|) T) ((|SparseUnivariateSkewPolynomial| . |SemiGroup|) T) ((|Polynomial| . |UniqueFactorizationDomain|) 148936) ((|U16Vector| . |HomogeneousAggregate|) 148913) ((|HomogeneousDistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 148863) ((|MultivariatePolynomial| . |OrderedSet|) 148834) ((|RomanNumeral| . |IntegralDomain|) T) ((|U16Matrix| . |TwoDimensionalArrayCategory|) 148783) ((|Polynomial| . |IntegralDomain|) 148669) ((|SparseUnivariatePolynomial| . |AbelianMonoid|) T) ((|SparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |IntegralDomain|) 148555) ((|SquareMatrix| . |Module|) 148462) ((|SquareFreeRegularTriangularSet| . |InnerEvalable|) 148381) ((|Result| . |ConvertibleTo|) NIL) ((|Result| . |CoercibleTo|) 148355) ((|IntegerMod| . |RightModule|) 148342) ((|OrdinaryWeightedPolynomials| . |Module|) 148299) ((|IntegerMod| . |BiModule|) 148284) ((|UnivariateTaylorSeries| . |AbelianSemiGroup|) T) ((|TaylorSeries| . |AbelianMonoidRing|) 148236) ((|DirectProductModule| . |CancellationAbelianMonoid|) T) ((|DirectProductMatrixModule| . |CancellationAbelianMonoid|) T) ((|SExpression| . |SetCategory|) T) ((|RadicalFunctionField| . |SetCategory|) T) ((|Asp12| . |CoercibleTo|) 148210) ((|SparseUnivariateLaurentSeries| . |OrderedSet|) NIL) ((|RealClosure| . |OrderedAbelianMonoid|) T) ((|RealClosure| . |OrderedCancellationAbelianMonoid|) T) ((|UnivariateTaylorSeries| . |AbelianGroup|) T) ((|MyExpression| . |RightModule|) 148098) ((|UnivariatePuiseuxSeries| . |AbelianGroup|) T) ((|AlgebraicFunctionField| . |LeftOreRing|) T) ((|PAdicInteger| . |LeftModule|) 148085) ((|UnivariatePuiseuxSeries| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeries| . |AbelianGroup|) T) ((|UnivariateLaurentSeries| . |AbelianSemiGroup|) T) ((|UnivariateFormalPowerSeries| . |AbelianSemiGroup|) T) ((|UnivariateFormalPowerSeries| . |AbelianGroup|) T) ((|RegularTriangularSet| . |Collection|) 148069) ((|PAdicRationalConstructor| . |OrderedIntegralDomain|) 148029) ((|PAdicRationalConstructor| . |PrincipalIdealDomain|) T) ((|MyExpression| . |BiModule|) 147885) ((|ModMonic| . |Eltable|) 147788) ((|InnerTaylorSeries| . |AbelianGroup|) T) ((|InnerTaylorSeries| . |AbelianSemiGroup|) T) ((|InnerSparseUnivariatePowerSeries| . |AbelianGroup|) T) ((|AlgebraicFunctionField| . |Monoid|) T) ((|Dequeue| . |InnerEvalable|) 147707) ((|InnerSparseUnivariatePowerSeries| . |AbelianSemiGroup|) T) ((|GeneralTriangularSet| . |Collection|) 147691) ((|GeneralPolynomialSet| . |Collection|) 147675) ((|PositiveInteger| . |Monoid|) T) ((|NonNegativeInteger| . |OrderedAbelianMonoidSup|) T) ((|NonNegativeInteger| . |OrderedAbelianSemiGroup|) T) ((|IndexCard| . |SetCategory|) T) ((|NonNegativeInteger| . |Monoid|) T) ((|DoubleFloat| . |Field|) T) ((|Stream| . |SetCategory|) 147645) ((|PAdicRational| . |UniqueFactorizationDomain|) T) ((|LinearOrdinaryDifferentialOperator2| . |CoercibleTo|) 147619) ((|PAdicRational| . |IntegralDomain|) T) ((|Cell| . |CoercibleTo|) 147593) ((|MachineComplex| . |Finite|) NIL) ((|FiniteFieldExtension| . |VectorSpace|) 147577) ((|LieSquareMatrix| . |BasicType|) T) ((|FiniteFieldNormalBasisExtension| . |VectorSpace|) 147561) ((|FiniteFieldCyclicGroupExtension| . |VectorSpace|) 147545) ((|XPolynomialRing| . |SetCategory|) T) ((|IndexedList| . |OrderedSet|) 147516) ((|UnivariateTaylorSeriesCZero| . |RightModule|) 147349) ((|OrdinaryDifferentialRing| . |GcdDomain|) 147325) ((|RegularChain| . |SetCategory|) T) ((|RegularChain| . |RegularTriangularSetCategory|) 147160) ((|RegularTriangularSet| . |PolynomialSetCategory|) 147129) ((|OrderedFreeMonoid| . |SemiGroup|) T) ((|RadicalFunctionField| . |Module|) 147057) ((|UnivariateTaylorSeriesCZero| . |BiModule|) 146858) ((|DirichletRing| . |CancellationAbelianMonoid|) T) ((|FreeMonoid| . |SemiGroup|) T) ((|GeneralTriangularSet| . |PolynomialSetCategory|) 146827) ((|GeneralPolynomialSet| . |PolynomialSetCategory|) 146796) ((|Places| . |SetCategoryWithDegree|) T) ((|Bits| . |Collection|) 146773) ((|Asp34| . |CoercibleTo|) 146747) ((|PoincareBirkhoffWittLyndonBasis| . |CoercibleTo|) 146721) ((|SimpleAlgebraicExtension| . |MonogenicAlgebra|) 146700) ((|MyExpression| . |Ring|) T) ((|IntegerMod| . |Ring|) T) ((|U16Vector| . |Eltable|) 146665) ((|PAdicInteger| . |LeftOreRing|) T) ((|OrderlyDifferentialPolynomial| . |LinearlyExplicitRingOver|) 146581) ((|Equation| . |Rng|) 146501) ((|Complex| . |UniqueFactorizationDomain|) 146347) ((|DoubleFloat| . |SemiGroup|) T) ((|FreeAbelianMonoid| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |QuotientFieldCategory|) 146271) ((|OrderedCompletion| . |SetCategory|) T) ((|MyExpression| . |DivisionRing|) 146238) ((|SparseMultivariateTaylorSeries| . |MultivariateTaylorSeriesCategory|) 146217) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |RightModule|) 146038) ((|UnivariatePuiseuxSeriesConstructor| . |PrincipalIdealDomain|) 146014) ((|PAdicInteger| . |Monoid|) T) ((|Complex| . |IntegralDomain|) 145883) ((|UnivariateLaurentSeriesConstructor| . |PrincipalIdealDomain|) 145859) ((|InnerPAdicInteger| . |LeftModule|) 145846) ((|Fraction| . |SetCategory|) T) ((|Integer| . |LeftModule|) 145833) ((|DrawOption| . |SetCategory|) T) ((|InnerAlgebraicNumber| . |LeftModule|) 145787) ((|DoubleFloat| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedIntegralDomain|) 145718) ((|ProjectivePlane| . |SetCategory|) T) ((|XPolynomial| . |BasicType|) T) ((|FiniteField| . |ExtensionField|) 145687) ((|XPBWPolynomial| . |BasicType|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |BiModule|) 145438) ((|Character| . |CoercibleTo|) 145412) ((|QuadraticForm| . |CancellationAbelianMonoid|) T) ((|AlgebraGivenByStructuralConstants| . |BasicType|) T) ((|DirectProduct| . |OrderedSet|) 145336) ((|XPolynomialRing| . |Module|) 145293) ((|UnivariatePolynomial| . |UniqueFactorizationDomain|) 145243) ((|BalancedBinaryTree| . |HomogeneousAggregate|) 145227) ((|UnivariatePolynomial| . |IntegralDomain|) 145090) ((|U16Vector| . |OneDimensionalArrayAggregate|) 145067) ((|SequentialDifferentialPolynomial| . |AbelianMonoidRing|) 144984) ((|RomanNumeral| . |SemiGroup|) T) ((|Polynomial| . |SemiGroup|) T) ((|BinaryTree| . |Aggregate|) T) ((|BinarySearchTree| . |Aggregate|) T) ((|U8Vector| . |Aggregate|) T) ((|U32Vector| . |EltableAggregate|) 144949) ((|NewSparseUnivariatePolynomial| . |AbelianMonoidRing|) 144910) ((|NewSparseMultivariatePolynomial| . |AbelianMonoidRing|) 144868) ((|U16Vector| . |IndexedAggregate|) 144833) ((|SparseUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteField| . |Finite|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |SemiGroup|) T) ((|SparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|RomanNumeral| . |AbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianMonoidRing|) 144812) ((|PAdicRational| . |Field|) T) ((|SparseUnivariateSkewPolynomial| . |CancellationAbelianMonoid|) T) ((|CliffordAlgebra| . |BasicType|) T) ((|MyUnivariatePolynomial| . |GcdDomain|) 144707) ((|Polynomial| . |AbelianMonoid|) T) ((|Interval| . |IntegralDomain|) T) ((|OrderlyDifferentialPolynomial| . |AbelianSemiGroup|) T) ((|OrderlyDifferentialPolynomial| . |AbelianGroup|) T) ((|SquareMatrix| . |InnerEvalable|) 144626) ((|IntegrationResult| . |RetractableTo|) 144610) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasis| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |Ring|) T) ((|TaylorSeries| . |PartialDifferentialRing|) 144588) ((|LieSquareMatrix| . |Evalable|) 144512) ((|UnivariateTaylorSeriesCZero| . |DifferentialRing|) 144449) ((|SplitHomogeneousDirectProduct| . |VectorSpace|) 144416) ((|MachineFloat| . |LeftModule|) 144370) ((|RadixExpansion| . |OrderedSet|) T) ((|RadicalFunctionField| . |CommutativeRing|) T) ((|PolynomialRing| . |CharacteristicNonZero|) 144330) ((|AssociatedLieAlgebra| . |SetCategory|) T) ((|AssociatedJordanAlgebra| . |SetCategory|) T) ((|PolynomialRing| . |CharacteristicZero|) 144293) ((|PseudoAlgebraicClosureOfFiniteField| . |PrincipalIdealDomain|) T) ((|MonoidRing| . |CharacteristicZero|) 144256) ((|MonoidRing| . |CharacteristicNonZero|) 144216) ((|Partition| . |OrderedSet|) T) ((|NeitherSparseOrDensePowerSeries| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |PrincipalIdealDomain|) 144192) ((|Expression| . |RightModule|) 144054) ((|ExponentialExpansion| . |RightModule|) 143926) ((|Quaternion| . |Eltable|) 143879) ((|SparseUnivariatePolynomialExpressions| . |PolynomialFactorizationExplicit|) 143829) ((|Fraction| . |Module|) 143770) ((|MachineInteger| . |OrderedRing|) T) ((|InfinitlyClosePoint| . |SetCategoryWithDegree|) T) ((|InfClsPt| . |SetCategory|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |FiniteAbelianMonoidRing|) 143660) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Ring|) T) ((|InnerPAdicInteger| . |LeftOreRing|) T) ((|Expression| . |BiModule|) 143490) ((|ExponentialExpansion| . |BiModule|) 143261) ((|Integer| . |LeftOreRing|) T) ((|InnerAlgebraicNumber| . |LeftOreRing|) T) ((|SparseUnivariatePolynomialExpressions| . |LeftModule|) 143158) ((|Product| . |BasicType|) T) ((|OrderedDirectProduct| . |BasicType|) 142850) ((|ModMonic| . |ConvertibleTo|) NIL) ((|ModMonic| . |CoercibleTo|) 142824) ((|Result| . |EltableAggregate|) 142794) ((|LinearOrdinaryDifferentialOperator| . |RetractableTo|) 142638) ((|PseudoAlgebraicClosureOfRationalNumber| . |EuclideanDomain|) T) ((|InnerPAdicInteger| . |Monoid|) T) ((|Integer| . |OrderedAbelianSemiGroup|) T) ((|Integer| . |OrderedAbelianGroup|) T) ((|Complex| . |Field|) 142572) ((|Integer| . |Monoid|) T) ((|InnerAlgebraicNumber| . |Monoid|) T) ((|Divisor| . |RetractableTo|) 142556) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |EuclideanDomain|) T) ((|SquareFreeRegularTriangularSet| . |HomogeneousAggregate|) 142540) ((|SequentialDifferentialPolynomial| . |PatternMatchable|) NIL) ((|PAdicRational| . |SemiGroup|) T) ((|BalancedPAdicRational| . |PolynomialFactorizationExplicit|) NIL) ((|XPolynomial| . |XPolynomialsCat|) 142513) ((|XPBWPolynomial| . |XPolynomialsCat|) 142492) ((|NewSparseUnivariatePolynomial| . |PatternMatchable|) NIL) ((|NewSparseMultivariatePolynomial| . |PatternMatchable|) 142271) ((|XDistributedPolynomial| . |AbelianSemiGroup|) T) ((|XDistributedPolynomial| . |AbelianGroup|) T) ((|Tuple| . |BasicType|) 142241) ((|SimpleFortranProgram| . |FortranProgramCategory|) T) ((|LaurentPolynomial| . |LeftModule|) 142228) ((|GeneralDistributedMultivariatePolynomial| . |PatternMatchable|) NIL) ((|ThreeDimensionalMatrix| . |BasicType|) 142198) ((|SequentialDifferentialPolynomial| . |RetractableTo|) 141912) ((|PAdicRational| . |AbelianMonoid|) T) ((|NewSparseUnivariatePolynomial| . |RetractableTo|) 141678) ((|NewSparseMultivariatePolynomial| . |RetractableTo|) 141458) ((|BalancedPAdicRational| . |LeftModule|) 141374) ((|GeneralDistributedMultivariatePolynomial| . |RetractableTo|) 141181) ((|ListMonoidOps| . |RetractableTo|) 141165) ((|LieExponentials| . |BasicType|) T) ((|Dequeue| . |HomogeneousAggregate|) 141149) ((|Vector| . |Aggregate|) T) ((|AssociatedLieAlgebra| . |Module|) 141133) ((|AssociatedJordanAlgebra| . |Module|) 141117) ((|LieSquareMatrix| . |Algebra|) 141062) ((|MachineFloat| . |LeftOreRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |BasicType|) T) ((|DoubleFloatMatrix| . |SetCategory|) T) ((|ComplexDoubleFloatMatrix| . |SetCategory|) T) ((|Asp78| . |CoercibleTo|) 141036) ((|AntiSymm| . |RetractableTo|) 141020) ((|SingleInteger| . |RightModule|) 141007) ((|SequentialDifferentialPolynomial| . |FullyLinearlyExplicitRingOver|) 140991) ((|NewSparseUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140975) ((|TwoDimensionalArray| . |TwoDimensionalArrayCategory|) 140901) ((|MachineFloat| . |OrderedAbelianSemiGroup|) T) ((|MachineFloat| . |OrderedAbelianGroup|) T) ((|InnerPrimeField| . |RetractableTo|) 140888) ((|InnerFiniteField| . |RetractableTo|) 140852) ((|MachineFloat| . |Monoid|) T) ((|FreeAbelianMonoid| . |CancellationAbelianMonoid|) T) ((|Expression| . |Ring|) 140684) ((|ExponentialExpansion| . |Ring|) T) ((|Complex| . |SemiGroup|) T) ((|NewSparseMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140668) ((|AssociationList| . |Collection|) 140610) ((|RadixExpansion| . |QuotientFieldCategory|) 140587) ((|U16Vector| . |ConvertibleTo|) 140562) ((|U16Vector| . |CoercibleTo|) 140536) ((|GeneralDistributedMultivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 140520) ((|Fraction| . |CommutativeRing|) T) ((|Expression| . |DivisionRing|) 140487) ((|ExponentialExpansion| . |DivisionRing|) T) ((|ExponentialExpansion| . |DifferentialRing|) NIL) ((|Equation| . |SetCategory|) 140184) ((|DoubleFloat| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |BiModule|) 140169) ((|Complex| . |AbelianMonoid|) T) ((|Octonion| . |CharacteristicZero|) 140132) ((|Octonion| . |CharacteristicNonZero|) 140092) ((|DirectProductModule| . |LinearlyExplicitRingOver|) 139964) ((|DirectProductMatrixModule| . |LinearlyExplicitRingOver|) 139836) ((|SparseUnivariatePolynomialExpressions| . |LeftOreRing|) 139731) ((|ExponentialOfUnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 139680) ((|SparseUnivariatePolynomialExpressions| . |Monoid|) T) ((|Stream| . |InnerEvalable|) 139599) ((|ThreeSpace| . |SetCategory|) T) ((|DoubleFloat| . |RealNumberSystem|) T) ((|OrderedDirectProduct| . |Evalable|) 139523) ((|SequentialDifferentialPolynomial| . |PartialDifferentialRing|) 139401) ((|NewSparseUnivariatePolynomial| . |PartialDifferentialRing|) 139299) ((|NewSparseMultivariatePolynomial| . |PartialDifferentialRing|) 139283) ((|XPolynomial| . |Algebra|) 139240) ((|XPBWPolynomial| . |Algebra|) 139197) ((|UnivariatePolynomial| . |SemiGroup|) T) ((|UnivariateSkewPolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |LeftOreRing|) 139173) ((|GeneralDistributedMultivariatePolynomial| . |PartialDifferentialRing|) 139133) ((|OrdSetInts| . |SetCategory|) T) ((|BalancedPAdicRational| . |LeftOreRing|) T) ((|UnivariatePolynomial| . |AbelianMonoid|) T) ((|Interval| . |SemiGroup|) T) ((|UnivariateSkewPolynomial| . |AbelianMonoid|) T) ((|LaurentPolynomial| . |Monoid|) T) ((|FiniteFieldExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|EuclideanModularRing| . |BasicType|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |PrincipalIdealDomain|) T) ((|RomanNumeral| . |CancellationAbelianMonoid|) T) ((|Polynomial| . |CancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |OrderedAbelianSemiGroup|) NIL) ((|BalancedPAdicRational| . |OrderedAbelianGroup|) NIL) ((|BalancedPAdicRational| . |Monoid|) T) ((|MachineComplex| . |PolynomialFactorizationExplicit|) NIL) ((|RegularChain| . |InnerEvalable|) 138827) ((|HomogeneousDistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|Interval| . |AbelianMonoid|) T) ((|ThreeDimensionalMatrix| . |Evalable|) 138751) ((|AssociatedLieAlgebra| . |NonAssociativeRng|) T) ((|AssociatedJordanAlgebra| . |NonAssociativeRng|) T) ((|UnivariateLaurentSeries| . |OrderedSet|) NIL) ((|RadicalFunctionField| . |EntireRing|) T) ((|DirectProductModule| . |AbelianGroup|) T) ((|MachineComplex| . |LeftModule|) 138680) ((|FiniteFieldNormalBasis| . |SetCategory|) T) ((|DirectProductModule| . |AbelianSemiGroup|) T) ((|DirectProductMatrixModule| . |AbelianGroup|) T) ((|DirectProductMatrixModule| . |AbelianSemiGroup|) T) ((|CliffordAlgebra| . |Algebra|) 138664) ((|Record| . |BasicType|) T) ((|PrimeField| . |PrincipalIdealDomain|) T) ((|HomogeneousDirectProduct| . |VectorSpace|) 138631) ((|DeRhamComplex| . |RetractableTo|) 138600) ((|SingleInteger| . |Ring|) T) ((|ModularField| . |EuclideanDomain|) T) ((|Equation| . |Module|) 138529) ((|MachineInteger| . |Rng|) T) ((|HexadecimalExpansion| . |GcdDomain|) T) ((|Fraction| . |InnerEvalable|) 138418) ((|DecimalExpansion| . |GcdDomain|) T) ((|SingleInteger| . |DifferentialRing|) T) ((|EqTable| . |Collection|) 138360) ((|Quaternion| . |ConvertibleTo|) 138296) ((|Quaternion| . |CoercibleTo|) 138270) ((|QueryEquation| . |CoercibleTo|) 138244) ((|BalancedPAdicInteger| . |Rng|) T) ((|LinearOrdinaryDifferentialOperator2| . |RightModule|) 138228) ((|DoubleFloat| . |HyperbolicFunctionCategory|) T) ((|GuessOption| . |CoercibleTo|) 138202) ((|FullPartialFractionExpansion| . |CoercibleTo|) 138176) ((|FullPartialFractionExpansion| . |ConvertibleTo|) 138147) ((|RectangularMatrix| . |VectorSpace|) 138114) ((|LinearOrdinaryDifferentialOperator2| . |BiModule|) 138093) ((|SquareMatrix| . |HomogeneousAggregate|) 138077) ((|OrderedDirectProduct| . |Algebra|) 138034) ((|Asp19| . |FortranVectorFunctionCategory|) T) ((|Asp19| . |FortranProgramCategory|) T) ((|StringTable| . |BasicType|) T) ((|PAdicRational| . |CancellationAbelianMonoid|) T) ((|Heap| . |BasicType|) 138004) ((|IntegerMod| . |Finite|) T) ((|MyUnivariatePolynomial| . |PolynomialCategory|) 137939) ((|SimpleAlgebraicExtension| . |BasicType|) T) ((|RightOpenIntervalRootCharacterization| . |BasicType|) T) ((|FiniteFieldNormalBasis| . |Module|) 137865) ((|MultivariatePolynomial| . |CharacteristicZero|) 137828) ((|MultivariatePolynomial| . |CharacteristicNonZero|) 137788) ((|RealClosure| . |LeftModule|) 137709) ((|IndexedMatrix| . |SetCategory|) 137679) ((|FiniteFieldExtension| . |BasicType|) T) ((|FiniteFieldNormalBasisExtension| . |BasicType|) T) ((|MachineComplex| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtension| . |BasicType|) T) ((|DirichletRing| . |AbelianGroup|) T) ((|DirichletRing| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |BasicType|) T) ((|PolynomialIdeals| . |SetCategory|) T) ((|FiniteField| . |LeftModule|) 137605) ((|SparseUnivariatePolynomial| . |LinearlyExplicitRingOver|) 137521) ((|SparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 137437) ((|FreeModule| . |IndexedDirectProductCategory|) 137416) ((|OnePointCompletion| . |OrderedRing|) 137386) ((|Float| . |UniqueFactorizationDomain|) T) ((|MachineComplex| . |Monoid|) T) ((|FortranExpression| . |Rng|) T) ((|UnivariateLaurentSeries| . |QuotientFieldCategory|) 137316) ((|ContinuedFraction| . |Rng|) T) ((|BalancedBinaryTree| . |CoercibleTo|) 137267) ((|SparseUnivariateTaylorSeries| . |CharacteristicNonZero|) 137227) ((|SparseUnivariateTaylorSeries| . |CharacteristicZero|) 137190) ((|Float| . |IntegralDomain|) T) ((|SparseUnivariatePuiseuxSeries| . |CharacteristicZero|) 137153) ((|SparseUnivariatePuiseuxSeries| . |CharacteristicNonZero|) 137113) ((|SparseUnivariateLaurentSeries| . |CharacteristicNonZero|) 136957) ((|Fraction| . |EntireRing|) T) ((|SparseUnivariateLaurentSeries| . |CharacteristicZero|) 136807) ((|SparseMultivariateTaylorSeries| . |CharacteristicZero|) 136770) ((|SparseMultivariateTaylorSeries| . |CharacteristicNonZero|) 136730) ((|ExponentialOfUnivariatePuiseuxSeries| . |Algebra|) 136518) ((|Complex| . |CancellationAbelianMonoid|) T) ((|ExponentialExpansion| . |OrderedCancellationAbelianMonoid|) NIL) ((|ExponentialExpansion| . |OrderedAbelianMonoid|) NIL) ((|LinearOrdinaryDifferentialOperator2| . |Ring|) T) ((|AlgebraicNumber| . |LeftModule|) 136472) ((|QuadraticForm| . |AbelianGroup|) T) ((|BinaryTree| . |RecursiveAggregate|) 136456) ((|BinarySearchTree| . |RecursiveAggregate|) 136440) ((|QuadraticForm| . |AbelianSemiGroup|) T) ((|PendantTree| . |BinaryRecursiveAggregate|) 136424) ((|String| . |BasicType|) T) ((|UnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |OrderedSet|) 136395) ((|U16Vector| . |EltableAggregate|) 136360) ((|SparseUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|SparseUnivariatePolynomial| . |AbelianGroup|) T) ((|StringTable| . |Evalable|) 136102) ((|Stream| . |HomogeneousAggregate|) 136086) ((|UnivariateSkewPolynomial| . |CancellationAbelianMonoid|) T) ((|SparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|SparseMultivariatePolynomial| . |AbelianGroup|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianSemiGroup|) T) ((|SparseUnivariateSkewPolynomial| . |AbelianGroup|) T) ((|NewSparseUnivariatePolynomial| . |EuclideanDomain|) 136062) ((|AffineSpace| . |AffineSpaceCategory|) 136046) ((|SparseTable| . |Collection|) 135988) ((|SquareFreeRegularTriangularSet| . |CoercibleTo|) 135940) ((|ListMultiDictionary| . |BasicType|) 135910) ((|Library| . |BasicType|) T) ((|SquareFreeRegularTriangularSet| . |ConvertibleTo|) 135846) ((|Interval| . |CancellationAbelianMonoid|) T) ((|LocalAlgebra| . |OrderedRing|) 135816) ((|RealClosure| . |OrderedAbelianGroup|) T) ((|RealClosure| . |OrderedAbelianSemiGroup|) T) ((|RealClosure| . |LeftOreRing|) T) ((|RealClosure| . |Monoid|) T) ((|Heap| . |Evalable|) 135740) ((|GenericNonAssociativeAlgebra| . |FramedNonAssociativeAlgebra|) 135696) ((|FiniteFieldNormalBasis| . |CommutativeRing|) T) ((|DoubleFloatMatrix| . |InnerEvalable|) NIL) ((|ComplexDoubleFloatMatrix| . |InnerEvalable|) NIL) ((|EuclideanModularRing| . |Algebra|) 135683) ((|e04ucfAnnaType| . |BasicType|) T) ((|e04nafAnnaType| . |BasicType|) T) ((|e04mbfAnnaType| . |BasicType|) T) ((|e04jafAnnaType| . |BasicType|) T) ((|e04gcfAnnaType| . |BasicType|) T) ((|e04fdfAnnaType| . |BasicType|) T) ((|e04dgfAnnaType| . |BasicType|) T) ((|d03fafAnnaType| . |BasicType|) T) ((|FiniteFieldCyclicGroup| . |RetractableTo|) 135652) ((|d03eefAnnaType| . |BasicType|) T) ((|d02ejfAnnaType| . |BasicType|) T) ((|d02cjfAnnaType| . |BasicType|) T) ((|d02bhfAnnaType| . |BasicType|) T) ((|d02bbfAnnaType| . |BasicType|) T) ((|FiniteField| . |LeftOreRing|) T) ((|d01TransformFunctionType| . |BasicType|) T) ((|d01gbfAnnaType| . |BasicType|) T) ((|ModMonic| . |RightModule|) 135386) ((|d01fcfAnnaType| . |BasicType|) T) ((|d01asfAnnaType| . |BasicType|) T) ((|d01aqfAnnaType| . |BasicType|) T) ((|d01apfAnnaType| . |BasicType|) T) ((|d01anfAnnaType| . |BasicType|) T) ((|d01amfAnnaType| . |BasicType|) T) ((|d01alfAnnaType| . |BasicType|) T) ((|d01akfAnnaType| . |BasicType|) T) ((|d01ajfAnnaType| . |BasicType|) T) ((|FiniteField| . |Monoid|) T) ((|ModMonic| . |BiModule|) 135088) ((|LieSquareMatrix| . |DifferentialExtension|) 135072) ((|InnerPrimeField| . |EuclideanDomain|) T) ((|InnerFiniteField| . |EuclideanDomain|) T) ((|Equation| . |InnerEvalable|) 135004) ((|BinaryExpansion| . |Evalable|) NIL) ((|Asp33| . |FortranProgramCategory|) T) ((|SplitHomogeneousDirectProduct| . |BasicType|) 134696) ((|OnePointCompletion| . |FullyRetractableTo|) 134680) ((|SingleInteger| . |OrderedCancellationAbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianMonoid|) T) ((|MachineInteger| . |SetCategory|) T) ((|AlgebraicNumber| . |LeftOreRing|) T) ((|Float| . |Field|) T) ((|Complex| . |HyperbolicFunctionCategory|) 134631) ((|Dequeue| . |CoercibleTo|) 134582) ((|CardinalNumber| . |SetCategory|) T) ((|BalancedPAdicInteger| . |SetCategory|) T) ((|AlgebraicNumber| . |Monoid|) T) ((|RegularChain| . |HomogeneousAggregate|) 134501) ((|CharacterClass| . |FiniteSetAggregate|) 134476) ((|CharacterClass| . |Finite|) T) ((|RegularTriangularSet| . |BasicType|) T) ((|IndexedDirectProductObject| . |IndexedDirectProductCategory|) 134455) ((|GeneralTriangularSet| . |BasicType|) T) ((|GeneralPolynomialSet| . |BasicType|) T) ((|ResidueRing| . |SemiGroup|) T) ((|MyUnivariatePolynomial| . |UnivariatePolynomialCategory|) 134439) ((|SparseUnivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 134388) ((|SparseUnivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 134337) ((|SparseUnivariateTaylorSeries| . |TrigonometricFunctionCategory|) 134286) ((|SparseUnivariateTaylorSeries| . |TranscendentalFunctionCategory|) 134235) ((|SparseUnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 134184) ((|String| . |Evalable|) NIL) ((|Asp9| . |FortranFunctionCategory|) T) ((|Asp9| . |FortranProgramCategory|) T) ((|SimpleAlgebraicExtension| . |StepThrough|) 134146) ((|SparseUnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 134095) ((|SparseUnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 134044) ((|ResidueRing| . |AbelianMonoid|) T) ((|SparseUnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 133993) ((|Interval| . |HyperbolicFunctionCategory|) T) ((|SparseUnivariateLaurentSeries| . |TranscendentalFunctionCategory|) 133942) ((|SparseUnivariateLaurentSeries| . |TrigonometricFunctionCategory|) 133891) ((|SparseUnivariateLaurentSeries| . |ArcTrigonometricFunctionCategory|) 133840) ((|SparseUnivariateLaurentSeries| . |ArcHyperbolicFunctionCategory|) 133789) ((|FreeGroup| . |SemiGroup|) T) ((|FiniteFieldExtension| . |StepThrough|) 133764) ((|FiniteFieldNormalBasisExtension| . |StepThrough|) 133739) ((|FiniteFieldCyclicGroupExtension| . |StepThrough|) 133714) ((|SparseMultivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 133663) ((|SparseMultivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 133612) ((|SparseMultivariateTaylorSeries| . |TrigonometricFunctionCategory|) 133561) ((|BinaryExpansion| . |StepThrough|) T) ((|SparseMultivariateTaylorSeries| . |TranscendentalFunctionCategory|) 133510) ((|OnePointCompletion| . |Rng|) 133480) ((|ListMultiDictionary| . |Evalable|) 133404) ((|Library| . |Evalable|) 133210) ((|SimpleAlgebraicExtension| . |Algebra|) 133033) ((|ModMonic| . |Ring|) T) ((|RomanNumeral| . |LinearlyExplicitRingOver|) 133010) ((|RadixExpansion| . |CharacteristicZero|) T) ((|Polynomial| . |LinearlyExplicitRingOver|) 132926) ((|HTMLFormat| . |SetCategory|) T) ((|RadixExpansion| . |CharacteristicNonZero|) NIL) ((|Float| . |SemiGroup|) T) ((|FreeAbelianMonoid| . |AbelianSemiGroup|) T) ((|FreeAbelianGroup| . |AbelianMonoid|) T) ((|Point| . |OrderedSet|) 132897) ((|ModMonic| . |FiniteAbelianMonoidRing|) 132858) ((|HomogeneousDistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 132774) ((|AlgebraicFunctionField| . |RetractableTo|) 132579) ((|MachineInteger| . |Module|) 132566) ((|ModMonic| . |DifferentialRing|) T) ((|FortranExpression| . |SetCategory|) T) ((|ContinuedFraction| . |SetCategory|) T) ((|FourierComponent| . |OrderedSet|) T) ((|Factored| . |GcdDomain|) 132490) ((|Float| . |AbelianMonoid|) T) ((|FiniteFieldExtension| . |Algebra|) 132444) ((|FiniteFieldNormalBasisExtension| . |Algebra|) 132398) ((|FiniteFieldCyclicGroupExtension| . |Algebra|) 132352) ((|Asp55| . |FortranVectorFunctionCategory|) T) ((|Asp55| . |FortranProgramCategory|) T) ((|DoubleFloat| . |AbelianSemiGroup|) T) ((|DoubleFloat| . |AbelianGroup|) T) ((|Operator| . |SemiGroup|) T) ((|BinaryExpansion| . |Algebra|) 132286) ((|OppositeMonogenicLinearOperator| . |SemiGroup|) T) ((|None| . |SetCategory|) T) ((|BalancedPAdicInteger| . |Module|) 132273) ((|LyndonWord| . |RetractableTo|) 132257) ((|Kernel| . |BasicType|) T) ((|Operator| . |AbelianMonoid|) T) ((|OppositeMonogenicLinearOperator| . |AbelianMonoid|) T) ((|U8Matrix| . |BasicType|) T) ((|Stream| . |Eltable|) 132229) ((|SplitHomogeneousDirectProduct| . |Evalable|) 132153) ((|Set| . |DictionaryOperations|) 132137) ((|Asp1| . |FortranFunctionCategory|) T) ((|Asp1| . |FortranProgramCategory|) T) ((|Bits| . |BasicType|) T) ((|AlgebraicFunctionField| . |FullyLinearlyExplicitRingOver|) 132108) ((|AffineSpace| . |SetCategory|) T) ((|U32Vector| . |LinearAggregate|) 132085) ((|LinearOrdinaryDifferentialOperator1| . |UnivariateSkewPolynomialCategory|) 132069) ((|U32Vector| . |FiniteLinearAggregate|) 132046) ((|RomanNumeral| . |AbelianGroup|) T) ((|RomanNumeral| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |DifferentialExtension|) 132014) ((|Polynomial| . |AbelianSemiGroup|) T) ((|Polynomial| . |AbelianGroup|) T) ((|LocalAlgebra| . |Rng|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|RegularTriangularSet| . |Evalable|) 131938) ((|PatternMatchResult| . |CoercibleTo|) 131912) ((|PatternMatchListResult| . |CoercibleTo|) 131886) ((|DirectProductModule| . |OrderedSet|) 131810) ((|DirectProductMatrixModule| . |OrderedSet|) 131734) ((|IndexedMatrix| . |InnerEvalable|) 131653) ((|PAdicRational| . |LinearlyExplicitRingOver|) 131620) ((|GeneralTriangularSet| . |Evalable|) 131544) ((|GeneralPolynomialSet| . |Evalable|) 131468) ((|FiniteFieldNormalBasis| . |EntireRing|) T) ((|Stream| . |UnaryRecursiveAggregate|) 131452) ((|SquareMatrix| . |CoercibleTo|) 131402) ((|SquareMatrix| . |ConvertibleTo|) 131338) ((|SplittingNode| . |BasicType|) T) ((|Quaternion| . |RightModule|) 131212) ((|AlgebraicFunctionField| . |PartialDifferentialRing|) 131131) ((|Stream| . |IndexedAggregate|) 131103) ((|MyExpression| . |LeftModule|) 130991) ((|IntegerMod| . |LeftModule|) 130978) ((|RoutinesTable| . |Collection|) 130911) ((|PAdicRationalConstructor| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |BiModule|) 130753) ((|FortranExpression| . |Module|) 130737) ((|OrdinaryWeightedPolynomials| . |CoercibleTo|) 130711) ((|ContinuedFraction| . |Module|) 130626) ((|Fraction| . |Eltable|) 130579) ((|PAdicRationalConstructor| . |IntegralDomain|) T) ((|BinaryExpansion| . |FullyPatternMatchable|) 130556) ((|Asp77| . |FortranMatrixFunctionCategory|) T) ((|Asp77| . |FortranProgramCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |PrincipalIdealDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PrincipalIdealDomain|) T) ((|MachineInteger| . |CommutativeRing|) T) ((|Automorphism| . |Monoid|) T) ((|HomogeneousDirectProduct| . |BasicType|) 130248) ((|Automorphism| . |Group|) T) ((|BalancedPAdicInteger| . |CommutativeRing|) T) ((|SplitHomogeneousDirectProduct| . |Algebra|) 130205) ((|Complex| . |LinearlyExplicitRingOver|) 130121) ((|DoubleFloatMatrix| . |HomogeneousAggregate|) 130094) ((|ComplexDoubleFloatMatrix| . |HomogeneousAggregate|) 130055) ((|RectangularMatrix| . |BasicType|) T) ((|PAdicRational| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |DirectProductCategory|) 130034) ((|PAdicRational| . |AbelianGroup|) T) ((|OrderlyDifferentialVariable| . |BasicType|) T) ((|U8Matrix| . |Evalable|) NIL) ((|FramedModule| . |BasicType|) T) ((|FreeModule| . |BasicType|) T) ((|Bits| . |Evalable|) NIL) ((|DenavitHartenbergMatrix| . |BasicType|) 130004) ((|BinaryTree| . |Type|) T) ((|BinarySearchTree| . |Type|) T) ((|U8Vector| . |Type|) T) ((|ResidueRing| . |CancellationAbelianMonoid|) T) ((|LieSquareMatrix| . |FiniteRankNonAssociativeAlgebra|) 129988) ((|UnivariateTaylorSeriesCZero| . |LeftModule|) 129885) ((|IntegerMod| . |Monoid|) T) ((|UnivariateTaylorSeries| . |CharacteristicNonZero|) 129845) ((|UnivariateTaylorSeries| . |CharacteristicZero|) 129808) ((|Quaternion| . |Ring|) T) ((|UnivariatePuiseuxSeries| . |CharacteristicZero|) 129771) ((|UnivariatePolynomial| . |LinearlyExplicitRingOver|) 129687) ((|SExpression| . |CoercibleTo|) 129661) ((|RadicalFunctionField| . |CoercibleTo|) 129635) ((|MyExpression| . |LeftOreRing|) 129602) ((|InnerFreeAbelianMonoid| . |AbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroup| . |EuclideanDomain|) T) ((|IndexedDirectProductAbelianMonoid| . |AbelianMonoid|) T) ((|FreeAbelianGroup| . |CancellationAbelianMonoid|) T) ((|Union| . |SetCategory|) T) ((|RadicalFunctionField| . |ConvertibleTo|) 129586) ((|Quaternion| . |DivisionRing|) 129562) ((|Quaternion| . |DifferentialRing|) 129527) ((|UnivariatePuiseuxSeries| . |CharacteristicNonZero|) 129487) ((|UnivariatePuiseuxSeriesConstructor| . |UniqueFactorizationDomain|) 129463) ((|OnePointCompletion| . |SetCategory|) T) ((|UnivariateLaurentSeries| . |CharacteristicNonZero|) 129313) ((|UnivariateLaurentSeries| . |CharacteristicZero|) 129169) ((|UnivariateLaurentSeriesConstructor| . |UniqueFactorizationDomain|) 129145) ((|UnivariateFormalPowerSeries| . |CharacteristicNonZero|) 129105) ((|UnivariateFormalPowerSeries| . |CharacteristicZero|) 129068) ((|MyExpression| . |Group|) 129044) ((|MyExpression| . |Monoid|) T) ((|Float| . |CancellationAbelianMonoid|) T) ((|Integer| . |PatternMatchable|) 129021) ((|Enumeration| . |SetCategory|) T) ((|ContinuedFraction| . |CommutativeRing|) T) ((|Complex| . |AbelianGroup|) T) ((|Complex| . |AbelianSemiGroup|) T) ((|AnonymousFunction| . |SetCategory|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |LeftModule|) 128842) ((|UnivariatePuiseuxSeriesConstructor| . |IntegralDomain|) 128781) ((|ModuleOperator| . |SemiGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |IntegralDomain|) 128720) ((|Integer| . |RetractableTo|) 128697) ((|InnerSparseUnivariatePowerSeries| . |CharacteristicZero|) 128660) ((|InnerSparseUnivariatePowerSeries| . |CharacteristicNonZero|) 128620) ((|InnerAlgebraicNumber| . |RetractableTo|) 128543) ((|Asp80| . |FortranMatrixFunctionCategory|) T) ((|Asp80| . |FortranProgramCategory|) T) ((|PAdicRationalConstructor| . |Field|) T) ((|SparseUnivariatePolynomialExpressions| . |AbelianMonoidRing|) 128504) ((|Operator| . |CancellationAbelianMonoid|) T) ((|OppositeMonogenicLinearOperator| . |CancellationAbelianMonoid|) T) ((|ModuleOperator| . |AbelianMonoid|) T) ((|IndexCard| . |CoercibleTo|) 128478) ((|XRecursivePolynomial| . |Rng|) T) ((|Float| . |RealNumberSystem|) T) ((|Reference| . |SetCategory|) 128448) ((|PendantTree| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Evalable|) 128372) ((|Stream| . |ConvertibleTo|) 128308) ((|Stream| . |CoercibleTo|) 128259) ((|DesingTree| . |Aggregate|) T) ((|SparseUnivariatePolynomial| . |OrderedSet|) 128230) ((|AssociationList| . |BasicType|) T) ((|SparseMultivariatePolynomial| . |OrderedSet|) 128201) ((|OrdinaryDifferentialRing| . |BasicType|) T) ((|UnivariatePolynomial| . |AbelianSemiGroup|) T) ((|UnivariatePolynomial| . |AbelianGroup|) T) ((|UnivariateSkewPolynomial| . |AbelianSemiGroup|) T) ((|AlgebraGivenByStructuralConstants| . |FiniteRankNonAssociativeAlgebra|) 128185) ((|UnivariateSkewPolynomial| . |AbelianGroup|) T) ((|MultivariatePolynomial| . |GcdDomain|) 128103) ((|XPolynomialRing| . |CoercibleTo|) 128077) ((|Interval| . |AbelianSemiGroup|) T) ((|Interval| . |AbelianGroup|) T) ((|FreeNilpotentLie| . |SetCategory|) T) ((|RectangularMatrix| . |Evalable|) 128001) ((|LocalAlgebra| . |SetCategory|) T) ((|MachineFloat| . |PatternMatchable|) 127980) ((|Vector| . |Type|) T) ((|DenavitHartenbergMatrix| . |Evalable|) 127904) ((|Character| . |Finite|) T) ((|RegularChain| . |ConvertibleTo|) 127775) ((|RegularChain| . |CoercibleTo|) 127662) ((|PseudoAlgebraicClosureOfFiniteField| . |UniqueFactorizationDomain|) T) ((|ExponentialExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|NeitherSparseOrDensePowerSeries| . |UniqueFactorizationDomain|) T) ((|UnivariateTaylorSeriesCZero| . |Monoid|) T) ((|MachineFloat| . |RetractableTo|) 127588) ((|ModularField| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |UniqueFactorizationDomain|) 127564) ((|SparseUnivariatePuiseuxSeries| . |GcdDomain|) 127540) ((|SparseUnivariateLaurentSeries| . |GcdDomain|) 127516) ((|PseudoAlgebraicClosureOfFiniteField| . |IntegralDomain|) T) ((|FortranCode| . |BasicType|) T) ((|NeitherSparseOrDensePowerSeries| . |IntegralDomain|) T) ((|PAdicRationalConstructor| . |SemiGroup|) T) ((|Expression| . |LeftModule|) 127243) ((|ExponentialExpansion| . |LeftModule|) 127115) ((|GeneralUnivariatePowerSeries| . |IntegralDomain|) 127054) ((|FortranExpression| . |InnerEvalable|) 127016) ((|InnerTable| . |Collection|) 126958) ((|AlgebraicFunctionField| . |EuclideanDomain|) T) ((|SparseUnivariatePolynomialExpressions| . |PatternMatchable|) NIL) ((|OrderedCompletion| . |CoercibleTo|) 126932) ((|MachineInteger| . |EntireRing|) T) ((|PAdicRationalConstructor| . |AbelianMonoid|) T) ((|Float| . |HyperbolicFunctionCategory|) T) ((|SimpleAlgebraicExtension| . |DifferentialExtension|) 126899) ((|IndexedDirectProductObject| . |BasicType|) T) ((|Fraction| . |ConvertibleTo|) 126587) ((|Fraction| . |CoercibleTo|) 126561) ((|DrawOption| . |CoercibleTo|) 126535) ((|BalancedPAdicInteger| . |EntireRing|) T) ((|SparseUnivariatePolynomialExpressions| . |RetractableTo|) 126345) ((|ProjectivePlane| . |CoercibleTo|) 126319) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |Monoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Field|) 126295) ((|UnivariateLaurentSeriesConstructor| . |Field|) 126271) ((|WuWenTsunTriangularSet| . |Aggregate|) T) ((|BalancedPAdicRational| . |Type|) T) ((|BinaryExpansion| . |DifferentialExtension|) 126248) ((|SymmetricPolynomial| . |BasicType|) T) ((|Pi| . |SetCategory|) T) ((|IndexedMatrix| . |HomogeneousAggregate|) 126232) ((|MyUnivariatePolynomial| . |BasicType|) T) ((|Multiset| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Algebra|) 126189) ((|CharacterClass| . |Aggregate|) T) ((|BalancedPAdicRational| . |Patternable|) 126148) ((|BalancedPAdicRational| . |PatternMatchable|) NIL) ((|LaurentPolynomial| . |RetractableTo|) 125979) ((|List| . |OrderedSet|) 125950) ((|WeightedPolynomials| . |BasicType|) T) ((|EqTable| . |BasicType|) T) ((|ModMonic| . |Finite|) 125925) ((|BalancedPAdicRational| . |RetractableTo|) 125884) ((|FreeNilpotentLie| . |Module|) 125868) ((|SparseUnivariatePolynomialExpressions| . |FullyLinearlyExplicitRingOver|) 125852) ((|LocalAlgebra| . |Module|) 125836) ((|AssociationList| . |Evalable|) 125596) ((|OrderlyDifferentialPolynomial| . |CharacteristicNonZero|) 125556) ((|OrderlyDifferentialPolynomial| . |CharacteristicZero|) 125519) ((|XPolynomialRing| . |FreeModuleCat|) 125498) ((|OrderedFreeMonoid| . |OrderedSet|) T) ((|ThreeDimensionalViewport| . |SetCategory|) T) ((|UnivariateTaylorSeries| . |ArcHyperbolicFunctionCategory|) 125447) ((|UnivariateTaylorSeries| . |ArcTrigonometricFunctionCategory|) 125396) ((|UnivariateTaylorSeries| . |TrigonometricFunctionCategory|) 125345) ((|UnivariateTaylorSeries| . |TranscendentalFunctionCategory|) 125294) ((|UnivariatePuiseuxSeries| . |TranscendentalFunctionCategory|) 125243) ((|StringTable| . |Dictionary|) 125179) ((|UnivariatePuiseuxSeries| . |TrigonometricFunctionCategory|) 125128) ((|FreeMonoid| . |OrderedSet|) 125099) ((|UnivariatePuiseuxSeries| . |ArcTrigonometricFunctionCategory|) 125048) ((|UnivariatePuiseuxSeries| . |ArcHyperbolicFunctionCategory|) 124997) ((|UnivariatePuiseuxSeriesConstructor| . |SemiGroup|) T) ((|DoubleFloatMatrix| . |MatrixCategory|) 124926) ((|ComplexDoubleFloatMatrix| . |MatrixCategory|) 124829) ((|UnivariateLaurentSeries| . |TranscendentalFunctionCategory|) 124778) ((|UnivariateLaurentSeries| . |TrigonometricFunctionCategory|) 124727) ((|UnivariateLaurentSeries| . |ArcTrigonometricFunctionCategory|) 124676) ((|InnerFreeAbelianMonoid| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeries| . |ArcHyperbolicFunctionCategory|) 124625) ((|UnivariateFormalPowerSeries| . |TrigonometricFunctionCategory|) 124574) ((|UnivariateFormalPowerSeries| . |TranscendentalFunctionCategory|) 124523) ((|UnivariateLaurentSeriesConstructor| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |ArcHyperbolicFunctionCategory|) 124472) ((|AssociatedLieAlgebra| . |CoercibleTo|) 124433) ((|AssociatedJordanAlgebra| . |CoercibleTo|) 124394) ((|AffinePlane| . |BasicType|) T) ((|DoubleFloat| . |OrderedSet|) T) ((|Expression| . |LeftOreRing|) 124361) ((|ExponentialExpansion| . |LeftOreRing|) T) ((|UnivariateFormalPowerSeries| . |ArcTrigonometricFunctionCategory|) 124310) ((|SingleInteger| . |LeftModule|) 124297) ((|SparseUnivariatePolynomialExpressions| . |PartialDifferentialRing|) 124195) ((|SimpleAlgebraicExtension| . |FiniteFieldCategory|) 124157) ((|IndexedString| . |Collection|) 124132) ((|PAdicInteger| . |EuclideanDomain|) T) ((|ContinuedFraction| . |EntireRing|) T) ((|BalancedPAdicRational| . |FullyLinearlyExplicitRingOver|) 124091) ((|BalancedPAdicRational| . |FullyEvalableOver|) 124050) ((|PseudoAlgebraicClosureOfFiniteField| . |Field|) T) ((|NeitherSparseOrDensePowerSeries| . |Field|) T) ((|ExponentialExpansion| . |OrderedAbelianSemiGroup|) NIL) ((|ExponentialExpansion| . |OrderedAbelianGroup|) NIL) ((|Expression| . |Monoid|) 123832) ((|ExponentialExpansion| . |Monoid|) T) ((|InfClsPt| . |CoercibleTo|) 123806) ((|GeneralUnivariatePowerSeries| . |Field|) 123782) ((|FiniteFieldExtension| . |FiniteFieldCategory|) 123757) ((|FiniteFieldNormalBasisExtension| . |FiniteFieldCategory|) 123732) ((|FiniteFieldCyclicGroupExtension| . |FiniteFieldCategory|) 123707) ((|Expression| . |Group|) 123683) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianMonoid|) T) ((|MoebiusTransform| . |SemiGroup|) T) ((|ModuleOperator| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator1| . |BasicType|) T) ((|Pi| . |Module|) 123637) ((|AssociationList| . |ExtensibleLinearAggregate|) 123579) ((|BasicFunctions| . |SetCategory|) T) ((|Asp28| . |CoercibleTo|) 123553) ((|OrderedVariableList| . |BasicType|) T) ((|LaurentPolynomial| . |PartialDifferentialRing|) 123485) ((|XRecursivePolynomial| . |SetCategory|) T) ((|FreeModule1| . |SetCategory|) T) ((|U32Vector| . |Aggregate|) T) ((|U16Vector| . |LinearAggregate|) 123462) ((|U16Vector| . |FiniteLinearAggregate|) 123439) ((|Asp73| . |Type|) T) ((|RomanNumeral| . |OrderedSet|) T) ((|Polynomial| . |OrderedSet|) 123410) ((|BalancedPAdicRational| . |PartialDifferentialRing|) NIL) ((|NewSparseUnivariatePolynomial| . |PrincipalIdealDomain|) 123386) ((|ModuleMonomial| . |OrderedSet|) T) ((|IndexedExponents| . |SetCategory|) T) ((|IndexedBits| . |SetCategory|) T) ((|FiniteFieldExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |UniqueFactorizationDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 123336) ((|DistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 123286) ((|SplitHomogeneousDirectProduct| . |DifferentialExtension|) 123254) ((|HomogeneousDistributedMultivariatePolynomial| . |OrderedSet|) 123225) ((|String| . |OpenMath|) T) ((|SquareMatrix| . |RightModule|) 123209) ((|FreeNilpotentLie| . |NonAssociativeRng|) T) ((|MyUnivariatePolynomial| . |Evalable|) 123196) ((|MachineComplex| . |Type|) T) ((|FiniteFieldExtensionByPolynomial| . |IntegralDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |IntegralDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |IntegralDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |IntegralDomain|) 123082) ((|DistributedMultivariatePolynomial| . |IntegralDomain|) 122968) ((|SquareMatrix| . |BiModule|) 122947) ((|GenericNonAssociativeAlgebra| . |NonAssociativeAlgebra|) 122903) ((|OrdinaryWeightedPolynomials| . |RightModule|) 122860) ((|OrdinaryDifferentialRing| . |Algebra|) 122780) ((|MachineComplex| . |Patternable|) 122752) ((|MachineComplex| . |PatternMatchable|) 122731) ((|EqTable| . |Evalable|) 122491) ((|PrimeField| . |UniqueFactorizationDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |SemiGroup|) T) ((|OrdinaryWeightedPolynomials| . |BiModule|) 122443) ((|LieSquareMatrix| . |FullyRetractableTo|) 122427) ((|NeitherSparseOrDensePowerSeries| . |SemiGroup|) T) ((|MachineComplex| . |RetractableTo|) 122346) ((|Stream| . |EltableAggregate|) 122318) ((|RadixExpansion| . |GcdDomain|) T) ((|PrimeField| . |IntegralDomain|) T) ((|InnerPrimeField| . |PrincipalIdealDomain|) T) ((|GeneralUnivariatePowerSeries| . |SemiGroup|) T) ((|InnerFiniteField| . |PrincipalIdealDomain|) T) ((|PartialFraction| . |GcdDomain|) T) ((|DoubleFloatMatrix| . |CoercibleTo|) 122292) ((|ComplexDoubleFloatMatrix| . |CoercibleTo|) 122266) ((|Asp20| . |CoercibleTo|) 122240) ((|SingleInteger| . |LeftOreRing|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianMonoid|) T) ((|Library| . |Dictionary|) 122173) ((|NeitherSparseOrDensePowerSeries| . |AbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |AbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |CancellationAbelianMonoid|) T) ((|SingleInteger| . |OrderedAbelianGroup|) T) ((|XDistributedPolynomial| . |XFreeAlgebra|) 122152) ((|SingleInteger| . |Monoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |LeftModule|) 122126) ((|Equation| . |CoercibleTo|) 121761) ((|Result| . |Aggregate|) T) ((|OrderedDirectProduct| . |OrderedRing|) 121731) ((|InnerPAdicInteger| . |EuclideanDomain|) T) ((|Integer| . |EuclideanDomain|) T) ((|InnerAlgebraicNumber| . |EuclideanDomain|) T) ((|XRecursivePolynomial| . |Module|) 121688) ((|MachineComplex| . |FullyLinearlyExplicitRingOver|) 121660) ((|MachineComplex| . |FullyEvalableOver|) 121632) ((|Pi| . |CommutativeRing|) T) ((|FreeModule1| . |Module|) 121589) ((|MyUnivariatePolynomial| . |StepThrough|) 121559) ((|PAdicRational| . |OrderedSet|) NIL) ((|Integer| . |RealConstant|) T) ((|InnerAlgebraicNumber| . |RealConstant|) T) ((|ThreeSpace| . |CoercibleTo|) 121533) ((|SplitHomogeneousDirectProduct| . |DirectProductCategory|) 121512) ((|Database| . |BasicType|) T) ((|SparseTable| . |BasicType|) T) ((|Asp31| . |CoercibleTo|) 121486) ((|SquareMatrix| . |Ring|) T) ((|SymmetricPolynomial| . |Algebra|) 121330) ((|OrdSetInts| . |CoercibleTo|) 121304) ((|Integer| . |IntegerNumberSystem|) T) ((|MyUnivariatePolynomial| . |Algebra|) 121044) ((|LieSquareMatrix| . |Rng|) T) ((|MultivariatePolynomial| . |PolynomialCategory|) 120949) ((|SquareMatrix| . |DifferentialRing|) 120914) ((|SingletonAsOrderedSet| . |SetCategory|) T) ((|ResidueRing| . |AbelianSemiGroup|) T) ((|ResidueRing| . |AbelianGroup|) T) ((|RadicalFunctionField| . |RightModule|) 120842) ((|Permutation| . |BasicType|) T) ((|OrdinaryWeightedPolynomials| . |Ring|) T) ((|NottinghamGroup| . |SemiGroup|) T) ((|MachineComplex| . |PartialDifferentialRing|) NIL) ((|FiniteFieldExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120826) ((|FiniteFieldExtensionByPolynomial| . |Field|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120810) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Field|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FiniteAlgebraicExtensionField|) 120794) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Field|) T) ((|HexadecimalExpansion| . |BasicType|) T) ((|WeightedPolynomials| . |Algebra|) 120751) ((|IndexedMatrix| . |MatrixCategory|) 120679) ((|DecimalExpansion| . |BasicType|) T) ((|RealClosure| . |RetractableTo|) 120505) ((|RadicalFunctionField| . |BiModule|) 120388) ((|SparseUnivariateTaylorSeries| . |PowerSeriesCategory|) 120323) ((|SparseUnivariatePuiseuxSeries| . |PowerSeriesCategory|) 120256) ((|IndexedList| . |Collection|) 120240) ((|SimpleAlgebraicExtension| . |FiniteRankAlgebra|) 120219) ((|FiniteFieldNormalBasis| . |CoercibleTo|) 120193) ((|FreeAbelianGroup| . |AbelianGroup|) T) ((|FiniteField| . |RetractableTo|) 120162) ((|FreeAbelianGroup| . |AbelianSemiGroup|) T) ((|SparseUnivariateLaurentSeries| . |PowerSeriesCategory|) 120108) ((|SparseMultivariateTaylorSeries| . |PowerSeriesCategory|) 120061) ((|Asp42| . |CoercibleTo|) 120035) ((|MachineFloat| . |EuclideanDomain|) T) ((|Complex| . |OrderedSet|) 120006) ((|PrimeField| . |Field|) T) ((|Float| . |AbelianSemiGroup|) T) ((|Float| . |AbelianGroup|) T) ((|PrimeField| . |FiniteAlgebraicExtensionField|) 119993) ((|Asp7| . |CoercibleTo|) 119967) ((|MachineFloat| . |RealConstant|) T) ((|Magma| . |OrderedSet|) T) ((|UnivariatePuiseuxSeriesConstructor| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |CancellationAbelianMonoid|) T) ((|PendantTree| . |RecursiveAggregate|) 119951) ((|Operator| . |AbelianGroup|) T) ((|AlgebraicNumber| . |RetractableTo|) 119874) ((|Operator| . |AbelianSemiGroup|) T) ((|OppositeMonogenicLinearOperator| . |AbelianSemiGroup|) T) ((|OppositeMonogenicLinearOperator| . |AbelianGroup|) T) ((|XPolynomial| . |Rng|) T) ((|XPBWPolynomial| . |Rng|) T) ((|LinearOrdinaryDifferentialOperator2| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |EuclideanDomain|) 119850) ((|DesingTree| . |RecursiveAggregate|) 119834) ((|XPolynomialRing| . |RightModule|) 119818) ((|UnivariatePolynomial| . |OrderedSet|) 119789) ((|OrderedDirectProduct| . |FullyRetractableTo|) 119750) ((|BalancedBinaryTree| . |BinaryRecursiveAggregate|) 119734) ((|Any| . |SetCategory|) T) ((|Plot3D| . |CoercibleTo|) 119708) ((|PAdicRational| . |QuotientFieldCategory|) 119675) ((|OpenMathEncoding| . |BasicType|) T) ((|XPolynomialRing| . |BiModule|) 119654) ((|LinearOrdinaryDifferentialOperator1| . |Algebra|) 119611) ((|Interval| . |OrderedSet|) T) ((|FiniteFieldExtensionByPolynomial| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |SemiGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |SemiGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |SemiGroup|) T) ((|DistributedMultivariatePolynomial| . |SemiGroup|) T) ((|LaurentPolynomial| . |EuclideanDomain|) 119587) ((|SparseTable| . |Evalable|) 119347) ((|LiePolynomial| . |AbelianMonoid|) T) ((|HomogeneousDirectProduct| . |DifferentialExtension|) 119315) ((|CliffordAlgebra| . |Rng|) T) ((|FiniteFieldExtensionByPolynomial| . |AbelianMonoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianMonoid|) T) ((|BalancedPAdicRational| . |EuclideanDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|DistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|RadicalFunctionField| . |Ring|) T) ((|ModMonic| . |PolynomialFactorizationExplicit|) 119265) ((|RadicalFunctionField| . |DifferentialRing|) 119217) ((|RadicalFunctionField| . |DivisionRing|) T) ((|BalancedPAdicRational| . |RealConstant|) NIL) ((|PrimeField| . |SemiGroup|) T) ((|UnivariatePuiseuxSeries| . |GcdDomain|) 119193) ((|UnivariateLaurentSeries| . |GcdDomain|) 119169) ((|IndexedMatrix| . |CoercibleTo|) 119120) ((|ModMonic| . |LeftModule|) 119017) ((|Fraction| . |RightModule|) 118958) ((|PseudoAlgebraicClosureOfFiniteField| . |CancellationAbelianMonoid|) T) ((|PolynomialIdeals| . |CoercibleTo|) 118932) ((|PrimeField| . |AbelianMonoid|) T) ((|NeitherSparseOrDensePowerSeries| . |CancellationAbelianMonoid|) T) ((|HexadecimalExpansion| . |Evalable|) NIL) ((|GeneralUnivariatePowerSeries| . |CancellationAbelianMonoid|) T) ((|DecimalExpansion| . |Evalable|) NIL) ((|Fraction| . |BiModule|) 118841) ((|OrderedDirectProduct| . |Rng|) 118751) ((|Multiset| . |SetAggregate|) 118735) ((|UnivariatePuiseuxSeriesConstructor| . |HyperbolicFunctionCategory|) 118684) ((|UnivariateLaurentSeriesConstructor| . |HyperbolicFunctionCategory|) 118633) ((|CharacterClass| . |SetAggregate|) 118608) ((|Pi| . |EntireRing|) T) ((|XPolynomialRing| . |Ring|) T) ((|RoutinesTable| . |BasicType|) T) ((|IndexedBits| . |InnerEvalable|) NIL) ((|MakeCachableSet| . |BasicType|) T) ((|HomogeneousDirectProduct| . |DirectProductCategory|) 118587) ((|SparseUnivariatePolynomial| . |CharacteristicNonZero|) 118547) ((|SparseUnivariatePolynomial| . |CharacteristicZero|) 118510) ((|SparseMultivariatePolynomial| . |CharacteristicZero|) 118473) ((|SparseMultivariatePolynomial| . |CharacteristicNonZero|) 118433) ((|AssociatedLieAlgebra| . |RightModule|) 118417) ((|AssociatedJordanAlgebra| . |RightModule|) 118401) ((|SparseUnivariateTaylorSeries| . |UnivariateTaylorSeriesCategory|) 118385) ((|LieSquareMatrix| . |SetCategory|) T) ((|LieSquareMatrix| . |RectangularMatrixCategory|) 118303) ((|SparseUnivariateTaylorSeries| . |UnivariatePowerSeriesCategory|) 118264) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesConstructorCategory|) 118199) ((|HexadecimalExpansion| . |StepThrough|) T) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 118158) ((|SparseUnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 118142) ((|SparseUnivariateLaurentSeries| . |UnivariateLaurentSeriesConstructorCategory|) 118078) ((|DecimalExpansion| . |StepThrough|) T) ((|FiniteFieldCyclicGroup| . |PrincipalIdealDomain|) T) ((|OrderlyDifferentialVariable| . |DifferentialVariableCategory|) 118062) ((|AssociatedLieAlgebra| . |BiModule|) 118041) ((|AssociatedJordanAlgebra| . |BiModule|) 118020) ((|SparseUnivariateLaurentSeries| . |UnivariatePowerSeriesCategory|) 117992) ((|OrderedCompletion| . |Ring|) 117962) ((|SparseUnivariateLaurentSeries| . |UnivariateLaurentSeriesCategory|) 117946) ((|InnerFreeAbelianMonoid| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |ExpressionSpace|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |AbelianMonoid|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianMonoid| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianMonoid|) T) ((|ModMonic| . |LeftOreRing|) 117841) ((|Fraction| . |Ring|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Rng|) T) ((|MachineComplex| . |EuclideanDomain|) T) ((|BinaryExpansion| . |OrderedRing|) T) ((|Fraction| . |DivisionRing|) T) ((|Fraction| . |DifferentialRing|) 117806) ((|ModMonic| . |Monoid|) T) ((|HexadecimalExpansion| . |Algebra|) 117740) ((|DecimalExpansion| . |Algebra|) 117674) ((|GeneralUnivariatePowerSeries| . |HyperbolicFunctionCategory|) 117623) ((|String| . |StringAggregate|) T) ((|SetOfMIntegersInOneToN| . |BasicType|) T) ((|MachineInteger| . |CoercibleTo|) 117597) ((|MachineInteger| . |ConvertibleTo|) 117478) ((|ModuleOperator| . |AbelianGroup|) T) ((|ModuleOperator| . |AbelianSemiGroup|) T) ((|CardinalNumber| . |CoercibleTo|) 117452) ((|BalancedPAdicInteger| . |CoercibleTo|) 117426) ((|Color| . |AbelianSemiGroup|) T) ((|XPolynomial| . |SetCategory|) T) ((|PAdicRationalConstructor| . |LinearlyExplicitRingOver|) 117342) ((|XPBWPolynomial| . |SetCategory|) T) ((|PolynomialRing| . |BasicType|) T) ((|MonoidRing| . |BasicType|) T) ((|ModularRing| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |BasicType|) T) ((|U16Vector| . |Aggregate|) T) ((|OrderlyDifferentialPolynomial| . |GcdDomain|) 117260) ((|AlgebraGivenByStructuralConstants| . |SetCategory|) T) ((|SequentialDifferentialVariable| . |OrderedSet|) T) ((|LiePolynomial| . |CancellationAbelianMonoid|) T) ((|RoutinesTable| . |Evalable|) 117066) ((|LieSquareMatrix| . |Module|) 117050) ((|EuclideanModularRing| . |Rng|) T) ((|FiniteFieldExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CancellationAbelianMonoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|DistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|MyExpression| . |Type|) T) ((|Factored| . |BasicType|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianMonoidRing|) 117011) ((|CliffordAlgebra| . |SetCategory|) T) ((|AssociationList| . |Dictionary|) 116953) ((|MyUnivariatePolynomial| . |DifferentialExtension|) 116937) ((|Quaternion| . |LeftModule|) 116861) ((|PrimitiveArray| . |OrderedSet|) 116832) ((|MyExpression| . |Patternable|) 116816) ((|MyExpression| . |PatternMatchable|) 116697) ((|DirectProduct| . |VectorSpace|) 116664) ((|RealClosure| . |EuclideanDomain|) T) ((|Equation| . |RightModule|) 116571) ((|PrimeField| . |CancellationAbelianMonoid|) T) ((|AlgebraicFunctionField| . |PrincipalIdealDomain|) T) ((|MyExpression| . |RetractableTo|) 116170) ((|HexadecimalExpansion| . |FullyPatternMatchable|) 116147) ((|HTMLFormat| . |CoercibleTo|) 116121) ((|FiniteField| . |EuclideanDomain|) T) ((|DecimalExpansion| . |FullyPatternMatchable|) 116098) ((|SimpleAlgebraicExtension| . |FullyRetractableTo|) 116082) ((|Equation| . |BiModule|) 115984) ((|PseudoAlgebraicClosureOfRationalNumber| . |UniqueFactorizationDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |UniqueFactorizationDomain|) T) ((|PAdicRationalConstructor| . |AbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |IntegralDomain|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |IntegralDomain|) T) ((|FortranExpression| . |CoercibleTo|) 115958) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianMonoidRing|) 115848) ((|DoubleFloat| . |CharacteristicZero|) T) ((|ContinuedFraction| . |CoercibleTo|) 115822) ((|SplitHomogeneousDirectProduct| . |OrderedRing|) 115792) ((|None| . |CoercibleTo|) 115766) ((|KeyedAccessFile| . |DictionaryOperations|) 115702) ((|GeneralSparseTable| . |DictionaryOperations|) 115644) ((|XPolynomial| . |Module|) 115601) ((|AlgebraicNumber| . |EuclideanDomain|) T) ((|XPBWPolynomial| . |Module|) 115558) ((|Product| . |SetCategory|) T) ((|OrderedDirectProduct| . |SetCategory|) 115250) ((|Exit| . |BasicType|) T) ((|PendantTree| . |Type|) T) ((|MyExpression| . |FullyLinearlyExplicitRingOver|) 115218) ((|AlgebraicNumber| . |RealConstant|) T) ((|UnivariateLaurentSeriesConstructor| . |LinearlyExplicitRingOver|) 115088) ((|Matrix| . |BasicType|) 115058) ((|AlgebraGivenByStructuralConstants| . |Module|) 115042) ((|InnerTable| . |BasicType|) T) ((|Asp27| . |FortranMatrixCategory|) T) ((|DesingTree| . |Type|) T) ((|Asp27| . |FortranProgramCategory|) T) ((|AffineSpace| . |CoercibleTo|) 115016) ((|Localize| . |AbelianMonoid|) T) ((|LieSquareMatrix| . |NonAssociativeRng|) T) ((|Tuple| . |SetCategory|) 114986) ((|FiniteFieldNormalBasis| . |RightModule|) 114912) ((|ThreeDimensionalMatrix| . |SetCategory|) 114882) ((|RomanNumeral| . |CharacteristicZero|) T) ((|Polynomial| . |CharacteristicZero|) 114845) ((|Polynomial| . |CharacteristicNonZero|) 114805) ((|Octonion| . |BasicType|) T) ((|CliffordAlgebra| . |Module|) 114789) ((|HomogeneousDistributedMultivariatePolynomial| . |CharacteristicZero|) 114752) ((|HomogeneousDistributedMultivariatePolynomial| . |CharacteristicNonZero|) 114712) ((|FiniteFieldNormalBasis| . |BiModule|) 114591) ((|SimpleAlgebraicExtension| . |Rng|) T) ((|FreeAbelianGroup| . |OrderedSet|) 114562) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|UnivariateTaylorSeries| . |PowerSeriesCategory|) 114497) ((|UnivariatePuiseuxSeries| . |PowerSeriesCategory|) 114430) ((|UnivariateLaurentSeries| . |PowerSeriesCategory|) 114376) ((|LieExponentials| . |SetCategory|) T) ((|MyExpression| . |PartialDifferentialRing|) 114354) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |CancellationAbelianMonoid|) T) ((|IndexedDirectProductAbelianGroup| . |CancellationAbelianMonoid|) T) ((|EqTable| . |Dictionary|) 114296) ((|FiniteFieldExtension| . |Rng|) T) ((|FiniteFieldNormalBasisExtension| . |Rng|) T) ((|FiniteFieldCyclicGroupExtension| . |Rng|) T) ((|Equation| . |Ring|) 114216) ((|UnivariateFormalPowerSeries| . |PowerSeriesCategory|) 114151) ((|Float| . |OrderedSet|) T) ((|BinaryExpansion| . |Rng|) T) ((|Quaternion| . |Monoid|) T) ((|PAdicInteger| . |PrincipalIdealDomain|) T) ((|OrderedCompletion| . |OrderedCancellationAbelianMonoid|) 114121) ((|OrderedCompletion| . |OrderedAbelianMonoid|) 114091) ((|Factored| . |Evalable|) 114018) ((|GraphImage| . |BasicType|) T) ((|InnerSparseUnivariatePowerSeries| . |PowerSeriesCategory|) 113964) ((|ExponentialOfUnivariatePuiseuxSeries| . |SetCategory|) T) ((|Fraction| . |OrderedCancellationAbelianMonoid|) 113924) ((|Fraction| . |OrderedAbelianMonoid|) 113884) ((|IndexedBits| . |HomogeneousAggregate|) 113861) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |RetractableTo|) 113807) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianGroup|) T) ((|UnivariatePuiseuxSeriesConstructor| . |AbelianSemiGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |AbelianSemiGroup|) T) ((|OrderedDirectProduct| . |Module|) 113736) ((|U32Matrix| . |BasicType|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |Field|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Field|) T) ((|MachineFloat| . |FloatingPointSystem|) T) ((|WuWenTsunTriangularSet| . |Type|) T) ((|SplitHomogeneousDirectProduct| . |FullyRetractableTo|) 113697) ((|RadicalFunctionField| . |Finite|) NIL) ((|BalancedBinaryTree| . |Aggregate|) T) ((|Multiset| . |Type|) T) ((|AlgebraGivenByStructuralConstants| . |NonAssociativeRng|) T) ((|IndexedString| . |BasicType|) T) ((|Asp49| . |FortranFunctionCategory|) T) ((|Asp49| . |FortranProgramCategory|) T) ((|LinearOrdinaryDifferentialOperator1| . |LinearOrdinaryDifferentialOperatorCategory|) 113681) ((|CharacterClass| . |Type|) T) ((|PAdicRational| . |CharacteristicZero|) T) ((|PAdicRational| . |CharacteristicNonZero|) NIL) ((|UnivariateTaylorSeriesCZero| . |PartialDifferentialRing|) 113545) ((|FiniteFieldNormalBasis| . |Ring|) T) ((|Asp30| . |FortranMatrixCategory|) T) ((|Asp30| . |FortranProgramCategory|) T) ((|SuchThat| . |BasicType|) T) ((|LieSquareMatrix| . |InnerEvalable|) 113464) ((|Matrix| . |Evalable|) 113388) ((|PolynomialRing| . |Algebra|) 113232) ((|MonoidRing| . |Algebra|) 113189) ((|InnerTable| . |Evalable|) 112949) ((|Expression| . |Type|) T) ((|FiniteFieldNormalBasis| . |DifferentialRing|) T) ((|FiniteFieldNormalBasis| . |DivisionRing|) T) ((|ExponentialExpansion| . |Type|) T) ((|EuclideanModularRing| . |SetCategory|) T) ((|SymbolTable| . |CoercibleTo|) 112923) ((|ModularField| . |UniqueFactorizationDomain|) T) ((|Stream| . |LinearAggregate|) 112907) ((|TaylorSeries| . |IntegralDomain|) 112874) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |AbelianGroup|) T) ((|ModularField| . |IntegralDomain|) T) ((|Expression| . |Patternable|) 112858) ((|Expression| . |PatternMatchable|) 112739) ((|ExponentialExpansion| . |Patternable|) 112654) ((|ExponentialExpansion| . |PatternMatchable|) NIL) ((|Octonion| . |Evalable|) 112613) ((|NeitherSparseOrDensePowerSeries| . |AbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Module|) 112401) ((|NeitherSparseOrDensePowerSeries| . |AbelianGroup|) T) ((|FreeAbelianMonoid| . |FreeAbelianMonoidCategory|) 112362) ((|HyperellipticFiniteDivisor| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |AbelianSemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |AbelianGroup|) T) ((|Factored| . |Algebra|) 112336) ((|Expression| . |RetractableTo|) 111840) ((|DoubleFloat| . |TranscendentalFunctionCategory|) T) ((|DoubleFloat| . |TrigonometricFunctionCategory|) T) ((|Union| . |CoercibleTo|) 111814) ((|ExponentialExpansion| . |RetractableTo|) 111678) ((|PseudoAlgebraicClosureOfRationalNumber| . |SemiGroup|) T) ((|Record| . |SetCategory|) T) ((|Record| . |RecordCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |SemiGroup|) T) ((|OnePointCompletion| . |CoercibleTo|) 111652) ((|SplitHomogeneousDirectProduct| . |Rng|) 111562) ((|InnerPAdicInteger| . |PrincipalIdealDomain|) T) ((|Integer| . |OrderedIntegralDomain|) T) ((|Integer| . |PrincipalIdealDomain|) T) ((|InnerAlgebraicNumber| . |PrincipalIdealDomain|) T) ((|CartesianTensor| . |RetractableTo|) 111546) ((|DoubleFloat| . |ArcTrigonometricFunctionCategory|) T) ((|Asp41| . |FortranVectorFunctionCategory|) T) ((|Asp41| . |FortranProgramCategory|) T) ((|Enumeration| . |CoercibleTo|) 111520) ((|Complex| . |CharacteristicZero|) 111483) ((|Complex| . |CharacteristicNonZero|) 111401) ((|DoubleFloat| . |ArcHyperbolicFunctionCategory|) T) ((|AnonymousFunction| . |CoercibleTo|) 111375) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianMonoid|) T) ((|Pi| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |DifferentialExtension|) 111352) ((|Heap| . |PriorityQueueAggregate|) 111336) ((|HomogeneousDirectProduct| . |OrderedRing|) 111306) ((|DecimalExpansion| . |DifferentialExtension|) 111283) ((|Asp6| . |FortranVectorFunctionCategory|) T) ((|Asp6| . |FortranProgramCategory|) T) ((|SquareFreeRegularTriangularSet| . |Aggregate|) T) ((|OrderedDirectProduct| . |CommutativeRing|) 111249) ((|MultivariatePolynomial| . |BasicType|) T) ((|Reference| . |CoercibleTo|) 111200) ((|IndexedBits| . |Eltable|) 111165) ((|Expression| . |FullyLinearlyExplicitRingOver|) 111133) ((|ExponentialExpansion| . |FullyLinearlyExplicitRingOver|) 111048) ((|ExponentialExpansion| . |FullyEvalableOver|) 110963) ((|U32Matrix| . |Evalable|) NIL) ((|OrderlyDifferentialPolynomial| . |PolynomialCategory|) 110840) ((|Localize| . |CancellationAbelianMonoid|) T) ((|UnivariatePolynomial| . |CharacteristicNonZero|) 110800) ((|UnivariatePolynomial| . |CharacteristicZero|) 110763) ((|U32Vector| . |Type|) T) ((|SparseUnivariateTaylorSeries| . |BasicType|) T) ((|SparseUnivariatePuiseuxSeries| . |BasicType|) T) ((|SparseUnivariateLaurentSeries| . |BasicType|) T) ((|StringTable| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |BasicType|) T) ((|Dequeue| . |Aggregate|) T) ((|EuclideanModularRing| . |Module|) 110750) ((|StringTable| . |KeyedDictionary|) 110723) ((|IndexedString| . |Evalable|) NIL) ((|UnivariateTaylorSeries| . |UnivariateTaylorSeriesCategory|) 110707) ((|UnivariateTaylorSeries| . |UnivariatePowerSeriesCategory|) 110668) ((|Heap| . |SetCategory|) 110638) ((|UnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesConstructorCategory|) 110579) ((|FreeNilpotentLie| . |CoercibleTo|) 110553) ((|IndexedDirectProductOrderedAbelianMonoid| . |OrderedSet|) T) ((|SparseTable| . |Dictionary|) 110495) ((|UnivariatePuiseuxSeries| . |UnivariatePowerSeriesCategory|) 110454) ((|UnivariatePuiseuxSeries| . |UnivariatePuiseuxSeriesCategory|) 110438) ((|UnivariateLaurentSeries| . |UnivariateLaurentSeriesConstructorCategory|) 110380) ((|UnivariateLaurentSeries| . |UnivariatePowerSeriesCategory|) 110352) ((|UnivariateLaurentSeries| . |UnivariateLaurentSeriesCategory|) 110336) ((|UnivariateFormalPowerSeries| . |UnivariateTaylorSeriesCategory|) 110320) ((|UnivariateFormalPowerSeries| . |UnivariatePowerSeriesCategory|) 110281) ((|LocalAlgebra| . |CoercibleTo|) 110255) ((|SparseUnivariateTaylorSeries| . |ElementaryFunctionCategory|) 110204) ((|MachineFloat| . |PrincipalIdealDomain|) T) ((|SparseUnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 110153) ((|SparseUnivariateLaurentSeries| . |ElementaryFunctionCategory|) 110102) ((|SparseMultivariateTaylorSeries| . |ElementaryFunctionCategory|) 110051) ((|SimpleAlgebraicExtension| . |SetCategory|) T) ((|RightOpenIntervalRootCharacterization| . |SetCategory|) T) ((|AlgebraicNumber| . |ExpressionSpace|) T) ((|Expression| . |PartialDifferentialRing|) 110013) ((|ExponentialExpansion| . |PartialDifferentialRing|) NIL) ((|RightOpenIntervalRootCharacterization| . |RealRootCharacterizationCategory|) 109992) ((|SingleInteger| . |PatternMatchable|) 109969) ((|Octonion| . |Algebra|) 109953) ((|DifferentialSparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 109869) ((|DistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 109785) ((|MachineInteger| . |RightModule|) 109772) ((|InnerSparseUnivariatePowerSeries| . |UnivariatePowerSeriesCategory|) 109744) ((|SingleInteger| . |RetractableTo|) 109721) ((|ExponentialOfUnivariatePuiseuxSeries| . |CommutativeRing|) 109627) ((|FiniteFieldExtension| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtension| . |SetCategory|) T) ((|FiniteFieldCyclicGroupExtension| . |SetCategory|) T) ((|IndexedBits| . |OneDimensionalArrayAggregate|) 109604) ((|Set| . |Collection|) 109588) ((|MyExpression| . |EuclideanDomain|) 109555) ((|BinaryExpansion| . |SetCategory|) T) ((|BalancedPAdicInteger| . |RightModule|) 109542) ((|ModularField| . |Field|) T) ((|IndexedBits| . |IndexedAggregate|) 109507) ((|MachineInteger| . |BiModule|) 109492) ((|FortranTemplate| . |BasicType|) T) ((|SparseUnivariatePolynomialExpressions| . |PrincipalIdealDomain|) 109468) ((|AssociationList| . |StreamAggregate|) 109410) ((|BalancedPAdicInteger| . |BiModule|) 109395) ((|DoubleFloatVector| . |OrderedSet|) T) ((|ComplexDoubleFloatVector| . |OrderedSet|) 109343) ((|AssociatedLieAlgebra| . |Monad|) T) ((|AssociatedJordanAlgebra| . |Monad|) T) ((|OrderedDirectProduct| . |InnerEvalable|) 109262) ((|Result| . |Type|) T) ((|Point| . |Collection|) 109246) ((|IndexedList| . |BasicType|) 109183) ((|SequentialDifferentialPolynomial| . |UniqueFactorizationDomain|) 109133) ((|NewSparseUnivariatePolynomial| . |UniqueFactorizationDomain|) 109083) ((|NewSparseMultivariatePolynomial| . |UniqueFactorizationDomain|) 109033) ((|Asp12| . |Type|) T) ((|Pi| . |CoercibleTo|) 108965) ((|Pi| . |ConvertibleTo|) 108834) ((|SparseUnivariatePolynomial| . |GcdDomain|) 108729) ((|String| . |SetCategory|) T) ((|SquareMatrix| . |LeftModule|) 108703) ((|SequentialDifferentialPolynomial| . |IntegralDomain|) 108589) ((|HomogeneousDirectProduct| . |FullyRetractableTo|) 108550) ((|LaurentPolynomial| . |PrincipalIdealDomain|) 108526) ((|GeneralDistributedMultivariatePolynomial| . |UniqueFactorizationDomain|) 108476) ((|SparseMultivariatePolynomial| . |GcdDomain|) 108394) ((|NewSparseUnivariatePolynomial| . |IntegralDomain|) 108257) ((|FortranProgram| . |CoercibleTo|) 108231) ((|NewSparseMultivariatePolynomial| . |IntegralDomain|) 108117) ((|MultivariatePolynomial| . |Evalable|) 108104) ((|ThreeDimensionalMatrix| . |InnerEvalable|) 108023) ((|LiePolynomial| . |AbelianSemiGroup|) T) ((|LiePolynomial| . |AbelianGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |IntegralDomain|) 107909) ((|BalancedPAdicRational| . |PrincipalIdealDomain|) T) ((|BalancedPAdicRational| . |OrderedIntegralDomain|) NIL) ((|FiniteFieldExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldExtensionByPolynomial| . |AbelianGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |AbelianGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |AbelianGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|DifferentialSparseMultivariatePolynomial| . |AbelianGroup|) T) ((|Asp74| . |FortranMatrixFunctionCategory|) T) ((|Asp74| . |FortranProgramCategory|) T) ((|DistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|DistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|ThreeDimensionalViewport| . |CoercibleTo|) 107883) ((|TaylorSeries| . |SemiGroup|) T) ((|TaylorSeries| . |AbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |Evalable|) 107684) ((|SparseMultivariateTaylorSeries| . |Evalable|) 107671) ((|SimpleAlgebraicExtension| . |Module|) 107494) ((|OrdinaryWeightedPolynomials| . |LeftModule|) 107441) ((|Point| . |PointCategory|) 107425) ((|PrimeField| . |AbelianGroup|) T) ((|EuclideanModularRing| . |CommutativeRing|) T) ((|PrimeField| . |AbelianSemiGroup|) T) ((|PAdicRationalConstructor| . |OrderedSet|) 107352) ((|PseudoAlgebraicClosureOfRationalNumber| . |CancellationAbelianMonoid|) T) ((|ModularField| . |SemiGroup|) T) ((|ModularField| . |AbelianMonoid|) T) ((|ListMultiDictionary| . |SetCategory|) 107322) ((|Library| . |KeyedDictionary|) 107292) ((|Library| . |SetCategory|) T) ((|InnerPrimeField| . |UniqueFactorizationDomain|) T) ((|InnerFiniteField| . |UniqueFactorizationDomain|) T) ((|InnerPrimeField| . |IntegralDomain|) T) ((|InnerFiniteField| . |IntegralDomain|) T) ((|FiniteFieldExtension| . |Module|) 107233) ((|FiniteFieldNormalBasisExtension| . |Module|) 107174) ((|FiniteFieldCyclicGroupExtension| . |Module|) 107115) ((|FortranExpression| . |RightModule|) 107099) ((|ContinuedFraction| . |BiModule|) 106964) ((|ContinuedFraction| . |RightModule|) 106879) ((|BinaryExpansion| . |Module|) 106813) ((|FortranExpression| . |BiModule|) 106792) ((|e04ucfAnnaType| . |SetCategory|) T) ((|e04nafAnnaType| . |SetCategory|) T) ((|e04mbfAnnaType| . |SetCategory|) T) ((|e04jafAnnaType| . |SetCategory|) T) ((|MachineInteger| . |Ring|) T) ((|e04gcfAnnaType| . |SetCategory|) T) ((|e04fdfAnnaType| . |SetCategory|) T) ((|e04dgfAnnaType| . |SetCategory|) T) ((|d03fafAnnaType| . |SetCategory|) T) ((|d03eefAnnaType| . |SetCategory|) T) ((|d02ejfAnnaType| . |SetCategory|) T) ((|Complex| . |TrigonometricFunctionCategory|) 106743) ((|Complex| . |TranscendentalFunctionCategory|) 106694) ((|d02cjfAnnaType| . |SetCategory|) T) ((|d02bhfAnnaType| . |SetCategory|) T) ((|BalancedPAdicInteger| . |Ring|) T) ((|d02bbfAnnaType| . |SetCategory|) T) ((|d01TransformFunctionType| . |SetCategory|) T) ((|MachineInteger| . |DifferentialRing|) T) ((|d01gbfAnnaType| . |SetCategory|) T) ((|d01fcfAnnaType| . |SetCategory|) T) ((|d01asfAnnaType| . |SetCategory|) T) ((|d01aqfAnnaType| . |SetCategory|) T) ((|d01apfAnnaType| . |SetCategory|) T) ((|d01anfAnnaType| . |SetCategory|) T) ((|d01amfAnnaType| . |SetCategory|) T) ((|d01alfAnnaType| . |SetCategory|) T) ((|d01akfAnnaType| . |SetCategory|) T) ((|d01ajfAnnaType| . |SetCategory|) T) ((|DirectProduct| . |BasicType|) 106386) ((|Complex| . |ArcHyperbolicFunctionCategory|) 106337) ((|Complex| . |ArcTrigonometricFunctionCategory|) 106288) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CancellationAbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator2| . |RetractableTo|) 106132) ((|HomogeneousDirectProduct| . |Rng|) 106042) ((|SquareMatrix| . |Aggregate|) T) ((|SplitHomogeneousDirectProduct| . |SetCategory|) 105734) ((|StochasticDifferential| . |BasicType|) T) ((|LieSquareMatrix| . |HomogeneousAggregate|) 105718) ((|Asp34| . |Type|) T) ((|BasicFunctions| . |CoercibleTo|) 105692) ((|XRecursivePolynomial| . |CoercibleTo|) 105666) ((|FreeModule1| . |CoercibleTo|) 105640) ((|MultivariatePolynomial| . |Algebra|) 105403) ((|Interval| . |TrigonometricFunctionCategory|) T) ((|Interval| . |TranscendentalFunctionCategory|) T) ((|IndexedExponents| . |CoercibleTo|) 105377) ((|IndexedList| . |Evalable|) 105301) ((|IndexedBits| . |CoercibleTo|) 105275) ((|IndexedBits| . |ConvertibleTo|) 105250) ((|SparseUnivariateLaurentSeries| . |StepThrough|) NIL) ((|RegularTriangularSet| . |RegularTriangularSetCategory|) 105219) ((|RegularTriangularSet| . |SetCategory|) T) ((|RadixExpansion| . |BasicType|) T) ((|Partition| . |BasicType|) T) ((|PartialFraction| . |BasicType|) T) ((|PoincareBirkhoffWittLyndonBasis| . |RetractableTo|) 105188) ((|SquareMatrix| . |Monoid|) T) ((|RadicalFunctionField| . |LeftModule|) 105116) ((|GeneralTriangularSet| . |SetCategory|) T) ((|GeneralPolynomialSet| . |SetCategory|) T) ((|IntegrationResult| . |AbelianMonoid|) T) ((|Interval| . |ArcHyperbolicFunctionCategory|) T) ((|Interval| . |ArcTrigonometricFunctionCategory|) T) ((|FourierSeries| . |BasicType|) T) ((|RoutinesTable| . |Dictionary|) 105049) ((|SparseUnivariateTaylorSeries| . |Algebra|) 104893) ((|OrdinaryWeightedPolynomials| . |Monoid|) T) ((|MachineComplex| . |PrincipalIdealDomain|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |AbelianSemiGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianGroup|) T) ((|IndexedDirectProductAbelianGroup| . |AbelianSemiGroup|) T) ((|SparseUnivariatePuiseuxSeries| . |Algebra|) 104681) ((|FortranExpression| . |Ring|) T) ((|SparseUnivariateLaurentSeries| . |Algebra|) 104396) ((|SimpleAlgebraicExtension| . |CommutativeRing|) T) ((|ContinuedFraction| . |Ring|) T) ((|SparseMultivariateTaylorSeries| . |Algebra|) 104240) ((|ModMonic| . |AbelianMonoidRing|) 104201) ((|FiniteFieldExtension| . |CommutativeRing|) T) ((|FiniteFieldNormalBasisExtension| . |CommutativeRing|) T) ((|InnerIndexedTwoDimensionalArray| . |TwoDimensionalArrayCategory|) 104175) ((|IndexedTwoDimensionalArray| . |TwoDimensionalArrayCategory|) 104077) ((|FiniteFieldNormalBasis| . |ExtensionField|) 104046) ((|DoubleFloat| . |GcdDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |EntireRing|) 103985) ((|FiniteFieldCyclicGroupExtension| . |CommutativeRing|) T) ((|ContinuedFraction| . |DivisionRing|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedSet|) 103854) ((|BinaryExpansion| . |CommutativeRing|) T) ((|PAdicRationalConstructor| . |QuotientFieldCategory|) 103838) ((|LinearOrdinaryDifferentialOperator| . |SemiGroup|) T) ((|InnerPrimeField| . |Field|) T) ((|InnerPrimeField| . |FiniteAlgebraicExtensionField|) 103825) ((|InnerFiniteField| . |FiniteAlgebraicExtensionField|) 103789) ((|InnerFiniteField| . |Field|) T) ((|Expression| . |EuclideanDomain|) 103756) ((|ExponentialExpansion| . |EuclideanDomain|) T) ((|IndexedVector| . |OrderedSet|) 103727) ((|SplitHomogeneousDirectProduct| . |Module|) 103656) ((|IndexedList| . |ExtensibleLinearAggregate|) 103640) ((|LinearOrdinaryDifferentialOperator| . |AbelianMonoid|) T) ((|Factored| . |DifferentialExtension|) 103624) ((|U16Matrix| . |BasicType|) T) ((|ExponentialExpansion| . |RealConstant|) NIL) ((|FiniteDivisor| . |AbelianMonoid|) T) ((|Divisor| . |AbelianMonoid|) T) ((|BalancedBinaryTree| . |RecursiveAggregate|) 103608) ((|AssociationList| . |AssociationListAggregate|) 103587) ((|Kernel| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |Finite|) T) ((|InnerAlgebraicNumber| . |AlgebraicallyClosedField|) T) ((|DirectProduct| . |Evalable|) 103511) ((|SequentialDifferentialPolynomial| . |SemiGroup|) T) ((|XPolynomialRing| . |LeftModule|) 103485) ((|NewSparseUnivariatePolynomial| . |SemiGroup|) T) ((|NewSparseMultivariatePolynomial| . |SemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |SemiGroup|) T) ((|RomanNumeral| . |GcdDomain|) T) ((|U8Matrix| . |SetCategory|) T) ((|Polynomial| . |GcdDomain|) 103403) ((|Bits| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |AbelianMonoid|) T) ((|OrdinaryDifferentialRing| . |Rng|) T) ((|NewSparseUnivariatePolynomial| . |AbelianMonoid|) T) ((|NewSparseMultivariatePolynomial| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |GcdDomain|) 103321) ((|StringTable| . |InnerEvalable|) 103005) ((|FreeModule1| . |FreeModuleCat|) 102984) ((|SymmetricPolynomial| . |FullyRetractableTo|) 102968) ((|GeneralModulePolynomial| . |AbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianMonoid|) T) ((|MyUnivariatePolynomial| . |FullyRetractableTo|) 102952) ((|MyExpression| . |ExpressionSpace|) T) ((|Heap| . |InnerEvalable|) 102871) ((|RadicalFunctionField| . |LeftOreRing|) T) ((|EuclideanModularRing| . |EntireRing|) T) ((|SingletonAsOrderedSet| . |CoercibleTo|) 102845) ((|Fraction| . |PolynomialFactorizationExplicit|) 102795) ((|AntiSymm| . |SemiGroup|) T) ((|RealClosure| . |PrincipalIdealDomain|) T) ((|RadicalFunctionField| . |Monoid|) T) ((|ModMonic| . |PatternMatchable|) NIL) ((|InnerPrimeField| . |SemiGroup|) T) ((|InnerFiniteField| . |SemiGroup|) T) ((|OrderedCompletion| . |LeftModule|) 102759) ((|TaylorSeries| . |CancellationAbelianMonoid|) T) ((|SparseUnivariateLaurentSeries| . |FullyPatternMatchable|) 102683) ((|RadixExpansion| . |Evalable|) NIL) ((|OrderedDirectProduct| . |HomogeneousAggregate|) 102667) ((|FiniteField| . |PrincipalIdealDomain|) T) ((|Stream| . |Aggregate|) T) ((|Fraction| . |LeftModule|) 102608) ((|AntiSymm| . |AbelianMonoid|) T) ((|ModularField| . |CancellationAbelianMonoid|) T) ((|ModMonic| . |RetractableTo|) 102418) ((|InnerPrimeField| . |AbelianMonoid|) T) ((|BinaryExpansion| . |InnerEvalable|) NIL) ((|InnerFiniteField| . |AbelianMonoid|) T) ((|Complex| . |FramedAlgebra|) 102366) ((|DoubleFloat| . |SpecialFunctionCategory|) T) ((|SplittingNode| . |SetCategory|) T) ((|XDistributedPolynomial| . |XAlgebra|) 102350) ((|MachineInteger| . |OrderedCancellationAbelianMonoid|) T) ((|MachineInteger| . |OrderedAbelianMonoid|) T) ((|Float| . |CharacteristicZero|) T) ((|SingleInteger| . |EuclideanDomain|) T) ((|UnivariateLaurentSeriesConstructor| . |QuotientFieldCategory|) 102317) ((|AlgebraicNumber| . |PrincipalIdealDomain|) T) ((|ThreeDimensionalMatrix| . |HomogeneousAggregate|) 102301) ((|DirectProductModule| . |VectorSpace|) 102268) ((|DirectProductMatrixModule| . |VectorSpace|) 102235) ((|Symbol| . |OrderedSet|) T) ((|SplitHomogeneousDirectProduct| . |CommutativeRing|) 102201) ((|SingleInteger| . |RealConstant|) T) ((|RegularChain| . |Aggregate|) T) ((|Operator| . |CharacteristicZero|) 102164) ((|Operator| . |CharacteristicNonZero|) 102124) ((|Multiset| . |BagAggregate|) 102108) ((|Kernel| . |CachableSet|) T) ((|HomogeneousDirectProduct| . |SetCategory|) 101800) ((|SymmetricPolynomial| . |Rng|) T) ((|PAdicRational| . |GcdDomain|) T) ((|Asp78| . |Type|) T) ((|DirectProduct| . |Algebra|) 101757) ((|CharacterClass| . |BagAggregate|) 101732) ((|Plcs| . |SetCategoryWithDegree|) T) ((|ModMonic| . |FullyLinearlyExplicitRingOver|) 101716) ((|MyUnivariatePolynomial| . |Rng|) T) ((|SingleInteger| . |IntegerNumberSystem|) T) ((|U16Matrix| . |Evalable|) NIL) ((|FreeNilpotentLie| . |RightModule|) 101700) ((|XPolynomialRing| . |Monoid|) T) ((|WeightedPolynomials| . |Rng|) T) ((|SparseUnivariatePolynomial| . |PolynomialCategory|) 101635) ((|Any| . |CoercibleTo|) 101609) ((|SparseMultivariatePolynomial| . |PolynomialCategory|) 101562) ((|LinearOrdinaryDifferentialOperator1| . |FullyRetractableTo|) 101546) ((|UnivariateTaylorSeries| . |BasicType|) T) ((|UnivariatePuiseuxSeries| . |BasicType|) T) ((|LocalAlgebra| . |RightModule|) 101530) ((|Localize| . |AbelianSemiGroup|) T) ((|Localize| . |AbelianGroup|) T) ((|String| . |InnerEvalable|) NIL) ((|UnivariateLaurentSeries| . |BasicType|) T) ((|U16Vector| . |Type|) T) ((|FreeNilpotentLie| . |BiModule|) 101509) ((|Dequeue| . |DequeueAggregate|) 101493) ((|UnivariateFormalPowerSeries| . |BasicType|) T) ((|RectangularMatrix| . |SetCategory|) T) ((|RadixExpansion| . |StepThrough|) T) ((|RectangularMatrix| . |RectangularMatrixCategory|) 101411) ((|OrderlyDifferentialVariable| . |SetCategory|) T) ((|FiniteFieldCyclicGroup| . |UniqueFactorizationDomain|) T) ((|AssociatedLieAlgebra| . |LeftModule|) 101395) ((|LocalAlgebra| . |BiModule|) 101374) ((|AssociatedJordanAlgebra| . |LeftModule|) 101358) ((|InnerTaylorSeries| . |BasicType|) T) ((|IntegrationResult| . |CancellationAbelianMonoid|) T) ((|InnerSparseUnivariatePowerSeries| . |BasicType|) T) ((|FramedModule| . |SetCategory|) T) ((|FreeModule| . |SetCategory|) T) ((|DenavitHartenbergMatrix| . |SetCategory|) 101328) ((|ListMultiDictionary| . |InnerEvalable|) 101247) ((|Library| . |InnerEvalable|) 100997) ((|OnePointCompletion| . |Ring|) 100967) ((|List| . |Collection|) 100951) ((|FiniteFieldCyclicGroup| . |IntegralDomain|) T) ((|ModMonic| . |PartialDifferentialRing|) 100849) ((|InnerTable| . |Dictionary|) 100791) ((|UnivariateTaylorSeries| . |ElementaryFunctionCategory|) 100740) ((|UnivariatePuiseuxSeries| . |ElementaryFunctionCategory|) 100689) ((|UnivariateLaurentSeries| . |ElementaryFunctionCategory|) 100638) ((|SimpleAlgebraicExtension| . |EntireRing|) 100572) ((|HexadecimalExpansion| . |OrderedRing|) T) ((|DeRhamComplex| . |SemiGroup|) T) ((|UnivariateFormalPowerSeries| . |ElementaryFunctionCategory|) 100521) ((|TaylorSeries| . |HyperbolicFunctionCategory|) 100470) ((|RadixExpansion| . |Algebra|) 100404) ((|DecimalExpansion| . |OrderedRing|) T) ((|Fraction| . |LeftOreRing|) T) ((|PartialFraction| . |Algebra|) 100345) ((|OrderedCompletion| . |OrderedAbelianSemiGroup|) 100315) ((|OrderedCompletion| . |OrderedAbelianGroup|) 100285) ((|OrderedCompletion| . |Monoid|) 100255) ((|FiniteFieldExtension| . |EntireRing|) T) ((|FiniteFieldNormalBasisExtension| . |EntireRing|) T) ((|FiniteFieldCyclicGroupExtension| . |EntireRing|) T) ((|Complex| . |GcdDomain|) 100156) ((|FourierSeries| . |Algebra|) 100140) ((|BinaryExpansion| . |EntireRing|) T) ((|DeRhamComplex| . |AbelianMonoid|) T) ((|Fraction| . |OrderedAbelianSemiGroup|) 100100) ((|Fraction| . |OrderedAbelianGroup|) 100060) ((|Fraction| . |Monoid|) T) ((|IndexedBits| . |EltableAggregate|) 100025) ((|Pi| . |RightModule|) 99979) ((|LinearOrdinaryDifferentialOperator| . |CancellationAbelianMonoid|) T) ((|SplitHomogeneousDirectProduct| . |InnerEvalable|) 99898) ((|FiniteDivisor| . |CancellationAbelianMonoid|) T) ((|Complex| . |FieldOfPrimeCharacteristic|) 99860) ((|Divisor| . |CancellationAbelianMonoid|) T) ((|HomogeneousDirectProduct| . |Module|) 99789) ((|OrderedDirectProduct| . |Eltable|) 99761) ((|Pi| . |BiModule|) 99688) ((|AffinePlane| . |AffineSpaceCategory|) 99672) ((|LinearOrdinaryDifferentialOperator1| . |Rng|) T) ((|UnivariatePolynomial| . |GcdDomain|) 99567) ((|SequentialDifferentialPolynomial| . |CancellationAbelianMonoid|) T) ((|DifferentialSparseMultivariatePolynomial| . |OrderedSet|) 99538) ((|DistributedMultivariatePolynomial| . |OrderedSet|) 99509) ((|NewSparseUnivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|NewSparseMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|Interval| . |GcdDomain|) T) ((|RectangularMatrix| . |Module|) 99438) ((|LocalAlgebra| . |Ring|) T) ((|RegularTriangularSet| . |InnerEvalable|) 99357) ((|GeneralModulePolynomial| . |CancellationAbelianMonoid|) T) ((|GeneralDistributedMultivariatePolynomial| . |CancellationAbelianMonoid|) T) ((|AssociationList| . |SetCategory|) T) ((|FreeModule| . |Module|) 99314) ((|OrdinaryDifferentialRing| . |SetCategory|) T) ((|GeneralTriangularSet| . |InnerEvalable|) 99233) ((|GeneralPolynomialSet| . |InnerEvalable|) 99152) ((|GenericNonAssociativeAlgebra| . |FiniteRankNonAssociativeAlgebra|) 99108) ((|AssociationList| . |KeyedDictionary|) 99087) ((|Expression| . |ExpressionSpace|) T) ((|LieSquareMatrix| . |CoercibleTo|) 99037) ((|OneDimensionalArray| . |OrderedSet|) 99008) ((|UnivariateLaurentSeries| . |Evalable|) 98827) ((|RadixExpansion| . |FullyPatternMatchable|) 98804) ((|OrderedDirectProduct| . |IndexedAggregate|) 98776) ((|IndexedFlexibleArray| . |OrderedSet|) 98747) ((|IndexedOneDimensionalArray| . |OrderedSet|) 98718) ((|AlgebraicFunctionField| . |UniqueFactorizationDomain|) T) ((|Quaternion| . |RetractableTo|) 98562) ((|AntiSymm| . |CancellationAbelianMonoid|) T) ((|InnerPrimeField| . |CancellationAbelianMonoid|) T) ((|InnerFiniteField| . |CancellationAbelianMonoid|) T) ((|Equation| . |LeftModule|) 98386) ((|FiniteFieldCyclicGroup| . |FiniteAlgebraicExtensionField|) 98355) ((|FiniteFieldCyclicGroup| . |Field|) T) ((|FreeAbelianGroup| . |FreeAbelianMonoidCategory|) 98327) ((|ExponentialOfUnivariatePuiseuxSeries| . |Eltable|) 98312) ((|AlgebraicFunctionField| . |IntegralDomain|) T) ((|Float| . |TranscendentalFunctionCategory|) T) ((|Float| . |TrigonometricFunctionCategory|) T) ((|Result| . |TableAggregate|) 98282) ((|Table| . |DictionaryOperations|) 98224) ((|SparseUnivariateLaurentSeries| . |DifferentialExtension|) 98148) ((|Result| . |BagAggregate|) 98081) ((|FortranCode| . |SetCategory|) T) ((|Float| . |ArcTrigonometricFunctionCategory|) T) ((|Float| . |ArcHyperbolicFunctionCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |AbelianSemiGroup|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianSemiGroup|) T) ((|Pi| . |Ring|) T) ((|InfinitlyClosePoint| . |InfinitlyClosePointCategory|) 98025) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |AbelianGroup|) T) ((|HashTable| . |DictionaryOperations|) 97967) ((|StringTable| . |HomogeneousAggregate|) 97890) ((|XRecursivePolynomial| . |RightModule|) 97874) ((|FreeModule1| . |RightModule|) 97858) ((|Pi| . |DivisionRing|) T) ((|OrderlyDifferentialPolynomial| . |BasicType|) T) ((|ModuleOperator| . |CharacteristicZero|) 97821) ((|ModuleOperator| . |CharacteristicNonZero|) 97781) ((|Heap| . |HomogeneousAggregate|) 97765) ((|XRecursivePolynomial| . |BiModule|) 97744) ((|HyperellipticFiniteDivisor| . |FiniteDivisorCategory|) 97713) ((|Quaternion| . |FullyLinearlyExplicitRingOver|) 97697) ((|IndexedDirectProductObject| . |SetCategory|) T) ((|HomogeneousDirectProduct| . |CommutativeRing|) 97663) ((|Quaternion| . |FullyEvalableOver|) 97647) ((|FractionalIdeal| . |BasicType|) T) ((|FreeModule1| . |BiModule|) 97626) ((|ElementaryFunctionsUnivariatePuiseuxSeries| . |PartialTranscendentalFunctions|) 97610) ((|ElementaryFunctionsUnivariateLaurentSeries| . |PartialTranscendentalFunctions|) 97594) ((|DoubleFloatMatrix| . |Aggregate|) T) ((|ComplexDoubleFloatMatrix| . |Aggregate|) T) ((|U8Matrix| . |InnerEvalable|) NIL) ((|XPolynomial| . |CoercibleTo|) 97568) ((|XPBWPolynomial| . |CoercibleTo|) 97542) ((|Bits| . |InnerEvalable|) NIL) ((|SparseUnivariatePolynomial| . |UnivariatePolynomialCategory|) 97526) ((|SparseUnivariateSkewPolynomial| . |UnivariateSkewPolynomialCategory|) 97510) ((|SymmetricPolynomial| . |SetCategory|) T) ((|BalancedBinaryTree| . |Type|) T) ((|Polynomial| . |PolynomialCategory|) 97451) ((|MyUnivariatePolynomial| . |SetCategory|) T) ((|OrdinaryDifferentialRing| . |Module|) 97371) ((|UnivariateLaurentSeries| . |StepThrough|) NIL) ((|HomogeneousDistributedMultivariatePolynomial| . |PolynomialCategory|) 97263) ((|RomanNumeral| . |CombinatorialFunctionCategory|) T) ((|TwoDimensionalArray| . |BasicType|) 97233) ((|AlgebraGivenByStructuralConstants| . |CoercibleTo|) 97207) ((|Asp4| . |CoercibleTo|) 97181) ((|FiniteFieldNormalBasis| . |LeftModule|) 97107) ((|WeightedPolynomials| . |SetCategory|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |OrderedSet|) T) ((|FiniteFieldCyclicGroup| . |SemiGroup|) T) ((|EqTable| . |SetCategory|) T) ((|Quaternion| . |PartialDifferentialRing|) 97039) ((|EqTable| . |KeyedDictionary|) 97018) ((|UnivariateTaylorSeries| . |Algebra|) 96862) ((|UnivariatePuiseuxSeries| . |Algebra|) 96650) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|UnivariateLaurentSeries| . |Algebra|) 96371) ((|HexadecimalExpansion| . |Rng|) T) ((|UnivariateFormalPowerSeries| . |Algebra|) 96215) ((|DecimalExpansion| . |Rng|) T) ((|FiniteFieldCyclicGroup| . |AbelianMonoid|) T) ((|CliffordAlgebra| . |CoercibleTo|) 96189) ((|OnePointCompletion| . |OrderedCancellationAbelianMonoid|) 96159) ((|OnePointCompletion| . |OrderedAbelianMonoid|) 96129) ((|MyExpression| . |PrincipalIdealDomain|) 96096) ((|InnerTaylorSeries| . |Algebra|) 96057) ((|InnerSparseUnivariatePowerSeries| . |Algebra|) 95901) ((|PAdicInteger| . |IntegralDomain|) T) ((|DeRhamComplex| . |CancellationAbelianMonoid|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |RadicalCategory|) 95850) ((|Asp50| . |CoercibleTo|) 95824) ((|ModMonic| . |EuclideanDomain|) 95800) ((|Equation| . |Monoid|) 95673) ((|OpenMathErrorKind| . |BasicType|) T) ((|OrderedVariableList| . |OrderedFinite|) T) ((|Equation| . |Group|) 95649) ((|XDistributedPolynomial| . |BasicType|) T) ((|AlgebraicFunctionField| . |Field|) T) ((|PAdicRationalConstructor| . |CharacteristicZero|) 95612) ((|AffinePlane| . |SetCategory|) T) ((|PAdicRationalConstructor| . |CharacteristicNonZero|) 95572) ((|String| . |HomogeneousAggregate|) 95547) ((|XRecursivePolynomial| . |Ring|) T) ((|HomogeneousDirectProduct| . |InnerEvalable|) 95466) ((|SquareFreeRegularTriangularSet| . |Type|) T) ((|Product| . |CoercibleTo|) 95440) ((|ListMultiDictionary| . |HomogeneousAggregate|) 95424) ((|Library| . |HomogeneousAggregate|) 95341) ((|OrderedDirectProduct| . |CoercibleTo|) 94990) ((|AlgebraicNumber| . |AlgebraicallyClosedField|) T) ((|SymmetricPolynomial| . |Module|) 94834) ((|LinearOrdinaryDifferentialOperator1| . |SetCategory|) T) ((|FortranTemplate| . |FileCategory|) 94799) ((|MyUnivariatePolynomial| . |Module|) 94539) ((|Set| . |BasicType|) T) ((|OrderlyDifferentialPolynomial| . |Evalable|) 94526) ((|OrderedVariableList| . |SetCategory|) T) ((|XPBWPolynomial| . |FreeModuleCat|) 94469) ((|RectangularMatrix| . |InnerEvalable|) 94388) ((|StringTable| . |Eltable|) 94361) ((|DirectProduct| . |DifferentialExtension|) 94329) ((|WeightedPolynomials| . |Module|) 94286) ((|OrdinaryDifferentialRing| . |CommutativeRing|) 94262) ((|FiniteFieldNormalBasis| . |LeftOreRing|) T) ((|DenavitHartenbergMatrix| . |InnerEvalable|) 94181) ((|LocalAlgebra| . |OrderedCancellationAbelianMonoid|) 94151) ((|LocalAlgebra| . |OrderedAbelianMonoid|) 94121) ((|Tuple| . |CoercibleTo|) 94040) ((|Dequeue| . |Type|) T) ((|ThreeDimensionalMatrix| . |CoercibleTo|) 93991) ((|Stream| . |RecursiveAggregate|) 93975) ((|FiniteFieldNormalBasis| . |Monoid|) T) ((|Point| . |BasicType|) 93912) ((|UnivariateLaurentSeries| . |FullyPatternMatchable|) 93842) ((|SplitHomogeneousDirectProduct| . |HomogeneousAggregate|) 93826) ((|TwoDimensionalArray| . |Evalable|) 93750) ((|FourierComponent| . |BasicType|) T) ((|TaylorSeries| . |AbelianGroup|) T) ((|TaylorSeries| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |SemiGroup|) T) ((|ModularField| . |AbelianGroup|) T) ((|LieExponentials| . |CoercibleTo|) 93724) ((|InnerFreeAbelianMonoid| . |FreeAbelianMonoidCategory|) 93703) ((|ModularField| . |AbelianSemiGroup|) T) ((|BinaryExpansion| . |Eltable|) NIL) ((|PositiveInteger| . |SemiGroup|) T) ((|AlgebraicFunctionField| . |AbelianMonoid|) T) ((|NonNegativeInteger| . |SemiGroup|) T) ((|Integer| . |UniqueFactorizationDomain|) T) ((|InnerAlgebraicNumber| . |UniqueFactorizationDomain|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |CoercibleTo|) 93677) ((|RadixExpansion| . |DifferentialExtension|) 93654) ((|Complex| . |ComplexCategory|) 93638) ((|InnerPAdicInteger| . |IntegralDomain|) T) ((|Integer| . |IntegralDomain|) T) ((|InnerAlgebraicNumber| . |IntegralDomain|) T) ((|NonNegativeInteger| . |AbelianMonoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |CharacteristicZero|) 93601) ((|StringTable| . |IndexedAggregate|) 93574) ((|UnivariatePuiseuxSeriesConstructor| . |CharacteristicNonZero|) 93534) ((|RegularTriangularSet| . |HomogeneousAggregate|) 93518) ((|UnivariateLaurentSeriesConstructor| . |CharacteristicNonZero|) 93405) ((|UnivariateLaurentSeriesConstructor| . |CharacteristicZero|) 93298) ((|XDistributedPolynomial| . |XPolynomialsCat|) 93277) ((|GeneralTriangularSet| . |HomogeneousAggregate|) 93261) ((|GeneralPolynomialSet| . |HomogeneousAggregate|) 93245) ((|IndexedMatrix| . |Aggregate|) T) ((|LinearOrdinaryDifferentialOperator1| . |Module|) 93202) ((|Localize| . |OrderedSet|) 93164) ((|SymmetricPolynomial| . |CommutativeRing|) 93093) ((|File| . |BasicType|) T) ((|DirectProduct| . |DirectProductCategory|) 93072) ((|DirectProductModule| . |BasicType|) T) ((|DirectProductMatrixModule| . |BasicType|) T) ((|UnivariatePolynomial| . |PolynomialCategory|) 93007) ((|BinaryFile| . |BasicType|) T) ((|DataList| . |OrderedSet|) 92978) ((|OrderlyDifferentialPolynomial| . |Algebra|) 92741) ((|MyUnivariatePolynomial| . |CommutativeRing|) 92571) ((|AssociationList| . |InnerEvalable|) 92279) ((|String| . |Eltable|) 92242) ((|Database| . |SetCategory|) T) ((|SparseTable| . |SetCategory|) T) ((|Places| . |BasicType|) T) ((|SparseTable| . |KeyedDictionary|) 92221) ((|IntegrationResult| . |AbelianSemiGroup|) T) ((|IntegrationResult| . |AbelianGroup|) T) ((|Set| . |Evalable|) 92145) ((|PolynomialRing| . |FullyRetractableTo|) 92129) ((|MachineFloat| . |UniqueFactorizationDomain|) T) ((|Library| . |Eltable|) 92099) ((|SequentialDifferentialPolynomial| . |LinearlyExplicitRingOver|) 92015) ((|NewSparseUnivariatePolynomial| . |LinearlyExplicitRingOver|) 91931) ((|NewSparseMultivariatePolynomial| . |LinearlyExplicitRingOver|) 91847) ((|FiniteFieldCyclicGroup| . |CancellationAbelianMonoid|) T) ((|EuclideanModularRing| . |CoercibleTo|) 91821) ((|Places| . |PlacesCategory|) 91764) ((|MachineFloat| . |IntegralDomain|) T) ((|Permutation| . |SetCategory|) T) ((|PAdicInteger| . |SemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |LinearlyExplicitRingOver|) 91680) ((|Permutation| . |PermutationCategory|) 91664) ((|PseudoAlgebraicClosureOfFiniteField| . |PseudoAlgebraicClosureOfFiniteFieldCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|Point| . |Evalable|) 91588) ((|Float| . |GcdDomain|) T) ((|PAdicInteger| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |CharacteristicNonZero|) T) ((|MachineInteger| . |LeftModule|) 91575) ((|PseudoAlgebraicClosureOfFiniteField| . |CharacteristicZero|) 91538) ((|DecimalExpansion| . |SetCategory|) T) ((|Expression| . |PrincipalIdealDomain|) 91505) ((|ExponentialExpansion| . |PrincipalIdealDomain|) T) ((|ExponentialExpansion| . |OrderedIntegralDomain|) NIL) ((|FreeNilpotentLie| . |Monad|) T) ((|NeitherSparseOrDensePowerSeries| . |CharacteristicNonZero|) 91465) ((|NeitherSparseOrDensePowerSeries| . |CharacteristicZero|) 91428) ((|U8Matrix| . |HomogeneousAggregate|) 91405) ((|BalancedPAdicInteger| . |LeftModule|) 91392) ((|GeneralUnivariatePowerSeries| . |CharacteristicNonZero|) 91352) ((|Factored| . |FullyRetractableTo|) 91336) ((|GeneralUnivariatePowerSeries| . |CharacteristicZero|) 91299) ((|Bits| . |HomogeneousAggregate|) 91276) ((|SparseUnivariatePolynomialExpressions| . |UniqueFactorizationDomain|) 91226) ((|Record| . |CoercibleTo|) 91200) ((|String| . |OneDimensionalArrayAggregate|) 91175) ((|SparseUnivariatePolynomialExpressions| . |IntegralDomain|) 91038) ((|String| . |IndexedAggregate|) 91001) ((|LinearOrdinaryDifferentialOperator| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator| . |AbelianSemiGroup|) T) ((|IndexedString| . |StringAggregate|) T) ((|SplitHomogeneousDirectProduct| . |Eltable|) 90973) ((|FiniteDivisor| . |AbelianSemiGroup|) T) ((|FiniteDivisor| . |AbelianGroup|) T) ((|Divisor| . |AbelianSemiGroup|) T) ((|Divisor| . |AbelianGroup|) T) ((|InnerAlgebraicNumber| . |Field|) T) ((|XDistributedPolynomial| . |Algebra|) 90930) ((|SquareMatrix| . |Type|) T) ((|Library| . |IndexedAggregate|) 90900) ((|SequentialDifferentialPolynomial| . |AbelianSemiGroup|) T) ((|SequentialDifferentialPolynomial| . |AbelianGroup|) T) ((|PolynomialRing| . |Rng|) T) ((|MyUnivariatePolynomial| . |InnerEvalable|) 90810) ((|IndexedExponents| . |OrderedAbelianMonoid|) T) ((|IndexedExponents| . |OrderedCancellationAbelianMonoid|) T) ((|BalancedPAdicRational| . |UniqueFactorizationDomain|) T) ((|DirichletRing| . |BasicType|) T) ((|LaurentPolynomial| . |IntegralDomain|) T) ((|NewSparseUnivariatePolynomial| . |AbelianSemiGroup|) T) ((|NewSparseUnivariatePolynomial| . |AbelianGroup|) T) ((|NewSparseMultivariatePolynomial| . |AbelianGroup|) T) ((|NewSparseMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|MonoidRing| . |Rng|) T) ((|ModularRing| . |Rng|) T) ((|LieSquareMatrix| . |RightModule|) 90794) ((|GeneralModulePolynomial| . |AbelianSemiGroup|) T) ((|BalancedPAdicRational| . |IntegralDomain|) T) ((|GeneralModulePolynomial| . |AbelianGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianSemiGroup|) T) ((|GeneralDistributedMultivariatePolynomial| . |AbelianGroup|) T) ((|SquareMatrix| . |RetractableTo|) 90638) ((|OrdinaryDifferentialRing| . |EntireRing|) 90614) ((|MyExpression| . |FunctionSpace|) 90598) ((|OpenMathEncoding| . |SetCategory|) T) ((|XPolynomial| . |RightModule|) 90582) ((|XPBWPolynomial| . |RightModule|) 90566) ((|LieSquareMatrix| . |BiModule|) 90545) ((|EqTable| . |InnerEvalable|) 90253) ((|UnivariatePuiseuxSeriesConstructor| . |TranscendentalFunctionCategory|) 90202) ((|UnivariatePuiseuxSeriesConstructor| . |TrigonometricFunctionCategory|) 90151) ((|UniversalSegment| . |BasicType|) 90121) ((|DirectProductModule| . |Evalable|) 90045) ((|DirectProductMatrixModule| . |Evalable|) 89969) ((|UnivariateLaurentSeries| . |DifferentialExtension|) 89899) ((|StringTable| . |ConvertibleTo|) NIL) ((|StringTable| . |CoercibleTo|) 89873) ((|UnivariateLaurentSeriesConstructor| . |TranscendentalFunctionCategory|) 89822) ((|UnivariateLaurentSeriesConstructor| . |TrigonometricFunctionCategory|) 89771) ((|SquareMatrix| . |FullyLinearlyExplicitRingOver|) 89755) ((|SingleInteger| . |OrderedIntegralDomain|) T) ((|SingleInteger| . |PrincipalIdealDomain|) T) ((|SplitHomogeneousDirectProduct| . |IndexedAggregate|) 89727) ((|SimpleAlgebraicExtension| . |ConvertibleTo|) 89711) ((|SimpleAlgebraicExtension| . |CoercibleTo|) 89685) ((|RightOpenIntervalRootCharacterization| . |CoercibleTo|) 89659) ((|InfinitlyClosePoint| . |BasicType|) T) ((|Heap| . |CoercibleTo|) 89610) ((|OrderedDirectProduct| . |EltableAggregate|) 89582) ((|KeyedAccessFile| . |Collection|) 89518) ((|Factored| . |Rng|) T) ((|HexadecimalExpansion| . |Module|) 89452) ((|HomogeneousDirectProduct| . |HomogeneousAggregate|) 89436) ((|FlexibleArray| . |OrderedSet|) 89407) ((|FortranExpression| . |LeftModule|) 89381) ((|AntiSymm| . |AbelianGroup|) T) ((|AntiSymm| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |Module|) 89315) ((|Complex| . |MonogenicAlgebra|) 89263) ((|ContinuedFraction| . |LeftModule|) 89178) ((|InnerPrimeField| . |AbelianGroup|) T) ((|InnerPrimeField| . |AbelianSemiGroup|) T) ((|InnerFiniteField| . |AbelianSemiGroup|) T) ((|InnerFiniteField| . |AbelianGroup|) T) ((|GeneralSparseTable| . |Collection|) 89120) ((|MachineInteger| . |LeftOreRing|) T) ((|QuadraticForm| . |BasicType|) T) ((|OutputForm| . |BasicType|) T) ((|Octonion| . |FullyRetractableTo|) 89076) ((|AlgebraicFunctionField| . |CancellationAbelianMonoid|) T) ((|d03fafAnnaType| . |PartialDifferentialEquationsSolverCategory|) T) ((|MachineFloat| . |Field|) T) ((|MachineInteger| . |OrderedAbelianSemiGroup|) T) ((|MachineInteger| . |OrderedAbelianGroup|) T) ((|InnerPAdicInteger| . |SemiGroup|) T) ((|Integer| . |SemiGroup|) T) ((|BalancedPAdicInteger| . |LeftOreRing|) T) ((|InnerAlgebraicNumber| . |SemiGroup|) T) ((|MachineInteger| . |Monoid|) T) ((|FiniteFieldExtension| . |CoercibleTo|) 89050) ((|FiniteFieldNormalBasisExtension| . |CoercibleTo|) 89024) ((|FiniteFieldCyclicGroupExtension| . |CoercibleTo|) 88998) ((|Asp24| . |FortranFunctionCategory|) T) ((|Asp24| . |FortranProgramCategory|) T) ((|BinaryExpansion| . |ConvertibleTo|) 88899) ((|BinaryExpansion| . |CoercibleTo|) 88873) ((|d03eefAnnaType| . |PartialDifferentialEquationsSolverCategory|) T) ((|PrimitiveArray| . |Collection|) 88857) ((|UnivariatePuiseuxSeriesConstructor| . |ArcTrigonometricFunctionCategory|) 88806) ((|NonNegativeInteger| . |CancellationAbelianMonoid|) T) ((|CardinalNumber| . |Monoid|) T) ((|BalancedPAdicInteger| . |Monoid|) T) ((|UnivariatePuiseuxSeriesConstructor| . |ArcHyperbolicFunctionCategory|) 88755) ((|RectangularMatrix| . |HomogeneousAggregate|) 88739) ((|InnerPAdicInteger| . |AbelianMonoid|) T) ((|Integer| . |AbelianMonoid|) T) ((|InnerAlgebraicNumber| . |AbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |ArcTrigonometricFunctionCategory|) 88688) ((|UnivariateLaurentSeriesConstructor| . |ArcHyperbolicFunctionCategory|) 88637) ((|SparseUnivariatePolynomial| . |BasicType|) T) ((|SparseMultivariatePolynomial| . |BasicType|) T) ((|SparseUnivariateSkewPolynomial| . |BasicType|) T) ((|DenavitHartenbergMatrix| . |HomogeneousAggregate|) 88621) ((|XPolynomial| . |BiModule|) 88600) ((|XPBWPolynomial| . |BiModule|) 88579) ((|AlgebraGivenByStructuralConstants| . |RightModule|) 88563) ((|UnivariatePolynomial| . |UnivariatePolynomialCategory|) 88547) ((|UnivariateSkewPolynomial| . |UnivariateSkewPolynomialCategory|) 88531) ((|SymmetricPolynomial| . |EntireRing|) 88498) ((|Bits| . |Eltable|) 88463) ((|SquareMatrix| . |PartialDifferentialRing|) 88395) ((|AlgebraGivenByStructuralConstants| . |BiModule|) 88374) ((|MyUnivariatePolynomial| . |EntireRing|) 88237) ((|XPolynomial| . |Ring|) T) ((|LieSquareMatrix| . |Ring|) T) ((|SparseUnivariateLaurentSeries| . |OrderedRing|) NIL) ((|String| . |ConvertibleTo|) NIL) ((|String| . |CoercibleTo|) 88211) ((|RoutinesTable| . |KeyedDictionary|) 88181) ((|RoutinesTable| . |SetCategory|) T) ((|Asp35| . |FortranVectorFunctionCategory|) T) ((|Asp35| . |FortranProgramCategory|) T) ((|LieSquareMatrix| . |DifferentialRing|) 88146) ((|CliffordAlgebra| . |RightModule|) 88130) ((|Interval| . |IntervalCategory|) 88114) ((|FiniteFieldExtensionByPolynomial| . |CharacteristicZero|) 88077) ((|FiniteFieldExtensionByPolynomial| . |CharacteristicNonZero|) 88008) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CharacteristicZero|) 87971) ((|MakeCachableSet| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CharacteristicNonZero|) 87902) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CharacteristicZero|) 87865) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CharacteristicNonZero|) 87796) ((|DifferentialSparseMultivariatePolynomial| . |CharacteristicNonZero|) 87756) ((|DifferentialSparseMultivariatePolynomial| . |CharacteristicZero|) 87719) ((|DirectProductModule| . |Algebra|) 87676) ((|DistributedMultivariatePolynomial| . |CharacteristicZero|) 87639) ((|BalancedPAdicRational| . |Field|) T) ((|DistributedMultivariatePolynomial| . |CharacteristicNonZero|) 87599) ((|DirectProductMatrixModule| . |Algebra|) 87556) ((|CliffordAlgebra| . |BiModule|) 87535) ((|RadicalFunctionField| . |RetractableTo|) 87340) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|MachineComplex| . |UniqueFactorizationDomain|) T) ((|Octonion| . |Rng|) T) ((|MachineFloat| . |SemiGroup|) T) ((|XPBWPolynomial| . |Ring|) T) ((|SparseUnivariatePolynomialExpressions| . |SemiGroup|) T) ((|Stream| . |Type|) T) ((|RadicalFunctionField| . |FullyLinearlyExplicitRingOver|) 87311) ((|PrimeField| . |CharacteristicNonZero|) T) ((|PrimeField| . |CharacteristicZero|) 87277) ((|PAdicInteger| . |CancellationAbelianMonoid|) T) ((|OrderedDirectProduct| . |RightModule|) 87147) ((|MachineFloat| . |AbelianMonoid|) T) ((|MachineComplex| . |IntegralDomain|) T) ((|ListMultiDictionary| . |CoercibleTo|) 87098) ((|ListMultiDictionary| . |ConvertibleTo|) 87034) ((|Library| . |ConvertibleTo|) NIL) ((|Library| . |CoercibleTo|) 87008) ((|HexadecimalExpansion| . |CommutativeRing|) T) ((|DeRhamComplex| . |AbelianGroup|) T) ((|ContinuedFraction| . |LeftOreRing|) T) ((|DeRhamComplex| . |AbelianSemiGroup|) T) ((|DecimalExpansion| . |CommutativeRing|) T) ((|GeneralUnivariatePowerSeries| . |TrigonometricFunctionCategory|) 86957) ((|GeneralUnivariatePowerSeries| . |TranscendentalFunctionCategory|) 86906) ((|e04ucfAnnaType| . |CoercibleTo|) 86880) ((|e04nafAnnaType| . |CoercibleTo|) 86854) ((|e04mbfAnnaType| . |CoercibleTo|) 86828) ((|e04jafAnnaType| . |CoercibleTo|) 86802) ((|e04gcfAnnaType| . |CoercibleTo|) 86776) ((|IndexedBits| . |LinearAggregate|) 86753) ((|e04fdfAnnaType| . |CoercibleTo|) 86727) ((|FortranExpression| . |Monoid|) T) ((|e04dgfAnnaType| . |CoercibleTo|) 86701) ((|Bits| . |OneDimensionalArrayAggregate|) 86678) ((|ContinuedFraction| . |Monoid|) T) ((|IndexedBits| . |FiniteLinearAggregate|) 86655) ((|d03fafAnnaType| . |CoercibleTo|) 86629) ((|IndexedList| . |StreamAggregate|) 86613) ((|IndexedBits| . |BitAggregate|) T) ((|Bits| . |IndexedAggregate|) 86578) ((|d03eefAnnaType| . |CoercibleTo|) 86552) ((|GeneralUnivariatePowerSeries| . |ArcHyperbolicFunctionCategory|) 86501) ((|GeneralUnivariatePowerSeries| . |ArcTrigonometricFunctionCategory|) 86450) ((|d02ejfAnnaType| . |CoercibleTo|) 86424) ((|d02cjfAnnaType| . |CoercibleTo|) 86398) ((|d02bhfAnnaType| . |CoercibleTo|) 86372) ((|d02bbfAnnaType| . |CoercibleTo|) 86346) ((|d01TransformFunctionType| . |CoercibleTo|) 86320) ((|d01gbfAnnaType| . |CoercibleTo|) 86294) ((|d01fcfAnnaType| . |CoercibleTo|) 86268) ((|d01asfAnnaType| . |CoercibleTo|) 86242) ((|d01aqfAnnaType| . |CoercibleTo|) 86216) ((|d01apfAnnaType| . |CoercibleTo|) 86190) ((|d01anfAnnaType| . |CoercibleTo|) 86164) ((|InputForm| . |SExpressionCategory|) 86088) ((|d01amfAnnaType| . |CoercibleTo|) 86062) ((|d01alfAnnaType| . |CoercibleTo|) 86036) ((|AssociationList| . |HomogeneousAggregate|) 85965) ((|d01akfAnnaType| . |CoercibleTo|) 85939) ((|d01ajfAnnaType| . |CoercibleTo|) 85913) ((|SparseUnivariatePolynomialExpressions| . |AbelianMonoid|) T) ((|OrderedDirectProduct| . |BiModule|) 85776) ((|List| . |BasicType|) 85713) ((|HomogeneousDirectProduct| . |Eltable|) 85685) ((|SplitHomogeneousDirectProduct| . |CoercibleTo|) 85334) ((|SetOfMIntegersInOneToN| . |SetCategory|) T) ((|RegularChain| . |Type|) T) ((|LaurentPolynomial| . |SemiGroup|) T) ((|XPolynomialRing| . |RetractableTo|) 85318) ((|SparseUnivariatePolynomial| . |Evalable|) 85305) ((|SparseMultivariatePolynomial| . |Evalable|) 85292) ((|BalancedPAdicRational| . |SemiGroup|) T) ((|U8Matrix| . |MatrixCategory|) 85243) ((|OrderedFreeMonoid| . |BasicType|) T) ((|LaurentPolynomial| . |AbelianMonoid|) T) ((|SparseTable| . |InnerEvalable|) 84951) ((|FreeMonoid| . |BasicType|) T) ((|FreeAbelianMonoid| . |BasicType|) T) ((|RadicalFunctionField| . |PartialDifferentialRing|) 84870) ((|PolynomialRing| . |SetCategory|) T) ((|CliffordAlgebra| . |Ring|) T) ((|MultivariatePolynomial| . |FullyRetractableTo|) 84854) ((|BalancedPAdicRational| . |AbelianMonoid|) T) ((|MonoidRing| . |SetCategory|) T) ((|ModularRing| . |SetCategory|) T) ((|MakeCachableSet| . |CachableSet|) T) ((|GenericNonAssociativeAlgebra| . |SetCategory|) T) ((|Expression| . |FunctionSpace|) 84838) ((|Fraction| . |Type|) T) ((|RegularTriangularSet| . |ConvertibleTo|) 84774) ((|RegularTriangularSet| . |CoercibleTo|) 84726) ((|RealClosure| . |UniqueFactorizationDomain|) T) ((|DoubleFloat| . |BasicType|) T) ((|DirichletRing| . |Algebra|) 84646) ((|OrderlyDifferentialPolynomial| . |DifferentialExtension|) 84630) ((|RealClosure| . |IntegralDomain|) T) ((|OnePointCompletion| . |LeftModule|) 84594) ((|FiniteField| . |UniqueFactorizationDomain|) T) ((|GeneralTriangularSet| . |CoercibleTo|) 84546) ((|GeneralTriangularSet| . |ConvertibleTo|) 84482) ((|GeneralPolynomialSet| . |ConvertibleTo|) 84418) ((|GeneralPolynomialSet| . |CoercibleTo|) 84370) ((|Fraction| . |Patternable|) 84354) ((|ExponentialOfUnivariatePuiseuxSeries| . |RightModule|) 84136) ((|Fraction| . |PatternMatchable|) 84017) ((|OrderedCompletion| . |RetractableTo|) 83861) ((|HexadecimalExpansion| . |InnerEvalable|) NIL) ((|HomogeneousDirectProduct| . |IndexedAggregate|) 83833) ((|FiniteField| . |IntegralDomain|) T) ((|DecimalExpansion| . |InnerEvalable|) NIL) ((|PAdicRationalConstructor| . |GcdDomain|) T) ((|Factored| . |SetCategory|) T) ((|Fraction| . |RetractableTo|) 83635) ((|ExponentialOfUnivariatePuiseuxSeries| . |BiModule|) 83385) ((|MachineComplex| . |Field|) T) ((|DoubleFloat| . |ElementaryFunctionCategory|) T) ((|AlgebraicNumber| . |UniqueFactorizationDomain|) T) ((|OrderedDirectProduct| . |Ring|) 83295) ((|InnerPAdicInteger| . |CancellationAbelianMonoid|) T) ((|Integer| . |CancellationAbelianMonoid|) T) ((|InnerAlgebraicNumber| . |CancellationAbelianMonoid|) T) ((|AlgebraicNumber| . |IntegralDomain|) T) ((|StringTable| . |EltableAggregate|) 83268) ((|SparseUnivariatePolynomial| . |StepThrough|) 83238) ((|Expression| . |AlgebraicallyClosedField|) 83205) ((|RomanNumeral| . |BasicType|) T) ((|OrderedDirectProduct| . |DifferentialRing|) 83142) ((|DirectProduct| . |OrderedRing|) 83112) ((|Polynomial| . |BasicType|) T) ((|ModuleMonomial| . |BasicType|) T) ((|EqTable| . |HomogeneousAggregate|) 83041) ((|HomogeneousDistributedMultivariatePolynomial| . |BasicType|) T) ((|MultivariatePolynomial| . |Rng|) T) ((|Kernel| . |CoercibleTo|) 83015) ((|Kernel| . |ConvertibleTo|) 82793) ((|Fraction| . |FullyLinearlyExplicitRingOver|) 82777) ((|Fraction| . |FullyEvalableOver|) 82761) ((|SparseUnivariatePolynomial| . |Algebra|) 82501) ((|SparseMultivariatePolynomial| . |Algebra|) 82264) ((|SparseUnivariateSkewPolynomial| . |Algebra|) 82221) ((|FreeNilpotentLie| . |LeftModule|) 82205) ((|List| . |Evalable|) 82129) ((|U8Matrix| . |CoercibleTo|) 82103) ((|PolynomialRing| . |Module|) 81947) ((|MonoidRing| . |Module|) 81904) ((|Dequeue| . |BagAggregate|) 81888) ((|AssociationList| . |Eltable|) 81800) ((|LocalAlgebra| . |LeftModule|) 81774) ((|Exit| . |SetCategory|) T) ((|EuclideanModularRing| . |RightModule|) 81761) ((|Bits| . |CoercibleTo|) 81735) ((|Bits| . |ConvertibleTo|) 81710) ((|GenericNonAssociativeAlgebra| . |Module|) 81666) ((|OrderlyDifferentialPolynomial| . |DifferentialPolynomialCategory|) 81532) ((|Matrix| . |SetCategory|) 81502) ((|InnerTable| . |SetCategory|) T) ((|SparseUnivariateTaylorSeries| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |Rng|) T) ((|EuclideanModularRing| . |BiModule|) 81487) ((|SparseUnivariateLaurentSeries| . |Rng|) T) ((|SparseMultivariateTaylorSeries| . |Rng|) T) ((|InnerTable| . |KeyedDictionary|) 81466) ((|RadixExpansion| . |OrderedRing|) T) ((|DenavitHartenbergMatrix| . |MatrixCategory|) 81418) ((|MachineComplex| . |SemiGroup|) T) ((|TaylorSeries| . |MultivariateTaylorSeriesCategory|) 81391) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |ProjectiveSpaceCategory|) 81335) ((|ExponentialOfUnivariatePuiseuxSeries| . |Ring|) T) ((|FiniteFieldCyclicGroup| . |AbelianSemiGroup|) T) ((|FiniteFieldCyclicGroup| . |AbelianGroup|) T) ((|Fraction| . |PartialDifferentialRing|) 81267) ((|Asp28| . |Type|) T) ((|OnePointCompletion| . |OrderedAbelianSemiGroup|) 81237) ((|Factored| . |Module|) 81211) ((|Octonion| . |SetCategory|) T) ((|OnePointCompletion| . |OrderedAbelianGroup|) 81181) ((|MachineFloat| . |CancellationAbelianMonoid|) T) ((|ModMonic| . |PrincipalIdealDomain|) 81157) ((|MachineComplex| . |AbelianMonoid|) T) ((|HexadecimalExpansion| . |EntireRing|) T) ((|OnePointCompletion| . |Monoid|) 81127) ((|ExponentialOfUnivariatePuiseuxSeries| . |DifferentialRing|) 81062) ((|ExponentialOfUnivariatePuiseuxSeries| . |DivisionRing|) 81038) ((|DecimalExpansion| . |EntireRing|) T) ((|RealClosure| . |Field|) T) ((|UnivariatePuiseuxSeriesConstructor| . |GcdDomain|) 81014) ((|UnivariateLaurentSeriesConstructor| . |GcdDomain|) 80990) ((|FiniteField| . |FiniteAlgebraicExtensionField|) 80959) ((|FiniteField| . |Field|) T) ((|SplittingNode| . |CoercibleTo|) 80933) ((|AssociationList| . |UnaryRecursiveAggregate|) 80875) ((|PAdicRational| . |BasicType|) T) ((|List| . |ExtensibleLinearAggregate|) 80859) ((|MachineFloat| . |RealNumberSystem|) T) ((|Pi| . |LeftModule|) 80813) ((|GraphImage| . |SetCategory|) T) ((|AssociationList| . |IndexedAggregate|) 80725) ((|String| . |EltableAggregate|) 80688) ((|SparseUnivariatePolynomialExpressions| . |CancellationAbelianMonoid|) T) ((|AlgebraicFunctionField| . |LinearlyExplicitRingOver|) 80578) ((|AlgebraicNumber| . |Field|) T) ((|SimpleFortranProgram| . |CoercibleTo|) 80552) ((|SequentialDifferentialPolynomial| . |OrderedSet|) 80523) ((|Library| . |EltableAggregate|) 80493) ((|U32Matrix| . |SetCategory|) T) ((|Polynomial| . |Evalable|) 80480) ((|NewSparseUnivariatePolynomial| . |OrderedSet|) 80451) ((|NewSparseMultivariatePolynomial| . |OrderedSet|) 80422) ((|GeneralDistributedMultivariatePolynomial| . |OrderedSet|) 80393) ((|HomogeneousDirectProduct| . |CoercibleTo|) 80042) ((|DirectProduct| . |FullyRetractableTo|) 80003) ((|DoubleFloatMatrix| . |Type|) T) ((|ComplexDoubleFloatMatrix| . |Type|) T) ((|DoubleFloatVector| . |Collection|) 79976) ((|ComplexDoubleFloatVector| . |Collection|) 79937) ((|Asp20| . |Type|) T) ((|MyUnivariatePolynomial| . |Eltable|) 79840) ((|LaurentPolynomial| . |CancellationAbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Evalable|) 79827) ((|RoutinesTable| . |InnerEvalable|) 79577) ((|EuclideanModularRing| . |Ring|) T) ((|BalancedPAdicRational| . |CancellationAbelianMonoid|) T) ((|GenericNonAssociativeAlgebra| . |NonAssociativeRng|) T) ((|PolynomialRing| . |CommutativeRing|) 79506) ((|SuchThat| . |SetCategory|) T) ((|SplitHomogeneousDirectProduct| . |EltableAggregate|) 79478) ((|SimpleAlgebraicExtension| . |RightModule|) 79360) ((|LocalAlgebra| . |OrderedAbelianSemiGroup|) 79330) ((|IndexedString| . |SetCategory|) T) ((|LocalAlgebra| . |OrderedAbelianGroup|) 79300) ((|LocalAlgebra| . |Monoid|) T) ((|EqTable| . |Eltable|) 79279) ((|Equation| . |Type|) T) ((|RectangularMatrix| . |CoercibleTo|) 79229) ((|RectangularMatrix| . |ConvertibleTo|) 79165) ((|RealClosure| . |SemiGroup|) T) ((|Complex| . |BasicType|) T) ((|ExtAlgBasis| . |OrderedSet|) T) ((|Set| . |Dictionary|) 79149) ((|OrderlyDifferentialVariable| . |CoercibleTo|) 79123) ((|SimpleAlgebraicExtension| . |BiModule|) 78973) ((|RadicalFunctionField| . |EuclideanDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |GcdDomain|) T) ((|Octonion| . |Module|) 78957) ((|FiniteFieldExtension| . |RightModule|) 78898) ((|FiniteField| . |SemiGroup|) T) ((|FiniteFieldNormalBasisExtension| . |RightModule|) 78839) ((|FramedModule| . |CoercibleTo|) 78813) ((|FreeModule| . |CoercibleTo|) 78787) ((|FiniteFieldCyclicGroupExtension| . |RightModule|) 78728) ((|DenavitHartenbergMatrix| . |CoercibleTo|) 78679) ((|RealClosure| . |AbelianMonoid|) T) ((|NeitherSparseOrDensePowerSeries| . |GcdDomain|) T) ((|BinaryExpansion| . |RightModule|) 78613) ((|NumericalPDEProblem| . |BasicType|) T) ((|NumericalOptimizationProblem| . |BasicType|) T) ((|NumericalODEProblem| . |BasicType|) T) ((|NumericalIntegrationProblem| . |BasicType|) T) ((|Magma| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |GcdDomain|) 78589) ((|Factored| . |CommutativeRing|) T) ((|FiniteFieldExtension| . |BiModule|) 78498) ((|FiniteFieldNormalBasisExtension| . |BiModule|) 78407) ((|FiniteFieldCyclicGroupExtension| . |BiModule|) 78316) ((|DirectProductModule| . |DifferentialExtension|) 78284) ((|DirectProductMatrixModule| . |DifferentialExtension|) 78252) ((|FiniteField| . |AbelianMonoid|) T) ((|Asp31| . |Type|) T) ((|DoubleFloat| . |Algebra|) 78206) ((|BinaryExpansion| . |BiModule|) 78101) ((|AlgebraicFunctionField| . |AbelianSemiGroup|) T) ((|AlgebraicFunctionField| . |AbelianGroup|) T) ((|LieSquareMatrix| . |Monad|) T) ((|Complex| . |ElementaryFunctionCategory|) 78052) ((|PseudoAlgebraicClosureOfFiniteField| . |FieldOfPrimeCharacteristic|) T) ((|AlgebraicNumber| . |SemiGroup|) T) ((|PositiveInteger| . |AbelianSemiGroup|) T) ((|NonNegativeInteger| . |AbelianSemiGroup|) T) ((|SparseTable| . |HomogeneousAggregate|) 77981) ((|Pi| . |LeftOreRing|) T) ((|HyperellipticFiniteDivisor| . |SetCategory|) T) ((|XRecursivePolynomial| . |LeftModule|) 77955) ((|UnivariatePolynomial| . |BasicType|) T) ((|UnivariateSkewPolynomial| . |BasicType|) T) ((|DirectProduct| . |Rng|) 77865) ((|RomanNumeral| . |StepThrough|) T) ((|Product| . |OrderedAbelianMonoid|) 77776) ((|FreeModule1| . |LeftModule|) 77760) ((|AlgebraicNumber| . |AbelianMonoid|) T) ((|Product| . |OrderedCancellationAbelianMonoid|) 77671) ((|OrderedDirectProduct| . |OrderedCancellationAbelianMonoid|) 77595) ((|OrderedDirectProduct| . |OrderedAbelianMonoid|) 77519) ((|EqTable| . |IndexedAggregate|) 77498) ((|Pi| . |Monoid|) T) ((|SparseUnivariatePolynomialExpressions| . |HyperbolicFunctionCategory|) 77449) ((|Interval| . |BasicType|) T) ((|StochasticDifferential| . |Rng|) T) ((|PAdicRational| . |Evalable|) 77357) ((|LinearOrdinaryDifferentialOperator1| . |Eltable|) 77336) ((|Boolean| . |Logic|) T) ((|Asp42| . |Type|) T) ((|RomanNumeral| . |Algebra|) 77323) ((|LiePolynomial| . |FreeLieAlgebra|) 77302) ((|Polynomial| . |Algebra|) 77065) ((|MultivariatePolynomial| . |SetCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Algebra|) 76828) ((|Asp7| . |Type|) T) ((|Interval| . |ElementaryFunctionCategory|) T) ((|UnivariateLaurentSeries| . |OrderedRing|) NIL) ((|SparseUnivariateTaylorSeries| . |SetCategory|) T) ((|SparseUnivariatePuiseuxSeries| . |SetCategory|) T) ((|SparseUnivariateLaurentSeries| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |RetractableTo|) 76797) ((|SimpleAlgebraicExtension| . |Ring|) T) ((|RadixExpansion| . |Rng|) T) ((|AssociationList| . |CoercibleTo|) 76771) ((|AssociationList| . |ConvertibleTo|) NIL) ((|PartialFraction| . |Rng|) T) ((|OrdinaryDifferentialRing| . |CoercibleTo|) 76745) ((|Stack| . |BasicType|) 76715) ((|SimpleAlgebraicExtension| . |DivisionRing|) 76649) ((|FourierSeries| . |Rng|) T) ((|FiniteFieldExtension| . |Ring|) T) ((|FiniteFieldNormalBasisExtension| . |Ring|) T) ((|File| . |FileCategory|) 76620) ((|FiniteFieldCyclicGroupExtension| . |Ring|) T) ((|DirectProductModule| . |DirectProductCategory|) 76599) ((|DirectProductMatrixModule| . |DirectProductCategory|) 76578) ((|BinaryFile| . |FileCategory|) 76536) ((|SimpleAlgebraicExtension| . |DifferentialRing|) 76430) ((|SparseMultivariateTaylorSeries| . |SetCategory|) T) ((|Equation| . |PartialDifferentialRing|) 76362) ((|BinaryExpansion| . |Ring|) T) ((|MyExpression| . |UniqueFactorizationDomain|) 76329) ((|MachineComplex| . |CancellationAbelianMonoid|) T) ((|Factored| . |InnerEvalable|) 76125) ((|FiniteFieldExtension| . |DifferentialRing|) 76100) ((|FiniteFieldExtension| . |DivisionRing|) T) ((|AlgebraGivenByStructuralConstants| . |Monad|) T) ((|FiniteFieldNormalBasisExtension| . |DifferentialRing|) 76075) ((|FiniteFieldNormalBasisExtension| . |DivisionRing|) T) ((|FiniteFieldCyclicGroupExtension| . |DifferentialRing|) 76050) ((|FiniteFieldCyclicGroupExtension| . |DivisionRing|) T) ((|MyExpression| . |IntegralDomain|) T) ((|Complex| . |Evalable|) 76009) ((|BinaryExpansion| . |DivisionRing|) T) ((|BinaryExpansion| . |DifferentialRing|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedAbelianMonoid|) T) ((|PAdicInteger| . |AbelianGroup|) T) ((|PAdicInteger| . |AbelianSemiGroup|) T) ((|Fraction| . |EuclideanDomain|) T) ((|IndexedBits| . |Aggregate|) T) ((|Bits| . |EltableAggregate|) 75974) ((|SplitHomogeneousDirectProduct| . |RightModule|) 75844) ((|PAdicRational| . |StepThrough|) NIL) ((|PseudoAlgebraicClosureOfRationalNumber| . |PseudoAlgebraicClosureOfRationalNumberCategory|) T) ((|PseudoAlgebraicClosureOfRationalNumber| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfPerfectFieldCategory|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |PseudoAlgebraicClosureOfRationalNumberCategory|) T) ((|FortranCode| . |CoercibleTo|) 75818) ((|Fraction| . |RealConstant|) 75787) ((|SplitHomogeneousDirectProduct| . |BiModule|) 75650) ((|PseudoAlgebraicClosureOfRationalNumber| . |CharacteristicNonZero|) 75590) ((|PseudoAlgebraicClosureOfRationalNumber| . |CharacteristicZero|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CharacteristicZero|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |CharacteristicNonZero|) 75530) ((|FortranTemplate| . |SetCategory|) T) ((|XRecursivePolynomial| . |Monoid|) T) ((|Asp19| . |CoercibleTo|) 75504) ((|PAdicRational| . |Algebra|) 75428) ((|IndexedMatrix| . |Type|) T) ((|IndexedVector| . |Collection|) 75412) ((|IndexedDirectProductObject| . |CoercibleTo|) 75386) ((|UnivariatePolynomial| . |Evalable|) 75373) ((|MultivariatePolynomial| . |Module|) 75136) ((|IndexedExponents| . |OrderedAbelianMonoidSup|) T) ((|IndexedExponents| . |OrderedAbelianSemiGroup|) T) ((|Integer| . |LinearlyExplicitRingOver|) 75113) ((|InnerAlgebraicNumber| . |LinearlyExplicitRingOver|) 75057) ((|FiniteFieldExtensionByPolynomial| . |GcdDomain|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |GcdDomain|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |GcdDomain|) T) ((|DifferentialSparseMultivariatePolynomial| . |GcdDomain|) 74975) ((|IndexedList| . |SetCategory|) 74912) ((|DistributedMultivariatePolynomial| . |GcdDomain|) 74830) ((|SparseTable| . |Eltable|) 74809) ((|SymmetricPolynomial| . |CoercibleTo|) 74783) ((|Matrix| . |InnerEvalable|) 74702) ((|PolynomialRing| . |EntireRing|) 74669) ((|InnerTable| . |InnerEvalable|) 74377) ((|MyUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|MyUnivariatePolynomial| . |CoercibleTo|) 74351) ((|WeightedPolynomials| . |CoercibleTo|) 74325) ((|SparseUnivariatePolynomial| . |DifferentialExtension|) 74309) ((|Complex| . |StepThrough|) 74271) ((|UnivariateTaylorSeriesCZero| . |IntegralDomain|) 74238) ((|SparseUnivariateTaylorSeries| . |Module|) 74082) ((|SparseUnivariatePuiseuxSeries| . |Module|) 73870) ((|Pattern| . |BasicType|) T) ((|SparseUnivariateLaurentSeries| . |Module|) 73585) ((|SparseMultivariateTaylorSeries| . |Module|) 73429) ((|Stream| . |LazyStreamAggregate|) 73413) ((|FiniteFieldExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73344) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73275) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FieldOfPrimeCharacteristic|) 73206) ((|RealClosure| . |CancellationAbelianMonoid|) T) ((|Octonion| . |InnerEvalable|) 73095) ((|EqTable| . |ConvertibleTo|) NIL) ((|EqTable| . |CoercibleTo|) 73069) ((|PrimeField| . |GcdDomain|) T) ((|Product| . |Finite|) 73014) ((|OrderedDirectProduct| . |Finite|) 72989) ((|IndexedDirectProductOrderedAbelianMonoid| . |IndexedDirectProductCategory|) 72968) ((|IndexedDirectProductAbelianMonoid| . |IndexedDirectProductCategory|) 72947) ((|HexadecimalExpansion| . |Eltable|) NIL) ((|HomogeneousDirectProduct| . |EltableAggregate|) 72919) ((|Factored| . |EntireRing|) T) ((|FiniteField| . |CancellationAbelianMonoid|) T) ((|DecimalExpansion| . |Eltable|) NIL) ((|MachineComplex| . |HyperbolicFunctionCategory|) NIL) ((|Automorphism| . |SemiGroup|) T) ((|Complex| . |Algebra|) 72677) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |IntegralDomain|) T) ((|UnivariatePuiseuxSeriesConstructor| . |PowerSeriesCategory|) 72610) ((|Stack| . |Evalable|) 72534) ((|UnivariateLaurentSeriesConstructor| . |PowerSeriesCategory|) 72480) ((|PrimeField| . |FieldOfPrimeCharacteristic|) T) ((|SplitHomogeneousDirectProduct| . |Ring|) 72390) ((|SparseTable| . |IndexedAggregate|) 72369) ((|MyExpression| . |Field|) 72336) ((|NeitherSparseOrDensePowerSeries| . |Collection|) 72277) ((|Boolean| . |OrderedSet|) T) ((|RoutinesTable| . |HomogeneousAggregate|) 72194) ((|InnerPAdicInteger| . |AbelianGroup|) T) ((|InnerPAdicInteger| . |AbelianSemiGroup|) T) ((|Integer| . |AbelianGroup|) T) ((|Integer| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |AbelianSemiGroup|) T) ((|InnerAlgebraicNumber| . |AbelianGroup|) T) ((|UnivariatePolynomial| . |StepThrough|) 72164) ((|SplitHomogeneousDirectProduct| . |DifferentialRing|) 72101) ((|AlgebraicNumber| . |CancellationAbelianMonoid|) T) ((|AffinePlane| . |CoercibleTo|) 72075) ((|ProjectiveSpace| . |SetCategoryWithDegree|) T) ((|TextFile| . |BasicType|) T) ((|DirectProduct| . |SetCategory|) 71767) ((|PAdicRational| . |FullyPatternMatchable|) 71734) ((|SequentialDifferentialVariable| . |BasicType|) T) ((|RewriteRule| . |BasicType|) T) ((|U32Matrix| . |InnerEvalable|) NIL) ((|KeyedAccessFile| . |BasicType|) T) ((|GeneralSparseTable| . |BasicType|) T) ((|UnivariatePolynomial| . |Algebra|) 71474) ((|StochasticDifferential| . |SetCategory|) T) ((|UnivariateSkewPolynomial| . |Algebra|) 71431) ((|SparseUnivariatePolynomialExpressions| . |LinearlyExplicitRingOver|) 71347) ((|MultivariatePolynomial| . |CommutativeRing|) 71200) ((|LinearOrdinaryDifferentialOperator1| . |CoercibleTo|) 71174) ((|Interval| . |Algebra|) 71161) ((|PrimitiveArray| . |BasicType|) 71098) ((|OrderedVariableList| . |CoercibleTo|) 71072) ((|OrderedVariableList| . |ConvertibleTo|) 70966) ((|IndexedString| . |InnerEvalable|) NIL) ((|UnivariateTaylorSeries| . |Rng|) T) ((|UnivariatePuiseuxSeries| . |Rng|) T) ((|UnivariateLaurentSeries| . |Rng|) T) ((|UnivariateFormalPowerSeries| . |Rng|) T) ((|IntegerMod| . |SemiGroup|) T) ((|TaylorSeries| . |CharacteristicZero|) 70929) ((|SparseUnivariateTaylorSeries| . |CommutativeRing|) 70858) ((|InnerTaylorSeries| . |Rng|) T) ((|InnerSparseUnivariatePowerSeries| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |CommutativeRing|) 70764) ((|SparseUnivariateLaurentSeries| . |CommutativeRing|) 70670) ((|SparseMultivariateTaylorSeries| . |CommutativeRing|) 70599) ((|RadixExpansion| . |SetCategory|) T) ((|Partition| . |SetCategory|) T) ((|PartialFraction| . |SetCategory|) T) ((|Octonion| . |OctonionCategory|) 70583) ((|NeitherSparseOrDensePowerSeries| . |LocalPowerSeriesCategory|) 70567) ((|NeitherSparseOrDensePowerSeries| . |PowerSeriesCategory|) 70513) ((|MyExpression| . |SemiGroup|) T) ((|MachineFloat| . |AbelianSemiGroup|) T) ((|MachineFloat| . |AbelianGroup|) T) ((|BalancedPAdicRational| . |LinearlyExplicitRingOver|) 70472) ((|MachineInteger| . |PatternMatchable|) 70449) ((|FourierSeries| . |SetCategory|) T) ((|Expression| . |UniqueFactorizationDomain|) 70416) ((|ExponentialExpansion| . |UniqueFactorizationDomain|) T) ((|Complex| . |FullyPatternMatchable|) 70400) ((|TaylorSeries| . |CharacteristicNonZero|) 70360) ((|GeneralUnivariatePowerSeries| . |PowerSeriesCategory|) 70293) ((|Asp33| . |CoercibleTo|) 70267) ((|MyExpression| . |AbelianMonoid|) T) ((|BinaryExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|BinaryExpansion| . |OrderedAbelianMonoid|) T) ((|Expression| . |IntegralDomain|) 70234) ((|MachineInteger| . |RetractableTo|) 70211) ((|ExponentialExpansion| . |IntegralDomain|) T) ((|IntegerMod| . |AbelianMonoid|) T) ((|CardinalNumber| . |RetractableTo|) 70177) ((|HomogeneousDirectProduct| . |RightModule|) 70047) ((|AssociationList| . |EltableAggregate|) 69959) ((|SparseUnivariatePolynomialExpressions| . |AbelianSemiGroup|) T) ((|SparseUnivariatePolynomialExpressions| . |AbelianGroup|) T) ((|DirectProduct| . |Module|) 69888) ((|HomogeneousDirectProduct| . |BiModule|) 69751) ((|SegmentBinding| . |BasicType|) 69721) ((|ResidueRing| . |BasicType|) T) ((|StochasticDifferential| . |Module|) 69690) ((|List| . |OpenMath|) 69663) ((|U16Matrix| . |SetCategory|) T) ((|MultivariatePolynomial| . |InnerEvalable|) 69567) ((|RectangularMatrix| . |RightModule|) 69551) ((|LaurentPolynomial| . |AbelianGroup|) T) ((|LaurentPolynomial| . |AbelianSemiGroup|) T) ((|RoutinesTable| . |Eltable|) 69521) ((|FreeGroup| . |BasicType|) T) ((|FreeAbelianGroup| . |BasicType|) T) ((|LieSquareMatrix| . |LeftModule|) 69495) ((|FreeModule| . |RightModule|) 69479) ((|RectangularMatrix| . |BiModule|) 69458) ((|OrderlyDifferentialPolynomial| . |FullyRetractableTo|) 69442) ((|BalancedPAdicRational| . |AbelianSemiGroup|) T) ((|Asp9| . |CoercibleTo|) 69416) ((|BalancedPAdicRational| . |AbelianGroup|) T) ((|KeyedAccessFile| . |Evalable|) 69158) ((|GeneralSparseTable| . |Evalable|) 68918) ((|UnivariateTaylorSeriesCZero| . |SemiGroup|) T) ((|SparseTable| . |ConvertibleTo|) NIL) ((|FreeModule| . |BiModule|) 68897) ((|Float| . |BasicType|) T) ((|Database| . |CoercibleTo|) 68871) ((|SparseTable| . |CoercibleTo|) 68845) ((|RadixExpansion| . |Module|) 68779) ((|SparseUnivariateLaurentSeries| . |InnerEvalable|) 68309) ((|PartialFraction| . |Module|) 68250) ((|SparseMultivariateTaylorSeries| . |InnerEvalable|) 68220) ((|FiniteFieldNormalBasis| . |EuclideanDomain|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianMonoid|) T) ((|Table| . |Collection|) 68162) ((|PrimitiveArray| . |Evalable|) 68086) ((|Operator| . |BasicType|) T) ((|FourierSeries| . |Module|) 68070) ((|DoubleFloat| . |OpenMath|) T) ((|OppositeMonogenicLinearOperator| . |BasicType|) T) ((|OpenMathError| . |BasicType|) T) ((|HashTable| . |Collection|) 68012) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePuiseuxSeriesConstructorCategory|) 67991) ((|SingleInteger| . |UniqueFactorizationDomain|) T) ((|FortranExpression| . |RetractableTo|) 67954) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePowerSeriesCategory|) 67913) ((|UnivariatePuiseuxSeriesConstructor| . |UnivariatePuiseuxSeriesCategory|) 67897) ((|UnivariateLaurentSeriesConstructor| . |UnivariateLaurentSeriesConstructorCategory|) 67876) ((|Asp55| . |CoercibleTo|) 67850) ((|Permutation| . |CoercibleTo|) 67824) ((|UnivariateLaurentSeriesConstructor| . |UnivariatePowerSeriesCategory|) 67796) ((|SingleInteger| . |IntegralDomain|) T) ((|PositiveInteger| . |OrderedSet|) T) ((|NonNegativeInteger| . |OrderedSet|) T) ((|HexadecimalExpansion| . |ConvertibleTo|) 67697) ((|HexadecimalExpansion| . |CoercibleTo|) 67671) ((|Float| . |ElementaryFunctionCategory|) T) ((|LyndonWord| . |OrderedSet|) T) ((|UnivariateLaurentSeriesConstructor| . |UnivariateLaurentSeriesCategory|) 67655) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |SemiGroup|) T) ((|DecimalExpansion| . |ConvertibleTo|) 67556) ((|DecimalExpansion| . |CoercibleTo|) 67530) ((|RoutinesTable| . |IndexedAggregate|) 67500) ((|OneDimensionalArray| . |Collection|) 67484) ((|IndexedFlexibleArray| . |Collection|) 67468) ((|IndexedOneDimensionalArray| . |Collection|) 67452) ((|FiniteFieldExtension| . |ExtensionField|) 67436) ((|FiniteFieldNormalBasisExtension| . |ExtensionField|) 67420) ((|FiniteFieldCyclicGroupExtension| . |ExtensionField|) 67404) ((|Expression| . |Field|) 67371) ((|ExponentialExpansion| . |Field|) T) ((|HomogeneousDirectProduct| . |Ring|) 67281) ((|MachineComplex| . |LinearlyExplicitRingOver|) 67253) ((|XPolynomial| . |LeftModule|) 67227) ((|XPBWPolynomial| . |LeftModule|) 67201) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianMonoid|) T) ((|Matrix| . |HomogeneousAggregate|) 67185) ((|Asp1| . |CoercibleTo|) 67159) ((|SplitHomogeneousDirectProduct| . |OrderedCancellationAbelianMonoid|) 67083) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianMonoid|) 67007) ((|InnerTable| . |HomogeneousAggregate|) 66936) ((|LieSquareMatrix| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |DifferentialRing|) 66873) ((|EqTable| . |EltableAggregate|) 66852) ((|DirectProduct| . |CommutativeRing|) 66818) ((|PseudoAlgebraicClosureOfFiniteField| . |VectorSpace|) 66802) ((|OrderlyDifferentialPolynomial| . |Rng|) T) ((|AlgebraGivenByStructuralConstants| . |LeftModule|) 66751) ((|SimpleAlgebraicExtension| . |Finite|) 66684) ((|MultivariatePolynomial| . |EntireRing|) 66570) ((|IndexedList| . |InnerEvalable|) 66489) ((|OrdinaryDifferentialRing| . |RightModule|) 66426) ((|SequentialDifferentialPolynomial| . |CharacteristicNonZero|) 66386) ((|FiniteFieldExtension| . |Finite|) 66361) ((|FiniteFieldNormalBasisExtension| . |Finite|) 66336) ((|FiniteFieldCyclicGroupExtension| . |Finite|) 66311) ((|SequentialDifferentialPolynomial| . |CharacteristicZero|) 66274) ((|PAdicRational| . |DifferentialExtension|) 66241) ((|OrdinaryDifferentialRing| . |BiModule|) 66151) ((|NewSparseUnivariatePolynomial| . |CharacteristicNonZero|) 66111) ((|NewSparseUnivariatePolynomial| . |CharacteristicZero|) 66074) ((|DifferentialSparseMultivariatePolynomial| . |PolynomialCategory|) 66027) ((|DirectProductModule| . |OrderedRing|) 65997) ((|DistributedMultivariatePolynomial| . |PolynomialCategory|) 65900) ((|DirectProductMatrixModule| . |OrderedRing|) 65870) ((|NewSparseMultivariatePolynomial| . |CharacteristicNonZero|) 65830) ((|NewSparseMultivariatePolynomial| . |CharacteristicZero|) 65793) ((|CliffordAlgebra| . |LeftModule|) 65767) ((|GeneralDistributedMultivariatePolynomial| . |CharacteristicZero|) 65730) ((|GeneralDistributedMultivariatePolynomial| . |CharacteristicNonZero|) 65690) ((|LieSquareMatrix| . |Monoid|) T) ((|OpenMathEncoding| . |CoercibleTo|) 65664) ((|UnivariateTaylorSeries| . |SetCategory|) T) ((|UnivariatePuiseuxSeries| . |SetCategory|) T) ((|UnivariateLaurentSeries| . |SetCategory|) T) ((|UnivariateFormalPowerSeries| . |SetCategory|) T) ((|TaylorSeries| . |TrigonometricFunctionCategory|) 65613) ((|TaylorSeries| . |TranscendentalFunctionCategory|) 65562) ((|SparseUnivariateTaylorSeries| . |EntireRing|) 65529) ((|SparseUnivariatePuiseuxSeries| . |EntireRing|) 65468) ((|SparseUnivariateLaurentSeries| . |EntireRing|) 65407) ((|SparseMultivariateTaylorSeries| . |EntireRing|) 65374) ((|FortranExpression| . |PartialDifferentialRing|) 65352) ((|RadixExpansion| . |CommutativeRing|) T) ((|PartialFraction| . |CommutativeRing|) T) ((|NeitherSparseOrDensePowerSeries| . |UnivariatePowerSeriesCategory|) 65324) ((|InnerTaylorSeries| . |SetCategory|) T) ((|InnerSparseUnivariatePowerSeries| . |SetCategory|) T) ((|MachineComplex| . |AbelianGroup|) T) ((|MachineComplex| . |AbelianSemiGroup|) T) ((|GeneralUnivariatePowerSeries| . |UnivariatePuiseuxSeriesCategory|) 65308) ((|GeneralUnivariatePowerSeries| . |UnivariatePowerSeriesCategory|) 65267) ((|Factored| . |Eltable|) 65185) ((|Expression| . |SemiGroup|) 64967) ((|ExponentialExpansion| . |SemiGroup|) T) ((|TaylorSeries| . |ArcHyperbolicFunctionCategory|) 64916) ((|TaylorSeries| . |ArcTrigonometricFunctionCategory|) 64865) ((|Asp77| . |CoercibleTo|) 64839) ((|ArrayStack| . |BasicType|) 64809) ((|IntegerMod| . |CancellationAbelianMonoid|) T) ((|U32Matrix| . |HomogeneousAggregate|) 64786) ((|MyExpression| . |CancellationAbelianMonoid|) T) ((|InnerPrimeField| . |CharacteristicNonZero|) T) ((|InnerPrimeField| . |CharacteristicZero|) 64752) ((|InnerFiniteField| . |CharacteristicZero|) 64718) ((|InnerFiniteField| . |CharacteristicNonZero|) T) ((|Expression| . |AbelianMonoid|) 64486) ((|AlgebraicFunctionField| . |FunctionFieldCategory|) 64460) ((|ExponentialExpansion| . |AbelianMonoid|) T) ((|String| . |LinearAggregate|) 64435) ((|OrderedDirectProduct| . |LeftModule|) 64249) ((|XDistributedPolynomial| . |Rng|) T) ((|String| . |FiniteLinearAggregate|) 64224) ((|Complex| . |DifferentialExtension|) 64208) ((|IndexedString| . |HomogeneousAggregate|) 64183) ((|DirectProduct| . |InnerEvalable|) 64102) ((|XPolynomial| . |Monoid|) T) ((|XPBWPolynomial| . |Monoid|) T) ((|SymmetricPolynomial| . |RightModule|) 63935) ((|MyUnivariatePolynomial| . |RightModule|) 63669) ((|SymmetricPolynomial| . |BiModule|) 63470) ((|OrdinaryDifferentialRing| . |Ring|) T) ((|MyUnivariatePolynomial| . |BiModule|) 63172) ((|InnerFreeAbelianMonoid| . |BasicType|) T) ((|AlgebraicNumber| . |LinearlyExplicitRingOver|) 63116) ((|IndexedDirectProductOrderedAbelianMonoid| . |BasicType|) T) ((|IndexedDirectProductAbelianMonoid| . |BasicType|) T) ((|WeightedPolynomials| . |RightModule|) 63073) ((|ResidueRing| . |Algebra|) 63057) ((|OrdinaryDifferentialRing| . |DifferentialRing|) T) ((|OrdinaryDifferentialRing| . |DivisionRing|) 63033) ((|InnerTable| . |Eltable|) 63012) ((|WeightedPolynomials| . |BiModule|) 62964) ((|UnivariatePolynomial| . |DifferentialExtension|) 62948) ((|UnivariateTaylorSeries| . |Module|) 62792) ((|UnivariatePuiseuxSeries| . |Module|) 62580) ((|RoutinesTable| . |ConvertibleTo|) NIL) ((|RoutinesTable| . |CoercibleTo|) 62554) ((|UnivariateLaurentSeries| . |Module|) 62275) ((|UnivariateFormalPowerSeries| . |Module|) 62119) ((|RadicalFunctionField| . |PrincipalIdealDomain|) T) ((|MakeCachableSet| . |CoercibleTo|) 62080) ((|CliffordAlgebra| . |Monoid|) T) ((|UnivariateTaylorSeriesCZero| . |CancellationAbelianMonoid|) T) ((|U8Vector| . |OrderedSet|) T) ((|SplitHomogeneousDirectProduct| . |Finite|) 62055) ((|RadixExpansion| . |InnerEvalable|) NIL) ((|DirectProductModule| . |FullyRetractableTo|) 62016) ((|DirectProductMatrixModule| . |FullyRetractableTo|) 61977) ((|RealClosure| . |AbelianSemiGroup|) T) ((|RealClosure| . |AbelianGroup|) T) ((|InnerTaylorSeries| . |Module|) 61938) ((|InnerSparseUnivariatePowerSeries| . |Module|) 61782) ((|Octonion| . |Eltable|) 61735) ((|BinaryTournament| . |BasicType|) 61705) ((|OnePointCompletion| . |RetractableTo|) 61549) ((|Complex| . |OpenMath|) 61522) ((|ExponentialOfUnivariatePuiseuxSeries| . |LeftModule|) 61391) ((|OrderedDirectProduct| . |Aggregate|) T) ((|ModuleOperator| . |BasicType|) T) ((|SingleInteger| . |SemiGroup|) T) ((|Reference| . |Type|) T) ((|Float| . |Algebra|) 61345) ((|FiniteField| . |AbelianSemiGroup|) T) ((|FiniteField| . |AbelianGroup|) T) ((|DoubleFloatVector| . |BasicType|) T) ((|Commutator| . |BasicType|) T) ((|Color| . |BasicType|) T) ((|ComplexDoubleFloatVector| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |VectorSpace|) 61329) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |VectorSpace|) 61313) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |VectorSpace|) 61297) ((|PseudoAlgebraicClosureOfRationalNumber| . |GcdDomain|) T) ((|Complex| . |FiniteFieldCategory|) 61259) ((|Integer| . |OrderedSet|) T) ((|InnerAlgebraicNumber| . |OrderedSet|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |GcdDomain|) T) ((|SingleInteger| . |AbelianMonoid|) T) ((|Asp80| . |CoercibleTo|) 61233) ((|MachineInteger| . |EuclideanDomain|) T) ((|Operator| . |Algebra|) 61190) ((|OppositeMonogenicLinearOperator| . |Algebra|) 61147) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CancellationAbelianMonoid|) T) ((|SparseTable| . |EltableAggregate|) 61126) ((|Product| . |Monoid|) 61014) ((|Product| . |OrderedAbelianMonoidSup|) 60925) ((|Product| . |OrderedAbelianSemiGroup|) 60836) ((|OrderedDirectProduct| . |OrderedAbelianGroup|) 60806) ((|BalancedPAdicInteger| . |EuclideanDomain|) T) ((|ArrayStack| . |Evalable|) 60730) ((|ThreeDimensionalMatrix| . |Aggregate|) T) ((|InnerTable| . |IndexedAggregate|) 60709) ((|AlgebraicNumber| . |AbelianSemiGroup|) T) ((|AlgebraicNumber| . |AbelianGroup|) T) ((|OrderedDirectProduct| . |OrderedAbelianSemiGroup|) 60633) ((|OrderedDirectProduct| . |OrderedAbelianMonoidSup|) 60591) ((|MachineInteger| . |RealConstant|) T) ((|LinearOrdinaryDifferentialOperator1| . |RightModule|) 60575) ((|Product| . |Group|) 60522) ((|OrderedDirectProduct| . |Monoid|) 60408) ((|PrimeField| . |VectorSpace|) 60395) ((|Divisor| . |FreeAbelianMonoidCategory|) 60367) ((|PseudoAlgebraicClosureOfRationalNumber| . |FieldOfPrimeCharacteristic|) 60307) ((|HomogeneousDirectProduct| . |OrderedCancellationAbelianMonoid|) 60231) ((|HomogeneousDirectProduct| . |OrderedAbelianMonoid|) 60155) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |FieldOfPrimeCharacteristic|) 60095) ((|SymmetricPolynomial| . |Ring|) T) ((|U16Matrix| . |InnerEvalable|) NIL) ((|MyUnivariatePolynomial| . |Ring|) T) ((|LinearOrdinaryDifferentialOperator1| . |BiModule|) 60074) ((|SymmetricPolynomial| . |FiniteAbelianMonoidRing|) 60044) ((|Tree| . |BasicType|) 60014) ((|SetOfMIntegersInOneToN| . |CoercibleTo|) 59988) ((|MachineInteger| . |IntegerNumberSystem|) T) ((|MyUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 59949) ((|OrderlyDifferentialPolynomial| . |SetCategory|) T) ((|MyUnivariatePolynomial| . |DifferentialRing|) T) ((|WeightedPolynomials| . |Ring|) T) ((|FractionalIdeal| . |SetCategory|) T) ((|DirectProductModule| . |Rng|) 59859) ((|DirectProductMatrixModule| . |Rng|) 59769) ((|EuclideanModularRing| . |LeftModule|) 59756) ((|IndexedString| . |Eltable|) 59719) ((|Matrix| . |MatrixCategory|) 59671) ((|UnivariateTaylorSeries| . |CommutativeRing|) 59600) ((|PolynomialRing| . |CoercibleTo|) 59574) ((|PAdicRationalConstructor| . |BasicType|) T) ((|MonoidRing| . |CoercibleTo|) 59548) ((|ModularRing| . |CoercibleTo|) 59522) ((|UnivariatePuiseuxSeries| . |CommutativeRing|) 59428) ((|UnivariateLaurentSeries| . |CommutativeRing|) 59334) ((|UnivariateFormalPowerSeries| . |CommutativeRing|) 59263) ((|MachineFloat| . |OrderedSet|) T) ((|RadixExpansion| . |EntireRing|) T) ((|GenericNonAssociativeAlgebra| . |CoercibleTo|) 59237) ((|LieExponentials| . |Monoid|) T) ((|TwoDimensionalArray| . |SetCategory|) 59207) ((|DataList| . |Collection|) 59191) ((|PartialFraction| . |EntireRing|) T) ((|RealClosure| . |RealClosedField|) T) ((|LieExponentials| . |Group|) T) ((|ModMonic| . |UniqueFactorizationDomain|) 59141) ((|ExponentialOfUnivariatePuiseuxSeries| . |LeftOreRing|) 59117) ((|UnivariateTaylorSeriesCZero| . |HyperbolicFunctionCategory|) 59066) ((|InnerTaylorSeries| . |CommutativeRing|) 59033) ((|InnerSparseUnivariatePowerSeries| . |CommutativeRing|) 58962) ((|Vector| . |OrderedSet|) 58933) ((|ModMonic| . |IntegralDomain|) 58796) ((|Fraction| . |PrincipalIdealDomain|) T) ((|Fraction| . |OrderedIntegralDomain|) 58756) ((|ExponentialOfUnivariatePuiseuxSeries| . |OrderedAbelianSemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |Monoid|) T) ((|Factored| . |CoercibleTo|) 58730) ((|Factored| . |ConvertibleTo|) 58576) ((|List| . |StreamAggregate|) 58560) ((|Bits| . |LinearAggregate|) 58537) ((|ContinuedFraction| . |EuclideanDomain|) T) ((|BinaryTournament| . |Evalable|) 58461) ((|Bits| . |FiniteLinearAggregate|) 58438) ((|FortranProgram| . |Type|) T) ((|Expression| . |CancellationAbelianMonoid|) 58240) ((|ExponentialExpansion| . |CancellationAbelianMonoid|) T) ((|Asp29| . |FortranProgramCategory|) T) ((|Bits| . |BitAggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |OrderedSet|) 58211) ((|IndexedList| . |HomogeneousAggregate|) 58195) ((|LinearOrdinaryDifferentialOperator2| . |SemiGroup|) T) ((|IndexedString| . |OneDimensionalArrayAggregate|) 58170) ((|DoubleFloatVector| . |Evalable|) NIL) ((|Asp10| . |FortranVectorFunctionCategory|) T) ((|ComplexDoubleFloatVector| . |Evalable|) NIL) ((|Asp10| . |FortranProgramCategory|) T) ((|OpenMathErrorKind| . |SetCategory|) T) ((|IndexedString| . |IndexedAggregate|) 58133) ((|Pi| . |RetractableTo|) 58077) ((|LinearOrdinaryDifferentialOperator1| . |Ring|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianMonoid|) T) ((|XDistributedPolynomial| . |SetCategory|) T) ((|OrderlyDifferentialPolynomial| . |Module|) 57840) ((|U32Matrix| . |MatrixCategory|) 57789) ((|BasicStochasticDifferential| . |OrderedSet|) T) ((|BalancedPAdicRational| . |OrderedSet|) NIL) ((|SparseUnivariatePolynomial| . |FullyRetractableTo|) 57773) ((|SparseMultivariatePolynomial| . |FullyRetractableTo|) 57757) ((|SparseUnivariateSkewPolynomial| . |FullyRetractableTo|) 57741) ((|DirichletRing| . |Rng|) T) ((|EuclideanModularRing| . |LeftOreRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |BasicType|) T) ((|UnivariateLaurentSeries| . |InnerEvalable|) 57313) ((|Tree| . |Evalable|) 57237) ((|Exit| . |CoercibleTo|) 57211) ((|UnivariateLaurentSeriesConstructor| . |BasicType|) T) ((|Set| . |SetCategory|) T) ((|SparseUnivariateTaylorSeries| . |Eltable|) 57196) ((|SparseUnivariatePuiseuxSeries| . |Eltable|) 57181) ((|EuclideanModularRing| . |Monoid|) T) ((|BinaryExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|Matrix| . |CoercibleTo|) 57132) ((|Matrix| . |ConvertibleTo|) 57068) ((|SimpleAlgebraicExtension| . |LeftModule|) 56950) ((|InfiniteTuple| . |CoercibleTo|) 56924) ((|InnerTable| . |ConvertibleTo|) NIL) ((|InnerTable| . |CoercibleTo|) 56898) ((|SparseUnivariateLaurentSeries| . |Eltable|) 56638) ((|HexadecimalExpansion| . |RightModule|) 56572) ((|ModularField| . |GcdDomain|) T) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |IndexedDirectProductCategory|) 56551) ((|IndexedDirectProductAbelianGroup| . |IndexedDirectProductCategory|) 56530) ((|DecimalExpansion| . |RightModule|) 56464) ((|FiniteFieldExtension| . |LeftModule|) 56405) ((|FiniteFieldNormalBasisExtension| . |LeftModule|) 56346) ((|DoubleFloat| . |OrderedRing|) T) ((|FiniteFieldCyclicGroupExtension| . |LeftModule|) 56287) ((|IndexedVector| . |BasicType|) 56224) ((|HomogeneousDirectProduct| . |Finite|) 56199) ((|BinaryExpansion| . |LeftModule|) 56133) ((|HexadecimalExpansion| . |BiModule|) 56028) ((|DirectProduct| . |HomogeneousAggregate|) 56012) ((|FiniteFieldCyclicGroup| . |CharacteristicZero|) 55978) ((|FiniteFieldCyclicGroup| . |CharacteristicNonZero|) T) ((|Complex| . |FiniteRankAlgebra|) 55926) ((|Point| . |VectorCategory|) 55910) ((|DecimalExpansion| . |BiModule|) 55805) ((|PAdicRationalConstructor| . |Evalable|) 55764) ((|Point| . |SetCategory|) 55701) ((|Octonion| . |ConvertibleTo|) 55637) ((|Octonion| . |CoercibleTo|) 55611) ((|MoebiusTransform| . |BasicType|) T) ((|FourierComponent| . |SetCategory|) T) ((|SingleInteger| . |CancellationAbelianMonoid|) T) ((|ModuleOperator| . |Algebra|) 55568) ((|Expression| . |HyperbolicFunctionCategory|) 55535) ((|IndexedBits| . |Type|) T) ((|UnivariatePuiseuxSeriesConstructor| . |ElementaryFunctionCategory|) 55484) ((|UnivariateLaurentSeriesConstructor| . |ElementaryFunctionCategory|) 55433) ((|FlexibleArray| . |Collection|) 55417) ((|RoutinesTable| . |EltableAggregate|) 55387) ((|XDistributedPolynomial| . |Module|) 55344) ((|StringTable| . |Aggregate|) T) ((|XRecursivePolynomial| . |RetractableTo|) 55306) ((|MyExpression| . |LinearlyExplicitRingOver|) 55178) ((|GraphImage| . |CoercibleTo|) 55152) ((|Heap| . |Aggregate|) T) ((|FreeModule1| . |RetractableTo|) 55136) ((|SparseUnivariatePolynomial| . |Rng|) T) ((|SparseMultivariatePolynomial| . |Rng|) T) ((|SparseUnivariateSkewPolynomial| . |Rng|) T) ((|RomanNumeral| . |OrderedRing|) T) ((|OrderlyDifferentialPolynomial| . |CommutativeRing|) 54989) ((|IndexedList| . |Eltable|) 54961) ((|U32Matrix| . |CoercibleTo|) 54935) ((|IntegerMod| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeries| . |EntireRing|) 54902) ((|UnivariatePuiseuxSeries| . |EntireRing|) 54841) ((|BalancedPAdicRational| . |QuotientFieldCategory|) 54800) ((|PseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|UnivariateLaurentSeries| . |EntireRing|) 54739) ((|NeitherSparseOrDensePowerSeries| . |BasicType|) T) ((|UnivariateFormalPowerSeries| . |EntireRing|) 54706) ((|TextFile| . |FileCategory|) 54671) ((|SparseUnivariateTaylorSeries| . |RadicalCategory|) 54620) ((|SparseUnivariatePuiseuxSeries| . |RadicalCategory|) 54569) ((|SequentialDifferentialVariable| . |DifferentialVariableCategory|) 54553) ((|GeneralUnivariatePowerSeries| . |BasicType|) T) ((|File| . |SetCategory|) T) ((|DirectProductModule| . |SetCategory|) T) ((|DirectProductMatrixModule| . |SetCategory|) T) ((|SparseUnivariateLaurentSeries| . |RadicalCategory|) 54502) ((|BinaryFile| . |SetCategory|) T) ((|SparseMultivariateTaylorSeries| . |RadicalCategory|) 54451) ((|PAdicRationalConstructor| . |StepThrough|) 54421) ((|SimpleAlgebraicExtension| . |LeftOreRing|) 54355) ((|KeyedAccessFile| . |FileCategory|) 54278) ((|SimpleAlgebraicExtension| . |Monoid|) T) ((|KeyedAccessFile| . |Dictionary|) 54214) ((|IndexedString| . |CoercibleTo|) 54188) ((|IndexedString| . |ConvertibleTo|) NIL) ((|MachineComplex| . |OrderedSet|) T) ((|GeneralSparseTable| . |Dictionary|) 54130) ((|HexadecimalExpansion| . |Ring|) T) ((|Places| . |SetCategory|) T) ((|Asp8| . |FortranVectorCategory|) T) ((|Asp8| . |FortranProgramCategory|) T) ((|DecimalExpansion| . |Ring|) T) ((|FiniteFieldExtension| . |LeftOreRing|) T) ((|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategoryWithDegree|) T) ((|FiniteFieldNormalBasisExtension| . |LeftOreRing|) T) ((|FiniteFieldCyclicGroupExtension| . |LeftOreRing|) T) ((|ModMonic| . |SemiGroup|) T) ((|InnerTaylorSeries| . |EntireRing|) 54097) ((|InnerSparseUnivariatePowerSeries| . |EntireRing|) 54064) ((|BinaryExpansion| . |LeftOreRing|) T) ((|HexadecimalExpansion| . |DivisionRing|) T) ((|HexadecimalExpansion| . |DifferentialRing|) T) ((|SuchThat| . |CoercibleTo|) 54038) ((|PAdicRationalConstructor| . |Algebra|) 53979) ((|DecimalExpansion| . |DivisionRing|) T) ((|DecimalExpansion| . |DifferentialRing|) T) ((|MyExpression| . |AbelianSemiGroup|) T) ((|MyExpression| . |AbelianGroup|) T) ((|FiniteFieldExtension| . |Monoid|) T) ((|FiniteFieldNormalBasisExtension| . |Monoid|) T) ((|FiniteFieldCyclicGroupExtension| . |Monoid|) T) ((|BinaryExpansion| . |OrderedAbelianSemiGroup|) T) ((|BinaryExpansion| . |OrderedAbelianGroup|) T) ((|IndexedList| . |UnaryRecursiveAggregate|) 53963) ((|BinaryExpansion| . |Monoid|) T) ((|ModMonic| . |AbelianMonoid|) T) ((|U16Matrix| . |HomogeneousAggregate|) 53940) ((|GeneralUnivariatePowerSeries| . |ElementaryFunctionCategory|) 53889) ((|IntegerMod| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |Evalable|) 53819) ((|Symbol| . |BasicType|) T) ((|AlgebraicFunctionField| . |CharacteristicNonZero|) 53766) ((|AlgebraicFunctionField| . |CharacteristicZero|) 53716) ((|IndexedList| . |IndexedAggregate|) 53688) ((|SplitHomogeneousDirectProduct| . |LeftModule|) 53502) ((|IndexedVector| . |Evalable|) 53426) ((|AssociationList| . |LinearAggregate|) 53368) ((|AssociationList| . |ListAggregate|) 53310) ((|AssociationList| . |FiniteLinearAggregate|) 53252) ((|String| . |Aggregate|) T) ((|PAdicRational| . |OrderedRing|) NIL) ((|LinearOrdinaryDifferentialOperator2| . |CancellationAbelianMonoid|) T) ((|HyperellipticFiniteDivisor| . |CoercibleTo|) 53226) ((|DirectProduct| . |Eltable|) 53198) ((|ListMultiDictionary| . |Aggregate|) T) ((|Library| . |Aggregate|) T) ((|SequentialDifferentialPolynomial| . |GcdDomain|) 53116) ((|OrderlyDifferentialPolynomial| . |InnerEvalable|) 52891) ((|NewSparseUnivariatePolynomial| . |GcdDomain|) 52786) ((|NewSparseMultivariatePolynomial| . |GcdDomain|) 52704) ((|NottinghamGroup| . |BasicType|) T) ((|GeneralDistributedMultivariatePolynomial| . |GcdDomain|) 52622) ((|Polynomial| . |FullyRetractableTo|) 52606) ((|MultivariatePolynomial| . |CoercibleTo|) 52580) ((|DirectProductModule| . |Module|) 52509) ((|DirectProductMatrixModule| . |Module|) 52438) ((|MultivariatePolynomial| . |ConvertibleTo|) 52216) ((|HomogeneousDistributedMultivariatePolynomial| . |FullyRetractableTo|) 52200) ((|FortranExpression| . |ExpressionSpace|) T) ((|DirichletRing| . |SetCategory|) T) ((|FiniteFieldNormalBasis| . |PrincipalIdealDomain|) T) ((|Queue| . |BasicType|) 52170) ((|RealClosure| . |OrderedSet|) T) ((|TwoDimensionalArray| . |InnerEvalable|) 52089) ((|UnivariateTaylorSeriesCZero| . |AbelianSemiGroup|) T) ((|UnivariateTaylorSeriesCZero| . |AbelianGroup|) T) ((|UnivariateLaurentSeriesConstructor| . |StepThrough|) 52030) ((|RadixExpansion| . |Eltable|) NIL) ((|DoubleFloat| . |Rng|) T) ((|Float| . |OpenMath|) T) ((|SplitHomogeneousDirectProduct| . |Aggregate|) T) ((|NeitherSparseOrDensePowerSeries| . |Evalable|) 51860) ((|InnerPrimeField| . |GcdDomain|) T) ((|InnerFiniteField| . |GcdDomain|) T) ((|UniversalSegment| . |SegmentCategory|) 51844) ((|UniversalSegment| . |SetCategory|) 51814) ((|DirectProduct| . |IndexedAggregate|) 51786) ((|UniversalSegment| . |SegmentExpansionCategory|) 51731) ((|SparseUnivariateTaylorSeries| . |CoercibleTo|) 51705) ((|SparseUnivariatePuiseuxSeries| . |CoercibleTo|) 51679) ((|SparseUnivariateLaurentSeries| . |CoercibleTo|) 51653) ((|SparseUnivariateLaurentSeries| . |ConvertibleTo|) NIL) ((|SparseMultivariateTaylorSeries| . |CoercibleTo|) 51627) ((|PAdicRationalConstructor| . |FullyPatternMatchable|) 51611) ((|InfinitlyClosePoint| . |SetCategory|) T) ((|InputForm| . |BasicType|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Algebra|) 51399) ((|UnivariateLaurentSeriesConstructor| . |Algebra|) 51157) ((|PAdicInteger| . |CharacteristicZero|) T) ((|InnerPrimeField| . |FieldOfPrimeCharacteristic|) T) ((|AlgebraicNumber| . |OrderedSet|) T) ((|InnerFiniteField| . |FieldOfPrimeCharacteristic|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianGroup|) T) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |AbelianSemiGroup|) T) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianGroup|) 51127) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianSemiGroup|) 51051) ((|SplitHomogeneousDirectProduct| . |OrderedAbelianMonoidSup|) 51009) ((|QuadraticForm| . |SetCategory|) T) ((|RegularTriangularSet| . |Aggregate|) T) ((|OutputForm| . |SetCategory|) T) ((|Variable| . |BasicType|) T) ((|SplitHomogeneousDirectProduct| . |Monoid|) 50895) ((|LiePolynomial| . |BasicType|) T) ((|InnerTable| . |EltableAggregate|) 50874) ((|Table| . |BasicType|) T) ((|GeneralTriangularSet| . |Aggregate|) T) ((|GeneralPolynomialSet| . |Aggregate|) T) ((|FiniteFieldExtensionByPolynomial| . |BasicType|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |BasicType|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |BasicType|) T) ((|DifferentialSparseMultivariatePolynomial| . |BasicType|) T) ((|DistributedMultivariatePolynomial| . |BasicType|) T) ((|Pi| . |EuclideanDomain|) T) ((|RomanNumeral| . |Rng|) T) ((|Polynomial| . |Rng|) T) ((|Expression| . |LinearlyExplicitRingOver|) 50746) ((|ExponentialExpansion| . |LinearlyExplicitRingOver|) 50661) ((|HomogeneousDistributedMultivariatePolynomial| . |Rng|) T) ((|HashTable| . |BasicType|) T) ((|FortranTemplate| . |CoercibleTo|) 50635) ((|SparseUnivariatePolynomial| . |SetCategory|) T) ((|SparseMultivariatePolynomial| . |SetCategory|) T) ((|SparseUnivariateSkewPolynomial| . |SetCategory|) T) ((|SplittingTree| . |BasicType|) T) ((|OrderlyDifferentialPolynomial| . |EntireRing|) 50521) ((|PolynomialRing| . |RightModule|) 50354) ((|Pi| . |RealConstant|) T) ((|MonoidRing| . |RightModule|) 50311) ((|Stack| . |StackAggregate|) 50295) ((|Set| . |InnerEvalable|) 50214) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |RightModule|) 50170) ((|PolynomialRing| . |BiModule|) 49971) ((|PseudoAlgebraicClosureOfRationalNumber| . |VectorSpace|) 49935) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |VectorSpace|) 49848) ((|PrimeField| . |BasicType|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |StepThrough|) T) ((|MonoidRing| . |BiModule|) 49800) ((|DirichletRing| . |Module|) 49720) ((|OneDimensionalArray| . |BasicType|) 49657) ((|IndexedList| . |ConvertibleTo|) 49593) ((|IndexedList| . |CoercibleTo|) 49511) ((|InnerIndexedTwoDimensionalArray| . |BasicType|) 49481) ((|IndexedFlexibleArray| . |BasicType|) 49418) ((|IndexedTwoDimensionalArray| . |BasicType|) 49388) ((|IndexedOneDimensionalArray| . |BasicType|) 49325) ((|GenericNonAssociativeAlgebra| . |BiModule|) 49248) ((|DirectProductModule| . |CommutativeRing|) 49214) ((|DirectProductMatrixModule| . |CommutativeRing|) 49180) ((|Factored| . |RightModule|) 49154) ((|TaylorSeries| . |PowerSeriesCategory|) 49095) ((|Quaternion| . |SemiGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Algebra|) 49049) ((|NeitherSparseOrDensePowerSeries| . |Algebra|) 48963) ((|Point| . |InnerEvalable|) 48882) ((|HexadecimalExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|GeneralUnivariatePowerSeries| . |Algebra|) 48670) ((|Factored| . |BiModule|) 48637) ((|HexadecimalExpansion| . |OrderedAbelianMonoid|) T) ((|Queue| . |Evalable|) 48561) ((|DecimalExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|DecimalExpansion| . |OrderedAbelianMonoid|) T) ((|Quaternion| . |AbelianMonoid|) T) ((|ModMonic| . |CancellationAbelianMonoid|) T) ((|UnivariateLaurentSeriesConstructor| . |FullyPatternMatchable|) 48528) ((|U8Matrix| . |Aggregate|) T) ((|Expression| . |AbelianSemiGroup|) 48296) ((|Complex| . |FullyRetractableTo|) 48280) ((|Expression| . |AbelianGroup|) 48082) ((|ExponentialExpansion| . |AbelianSemiGroup|) T) ((|ExponentialExpansion| . |AbelianGroup|) T) ((|OrderedVariableList| . |Finite|) T) ((|Bits| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |LeftModule|) 47896) ((|PAdicRational| . |Rng|) T) ((|IndexedString| . |EltableAggregate|) 47859) ((|InnerPAdicInteger| . |CharacteristicZero|) T) ((|Integer| . |CharacteristicZero|) T) ((|InnerAlgebraicNumber| . |CharacteristicZero|) T) ((|SparseUnivariatePolynomial| . |Module|) 47599) ((|SparseMultivariatePolynomial| . |Module|) 47362) ((|SingleInteger| . |LinearlyExplicitRingOver|) 47339) ((|SparseUnivariateSkewPolynomial| . |Module|) 47296) ((|LieSquareMatrix| . |Type|) T) ((|Mapping| . |BasicType|) T) ((|DirectProduct| . |CoercibleTo|) 46945) ((|UnivariatePolynomial| . |FullyRetractableTo|) 46929) ((|U16Matrix| . |MatrixCategory|) 46878) ((|Table| . |Evalable|) 46638) ((|PolynomialRing| . |Ring|) T) ((|MonoidRing| . |Ring|) T) ((|ModularRing| . |Ring|) T) ((|List| . |SetCategory|) 46575) ((|RectangularMatrix| . |LeftModule|) 46559) ((|UnivariateSkewPolynomial| . |FullyRetractableTo|) 46543) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |BasicType|) T) ((|IndexedDirectProductAbelianGroup| . |BasicType|) T) ((|DistributedMultivariatePolynomial| . |Evalable|) 46530) ((|DifferentialSparseMultivariatePolynomial| . |Evalable|) 46517) ((|StochasticDifferential| . |CoercibleTo|) 46491) ((|PolynomialRing| . |FiniteAbelianMonoidRing|) 46470) ((|FreeModule| . |LeftModule|) 46454) ((|HashTable| . |Evalable|) 46214) ((|DirectProductModule| . |InnerEvalable|) 46133) ((|LieSquareMatrix| . |RetractableTo|) 45977) ((|DirectProductMatrixModule| . |InnerEvalable|) 45896) ((|SplittingTree| . |Evalable|) 45786) ((|DirichletRing| . |CommutativeRing|) 45752) ((|OrderedFreeMonoid| . |SetCategory|) T) ((|Octonion| . |RightModule|) 45736) ((|UnivariateTaylorSeries| . |Eltable|) 45721) ((|UnivariatePuiseuxSeries| . |Eltable|) 45706) ((|UnivariateLaurentSeries| . |Eltable|) 45470) ((|UnivariateFormalPowerSeries| . |Eltable|) 45455) ((|FreeMonoid| . |SetCategory|) T) ((|FreeAbelianMonoid| . |SetCategory|) T) ((|Factored| . |Ring|) T) ((|Complex| . |Rng|) T) ((|OneDimensionalArray| . |Evalable|) 45379) ((|Octonion| . |BiModule|) 45358) ((|InnerSparseUnivariatePowerSeries| . |Eltable|) 45343) ((|InnerIndexedTwoDimensionalArray| . |Evalable|) 45267) ((|IndexedFlexibleArray| . |Evalable|) 45191) ((|IndexedTwoDimensionalArray| . |Evalable|) 45115) ((|IndexedOneDimensionalArray| . |Evalable|) 45039) ((|Factored| . |DifferentialRing|) 45004) ((|HomogeneousDirectProduct| . |Aggregate|) T) ((|RadixExpansion| . |ConvertibleTo|) 44905) ((|DoubleFloat| . |SetCategory|) T) ((|RadixExpansion| . |CoercibleTo|) 44879) ((|Partition| . |CoercibleTo|) 44853) ((|Partition| . |ConvertibleTo|) 44821) ((|PartialFraction| . |CoercibleTo|) 44795) ((|MachineFloat| . |CharacteristicZero|) T) ((|MachineInteger| . |PrincipalIdealDomain|) T) ((|MachineInteger| . |OrderedIntegralDomain|) T) ((|FourierSeries| . |CoercibleTo|) 44769) ((|SingleInteger| . |AbelianGroup|) T) ((|SingleInteger| . |AbelianSemiGroup|) T) ((|LieSquareMatrix| . |FullyLinearlyExplicitRingOver|) 44753) ((|BalancedPAdicInteger| . |PrincipalIdealDomain|) T) ((|PAdicRationalConstructor| . |DifferentialExtension|) 44737) ((|Asp4| . |Type|) T) ((|BinaryTournament| . |BinaryTreeCategory|) 44721) ((|RectangularMatrix| . |Aggregate|) T) ((|XPolynomial| . |RetractableTo|) 44677) ((|XPBWPolynomial| . |RetractableTo|) 44590) ((|UnivariatePolynomial| . |Rng|) T) ((|SparseUnivariatePolynomialExpressions| . |CharacteristicNonZero|) 44550) ((|SparseUnivariatePolynomialExpressions| . |CharacteristicZero|) 44513) ((|UnivariateSkewPolynomial| . |Rng|) T) ((|HomogeneousDirectProduct| . |OrderedAbelianGroup|) 44483) ((|FiniteFieldExtensionByPolynomial| . |StepThrough|) 44458) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |StepThrough|) 44433) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |StepThrough|) 44408) ((|HomogeneousDirectProduct| . |OrderedAbelianSemiGroup|) 44332) ((|HomogeneousDirectProduct| . |OrderedAbelianMonoidSup|) 44290) ((|DenavitHartenbergMatrix| . |Aggregate|) T) ((|HomogeneousDirectProduct| . |Monoid|) 44176) ((|TwoDimensionalArray| . |HomogeneousAggregate|) 44160) ((|Interval| . |Rng|) T) ((|U16Matrix| . |CoercibleTo|) 44134) ((|SparseUnivariatePolynomial| . |CommutativeRing|) 43964) ((|SparseMultivariatePolynomial| . |CommutativeRing|) 43817) ((|RomanNumeral| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |PolynomialCategory|) 43688) ((|Polynomial| . |SetCategory|) T) ((|OrdinaryDifferentialRing| . |LeftModule|) 43625) ((|NewSparseUnivariatePolynomial| . |PolynomialCategory|) 43560) ((|ModuleMonomial| . |SetCategory|) T) ((|NewSparseMultivariatePolynomial| . |PolynomialCategory|) 43513) ((|IndexedFlexibleArray| . |ExtensibleLinearAggregate|) 43497) ((|LieSquareMatrix| . |PartialDifferentialRing|) 43429) ((|HomogeneousDistributedMultivariatePolynomial| . |SetCategory|) T) ((|GeneralDistributedMultivariatePolynomial| . |PolynomialCategory|) 43379) ((|Asp50| . |Type|) T) ((|FiniteFieldExtensionByPolynomial| . |Algebra|) 43333) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Algebra|) 43287) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Algebra|) 43241) ((|DifferentialSparseMultivariatePolynomial| . |Algebra|) 43004) ((|DistributedMultivariatePolynomial| . |Algebra|) 42767) ((|PrimeField| . |StepThrough|) T) ((|LaurentPolynomial| . |CharacteristicZero|) 42730) ((|LaurentPolynomial| . |CharacteristicNonZero|) 42690) ((|BalancedPAdicRational| . |CharacteristicZero|) T) ((|BalancedPAdicRational| . |CharacteristicNonZero|) NIL) ((|FramedModule| . |Monoid|) T) ((|Octonion| . |Ring|) T) ((|FiniteFieldCyclicGroup| . |GcdDomain|) T) ((|UnivariateTaylorSeries| . |RadicalCategory|) 42639) ((|UnivariatePuiseuxSeries| . |RadicalCategory|) 42588) ((|UnivariateLaurentSeries| . |RadicalCategory|) 42537) ((|UnivariateFormalPowerSeries| . |RadicalCategory|) 42486) ((|PrimeField| . |Algebra|) 42440) ((|DoubleFloat| . |Module|) 42394) ((|MyExpression| . |OrderedSet|) T) ((|AlgebraicFunctionField| . |FramedAlgebra|) 42360) ((|ExponentialOfUnivariatePuiseuxSeries| . |AbelianMonoidRing|) 42319) ((|Quaternion| . |CancellationAbelianMonoid|) T) ((|OrderedDirectProduct| . |Type|) T) ((|ContinuedFraction| . |PrincipalIdealDomain|) T) ((|FiniteFieldCyclicGroup| . |FieldOfPrimeCharacteristic|) T) ((|IndexedList| . |EltableAggregate|) 42291) ((|AssociationList| . |Aggregate|) T) ((|OrderedDirectProduct| . |RetractableTo|) 42042) ((|MyUnivariatePolynomial| . |PolynomialFactorizationExplicit|) 41992) ((|Localize| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianGroup|) T) ((|LinearOrdinaryDifferentialOperator2| . |AbelianSemiGroup|) T) ((|Set| . |HomogeneousAggregate|) 41976) ((|UnivariateLaurentSeriesConstructor| . |DifferentialExtension|) 41943) ((|ThreeDimensionalMatrix| . |Type|) T) ((|DataList| . |BasicType|) 41880) ((|PAdicRational| . |SetCategory|) T) ((|SymmetricPolynomial| . |LeftModule|) 41777) ((|RomanNumeral| . |Module|) 41764) ((|MultivariatePolynomial| . |RightModule|) 41521) ((|SparseUnivariatePolynomial| . |InnerEvalable|) 41431) ((|Polynomial| . |Module|) 41194) ((|SparseMultivariatePolynomial| . |InnerEvalable|) 41146) ((|MyUnivariatePolynomial| . |LeftModule|) 41043) ((|HomogeneousDistributedMultivariatePolynomial| . |Module|) 40806) ((|Asp27| . |CoercibleTo|) 40780) ((|MultivariatePolynomial| . |BiModule|) 40505) ((|OrdinaryDifferentialRing| . |LeftOreRing|) 40481) ((|Point| . |HomogeneousAggregate|) 40465) ((|WeightedPolynomials| . |LeftModule|) 40412) ((|SparseUnivariateTaylorSeries| . |RightModule|) 40245) ((|OrdinaryDifferentialRing| . |Monoid|) T) ((|SparseUnivariatePuiseuxSeries| . |RightModule|) 40027) ((|SparseUnivariateLaurentSeries| . |RightModule|) 39736) ((|DirichletRing| . |EntireRing|) 39702) ((|SparseMultivariateTaylorSeries| . |RightModule|) 39535) ((|RadicalFunctionField| . |UniqueFactorizationDomain|) T) ((|Segment| . |BasicType|) 39505) ((|OrderedDirectProduct| . |FullyLinearlyExplicitRingOver|) 39473) ((|RadicalFunctionField| . |IntegralDomain|) T) ((|SparseUnivariateTaylorSeries| . |BiModule|) 39274) ((|SparseUnivariatePuiseuxSeries| . |BiModule|) 39024) ((|SparseUnivariateLaurentSeries| . |BiModule|) 38653) ((|SparseMultivariateTaylorSeries| . |BiModule|) 38454) ((|SExpressionOf| . |SExpressionCategory|) 38418) ((|Float| . |OrderedRing|) T) ((|UnivariateTaylorSeries| . |CoercibleTo|) 38392) ((|UnivariatePuiseuxSeries| . |CoercibleTo|) 38366) ((|UnivariateLaurentSeries| . |CoercibleTo|) 38340) ((|UnivariateLaurentSeries| . |ConvertibleTo|) NIL) ((|UnivariateFormalPowerSeries| . |CoercibleTo|) 38314) ((|DirectProduct| . |EltableAggregate|) 38286) ((|AlgebraicFunctionField| . |GcdDomain|) T) ((|DoubleFloat| . |CommutativeRing|) T) ((|Complex| . |SetCategory|) T) ((|MachineComplex| . |CharacteristicZero|) T) ((|MachineComplex| . |CharacteristicNonZero|) NIL) ((|InnerTaylorSeries| . |CoercibleTo|) 38260) ((|InnerSparseUnivariatePowerSeries| . |CoercibleTo|) 38234) ((|NumericalPDEProblem| . |SetCategory|) T) ((|NumericalOptimizationProblem| . |SetCategory|) T) ((|NumericalODEProblem| . |SetCategory|) T) ((|NumericalIntegrationProblem| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |UnivariateSkewPolynomialCategory|) 38218) ((|Magma| . |SetCategory|) T) ((|OrderedDirectProduct| . |PartialDifferentialRing|) 38122) ((|SparseUnivariatePolynomialExpressions| . |TranscendentalFunctionCategory|) 38073) ((|SparseUnivariatePolynomialExpressions| . |TrigonometricFunctionCategory|) 38024) ((|AlgebraicFunctionField| . |FieldOfPrimeCharacteristic|) NIL) ((|SingleInteger| . |Logic|) T) ((|PAdicRational| . |Module|) 37948) ((|DirectProductModule| . |HomogeneousAggregate|) 37932) ((|DirectProductMatrixModule| . |HomogeneousAggregate|) 37916) ((|ModMonic| . |LinearlyExplicitRingOver|) 37832) ((|LinearOrdinaryDifferentialOperator1| . |LeftModule|) 37806) ((|EqTable| . |Aggregate|) T) ((|SparseUnivariatePolynomialExpressions| . |ArcTrigonometricFunctionCategory|) 37757) ((|SparseUnivariatePolynomialExpressions| . |ArcHyperbolicFunctionCategory|) 37708) ((|MultivariatePolynomial| . |Ring|) T) ((|InnerPrimeField| . |VectorSpace|) 37695) ((|InnerFiniteField| . |VectorSpace|) 37659) ((|UnivariatePolynomial| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |EntireRing|) 37522) ((|SparseMultivariatePolynomial| . |EntireRing|) 37408) ((|RomanNumeral| . |CommutativeRing|) T) ((|MyUnivariatePolynomial| . |LeftOreRing|) 37303) ((|UnivariateSkewPolynomial| . |SetCategory|) T) ((|Polynomial| . |CommutativeRing|) 37156) ((|NewSparseUnivariatePolynomial| . |UnivariatePolynomialCategory|) 37140) ((|List| . |InnerEvalable|) 37059) ((|Asp49| . |CoercibleTo|) 37033) ((|MultivariatePolynomial| . |FiniteAbelianMonoidRing|) 36967) ((|SymmetricPolynomial| . |Monoid|) T) ((|Interval| . |SetCategory|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |CommutativeRing|) 36820) ((|MyUnivariatePolynomial| . |Monoid|) T) ((|DataList| . |Evalable|) 36744) ((|SquareMatrix| . |SemiGroup|) T) ((|Asp30| . |CoercibleTo|) 36718) ((|WeightedPolynomials| . |Monoid|) T) ((|SparseUnivariateTaylorSeries| . |Ring|) T) ((|SparseUnivariatePuiseuxSeries| . |Ring|) T) ((|FlexibleArray| . |BasicType|) 36655) ((|SparseUnivariateLaurentSeries| . |Ring|) T) ((|SquareMatrix| . |AbelianMonoid|) T) ((|SparseMultivariateTaylorSeries| . |Ring|) T) ((|ArrayStack| . |StackAggregate|) 36639) ((|OrdinaryWeightedPolynomials| . |SemiGroup|) T) ((|SparseUnivariateTaylorSeries| . |DifferentialRing|) 36576) ((|SparseUnivariatePuiseuxSeries| . |DivisionRing|) 36552) ((|SparseUnivariatePuiseuxSeries| . |DifferentialRing|) 36487) ((|SparseUnivariateLaurentSeries| . |DifferentialRing|) 36324) ((|SparseUnivariateLaurentSeries| . |DivisionRing|) 36300) ((|ExponentialOfUnivariatePuiseuxSeries| . |PartialDifferentialRing|) 36162) ((|PseudoAlgebraicClosureOfRationalNumber| . |BasicType|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |BasicType|) T) ((|OrdinaryWeightedPolynomials| . |AbelianMonoid|) T) ((|Complex| . |Module|) 35920) ((|SetOfMIntegersInOneToN| . |Finite|) T) ((|Fraction| . |UniqueFactorizationDomain|) T) ((|RealClosure| . |CharacteristicZero|) T) ((|RadicalFunctionField| . |Field|) T) ((|Point| . |Eltable|) 35892) ((|PAdicInteger| . |GcdDomain|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |FiniteFieldCategory|) T) ((|Expression| . |OrderedSet|) T) ((|ExponentialExpansion| . |OrderedSet|) NIL) ((|Palette| . |BasicType|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |InfinitlyClosePointCategory|) 35419) ((|ModMonic| . |AbelianSemiGroup|) T) ((|Fraction| . |IntegralDomain|) T) ((|ModMonic| . |AbelianGroup|) T) ((|FiniteField| . |CharacteristicZero|) 35385) ((|FiniteField| . |CharacteristicNonZero|) T) ((|Stack| . |SetCategory|) 35355) ((|GenericNonAssociativeAlgebra| . |Monad|) T) ((|Asp41| . |CoercibleTo|) 35329) ((|BasicOperator| . |OrderedSet|) T) ((|DataList| . |ExtensibleLinearAggregate|) 35313) ((|DirectProduct| . |RightModule|) 35183) ((|Asp6| . |CoercibleTo|) 35157) ((|MonoidRing| . |Finite|) 35102) ((|Symbol| . |OpenMath|) T) ((|Multiset| . |DictionaryOperations|) 35086) ((|UnivariatePolynomial| . |Module|) 34826) ((|StringTable| . |Type|) T) ((|CharacterClass| . |DictionaryOperations|) 34801) ((|DirectProduct| . |BiModule|) 34664) ((|StochasticDifferential| . |RightModule|) 34633) ((|AlgebraicNumber| . |CharacteristicZero|) T) ((|PAdicRational| . |CommutativeRing|) T) ((|UnivariateSkewPolynomial| . |Module|) 34590) ((|Heap| . |Type|) T) ((|Polynomial| . |InnerEvalable|) 34530) ((|LinearOrdinaryDifferentialOperator1| . |Monoid|) T) ((|Interval| . |Module|) 34517) ((|StochasticDifferential| . |BiModule|) 34466) ((|ResidueRing| . |Rng|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |InnerEvalable|) 34370) ((|Point| . |OneDimensionalArrayAggregate|) 34354) ((|Point| . |IndexedAggregate|) 34326) ((|OrderlyDifferentialPolynomial| . |ConvertibleTo|) NIL) ((|OrderlyDifferentialPolynomial| . |CoercibleTo|) 34300) ((|RadixExpansion| . |RightModule|) 34234) ((|FractionalIdeal| . |CoercibleTo|) 34208) ((|DirectProductModule| . |Eltable|) 34180) ((|DirectProductMatrixModule| . |Eltable|) 34152) ((|HexadecimalExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|Expression| . |AlgebraicallyClosedFunctionSpace|) 34110) ((|BinaryExpansion| . |Type|) T) ((|RadicalFunctionField| . |SemiGroup|) T) ((|DecimalExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|PartialFraction| . |RightModule|) 34051) ((|U32Vector| . |OrderedSet|) T) ((|SimpleAlgebraicExtension| . |RetractableTo|) 33895) ((|RadixExpansion| . |BiModule|) 33790) ((|Multiset| . |MultiDictionary|) 33774) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialExtension|) 33758) ((|FourierSeries| . |RightModule|) 33742) ((|Float| . |Rng|) T) ((|RadicalFunctionField| . |AbelianMonoid|) T) ((|PartialFraction| . |BiModule|) 33651) ((|MachineComplex| . |TrigonometricFunctionCategory|) NIL) ((|HexadecimalExpansion| . |LeftModule|) 33585) ((|BinaryExpansion| . |Patternable|) 33562) ((|BinaryExpansion| . |PatternMatchable|) 33539) ((|MachineComplex| . |TranscendentalFunctionCategory|) NIL) ((|DecimalExpansion| . |LeftModule|) 33473) ((|FiniteFieldExtension| . |RetractableTo|) 33457) ((|FiniteFieldNormalBasisExtension| . |RetractableTo|) 33441) ((|FlexibleArray| . |Evalable|) 33365) ((|FiniteFieldCyclicGroupExtension| . |RetractableTo|) 33349) ((|DoubleFloat| . |EntireRing|) T) ((|FourierSeries| . |BiModule|) 33328) ((|TwoDimensionalArray| . |CoercibleTo|) 33279) ((|Complex| . |CommutativeRing|) T) ((|SingleInteger| . |OrderedSet|) T) ((|BinaryExpansion| . |RetractableTo|) 33223) ((|Pattern| . |SetCategory|) T) ((|Operator| . |Rng|) T) ((|OppositeMonogenicLinearOperator| . |Rng|) T) ((|MachineComplex| . |ArcHyperbolicFunctionCategory|) NIL) ((|MachineComplex| . |ArcTrigonometricFunctionCategory|) NIL) ((|ExponentialExpansion| . |QuotientFieldCategory|) 33138) ((|InnerPAdicInteger| . |GcdDomain|) T) ((|Integer| . |GcdDomain|) T) ((|InnerAlgebraicNumber| . |GcdDomain|) T) ((|Fraction| . |Field|) T) ((|DirectProduct| . |Ring|) 33048) ((|SparseTable| . |Aggregate|) T) ((|Plcs| . |BasicType|) T) ((|Pi| . |PrincipalIdealDomain|) T) ((|Quaternion| . |LinearlyExplicitRingOver|) 32964) ((|DirectProductModule| . |IndexedAggregate|) 32936) ((|DirectProductMatrixModule| . |IndexedAggregate|) 32908) ((|SimpleAlgebraicExtension| . |FullyLinearlyExplicitRingOver|) 32892) ((|PAdicRational| . |InnerEvalable|) 32662) ((|DirectProduct| . |DifferentialRing|) 32599) ((|String| . |Type|) T) ((|OpenMathErrorKind| . |CoercibleTo|) 32573) ((|ProjectiveSpace| . |ProjectiveSpaceCategory|) 32557) ((|XPolynomialRing| . |SemiGroup|) T) ((|XDistributedPolynomial| . |CoercibleTo|) 32531) ((|UnivariatePolynomial| . |CommutativeRing|) 32361) ((|BinaryExpansion| . |FullyLinearlyExplicitRingOver|) 32338) ((|BinaryExpansion| . |FullyEvalableOver|) 32315) ((|RomanNumeral| . |EntireRing|) T) ((|Polynomial| . |EntireRing|) 32201) ((|Octonion| . |Finite|) 32176) ((|Plcs| . |PlacesCategory|) 32155) ((|ListMultiDictionary| . |Type|) T) ((|Library| . |Type|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |EntireRing|) 32041) ((|Interval| . |CommutativeRing|) T) ((|FlexibleArray| . |ExtensibleLinearAggregate|) 32025) ((|XPolynomialRing| . |AbelianMonoid|) T) ((|TaylorSeries| . |BasicType|) T) ((|TextFile| . |SetCategory|) T) ((|SequentialDifferentialVariable| . |SetCategory|) T) ((|RewriteRule| . |SetCategory|) T) ((|Asp74| . |CoercibleTo|) 31999) ((|ModularField| . |BasicType|) T) ((|FiniteFieldExtensionByPolynomial| . |FiniteFieldCategory|) 31974) ((|KeyedAccessFile| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |FiniteFieldCategory|) 31949) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |FiniteFieldCategory|) 31924) ((|Table| . |Dictionary|) 31866) ((|GeneralSparseTable| . |SetCategory|) T) ((|DirichletRing| . |Eltable|) 31830) ((|DifferentialSparseMultivariatePolynomial| . |DifferentialPolynomialCategory|) 31778) ((|SquareMatrix| . |CancellationAbelianMonoid|) T) ((|KeyedAccessFile| . |KeyedDictionary|) 31751) ((|SimpleAlgebraicExtension| . |PartialDifferentialRing|) 31654) ((|RadixExpansion| . |Ring|) T) ((|PartialFraction| . |Ring|) T) ((|GeneralSparseTable| . |KeyedDictionary|) 31633) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianMonoid|) NIL) ((|SparseUnivariateLaurentSeries| . |OrderedCancellationAbelianMonoid|) NIL) ((|Set| . |ConvertibleTo|) 31569) ((|Set| . |CoercibleTo|) 31543) ((|HashTable| . |Dictionary|) 31485) ((|RadixExpansion| . |DivisionRing|) T) ((|RadixExpansion| . |DifferentialRing|) T) ((|PrimitiveArray| . |SetCategory|) 31422) ((|FourierSeries| . |Ring|) T) ((|PartialFraction| . |DivisionRing|) T) ((|OrdinaryWeightedPolynomials| . |CancellationAbelianMonoid|) T) ((|MachineFloat| . |GcdDomain|) T) ((|HexadecimalExpansion| . |LeftOreRing|) T) ((|OrderedCompletion| . |SemiGroup|) 31392) ((|BinaryExpansion| . |PartialDifferentialRing|) NIL) ((|TaylorSeries| . |ElementaryFunctionCategory|) 31341) ((|DecimalExpansion| . |LeftOreRing|) T) ((|PAdicRationalConstructor| . |OrderedRing|) 31301) ((|SplitHomogeneousDirectProduct| . |Type|) T) ((|Permutation| . |Monoid|) T) ((|Complex| . |InnerEvalable|) 31190) ((|Quaternion| . |AbelianSemiGroup|) T) ((|Permutation| . |Group|) T) ((|Fraction| . |SemiGroup|) T) ((|HexadecimalExpansion| . |OrderedAbelianSemiGroup|) T) ((|HexadecimalExpansion| . |OrderedAbelianGroup|) T) ((|PrimeField| . |FiniteFieldCategory|) T) ((|HexadecimalExpansion| . |Monoid|) T) ((|DecimalExpansion| . |OrderedAbelianSemiGroup|) T) ((|DecimalExpansion| . |OrderedAbelianGroup|) T) ((|Quaternion| . |AbelianGroup|) T) ((|DecimalExpansion| . |Monoid|) T) ((|OrderedCompletion| . |AbelianMonoid|) 31125) ((|ExponentialOfUnivariatePuiseuxSeries| . |EuclideanDomain|) 31101) ((|Result| . |DictionaryOperations|) 31034) ((|Fraction| . |AbelianMonoid|) T) ((|Point| . |ConvertibleTo|) 30970) ((|Point| . |CoercibleTo|) 30888) ((|List| . |HomogeneousAggregate|) 30872) ((|AssociationList| . |RecursiveAggregate|) 30814) ((|PseudoAlgebraicClosureOfRationalNumber| . |Algebra|) 30768) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Algebra|) 30722) ((|SparseUnivariatePolynomialExpressions| . |GcdDomain|) 30617) ((|FourierComponent| . |CoercibleTo|) 30591) ((|SplitHomogeneousDirectProduct| . |RetractableTo|) 30342) ((|IndexedString| . |LinearAggregate|) 30317) ((|IndexedString| . |FiniteLinearAggregate|) 30292) ((|FiniteFieldCyclicGroup| . |VectorSpace|) 30261) ((|RegularTriangularSet| . |Type|) T) ((|PAdicRational| . |EntireRing|) T) ((|UnivariatePolynomial| . |InnerEvalable|) 30171) ((|GeneralTriangularSet| . |Type|) T) ((|GeneralPolynomialSet| . |Type|) T) ((|IntegrationResult| . |BasicType|) T) ((|SparseUnivariatePolynomial| . |Eltable|) 30074) ((|LaurentPolynomial| . |GcdDomain|) 30050) ((|Queue| . |QueueAggregate|) 30034) ((|XDistributedPolynomial| . |FreeModuleCat|) 29991) ((|BalancedPAdicRational| . |GcdDomain|) T) ((|TexFormat| . |BasicType|) T) ((|SegmentBinding| . |SetCategory|) 29961) ((|ResidueRing| . |SetCategory|) T) ((|PoincareBirkhoffWittLyndonBasis| . |OrderedSet|) T) ((|UnivariateTaylorSeries| . |RightModule|) 29794) ((|FiniteFieldNormalBasis| . |UniqueFactorizationDomain|) T) ((|UnivariatePuiseuxSeries| . |RightModule|) 29576) ((|SplitHomogeneousDirectProduct| . |FullyLinearlyExplicitRingOver|) 29544) ((|UnivariateLaurentSeries| . |RightModule|) 29259) ((|UnivariateFormalPowerSeries| . |RightModule|) 29092) ((|UnivariateTaylorSeries| . |BiModule|) 28893) ((|UnivariatePuiseuxSeries| . |BiModule|) 28643) ((|UnivariateLaurentSeries| . |BiModule|) 28284) ((|UnivariateFormalPowerSeries| . |BiModule|) 28085) ((|TaylorSeries| . |Evalable|) 28072) ((|FiniteFieldNormalBasis| . |IntegralDomain|) T) ((|File| . |CoercibleTo|) 28046) ((|EuclideanModularRing| . |EuclideanDomain|) T) ((|InnerTaylorSeries| . |RightModule|) 28007) ((|InnerSparseUnivariatePowerSeries| . |RightModule|) 27840) ((|FreeGroup| . |SetCategory|) T) ((|FreeAbelianGroup| . |SetCategory|) T) ((|DirectProductModule| . |CoercibleTo|) 27790) ((|DirectProductMatrixModule| . |CoercibleTo|) 27740) ((|RadicalFunctionField| . |CancellationAbelianMonoid|) T) ((|BinaryFile| . |CoercibleTo|) 27714) ((|AssociatedLieAlgebra| . |AbelianMonoid|) T) ((|MachineComplex| . |FramedAlgebra|) 27638) ((|AssociatedJordanAlgebra| . |AbelianMonoid|) T) ((|LinearOrdinaryDifferentialOperator| . |BasicType|) T) ((|InnerTaylorSeries| . |BiModule|) 27597) ((|InnerSparseUnivariatePowerSeries| . |BiModule|) 27398) ((|Float| . |SetCategory|) T) ((|FiniteDivisor| . |BasicType|) T) ((|Complex| . |EntireRing|) 27267) ((|Divisor| . |BasicType|) T) ((|UnivariateLaurentSeriesConstructor| . |OrderedRing|) 27198) ((|Places| . |CoercibleTo|) 27172) ((|ModuleOperator| . |Rng|) T) ((|Stack| . |InnerEvalable|) 27091) ((|SplitHomogeneousDirectProduct| . |PartialDifferentialRing|) 26995) ((|Operator| . |SetCategory|) T) ((|OppositeMonogenicLinearOperator| . |SetCategory|) T) ((|OpenMathError| . |SetCategory|) T) ((|AttributeButtons| . |BasicType|) T) ((|Character| . |OrderedSet|) T) ((|MyExpression| . |CharacteristicZero|) 26958) ((|MyExpression| . |CharacteristicNonZero|) 26918) ((|Kernel| . |Patternable|) 26902) ((|U8Matrix| . |Type|) T) ((|U8Vector| . |Collection|) 26879) ((|Bits| . |Type|) T) ((|SequentialDifferentialPolynomial| . |BasicType|) T) ((|RoutinesTable| . |Aggregate|) T) ((|NewSparseUnivariatePolynomial| . |BasicType|) T) ((|NewSparseMultivariatePolynomial| . |BasicType|) T) ((|GeneralModulePolynomial| . |BasicType|) T) ((|GeneralDistributedMultivariatePolynomial| . |BasicType|) T) ((|DirectProduct| . |OrderedCancellationAbelianMonoid|) 26803) ((|DirectProduct| . |OrderedAbelianMonoid|) 26727) ((|NeitherSparseOrDensePowerSeries| . |StreamAggregate|) 26668) ((|ListMonoidOps| . |BasicType|) T) ((|UnivariatePolynomial| . |EntireRing|) 26531) ((|LiePolynomial| . |LieAlgebra|) 26515) ((|List| . |Eltable|) 26487) ((|ResidueRing| . |Module|) 26471) ((|Interval| . |EntireRing|) T) ((|PolynomialRing| . |LeftModule|) 26368) ((|XPolynomialRing| . |CancellationAbelianMonoid|) T) ((|MonoidRing| . |LeftModule|) 26315) ((|ModularRing| . |LeftModule|) 26302) ((|ExtAlgBasis| . |BasicType|) T) ((|GenericNonAssociativeAlgebra| . |LeftModule|) 26195) ((|AntiSymm| . |BasicType|) T) ((|InnerPrimeField| . |BasicType|) T) ((|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|InnerFiniteField| . |BasicType|) T) ((|UnivariateTaylorSeries| . |Ring|) T) ((|UnivariatePuiseuxSeries| . |Ring|) T) ((|UnivariateLaurentSeries| . |Ring|) T) ((|UnivariateFormalPowerSeries| . |Ring|) T) ((|UnivariateTaylorSeries| . |DifferentialRing|) 26132) ((|UnivariatePuiseuxSeries| . |DivisionRing|) 26108) ((|FreeAbelianGroup| . |Module|) 26085) ((|UnivariatePuiseuxSeries| . |DifferentialRing|) 26020) ((|UnivariateLaurentSeries| . |DifferentialRing|) 25863) ((|UnivariateLaurentSeries| . |DivisionRing|) 25839) ((|UnivariateFormalPowerSeries| . |DifferentialRing|) 25776) ((|TaylorSeries| . |Algebra|) 25620) ((|RadixExpansion| . |OrderedCancellationAbelianMonoid|) T) ((|InnerTaylorSeries| . |Ring|) T) ((|InnerSparseUnivariatePowerSeries| . |Ring|) T) ((|RadixExpansion| . |OrderedAbelianMonoid|) T) ((|Partition| . |OrderedCancellationAbelianMonoid|) T) ((|Partition| . |OrderedAbelianMonoid|) T) ((|DirichletRing| . |CoercibleTo|) 25594) ((|PAdicRationalConstructor| . |Rng|) T) ((|PAdicInteger| . |PAdicIntegerCategory|) 25578) ((|MachineComplex| . |GcdDomain|) T) ((|Float| . |Module|) 25532) ((|Factored| . |LeftModule|) 25506) ((|ModMonic| . |OrderedSet|) 25477) ((|ModularField| . |Algebra|) 25431) ((|InnerSparseUnivariatePowerSeries| . |DifferentialRing|) 25379) ((|AlgebraicFunctionField| . |MonogenicAlgebra|) 25345) ((|FiniteFieldNormalBasis| . |FiniteAlgebraicExtensionField|) 25314) ((|FiniteFieldNormalBasis| . |Field|) T) ((|UnivariateTaylorSeriesCZero| . |CharacteristicNonZero|) 25274) ((|UnivariateTaylorSeriesCZero| . |CharacteristicZero|) 25237) ((|SimpleAlgebraicExtension| . |EuclideanDomain|) 25171) ((|Equation| . |SemiGroup|) 25017) ((|SimpleFortranProgram| . |Type|) T) ((|SubSpaceComponentProperty| . |BasicType|) T) ((|UniversalSegment| . |CoercibleTo|) 24968) ((|OrderedCompletion| . |CancellationAbelianMonoid|) 24903) ((|List| . |UnaryRecursiveAggregate|) 24887) ((|Operator| . |Module|) 24844) ((|OppositeMonogenicLinearOperator| . |Module|) 24801) ((|HomogeneousDirectProduct| . |Type|) T) ((|FiniteFieldExtension| . |EuclideanDomain|) T) ((|FiniteFieldNormalBasisExtension| . |EuclideanDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |EuclideanDomain|) T) ((|List| . |IndexedAggregate|) 24773) ((|Fraction| . |CancellationAbelianMonoid|) T) ((|IndexedList| . |ListAggregate|) 24757) ((|BinaryExpansion| . |EuclideanDomain|) T) ((|Equation| . |AbelianMonoid|) 24591) ((|IndexedList| . |LinearAggregate|) 24575) ((|MachineComplex| . |FieldOfPrimeCharacteristic|) NIL) ((|IndexedList| . |FiniteLinearAggregate|) 24559) ((|InfinitlyClosePoint| . |CoercibleTo|) 24533) ((|ArrayStack| . |SetCategory|) 24503) ((|BinaryExpansion| . |RealConstant|) T) ((|Integer| . |CombinatorialFunctionCategory|) T) ((|Vector| . |Collection|) 24487) ((|HomogeneousDirectProduct| . |RetractableTo|) 24238) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CharacteristicNonZero|) 24160) ((|UnivariatePuiseuxSeriesWithExponentialSingularity| . |CharacteristicZero|) 24085) ((|RectangularMatrix| . |Type|) T) ((|QuadraticForm| . |CoercibleTo|) 24059) ((|OutputForm| . |CoercibleTo|) 24033) ((|OrderlyDifferentialPolynomial| . |RightModule|) 23790) ((|SequentialDifferentialPolynomial| . |Evalable|) 23777) ((|DenavitHartenbergMatrix| . |Type|) T) ((|NewSparseUnivariatePolynomial| . |Evalable|) 23764) ((|NewSparseMultivariatePolynomial| . |Evalable|) 23751) ((|OrderlyDifferentialPolynomial| . |BiModule|) 23476) ((|GeneralDistributedMultivariatePolynomial| . |Evalable|) 23463) ((|SparseUnivariatePolynomial| . |ConvertibleTo|) NIL) ((|SparseUnivariatePolynomial| . |CoercibleTo|) 23437) ((|SparseMultivariatePolynomial| . |CoercibleTo|) 23411) ((|SparseMultivariatePolynomial| . |ConvertibleTo|) 23018) ((|ResidueRing| . |CommutativeRing|) T) ((|SparseUnivariateSkewPolynomial| . |CoercibleTo|) 22992) ((|Point| . |EltableAggregate|) 22964) ((|KeyedAccessFile| . |InnerEvalable|) 22648) ((|OrderlyDifferentialVariable| . |RetractableTo|) 22632) ((|GeneralSparseTable| . |InnerEvalable|) 22340) ((|PolynomialRing| . |Monoid|) T) ((|MonoidRing| . |Monoid|) T) ((|ModularRing| . |Monoid|) T) ((|FiniteFieldNormalBasis| . |SemiGroup|) T) ((|TheSymbolTable| . |CoercibleTo|) 22314) ((|DeRhamComplex| . |BasicType|) T) ((|HomogeneousDirectProduct| . |FullyLinearlyExplicitRingOver|) 22282) ((|InnerFreeAbelianMonoid| . |SetCategory|) T) ((|IndexedDirectProductOrderedAbelianMonoid| . |SetCategory|) T) ((|IndexedDirectProductAbelianMonoid| . |SetCategory|) T) ((|Octonion| . |LeftModule|) 22256) ((|RealClosure| . |GcdDomain|) T) ((|PrimitiveArray| . |InnerEvalable|) 22175) ((|FiniteFieldNormalBasis| . |AbelianMonoid|) T) ((|U16Vector| . |OrderedSet|) T) ((|AssociatedLieAlgebra| . |CancellationAbelianMonoid|) T) ((|AssociatedJordanAlgebra| . |CancellationAbelianMonoid|) T) ((|Factored| . |LeftOreRing|) 22099) ((|FiniteField| . |GcdDomain|) T) ((|DirectProduct| . |Finite|) 22074) ((|Float| . |CommutativeRing|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Rng|) T) ((|UnivariateLaurentSeriesConstructor| . |Rng|) T) ((|DoubleFloat| . |RadicalCategory|) T) ((|ProjectivePlane| . |SetCategoryWithDegree|) T) ((|MachineFloat| . |FortranMachineTypeCategory|) T) ((|Factored| . |Monoid|) T) ((|MachineInteger| . |UniqueFactorizationDomain|) T) ((|SquareMatrix| . |LinearlyExplicitRingOver|) 21990) ((|XDistributedPolynomial| . |RightModule|) 21974) ((|InnerPAdicInteger| . |PAdicIntegerCategory|) 21958) ((|StringTable| . |TableAggregate|) 21931) ((|ModuleOperator| . |SetCategory|) T) ((|MachineInteger| . |IntegralDomain|) T) ((|BinaryTournament| . |SetCategory|) 21901) ((|HomogeneousDirectProduct| . |PartialDifferentialRing|) 21805) ((|DoubleFloatVector| . |VectorCategory|) 21778) ((|DoubleFloatVector| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |VectorCategory|) 21739) ((|Commutator| . |SetCategory|) T) ((|LinearOrdinaryDifferentialOperator| . |Algebra|) 21696) ((|FiniteField| . |FieldOfPrimeCharacteristic|) T) ((|Expression| . |CharacteristicZero|) 21659) ((|Expression| . |CharacteristicNonZero|) 21619) ((|BalancedPAdicInteger| . |IntegralDomain|) T) ((|ExponentialExpansion| . |CharacteristicZero|) 21513) ((|ExponentialExpansion| . |CharacteristicNonZero|) 21404) ((|AlgebraicNumber| . |GcdDomain|) T) ((|Color| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |SetCategory|) T) ((|StringTable| . |BagAggregate|) 21340) ((|SparseUnivariatePolynomialExpressions| . |PolynomialCategory|) 21275) ((|NewSparseUnivariatePolynomial| . |StepThrough|) 21245) ((|Matrix| . |Aggregate|) T) ((|XDistributedPolynomial| . |BiModule|) 21224) ((|InnerTable| . |Aggregate|) T) ((|Heap| . |BagAggregate|) 21208) ((|DirectProductModule| . |EltableAggregate|) 21180) ((|DirectProductMatrixModule| . |EltableAggregate|) 21152) ((|PAdicRational| . |Eltable|) 21037) ((|AssociationList| . |Type|) T) ((|OrderlyDifferentialPolynomial| . |Ring|) T) ((|SymmetricPolynomial| . |AbelianMonoidRing|) 21007) ((|OrderlyDifferentialPolynomial| . |FiniteAbelianMonoidRing|) 20927) ((|SequentialDifferentialPolynomial| . |Algebra|) 20690) ((|OrderlyDifferentialPolynomial| . |DifferentialRing|) 20655) ((|NewSparseUnivariatePolynomial| . |Algebra|) 20395) ((|NewSparseMultivariatePolynomial| . |Algebra|) 20158) ((|MyUnivariatePolynomial| . |AbelianMonoidRing|) 20119) ((|GeneralDistributedMultivariatePolynomial| . |Algebra|) 19882) ((|List| . |ConvertibleTo|) 19818) ((|List| . |CoercibleTo|) 19736) ((|InnerPrimeField| . |StepThrough|) T) ((|InnerFiniteField| . |StepThrough|) T) ((|Stack| . |HomogeneousAggregate|) 19720) ((|Tree| . |SetCategory|) 19690) ((|SquareMatrix| . |AbelianSemiGroup|) T) ((|SquareMatrix| . |AbelianGroup|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Rng|) T) ((|NeitherSparseOrDensePowerSeries| . |Rng|) T) ((|UnivariateTaylorSeriesCZero| . |TrigonometricFunctionCategory|) 19639) ((|UnivariateTaylorSeriesCZero| . |TranscendentalFunctionCategory|) 19588) ((|GeneralUnivariatePowerSeries| . |Rng|) T) ((|UnivariateLaurentSeries| . |OrderedAbelianMonoid|) NIL) ((|UnivariateLaurentSeries| . |OrderedCancellationAbelianMonoid|) NIL) ((|Quaternion| . |OrderedSet|) 19559) ((|OrderedFreeMonoid| . |CoercibleTo|) 19533) ((|OrdinaryWeightedPolynomials| . |AbelianGroup|) T) ((|OrdinaryWeightedPolynomials| . |AbelianSemiGroup|) T) ((|Octonion| . |Monoid|) T) ((|InfClsPt| . |SetCategoryWithDegree|) T) ((|ContinuedFraction| . |UniqueFactorizationDomain|) T) ((|InnerPrimeField| . |Algebra|) 19487) ((|InnerFiniteField| . |Algebra|) 19441) ((|FreeMonoid| . |CoercibleTo|) 19415) ((|FreeAbelianMonoid| . |CoercibleTo|) 19389) ((|Complex| . |Eltable|) 19342) ((|UnivariateTaylorSeriesCZero| . |ArcHyperbolicFunctionCategory|) 19291) ((|UnivariateTaylorSeriesCZero| . |ArcTrigonometricFunctionCategory|) 19240) ((|Asp19| . |Type|) T) ((|Boolean| . |BasicType|) T) ((|PAdicRationalConstructor| . |SetCategory|) T) ((|ContinuedFraction| . |IntegralDomain|) T) ((|ModuleOperator| . |Module|) 19197) ((|Equation| . |CancellationAbelianMonoid|) 19031) ((|DoubleFloat| . |CoercibleTo|) 19005) ((|DoubleFloat| . |ConvertibleTo|) 18908) ((|U32Matrix| . |Aggregate|) T) ((|RadicalFunctionField| . |LinearlyExplicitRingOver|) 18798) ((|XDistributedPolynomial| . |Ring|) T) ((|SingleInteger| . |CharacteristicZero|) T) ((|Library| . |TableAggregate|) 18768) ((|MultivariatePolynomial| . |PolynomialFactorizationExplicit|) 18718) ((|IndexedString| . |Aggregate|) T) ((|ListMultiDictionary| . |BagAggregate|) 18702) ((|Library| . |BagAggregate|) 18635) ((|MyUnivariatePolynomial| . |PatternMatchable|) NIL) ((|UnivariatePolynomial| . |Eltable|) 18538) ((|MultivariatePolynomial| . |LeftModule|) 18435) ((|EqTable| . |Type|) T) ((|SymmetricPolynomial| . |RetractableTo|) 18279) ((|MyUnivariatePolynomial| . |RetractableTo|) 18089) ((|SparseUnivariateLaurentSeries| . |PolynomialFactorizationExplicit|) NIL) ((|RomanNumeral| . |ConvertibleTo|) 17970) ((|RomanNumeral| . |CoercibleTo|) 17944) ((|FiniteFieldCyclicGroup| . |BasicType|) T) ((|DirectProductModule| . |RightModule|) 17814) ((|DirectProductMatrixModule| . |RightModule|) 17684) ((|ScriptFormulaFormat| . |BasicType|) T) ((|Polynomial| . |CoercibleTo|) 17658) ((|Polynomial| . |ConvertibleTo|) 17436) ((|ModuleMonomial| . |CoercibleTo|) 17410) ((|WuWenTsunTriangularSet| . |TriangularSetCategory|) 17379) ((|HomogeneousDistributedMultivariatePolynomial| . |CoercibleTo|) 17353) ((|HomogeneousDistributedMultivariatePolynomial| . |ConvertibleTo|) 17131) ((|DifferentialSparseMultivariatePolynomial| . |FullyRetractableTo|) 17115) ((|DistributedMultivariatePolynomial| . |FullyRetractableTo|) 17099) ((|DirectProductModule| . |BiModule|) 16962) ((|DirectProductMatrixModule| . |BiModule|) 16825) ((|SparseUnivariateTaylorSeries| . |LeftModule|) 16722) ((|SparseUnivariatePuiseuxSeries| . |LeftModule|) 16591) ((|SparseUnivariateLaurentSeries| . |LeftModule|) 16387) ((|SparseMultivariateTaylorSeries| . |LeftModule|) 16284) ((|FiniteFieldNormalBasis| . |CancellationAbelianMonoid|) T) ((|Asp73| . |FortranVectorFunctionCategory|) T) ((|Asp73| . |FortranProgramCategory|) T) ((|RadicalFunctionField| . |AbelianSemiGroup|) T) ((|RadicalFunctionField| . |AbelianGroup|) T) ((|PAdicRationalConstructor| . |Module|) 16225) ((|Float| . |EntireRing|) T) ((|Complex| . |RadicalCategory|) 16137) ((|MyUnivariatePolynomial| . |FullyLinearlyExplicitRingOver|) 16121) ((|MachineComplex| . |FortranMachineTypeCategory|) T) ((|Quaternion| . |QuaternionCategory|) 16105) ((|MachineInteger| . |SemiGroup|) T) ((|MachineComplex| . |ComplexCategory|) 16077) ((|UnivariatePuiseuxSeriesConstructor| . |SetCategory|) T) ((|UnivariateLaurentSeriesConstructor| . |SetCategory|) T) ((|Expression| . |TranscendentalFunctionCategory|) 16044) ((|Expression| . |TrigonometricFunctionCategory|) 16011) ((|SubSpace| . |BasicType|) T) ((|Expression| . |PrimitiveFunctionCategory|) 15978) ((|CardinalNumber| . |SemiGroup|) T) ((|BalancedPAdicInteger| . |SemiGroup|) T) ((|IndexedVector| . |VectorCategory|) 15962) ((|MachineInteger| . |AbelianMonoid|) T) ((|IndexedVector| . |SetCategory|) 15899) ((|ArrayStack| . |InnerEvalable|) 15818) ((|ContinuedFraction| . |Field|) T) ((|SparseUnivariatePolynomialExpressions| . |UnivariatePolynomialCategory|) 15802) ((|Expression| . |ArcTrigonometricFunctionCategory|) 15769) ((|Expression| . |ArcHyperbolicFunctionCategory|) 15736) ((|KeyedAccessFile| . |HomogeneousAggregate|) 15659) ((|CardinalNumber| . |AbelianMonoid|) T) ((|BalancedPAdicInteger| . |AbelianMonoid|) T) ((|MoebiusTransform| . |SetCategory|) T) ((|GeneralSparseTable| . |HomogeneousAggregate|) 15588) ((|Fraction| . |LinearlyExplicitRingOver|) 15504) ((|LinearOrdinaryDifferentialOperator1| . |RetractableTo|) 15348) ((|MyUnivariatePolynomial| . |PartialDifferentialRing|) 15246) ((|PrimitiveArray| . |HomogeneousAggregate|) 15230) ((|MultivariatePolynomial| . |LeftOreRing|) 15148) ((|FiniteFieldExtensionByPolynomial| . |Rng|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Rng|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Rng|) T) ((|DifferentialSparseMultivariatePolynomial| . |Rng|) T) ((|DistributedMultivariatePolynomial| . |Rng|) T) ((|PAdicRational| . |ConvertibleTo|) NIL) ((|PAdicRational| . |CoercibleTo|) 15122) ((|XPolynomialRing| . |AbelianGroup|) T) ((|Interval| . |RadicalCategory|) T) ((|MultivariatePolynomial| . |Monoid|) T) ((|XPolynomialRing| . |AbelianSemiGroup|) T) ((|DirectProductModule| . |Ring|) 15032) ((|DirectProductMatrixModule| . |Ring|) 14942) ((|DirichletRing| . |RightModule|) 14862) ((|Asp33| . |Type|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |BasicType|) T) ((|DirectProductModule| . |DifferentialRing|) 14799) ((|DirectProductMatrixModule| . |DifferentialRing|) 14736) ((|DirichletRing| . |BiModule|) 14649) ((|AlgebraicFunctionField| . |BasicType|) T) ((|PrimeField| . |Rng|) T) ((|SparseUnivariatePuiseuxSeries| . |LeftOreRing|) 14625) ((|SparseUnivariateLaurentSeries| . |LeftOreRing|) 14601) ((|SparseUnivariateTaylorSeries| . |Monoid|) T) ((|SparseUnivariatePuiseuxSeries| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |Monoid|) T) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianGroup|) NIL) ((|SparseUnivariateLaurentSeries| . |OrderedAbelianSemiGroup|) NIL) ((|SparseMultivariateTaylorSeries| . |Monoid|) T) ((|PlacesOverPseudoAlgebraicClosureOfFiniteField| . |PlacesCategory|) 14464) ((|PseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PositiveInteger| . |BasicType|) T) ((|NeitherSparseOrDensePowerSeries| . |SetCategory|) T) ((|NonNegativeInteger| . |BasicType|) T) ((|LyndonWord| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |SetCategory|) T) ((|FortranExpression| . |SemiGroup|) T) ((|UnivariatePuiseuxSeriesConstructor| . |Module|) 14252) ((|ContinuedFraction| . |SemiGroup|) T) ((|ExponentialOfUnivariatePuiseuxSeries| . |PrincipalIdealDomain|) 14228) ((|MyExpression| . |GcdDomain|) 14195) ((|PAdicRationalConstructor| . |CommutativeRing|) T) ((|UnivariateLaurentSeriesConstructor| . |Module|) 13953) ((|OrderedCompletion| . |AbelianGroup|) 13888) ((|OrderedCompletion| . |AbelianSemiGroup|) 13823) ((|DataList| . |StreamAggregate|) 13807) ((|BinaryTournament| . |InnerEvalable|) 13726) ((|Fraction| . |AbelianSemiGroup|) T) ((|Fraction| . |AbelianGroup|) T) ((|FortranExpression| . |AbelianMonoid|) T) ((|Complex| . |ConvertibleTo|) 13346) ((|Complex| . |CoercibleTo|) 13320) ((|ContinuedFraction| . |AbelianMonoid|) T) ((|List| . |EltableAggregate|) 13292) ((|DoubleFloatVector| . |InnerEvalable|) NIL) ((|ComplexDoubleFloatVector| . |InnerEvalable|) NIL) ((|IndexedList| . |Aggregate|) T) ((|NumericalPDEProblem| . |CoercibleTo|) 13266) ((|Asp9| . |Type|) T) ((|NumericalOptimizationProblem| . |CoercibleTo|) 13240) ((|NumericalODEProblem| . |CoercibleTo|) 13214) ((|NumericalIntegrationProblem| . |CoercibleTo|) 13188) ((|Magma| . |CoercibleTo|) 13162) ((|DirectProduct| . |LeftModule|) 12976) ((|Symbol| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |RightModule|) 12710) ((|SparseTable| . |Type|) T) ((|SparseMultivariatePolynomial| . |RightModule|) 12467) ((|SparseUnivariateSkewPolynomial| . |RightModule|) 12451) ((|StochasticDifferential| . |LeftModule|) 12420) ((|SparseUnivariatePolynomial| . |BiModule|) 12122) ((|SparseMultivariatePolynomial| . |BiModule|) 11847) ((|SparseUnivariateSkewPolynomial| . |BiModule|) 11826) ((|UnivariatePolynomial| . |ConvertibleTo|) NIL) ((|UnivariatePolynomial| . |CoercibleTo|) 11800) ((|FiniteFieldCyclicGroup| . |StepThrough|) T) ((|UnivariateSkewPolynomial| . |CoercibleTo|) 11774) ((|RewriteRule| . |Eltable|) 11753) ((|DirichletRing| . |Ring|) T) ((|Asp55| . |Type|) T) ((|RadixExpansion| . |PolynomialFactorizationExplicit|) NIL) ((|KeyedAccessFile| . |Eltable|) 11726) ((|Tree| . |InnerEvalable|) 11645) ((|HexadecimalExpansion| . |Type|) T) ((|Interval| . |CoercibleTo|) 11619) ((|GeneralSparseTable| . |Eltable|) 11598) ((|SequentialDifferentialPolynomial| . |DifferentialExtension|) 11582) ((|RadixExpansion| . |LeftModule|) 11516) ((|DecimalExpansion| . |Type|) T) ((|PrimitiveArray| . |Eltable|) 11488) ((|PartialFraction| . |LeftModule|) 11429) ((|EuclideanModularRing| . |PrincipalIdealDomain|) T) ((|OrdinaryDifferentialRing| . |EuclideanDomain|) 11405) ((|PAdicInteger| . |BasicType|) T) ((|NewSparseUnivariatePolynomial| . |DifferentialExtension|) 11389) ((|NottinghamGroup| . |SetCategory|) T) ((|PseudoAlgebraicClosureOfFiniteField| . |Module|) 11330) ((|NeitherSparseOrDensePowerSeries| . |Module|) 11244) ((|AssociatedLieAlgebra| . |AbelianGroup|) T) ((|AssociatedLieAlgebra| . |AbelianSemiGroup|) T) ((|AssociatedJordanAlgebra| . |AbelianGroup|) T) ((|FiniteFieldCyclicGroup| . |Algebra|) 11198) ((|MachineComplex| . |MonogenicAlgebra|) 11122) ((|HexadecimalExpansion| . |Patternable|) 11099) ((|HexadecimalExpansion| . |PatternMatchable|) 11076) ((|GeneralUnivariatePowerSeries| . |Module|) 10864) ((|DecimalExpansion| . |Patternable|) 10841) ((|Asp1| . |Type|) T) ((|DecimalExpansion| . |PatternMatchable|) 10818) ((|AssociatedJordanAlgebra| . |AbelianSemiGroup|) T) ((|FourierSeries| . |LeftModule|) 10792) ((|HexadecimalExpansion| . |RetractableTo|) 10736) ((|PAdicRationalConstructor| . |InnerEvalable|) 10625) ((|DecimalExpansion| . |RetractableTo|) 10569) ((|DirectProduct| . |Aggregate|) T) ((|Queue| . |SetCategory|) 10539) ((|UnivariatePuiseuxSeriesConstructor| . |CommutativeRing|) 10445) ((|UnivariateLaurentSeriesConstructor| . |CommutativeRing|) 10351) ((|ModMonic| . |CharacteristicNonZero|) 10311) ((|ModMonic| . |CharacteristicZero|) 10274) ((|MachineInteger| . |CancellationAbelianMonoid|) T) ((|CartesianTensor| . |GradedAlgebra|) 10235) ((|GuessOptionFunctions0| . |BasicType|) T) ((|LinearOrdinaryDifferentialOperator| . |LinearOrdinaryDifferentialOperatorCategory|) 10219) ((|Stack| . |CoercibleTo|) 10170) ((|BalancedPAdicInteger| . |CancellationAbelianMonoid|) T) ((|Pi| . |UniqueFactorizationDomain|) T) ((|KeyedAccessFile| . |IndexedAggregate|) 10143) ((|GeneralSparseTable| . |IndexedAggregate|) 10122) ((|FiniteDivisor| . |FiniteDivisorCategory|) 10091) ((|InputForm| . |SetCategory|) T) ((|SparseUnivariatePolynomial| . |Ring|) T) ((|Pi| . |IntegralDomain|) T) ((|Divisor| . |DivisorCategory|) 10075) ((|SparseMultivariatePolynomial| . |Ring|) T) ((|SparseUnivariateSkewPolynomial| . |Ring|) T) ((|DirectProduct| . |OrderedAbelianGroup|) 10045) ((|DirectProduct| . |OrderedAbelianSemiGroup|) 9969) ((|DirectProduct| . |OrderedAbelianMonoidSup|) 9927) ((|SparseUnivariatePolynomial| . |FiniteAbelianMonoidRing|) 9888) ((|DirectProduct| . |Monoid|) 9774) ((|PrimitiveArray| . |OneDimensionalArrayAggregate|) 9758) ((|HexadecimalExpansion| . |FullyLinearlyExplicitRingOver|) 9735) ((|HexadecimalExpansion| . |FullyEvalableOver|) 9712) ((|SparseMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 9670) ((|FiniteField| . |VectorSpace|) 9639) ((|DecimalExpansion| . |FullyLinearlyExplicitRingOver|) 9616) ((|DecimalExpansion| . |FullyEvalableOver|) 9593) ((|PrimitiveArray| . |IndexedAggregate|) 9565) ((|SparseUnivariatePolynomial| . |DifferentialRing|) T) ((|LiePolynomial| . |SetCategory|) T) ((|Variable| . |SetCategory|) T) ((|Table| . |SetCategory|) T) ((|SequentialDifferentialPolynomial| . |DifferentialPolynomialCategory|) 9425) ((|FiniteFieldExtensionByPolynomial| . |SetCategory|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |SetCategory|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |SetCategory|) T) ((|DifferentialSparseMultivariatePolynomial| . |SetCategory|) T) ((|DistributedMultivariatePolynomial| . |SetCategory|) T) ((|Asp77| . |Type|) T) ((|BinaryTree| . |BasicType|) 9395) ((|BinarySearchTree| . |BasicType|) 9365) ((|MyUnivariatePolynomial| . |EuclideanDomain|) 9341) ((|Table| . |KeyedDictionary|) 9320) ((|U8Vector| . |BasicType|) T) ((|SplittingTree| . |SetCategory|) T) ((|HashTable| . |SetCategory|) T) ((|SimpleAlgebraicExtension| . |PrincipalIdealDomain|) 9254) ((|RadixExpansion| . |OrderedAbelianSemiGroup|) T) ((|HashTable| . |KeyedDictionary|) 9233) ((|DirectProductModule| . |OrderedCancellationAbelianMonoid|) 9157) ((|DirectProductModule| . |OrderedAbelianMonoid|) 9081) ((|DirectProductMatrixModule| . |OrderedCancellationAbelianMonoid|) 9005) ((|AlgebraicFunctionField| . |StepThrough|) NIL) ((|DirectProductMatrixModule| . |OrderedAbelianMonoid|) 8929) ((|RadixExpansion| . |OrderedAbelianGroup|) T) ((|RadixExpansion| . |LeftOreRing|) T) ((|RadixExpansion| . |Monoid|) T) ((|Partition| . |OrderedAbelianSemiGroup|) T) ((|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| . |SetCategory|) T) ((|PartialFraction| . |LeftOreRing|) T) ((|PartialFraction| . |Monoid|) T) ((|PrimeField| . |SetCategory|) T) ((|PAdicRationalConstructor| . |EntireRing|) T) ((|ArrayStack| . |HomogeneousAggregate|) 8913) ((|HexadecimalExpansion| . |PartialDifferentialRing|) NIL) ((|PseudoAlgebraicClosureOfFiniteField| . |CommutativeRing|) T) ((|DoubleFloat| . |RightModule|) 8867) ((|OnePointCompletion| . |SemiGroup|) 8837) ((|DecimalExpansion| . |PartialDifferentialRing|) NIL) ((|NeitherSparseOrDensePowerSeries| . |CommutativeRing|) T) ((|OneDimensionalArray| . |SetCategory|) 8774) ((|InnerIndexedTwoDimensionalArray| . |SetCategory|) 8744) ((|IndexedFlexibleArray| . |SetCategory|) 8681) ((|IndexedTwoDimensionalArray| . |SetCategory|) 8651) ((|IndexedOneDimensionalArray| . |SetCategory|) 8588) ((|InnerPAdicInteger| . |BasicType|) T) ((|Integer| . |BasicType|) T) ((|InnerAlgebraicNumber| . |BasicType|) T) ((|GeneralUnivariatePowerSeries| . |CommutativeRing|) 8494) ((|FiniteFieldExtension| . |PrincipalIdealDomain|) T) ((|FiniteFieldNormalBasisExtension| . |PrincipalIdealDomain|) T) ((|FiniteFieldCyclicGroupExtension| . |PrincipalIdealDomain|) T) ((|DoubleFloat| . |BiModule|) 8421) ((|OnePointCompletion| . |AbelianMonoid|) 8356) ((|FourierSeries| . |Monoid|) T) ((|BinaryExpansion| . |PrincipalIdealDomain|) T) ((|AlgebraicFunctionField| . |Algebra|) 8284) ((|BinaryExpansion| . |OrderedIntegralDomain|) T) ((|InnerPrimeField| . |FiniteFieldCategory|) T) ((|InnerFiniteField| . |FiniteFieldCategory|) T) ((|UnivariateLaurentSeriesConstructor| . |InnerEvalable|) 8115) ((|Expression| . |GcdDomain|) 8082) ((|ExponentialExpansion| . |GcdDomain|) T) ((|U16Matrix| . |Aggregate|) T) ((|Operator| . |Eltable|) 8061) ((|FortranExpression| . |CancellationAbelianMonoid|) T) ((|ContinuedFraction| . |CancellationAbelianMonoid|) T) ((|Equation| . |AbelianSemiGroup|) 7861) ((|Equation| . |AbelianGroup|) 7695) ((|AssociationList| . |TableAggregate|) 7674) ((|Asp24| . |CoercibleTo|) 7648) ((|Pattern| . |CoercibleTo|) 7622) ((|IndexedVector| . |InnerEvalable|) 7541) ((|AssociationList| . |BagAggregate|) 7483) ((|Set| . |FiniteSetAggregate|) 7467) ((|Set| . |Finite|) 7442) ((|RoutinesTable| . |Type|) T) ((|RomanNumeral| . |RightModule|) 7429) ((|Polynomial| . |RightModule|) 7186) ((|HomogeneousDistributedMultivariatePolynomial| . |RightModule|) 6943) ((|LiePolynomial| . |Module|) 6927) ((|RomanNumeral| . |BiModule|) 6912) ((|Polynomial| . |BiModule|) 6637) ((|Pi| . |Field|) T) ((|FiniteFieldExtensionByPolynomial| . |Module|) 6578) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |Module|) 6519) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |Module|) 6460) ((|DifferentialSparseMultivariatePolynomial| . |Module|) 6223) ((|DistributedMultivariatePolynomial| . |Module|) 5986) ((|TwoDimensionalViewport| . |BasicType|) T) ((|Vector| . |BasicType|) 5923) ((|Point| . |LinearAggregate|) 5907) ((|UnivariateTaylorSeries| . |LeftModule|) 5804) ((|HomogeneousDistributedMultivariatePolynomial| . |BiModule|) 5529) ((|UnivariatePuiseuxSeries| . |LeftModule|) 5398) ((|UnivariateLaurentSeries| . |LeftModule|) 5200) ((|UnivariateLaurentSeries| . |PolynomialFactorizationExplicit|) NIL) ((|Point| . |FiniteLinearAggregate|) 5184) ((|UnivariateFormalPowerSeries| . |LeftModule|) 5081) ((|Asp35| . |CoercibleTo|) 5055) ((|PolynomialRing| . |AbelianMonoidRing|) 5034) ((|LocalAlgebra| . |SemiGroup|) T) ((|Mapping| . |SetCategory|) T) ((|MathMLFormat| . |BasicType|) T) ((|MachineFloat| . |BasicType|) T) ((|TextFile| . |CoercibleTo|) 5008) ((|SequentialDifferentialVariable| . |CoercibleTo|) 4982) ((|RewriteRule| . |CoercibleTo|) 4956) ((|PrimeField| . |Module|) 4910) ((|BinaryTournament| . |HomogeneousAggregate|) 4894) ((|NeitherSparseOrDensePowerSeries| . |InnerEvalable|) 4676) ((|LocalAlgebra| . |AbelianMonoid|) T) ((|FreeNilpotentLie| . |AbelianMonoid|) T) ((|KeyedAccessFile| . |CoercibleTo|) 4650) ((|Asp80| . |Type|) T) ((|KeyedAccessFile| . |ConvertibleTo|) NIL) ((|GeneralSparseTable| . |ConvertibleTo|) NIL) ((|GeneralSparseTable| . |CoercibleTo|) 4624) ((|FiniteFieldNormalBasis| . |AbelianSemiGroup|) T) ((|FiniteFieldNormalBasis| . |AbelianGroup|) T) ((|DoubleFloatVector| . |HomogeneousAggregate|) 4597) ((|BinaryTree| . |Evalable|) 4521) ((|IndexedDirectProductOrderedAbelianMonoidSup| . |SetCategory|) T) ((|IndexedDirectProductAbelianGroup| . |SetCategory|) T) ((|ComplexDoubleFloatVector| . |HomogeneousAggregate|) 4482) ((|BinarySearchTree| . |Evalable|) 4406) ((|InnerTaylorSeries| . |LeftModule|) 4393) ((|DoubleFloatMatrix| . |TwoDimensionalArrayCategory|) 4322) ((|ComplexDoubleFloatMatrix| . |TwoDimensionalArrayCategory|) 4225) ((|DoubleFloat| . |Ring|) T) ((|InnerSparseUnivariatePowerSeries| . |LeftModule|) 4122) ((|U8Vector| . |Evalable|) NIL) ((|Float| . |RadicalCategory|) T) ((|DoubleFloat| . |DivisionRing|) T) ((|DoubleFloat| . |DifferentialRing|) T) ((|SparseUnivariatePolynomialExpressions| . |BasicType|) T) ((|PrimitiveArray| . |ConvertibleTo|) 4058) ((|PrimitiveArray| . |CoercibleTo|) 3976) ((|PAdicInteger| . |Algebra|) 3963) ((|UnivariatePuiseuxSeriesConstructor| . |EntireRing|) 3902) ((|UnivariateLaurentSeriesConstructor| . |EntireRing|) 3841) ((|SingleInteger| . |GcdDomain|) T) ((|IndexCard| . |OrderedSet|) T) ((|Expression| . |SpecialFunctionCategory|) 3808) ((|Quaternion| . |CharacteristicZero|) 3771) ((|Quaternion| . |CharacteristicNonZero|) 3731) ((|MyExpression| . |CombinatorialOpsCategory|) T) ((|MyExpression| . |CombinatorialFunctionCategory|) T) ((|InnerAlgebraicNumber| . |Evalable|) 3718) ((|EqTable| . |TableAggregate|) 3697) ((|Pi| . |SemiGroup|) T) ((|PAdicRational| . |RightModule|) 3621) ((|LaurentPolynomial| . |BasicType|) T) ((|Tree| . |HomogeneousAggregate|) 3605) ((|DirectProductModule| . |Finite|) 3580) ((|DirectProductMatrixModule| . |Finite|) 3555) ((|SparseUnivariatePolynomialExpressions| . |ElementaryFunctionCategory|) 3506) ((|RomanNumeral| . |Ring|) T) ((|EqTable| . |BagAggregate|) 3448) ((|BasicStochasticDifferential| . |BasicType|) T) ((|BalancedPAdicRational| . |BasicType|) T) ((|AffineSpace| . |SetCategoryWithDegree|) T) ((|Polynomial| . |Ring|) T) ((|PAdicRational| . |BiModule|) 3323) ((|Pi| . |AbelianMonoid|) T) ((|HomogeneousDistributedMultivariatePolynomial| . |Ring|) T) ((|RomanNumeral| . |DifferentialRing|) T) ((|Polynomial| . |FiniteAbelianMonoidRing|) 3275) ((|HomogeneousDistributedMultivariatePolynomial| . |FiniteAbelianMonoidRing|) 3196) ((|FiniteFieldExtensionByPolynomial| . |CommutativeRing|) T) ((|FiniteFieldNormalBasisExtensionByPolynomial| . |CommutativeRing|) T) ((|FiniteFieldCyclicGroupExtensionByPolynomial| . |CommutativeRing|) T) ((|DifferentialSparseMultivariatePolynomial| . |CommutativeRing|) 3049) ((|DistributedMultivariatePolynomial| . |CommutativeRing|) 2902) ((|PolynomialRing| . |RetractableTo|) 2746) ((|MonoidRing| . |RetractableTo|) 2717) ((|SExpressionOf| . |BasicType|) T) ((|SegmentBinding| . |CoercibleTo|) 2668) ((|ResidueRing| . |CoercibleTo|) 2642) ((|UnivariatePuiseuxSeries| . |LeftOreRing|) 2618) ((|UnivariateLaurentSeries| . |LeftOreRing|) 2594) ((|UnivariateTaylorSeriesCZero| . |PowerSeriesCategory|) 2529) ((|UnivariateTaylorSeries| . |Monoid|) T) ((|UnivariatePuiseuxSeries| . |Monoid|) T) ((|UnivariateLaurentSeries| . |Monoid|) T) ((|UnivariateLaurentSeries| . |OrderedAbelianGroup|) NIL) ((|UnivariateLaurentSeries| . |OrderedAbelianSemiGroup|) NIL) ((|PseudoAlgebraicClosureOfFiniteField| . |EntireRing|) T) ((|Complex| . |RightModule|) 2411) ((|PrimeField| . |CommutativeRing|) T) ((|NeitherSparseOrDensePowerSeries| . |EntireRing|) T) ((|UnivariateFormalPowerSeries| . |Monoid|) T) ((|WuWenTsunTriangularSet| . |Collection|) 2395) ((|RadicalFunctionField| . |FunctionFieldCategory|) 2369) ((|Queue| . |InnerEvalable|) 2288) ((|OrderedCompletion| . |OrderedSet|) 2258) ((|Integer| . |StepThrough|) T) ((|GeneralUnivariatePowerSeries| . |EntireRing|) 2197) ((|InnerTaylorSeries| . |Monoid|) T) ((|FreeGroup| . |CoercibleTo|) 2171) ((|FreeAbelianGroup| . |CoercibleTo|) 2145) ((|Factored| . |RetractableTo|) 1989) ((|InnerSparseUnivariatePowerSeries| . |Monoid|) T) ((|Fraction| . |OrderedSet|) 1916) ((|Complex| . |BiModule|) 1766) ((|PseudoAlgebraicClosureOfRationalNumber| . |Rng|) T) ((|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| . |Rng|) T) ((|OnePointCompletion| . |CancellationAbelianMonoid|) 1701) ((|Multiset| . |Collection|) 1685) ((|Vector| . |Evalable|) 1609) ((|HexadecimalExpansion| . |EuclideanDomain|) T) ((|Float| . |CoercibleTo|) 1559) ((|IndexedList| . |RecursiveAggregate|) 1543) ((|Float| . |ConvertibleTo|) 1427) ((|DecimalExpansion| . |EuclideanDomain|) T) ((|CharacterClass| . |Collection|) 1402) ((|ModuleOperator| . |Eltable|) 1381) ((|SparseUnivariatePolynomialExpressions| . |Evalable|) 1368) ((|HexadecimalExpansion| . |RealConstant|) T) ((|InnerPAdicInteger| . |Algebra|) 1355) ((|Integer| . |Algebra|) 1342) ((|InnerAlgebraicNumber| . |Algebra|) 1296) ((|DoubleFloatVector| . |Eltable|) 1257) ((|ComplexDoubleFloatVector| . |Eltable|) 1206) ((|DecimalExpansion| . |RealConstant|) T) ((|PAdicRational| . |Ring|) T) ((|Operator| . |CoercibleTo|) 1180) ((|OppositeMonogenicLinearOperator| . |CoercibleTo|) 1154) ((|OpenMathError| . |CoercibleTo|) 1128) ((|OrderlyDifferentialPolynomial| . |PolynomialFactorizationExplicit|) 1078) ((|XRecursivePolynomial| . |SemiGroup|) T) ((|UnivariatePolynomial| . |RightModule|) 812) ((|UnivariateSkewPolynomial| . |RightModule|) 796) ((|PAdicRational| . |DivisionRing|) T) ((|PAdicRational| . |DifferentialRing|) NIL) ((|Matrix| . |Type|) T) ((|XRecursivePolynomial| . |AbelianMonoid|) T) ((|OrderlyDifferentialPolynomial| . |LeftModule|) 693) ((|InnerTable| . |Type|) T) ((|Factored| . |FullyEvalableOver|) 677) ((|Interval| . |RightModule|) 664) ((|UnivariatePolynomial| . |BiModule|) 366) ((|MachineInteger| . |LinearlyExplicitRingOver|) 343) ((|UnivariateSkewPolynomial| . |BiModule|) 322) ((|FreeModule1| . |AbelianMonoid|) T) ((|Table| . |InnerEvalable|) 30)) 
\ No newline at end of file
diff --git a/src/share/algebra/dependents.daase/index.kaf b/src/share/algebra/dependents.daase/index.kaf
index 426e4e3..24e027f 100644
--- a/src/share/algebra/dependents.daase/index.kaf
+++ b/src/share/algebra/dependents.daase/index.kaf
@@ -1,4 +1,4 @@
-77354               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
+77560               (|AbelianGroup&| |FourierSeries| |FreeAbelianGroup| |IndexedDirectProductAbelianGroup| |QuadraticForm|)
 (|AbelianMonoid&| |CardinalNumber| |EuclideanModularRing| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IndexedDirectProductAbelianMonoid| |ListMonoidOps| |ModularField| |ModularRing| |RecurrenceOperator|)
 (|AbelianMonoidRing&| |FractionFreeFastGaussian|)
 (|AbelianSemiGroup&| |Color| |IncrementingMaps| |PositiveInteger|)
@@ -26,7 +26,7 @@
 (|FreeAbelianMonoidCategory| |InnerFreeAbelianMonoid|)
 (|CharacterClass|)
 (|AlgebraicNumber| |BalancedFactorisation| |ConstantLODE| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |FullPartialFractionExpansion| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |GenusZeroIntegration| |GroebnerFactorizationPackage| |InfiniteProductCharacteristicZero| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerMultFact| |InternalRationalUnivariateRepresentationPackage| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LinearOrdinaryDifferentialOperatorFactorizer| |MRationalFactorize| |MachineFloat| |MultivariateFactorize| |NonLinearFirstOrderODESolver| |ODEIntegration| |ParametricLinearEquations| |PartialFractionPackage| |Pi| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |PureAlgebraicIntegration| |PureAlgebraicLODE| |RadicalSolvePackage| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalIntegration| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtensionAlgFactor| |StreamInfiniteProduct| |TransSolvePackage| |TranscendentalRischDE| |TranscendentalRischDESystem| |UnivariatePolynomialDecompositionPackage| |ZeroDimensionalSolvePackage|)
-(|AssociatedJordanAlgebra| |AssociatedLieAlgebra| |Float| |FortranScalarType| |InfiniteTuple| |LieSquareMatrix| |MakeCachableSet| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Pi| |QuasiAlgebraicSet| |QueryEquation| |RectangularMatrix| |SquareMatrix| |Switch| |SymbolTable| |TheSymbolTable| |Tuple| |Variable|)
+(|AssociatedJordanAlgebra| |AssociatedLieAlgebra| |Cell| |Float| |FortranScalarType| |InfiniteTuple| |LieSquareMatrix| |MakeCachableSet| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Pi| |QuasiAlgebraicSet| |QueryEquation| |RectangularMatrix| |SimpleCell| |SquareMatrix| |Switch| |SymbolTable| |TheSymbolTable| |Tuple| |Variable|)
 (|Collection&|)
 (|FunctionSpaceSum| |Guess| |MyExpression| |RecurrenceOperator|)
 (|Algebra| |Algebra&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |CartesianTensor| |CartesianTensorFunctions2| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |CoerceVectorMatrixPackage| |Complex| |ComplexCategory| |ComplexCategory&| |ComplexFunctions2| |ComplexPattern| |ComplexPatternMatch| |EuclideanModularRing| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra| |FiniteRankNonAssociativeAlgebra&| |FourierSeries| |FramedAlgebra| |FramedAlgebra&| |FramedNonAssociativeAlgebra| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeLieAlgebra| |FreeNilpotentLie| |GeneralModulePolynomial| |GenericNonAssociativeAlgebra| |GradedAlgebra| |GradedAlgebra&| |GradedModule| |GradedModule&| |IntegerMod| |LieAlgebra| |LieAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LocalAlgebra| |Localize| |MatrixLinearAlgebraFunctions| |ModularField| |ModularRing| |Module| |Module&| |MonogenicAlgebra| |MonogenicAlgebra&| |NonAssociativeAlgebra| |NonAssociativeAlgebra&| |NumberTheoreticPolynomialFunctions| |Octonion| |OctonionCategory| |OctonionCategory&| |OctonionCategoryFunctions2| |OrthogonalPolynomialFunctions| |Quaternion| |QuaternionCategory| |QuaternionCategory&| |QuaternionCategoryFunctions2| |ResidueRing| |SimpleAlgebraicExtension| |XPBWPolynomial|)
@@ -96,7 +96,7 @@
 (|Factored| |FullyRetractableTo&| |LaurentPolynomial| |Octonion| |OnePointCompletion| |OrderedCompletion| |RealClosure|)
 (|AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |DoubleResultantPackage| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |HyperellipticFiniteDivisor| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PureAlgebraicLODE| |RadicalFunctionField| |ReducedDivisor|)
 (|AlgebraicFunction| |AlgebraicIntegrate| |AlgebraicIntegration| |ApplyRules| |CombinatorialFunction| |ComplexTrigonometricManipulations| |ElementaryFunction| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |Expression| |ExpressionSolve| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenerateUnivariatePowerSeries| |GenusZeroIntegration| |Guess| |InnerTrigonometricManipulations| |IntegrationTools| |LiouvillianFunction| |MyExpression| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |RecurrenceOperator| |RewriteRule| |Ruleset| |SimpleFortranProgram| |TopLevelDrawFunctionsForAlgebraicCurves| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
-(|BalancedFactorisation| |DefiniteIntegrationTools| |EigenPackage| |ElementaryFunctionSign| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FGLMIfCanPackage| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GcdDomain&| |GenusZeroIntegration| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |InnerNumericFloatSolvePackage| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |LazardSetSolvingPackage| |LexTriangularPackage| |LinGroebnerPackage| |NormInMonogenicAlgebra| |NormalizationPackage| |NormalizedTriangularSetCategory| |PatternMatchIntegration| |PolyGroebner| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |QuasiComponentPackage| |RationalFunctionLimitPackage| |RationalFunctionSign| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
+(|BalancedFactorisation| |CylindricalAlgebraicDecompositionUtilities| |DefiniteIntegrationTools| |EigenPackage| |ElementaryFunctionSign| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |ExponentialExpansion| |ExpressionToUnivariatePowerSeries| |FGLMIfCanPackage| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |GcdDomain&| |GenusZeroIntegration| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |InnerNumericFloatSolvePackage| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |LazardSetSolvingPackage| |LexTriangularPackage| |LinGroebnerPackage| |NormInMonogenicAlgebra| |NormalizationPackage| |NormalizedTriangularSetCategory| |PatternMatchIntegration| |PolyGroebner| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PureAlgebraicIntegration| |QuasiAlgebraicSet| |QuasiComponentPackage| |RationalFunctionLimitPackage| |RationalFunctionSign| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |SquareFreeNormalizedTriangularSetCategory| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetCategory| |SquareFreeRegularTriangularSetGcdPackage| |SupFractionFactorizer| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|CartesianTensor| |GradedAlgebra&|)
 (|CartesianTensor| |GradedModule&|)
 (|Automorphism| |FractionalIdeal| |FreeGroup| |Group&| |LieExponentials| |MoebiusTransform| |NottinghamGroup|)
@@ -167,7 +167,7 @@
 (|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |DesingTreePackage| |DistributedMultivariatePolynomial| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |HomogeneousDistributedMultivariatePolynomial| |InfinitlyClosePoint| |InfinitlyClosePointCategory| |InterpolateFormsPackage| |IntersectionDivisorPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |ParametrizationPackage| |ProjectiveAlgebraicSetPackage| |RegularChain|)
 (|OrderlyDifferentialPolynomial|)
 (|d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType|)
-(|FortranScalarType| |InfiniteTuple| |InputForm| |QuasiAlgebraicSet| |QueryEquation| |SExpression| |Switch| |SymbolTable| |TheSymbolTable|)
+(|Cell| |FortranScalarType| |InfiniteTuple| |InputForm| |QuasiAlgebraicSet| |QueryEquation| |SExpression| |SimpleCell| |Switch| |SymbolTable| |TheSymbolTable|)
 (|PAdicRational|)
 (|BalancedPAdicInteger| |InnerPAdicInteger| |PAdicInteger| |PAdicRationalConstructor|)
 (|d03eefAnnaType| |d03fafAnnaType|)
@@ -209,7 +209,7 @@
 (|Queue|)
 (|BalancedPAdicRational| |BinaryExpansion| |CommonDenominator| |DecimalExpansion| |ExponentialExpansion| |Fraction| |FractionalIdeal| |FractionalIdealFunctions2| |FramedModule| |HexadecimalExpansion| |InnerCommonDenominator| |InnerMatrixQuotientFieldFunctions| |MatrixCommonDenominator| |PAdicRational| |PAdicRationalConstructor| |PatternMatchQuotientFieldCategory| |QuotientFieldCategory&| |QuotientFieldCategoryFunctions2| |RadixExpansion| |UnivariatePolynomialCommonDenominator|)
 (|CoordinateSystems| |ElementaryFunction| |InnerTrigonometricManipulations| |LiouvillianFunction| |RadicalCategory&|)
-(|RealClosedField&| |RealClosure|)
+(|Cell| |CylindricalAlgebraicDecompositionPackage| |RealClosedField&| |RealClosure| |SimpleCell|)
 (|AlgebraicNumber| |InnerAlgebraicNumber| |Pi| |RealClosure| |ZeroDimensionalSolvePackage|)
 (|RealNumberSystem&|)
 (|RealRootCharacterizationCategory&| |RightOpenIntervalRootCharacterization|)
@@ -262,7 +262,7 @@
 (|UnivariatePuiseuxSeries|)
 (|ElementaryFunctionsUnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory| |UnivariatePuiseuxSeriesConstructorCategory&|)
 (|ElementaryFunctionsUnivariateLaurentSeries| |SparseUnivariateLaurentSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&|)
-(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MyUnivariatePolynomial| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
+(|AlgFactor| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |BalancedFactorisation| |BezoutMatrix| |BoundIntegerRoots| |BrillhartTests| |ChangeOfVariable| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |CommuteUnivariatePolynomialCategory| |ComplexFactorization| |ComplexRootFindingPackage| |ComplexRootPackage| |CylindricalAlgebraicDecompositionUtilities| |DistinctDegreeFactorize| |DoubleResultantPackage| |EuclideanModularRing| |FindOrderFinite| |FiniteDivisor| |FiniteDivisorCategory| |FiniteDivisorCategory&| |FiniteDivisorFunctions2| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteRankAlgebra| |FiniteRankAlgebra&| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra| |FramedAlgebra&| |FramedModule| |FullPartialFractionExpansion| |FunctionFieldCategory| |FunctionFieldCategory&| |FunctionFieldCategoryFunctions2| |FunctionFieldIntegralBasis| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GenExEuclid| |GeneralHenselPackage| |HeuGcd| |HyperellipticFiniteDivisor| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerModularGcd| |InnerPolySign| |IntegralBasisPolynomialTools| |IntegralBasisTools| |Kovacic| |LaurentPolynomial| |LinearOrdinaryDifferentialOperatorFactorizer| |ModMonic| |ModularDistinctDegreeFactorizer| |MonogenicAlgebra| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MyUnivariatePolynomial| |NPCoef| |NewSparseUnivariatePolynomial| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberFieldIntegralBasis| |PAdicWildFunctionFieldIntegralBasis| |PadeApproximants| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursionUnivariate| |PolynomialInterpolationAlgorithms| |PolynomialSolveByFormulas| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoRemainderSequence| |PureAlgebraicLODE| |RadicalFunctionField| |RationalFactorize| |RationalFunctionFactor| |RationalIntegration| |RationalLODE| |RationalRicDE| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory| |RealRootCharacterizationCategory&| |RealZeroPackage| |RealZeroPackageQ| |ReduceLODE| |ReducedDivisor| |RightOpenIntervalRootCharacterization| |SAERationalFunctionAlgFactor| |SimpleAlgebraicExtension| |SimpleAlgebraicExtensionAlgFactor| |SimpleCell| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SubResultantPackage| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalRischDE| |TranscendentalRischDESystem| |UTSodetools| |UnivariateFactorize| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |WildFunctionFieldIntegralBasis|)
 (|FunctionSpaceToUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |UnivariatePowerSeriesCategory&|)
 (|ExponentialExpansion| |UnivariatePuiseuxSeriesWithExponentialSingularity|)
 (|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries|)
@@ -276,4 +276,4 @@
 (|CliffordAlgebra| |VectorSpace&|)
 (|XPolynomialRing|)
 (|XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XRecursivePolynomial|)
-(("XPolynomialsCat" 0 77251) ("XAlgebra" 0 77231) ("VectorSpace" 0 77196) ("VectorCategory" 0 77104) ("Vector" 0 76916) ("UnivariateTaylorSeriesCategory" 0 76322) ("UnivariateTaylorSeries" 0 76268) ("UnivariateSkewPolynomialCategory" 0 76100) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 76075) ("UnivariatePuiseuxSeriesConstructorCategory" 0 75887) ("UnivariatePuiseuxSeriesCategory" 0 75815) ("UnivariatePuiseuxSeries" 0 75738) ("UnivariatePowerSeriesCategory" 0 75629) ("UnivariatePolynomialCategory" 0 72569) ("UnivariateLaurentSeriesConstructorCategory" 0 72381) ("UnivariateLaurentSeriesCategory" 0 72206) ("UnivariateLaurentSeries" 0 72178) ("UniqueFactorizationDomain" 0 72022) ("UnaryRecursiveAggregate" 0 71993) ("U8Vector" 0 71980) ("U32Vector" 0 71966) ("U16Vector" 0 71952) ("Type" 0 69542) ("TwoDimensionalArrayCategory" 0 69424) ("TrigonometricFunctionCategory" 0 69389) ("TriangularSetCategory" 0 69314) ("TranscendentalFunctionCategory" 0 68160) ("ThreeSpaceCategory" 0 68145) ("TableAggregate" 0 67980) ("SymbolTable" 0 67961) ("Symbol" 0 65536) ("StringCategory" 0 65525) ("StringAggregate" 0 65488) ("String" 0 65342) ("StreamAggregate" 0 65294) ("StepThrough" 0 65279) ("StackAggregate" 0 65256) ("SquareMatrixCategory" 0 65169) ("SquareMatrix" 0 65100) ("SquareFreeRegularTriangularSetCategory" 0 64946) ("SplittingNode" 0 64928) ("SpecialFunctionCategory" 0 64886) ("SparseUnivariateTaylorSeries" 0 64820) ("SparseUnivariatePolynomialExpressions" 0 64786) ("SparseUnivariatePolynomial" 0 64620) ("SparseUnivariateLaurentSeries" 0 64586) ("SparseMultivariatePolynomial" 0 64440) ("SingleInteger" 0 64379) ("SetCategoryWithDegree" 0 64367) ("SetCategory" 0 61268) ("SetAggregate" 0 61250) ("SequentialDifferentialVariable" 0 61213) ("SemiGroup" 0 61198) ("SegmentCategory" 0 61167) ("SExpressionCategory" 0 61123) ("SExpression" 0 61109) ("Rng" 0 61055) ("Ring" 0 56568) ("RetractableTo" 0 54265) ("RegularTriangularSetCategory" 0 53977) ("RecursivePolynomialCategory" 0 53162) ("RecursiveAggregate" 0 53115) ("RectangularMatrixCategory" 0 53026) ("RealRootCharacterizationCategory" 0 52948) ("RealNumberSystem" 0 52926) ("RealConstant" 0 52834) ("RealClosedField" 0 52799) ("RadicalCategory" 0 52681) ("QuotientFieldCategory" 0 52198) ("QueueAggregate" 0 52188) ("QuaternionCategory" 0 52120) ("Quaternion" 0 52107) ("QuadraticForm" 0 52087) ("PseudoAlgebraicClosureOfRationalNumberCategory" 0 51986) ("PseudoAlgebraicClosureOfRationalNumber" 0 51935) ("PseudoAlgebraicClosureOfFiniteFieldCategory" 0 51895) ("PseudoAlgebraicClosureOfFiniteField" 0 51674) ("PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory" 0 51557) ("ProjectiveSpaceCategory" 0 51079) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 51016) ("ProjectivePlane" 0 51003) ("PriorityQueueAggregate" 0 50994) ("PrimitiveFunctionCategory" 0 50756) ("PrimitiveArray" 0 50746) ("PrimeField" 0 50680) ("PowerSeriesCategory" 0 50655) ("PositiveInteger" 0 50185) ("PolynomialSetCategory" 0 50135) ("PolynomialFactorizationExplicit" 0 49946) ("PolynomialCategory" 0 48389) ("Polynomial" 0 48222) ("PointCategory" 0 48212) ("PoincareBirkhoffWittLyndonBasis" 0 48193) ("PlottableSpaceCurveCategory" 0 48153) ("PlottablePlaneCurveCategory" 0 48118) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 48055) ("PlacesCategory" 0 47752) ("Places" 0 47739) ("PermutationCategory" 0 47723) ("Patternable" 0 47712) ("PatternMatchable" 0 47458) ("Pattern" 0 47218) ("Partition" 0 47194) ("PartialTranscendentalFunctions" 0 47063) ("PartialDifferentialRing" 0 46910) ("PartialDifferentialEquationsSolverCategory" 0 46874) ("PAdicIntegerCategory" 0 46787) ("PAdicInteger" 0 46769) ("OutputForm" 0 46629) ("OrdinaryDifferentialEquationsSolverCategory" 0 46559) ("OrderlyDifferentialVariable" 0 46525) ("OrderedVariableList" 0 45976) ("OrderedSet" 0 40809) ("OrderedRing" 0 40333) ("OrderedMonoid" 0 40293) ("OrderedIntegralDomain" 0 40269) ("OrderedFreeMonoid" 0 40242) ("OrderedFinite" 0 40206) ("OrderedCancellationAbelianMonoid" 0 40192) ("OrderedAbelianMonoidSup" 0 38179) ("OrderedAbelianMonoid" 0 37818) ("OpenMath" 0 37736) ("OneDimensionalArrayAggregate" 0 37560) ("OneDimensionalArray" 0 37536) ("OctonionCategory" 0 37474) ("NumericalOptimizationCategory" 0 37353) ("NumericalIntegrationCategory" 0 37154) ("NonNegativeInteger" 0 35746) ("NonAssociativeRng" 0 35723) ("NonAssociativeRing" 0 35699) ("NonAssociativeAlgebra" 0 35604) ("NewSparseMultivariatePolynomial" 0 35587) ("NeitherSparseOrDensePowerSeries" 0 35456) ("MyUnivariatePolynomial" 0 35439) ("MultivariateTaylorSeriesCategory" 0 35389) ("MultisetAggregate" 0 35376) ("MultiDictionary" 0 35352) ("Monoid" 0 35148) ("MonogenicLinearOperator" 0 35079) ("MonogenicAlgebra" 0 34794) ("MonadWithUnit" 0 34775) ("Monad" 0 34764) ("Module" 0 34611) ("MatrixCategory" 0 34217) ("Matrix" 0 34095) ("MachineFloat" 0 34076) ("LyndonWord" 0 34024) ("Logic" 0 33987) ("LocalPowerSeriesCategory" 0 33653) ("ListAggregate" 0 33549) ("List" 0 32295) ("LinearlyExplicitRingOver" 0 31288) ("LinearOrdinaryDifferentialOperatorCategory" 0 30873) ("LinearAggregate" 0 30852) ("LieAlgebra" 0 30836) ("LeftModule" 0 30630) ("LeftAlgebra" 0 30586) ("LazyStreamAggregate" 0 30498) ("KeyedDictionary" 0 30477) ("Kernel" 0 30426) ("IntervalCategory" 0 30413) ("IntegralDomain" 0 28250) ("IntegerNumberSystem" 0 27988) ("Integer" 0 24886) ("InputForm" 0 24609) ("InnerPrimeField" 0 24588) ("InnerEvalable" 0 24569) ("InfinitlyClosePointCategory" 0 24382) ("IndexedVector" 0 24364) ("IndexedOneDimensionalArray" 0 24333) ("IndexedExponents" 0 24070) ("IndexedDirectProductCategory" 0 23847) ("IndexedAggregate" 0 23811) ("HyperbolicFunctionCategory" 0 23779) ("HomogeneousDirectProduct" 0 23730) ("HomogeneousAggregate" 0 23679) ("Group" 0 23568) ("GradedModule" 0 23532) ("GradedAlgebra" 0 23495) ("GcdDomain" 0 22009) ("FunctionSpace" 0 20776) ("FunctionFieldCategory" 0 20364) ("FullyRetractableTo" 0 20243) ("FullyLinearlyExplicitRingOver" 0 20208) ("FullyEvalableOver" 0 20174) ("FreeModuleCat" 0 20082) ("FreeLieAlgebra" 0 20064) ("FreeAbelianMonoidCategory" 0 19998) ("FramedNonAssociativeAlgebra" 0 19823) ("FramedAlgebra" 0 19633) ("Fraction" 0 18254) ("FortranVectorFunctionCategory" 0 18158) ("FortranVectorCategory" 0 18149) ("FortranScalarType" 0 18130) ("FortranProgramCategory" 0 18064) ("FortranMatrixFunctionCategory" 0 18030) ("FortranMatrixCategory" 0 17996) ("FortranMachineTypeCategory" 0 17925) ("FortranFunctionCategory" 0 17886) ("FloatingPointSystem" 0 17731) ("Float" 0 17609) ("FiniteSetAggregate" 0 17531) ("FiniteRankNonAssociativeAlgebra" 0 17494) ("FiniteRankAlgebra" 0 17471) ("FiniteLinearAggregate" 0 16933) ("FiniteFieldCategory" 0 15770) ("FiniteDivisorCategory" 0 15698) ("FiniteAlgebraicExtensionField" 0 15283) ("FiniteAbelianMonoidRing" 0 15014) ("Finite" 0 14835) ("FileNameCategory" 0 14822) ("FileName" 0 14753) ("FileCategory" 0 14684) ("FieldOfPrimeCharacteristic" 0 14620) ("Field" 0 11510) ("ExtensionField" 0 11452) ("ExtensibleLinearAggregate" 0 11382) ("ExpressionSpace" 0 11219) ("Expression" 0 11176) ("ExponentialOfUnivariatePuiseuxSeries" 0 11122) ("Evalable" 0 11108) ("EuclideanDomain" 0 9950) ("Equation" 0 9934) ("EltableAggregate" 0 9912) ("Eltable" 0 9789) ("ElementaryFunctionCategory" 0 9721) ("DoubleFloatVector" 0 9699) ("DoubleFloat" 0 9531) ("DivisorCategory" 0 9350) ("Divisor" 0 9276) ("DivisionRing" 0 9258) ("DistributedMultivariatePolynomial" 0 9184) ("DirectProductCategory" 0 8366) ("DirectProduct" 0 8175) ("DifferentialVariableCategory" 0 7968) ("DifferentialRing" 0 7780) ("DifferentialPolynomialCategory" 0 7634) ("DifferentialExtension" 0 7576) ("DictionaryOperations" 0 7550) ("Dictionary" 0 7534) ("DesingTreeCategory" 0 7428) ("DequeueAggregate" 0 7416) ("ConvertibleTo" 0 6595) ("ComplexDoubleFloatVector" 0 6566) ("ComplexCategory" 0 6433) ("Complex" 0 6194) ("CommutativeRing" 0 4843) ("CombinatorialOpsCategory" 0 4778) ("Collection" 0 4762) ("CoercibleTo" 0 4430) ("CharacteristicZero" 0 3086) ("Character" 0 3067) ("CancellationAbelianMonoid" 0 3012) ("CachableSet" 0 2969) ("Boolean" 0 2881) ("BlowUpMethodCategory" 0 2512) ("BitAggregate" 0 2473) ("BinaryTreeCategory" 0 2377) ("BinaryRecursiveAggregate" 0 2333) ("BiModule" 0 2291) ("BasicType" 0 2276) ("BasicOperator" 0 2246) ("BalancedPAdicInteger" 0 2220) ("BagAggregate" 0 2202) ("Automorphism" 0 2140) ("AssociationListAggregate" 0 2120) ("ArcTrigonometricFunctionCategory" 0 2082) ("Any" 0 2045) ("AlgebraicallyClosedFunctionSpace" 0 1680) ("AlgebraicallyClosedField" 0 1017) ("AlgebraicNumber" 0 983) ("Algebra" 0 596) ("Aggregate" 0 549) ("AffineSpaceCategory" 0 466) ("AbelianSemiGroup" 0 399) ("AbelianMonoidRing" 0 349) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
+(("XPolynomialsCat" 0 77457) ("XAlgebra" 0 77437) ("VectorSpace" 0 77402) ("VectorCategory" 0 77310) ("Vector" 0 77122) ("UnivariateTaylorSeriesCategory" 0 76528) ("UnivariateTaylorSeries" 0 76474) ("UnivariateSkewPolynomialCategory" 0 76306) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 76281) ("UnivariatePuiseuxSeriesConstructorCategory" 0 76093) ("UnivariatePuiseuxSeriesCategory" 0 76021) ("UnivariatePuiseuxSeries" 0 75944) ("UnivariatePowerSeriesCategory" 0 75835) ("UnivariatePolynomialCategory" 0 72717) ("UnivariateLaurentSeriesConstructorCategory" 0 72529) ("UnivariateLaurentSeriesCategory" 0 72354) ("UnivariateLaurentSeries" 0 72326) ("UniqueFactorizationDomain" 0 72170) ("UnaryRecursiveAggregate" 0 72141) ("U8Vector" 0 72128) ("U32Vector" 0 72114) ("U16Vector" 0 72100) ("Type" 0 69690) ("TwoDimensionalArrayCategory" 0 69572) ("TrigonometricFunctionCategory" 0 69537) ("TriangularSetCategory" 0 69462) ("TranscendentalFunctionCategory" 0 68308) ("ThreeSpaceCategory" 0 68293) ("TableAggregate" 0 68128) ("SymbolTable" 0 68109) ("Symbol" 0 65684) ("StringCategory" 0 65673) ("StringAggregate" 0 65636) ("String" 0 65490) ("StreamAggregate" 0 65442) ("StepThrough" 0 65427) ("StackAggregate" 0 65404) ("SquareMatrixCategory" 0 65317) ("SquareMatrix" 0 65248) ("SquareFreeRegularTriangularSetCategory" 0 65094) ("SplittingNode" 0 65076) ("SpecialFunctionCategory" 0 65034) ("SparseUnivariateTaylorSeries" 0 64968) ("SparseUnivariatePolynomialExpressions" 0 64934) ("SparseUnivariatePolynomial" 0 64768) ("SparseUnivariateLaurentSeries" 0 64734) ("SparseMultivariatePolynomial" 0 64588) ("SingleInteger" 0 64527) ("SetCategoryWithDegree" 0 64515) ("SetCategory" 0 61416) ("SetAggregate" 0 61398) ("SequentialDifferentialVariable" 0 61361) ("SemiGroup" 0 61346) ("SegmentCategory" 0 61315) ("SExpressionCategory" 0 61271) ("SExpression" 0 61257) ("Rng" 0 61203) ("Ring" 0 56716) ("RetractableTo" 0 54413) ("RegularTriangularSetCategory" 0 54125) ("RecursivePolynomialCategory" 0 53310) ("RecursiveAggregate" 0 53263) ("RectangularMatrixCategory" 0 53174) ("RealRootCharacterizationCategory" 0 53096) ("RealNumberSystem" 0 53074) ("RealConstant" 0 52982) ("RealClosedField" 0 52884) ("RadicalCategory" 0 52766) ("QuotientFieldCategory" 0 52283) ("QueueAggregate" 0 52273) ("QuaternionCategory" 0 52205) ("Quaternion" 0 52192) ("QuadraticForm" 0 52172) ("PseudoAlgebraicClosureOfRationalNumberCategory" 0 52071) ("PseudoAlgebraicClosureOfRationalNumber" 0 52020) ("PseudoAlgebraicClosureOfFiniteFieldCategory" 0 51980) ("PseudoAlgebraicClosureOfFiniteField" 0 51759) ("PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory" 0 51642) ("ProjectiveSpaceCategory" 0 51164) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 51101) ("ProjectivePlane" 0 51088) ("PriorityQueueAggregate" 0 51079) ("PrimitiveFunctionCategory" 0 50841) ("PrimitiveArray" 0 50831) ("PrimeField" 0 50765) ("PowerSeriesCategory" 0 50740) ("PositiveInteger" 0 50270) ("PolynomialSetCategory" 0 50220) ("PolynomialFactorizationExplicit" 0 50031) ("PolynomialCategory" 0 48474) ("Polynomial" 0 48307) ("PointCategory" 0 48297) ("PoincareBirkhoffWittLyndonBasis" 0 48278) ("PlottableSpaceCurveCategory" 0 48238) ("PlottablePlaneCurveCategory" 0 48203) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 48140) ("PlacesCategory" 0 47837) ("Places" 0 47824) ("PermutationCategory" 0 47808) ("Patternable" 0 47797) ("PatternMatchable" 0 47543) ("Pattern" 0 47303) ("Partition" 0 47279) ("PartialTranscendentalFunctions" 0 47148) ("PartialDifferentialRing" 0 46995) ("PartialDifferentialEquationsSolverCategory" 0 46959) ("PAdicIntegerCategory" 0 46872) ("PAdicInteger" 0 46854) ("OutputForm" 0 46694) ("OrdinaryDifferentialEquationsSolverCategory" 0 46624) ("OrderlyDifferentialVariable" 0 46590) ("OrderedVariableList" 0 46041) ("OrderedSet" 0 40874) ("OrderedRing" 0 40398) ("OrderedMonoid" 0 40358) ("OrderedIntegralDomain" 0 40334) ("OrderedFreeMonoid" 0 40307) ("OrderedFinite" 0 40271) ("OrderedCancellationAbelianMonoid" 0 40257) ("OrderedAbelianMonoidSup" 0 38244) ("OrderedAbelianMonoid" 0 37883) ("OpenMath" 0 37801) ("OneDimensionalArrayAggregate" 0 37625) ("OneDimensionalArray" 0 37601) ("OctonionCategory" 0 37539) ("NumericalOptimizationCategory" 0 37418) ("NumericalIntegrationCategory" 0 37219) ("NonNegativeInteger" 0 35811) ("NonAssociativeRng" 0 35788) ("NonAssociativeRing" 0 35764) ("NonAssociativeAlgebra" 0 35669) ("NewSparseMultivariatePolynomial" 0 35652) ("NeitherSparseOrDensePowerSeries" 0 35521) ("MyUnivariatePolynomial" 0 35504) ("MultivariateTaylorSeriesCategory" 0 35454) ("MultisetAggregate" 0 35441) ("MultiDictionary" 0 35417) ("Monoid" 0 35213) ("MonogenicLinearOperator" 0 35144) ("MonogenicAlgebra" 0 34859) ("MonadWithUnit" 0 34840) ("Monad" 0 34829) ("Module" 0 34676) ("MatrixCategory" 0 34282) ("Matrix" 0 34160) ("MachineFloat" 0 34141) ("LyndonWord" 0 34089) ("Logic" 0 34052) ("LocalPowerSeriesCategory" 0 33718) ("ListAggregate" 0 33614) ("List" 0 32360) ("LinearlyExplicitRingOver" 0 31353) ("LinearOrdinaryDifferentialOperatorCategory" 0 30938) ("LinearAggregate" 0 30917) ("LieAlgebra" 0 30901) ("LeftModule" 0 30695) ("LeftAlgebra" 0 30651) ("LazyStreamAggregate" 0 30563) ("KeyedDictionary" 0 30542) ("Kernel" 0 30491) ("IntervalCategory" 0 30478) ("IntegralDomain" 0 28315) ("IntegerNumberSystem" 0 28053) ("Integer" 0 24951) ("InputForm" 0 24674) ("InnerPrimeField" 0 24653) ("InnerEvalable" 0 24634) ("InfinitlyClosePointCategory" 0 24447) ("IndexedVector" 0 24429) ("IndexedOneDimensionalArray" 0 24398) ("IndexedExponents" 0 24135) ("IndexedDirectProductCategory" 0 23912) ("IndexedAggregate" 0 23876) ("HyperbolicFunctionCategory" 0 23844) ("HomogeneousDirectProduct" 0 23795) ("HomogeneousAggregate" 0 23744) ("Group" 0 23633) ("GradedModule" 0 23597) ("GradedAlgebra" 0 23560) ("GcdDomain" 0 22029) ("FunctionSpace" 0 20796) ("FunctionFieldCategory" 0 20384) ("FullyRetractableTo" 0 20263) ("FullyLinearlyExplicitRingOver" 0 20228) ("FullyEvalableOver" 0 20194) ("FreeModuleCat" 0 20102) ("FreeLieAlgebra" 0 20084) ("FreeAbelianMonoidCategory" 0 20018) ("FramedNonAssociativeAlgebra" 0 19843) ("FramedAlgebra" 0 19653) ("Fraction" 0 18274) ("FortranVectorFunctionCategory" 0 18178) ("FortranVectorCategory" 0 18169) ("FortranScalarType" 0 18150) ("FortranProgramCategory" 0 18084) ("FortranMatrixFunctionCategory" 0 18050) ("FortranMatrixCategory" 0 18016) ("FortranMachineTypeCategory" 0 17945) ("FortranFunctionCategory" 0 17906) ("FloatingPointSystem" 0 17751) ("Float" 0 17629) ("FiniteSetAggregate" 0 17551) ("FiniteRankNonAssociativeAlgebra" 0 17514) ("FiniteRankAlgebra" 0 17491) ("FiniteLinearAggregate" 0 16953) ("FiniteFieldCategory" 0 15790) ("FiniteDivisorCategory" 0 15718) ("FiniteAlgebraicExtensionField" 0 15303) ("FiniteAbelianMonoidRing" 0 15034) ("Finite" 0 14855) ("FileNameCategory" 0 14842) ("FileName" 0 14773) ("FileCategory" 0 14704) ("FieldOfPrimeCharacteristic" 0 14640) ("Field" 0 11530) ("ExtensionField" 0 11472) ("ExtensibleLinearAggregate" 0 11402) ("ExpressionSpace" 0 11239) ("Expression" 0 11196) ("ExponentialOfUnivariatePuiseuxSeries" 0 11142) ("Evalable" 0 11128) ("EuclideanDomain" 0 9970) ("Equation" 0 9954) ("EltableAggregate" 0 9932) ("Eltable" 0 9809) ("ElementaryFunctionCategory" 0 9741) ("DoubleFloatVector" 0 9719) ("DoubleFloat" 0 9551) ("DivisorCategory" 0 9370) ("Divisor" 0 9296) ("DivisionRing" 0 9278) ("DistributedMultivariatePolynomial" 0 9204) ("DirectProductCategory" 0 8386) ("DirectProduct" 0 8195) ("DifferentialVariableCategory" 0 7988) ("DifferentialRing" 0 7800) ("DifferentialPolynomialCategory" 0 7654) ("DifferentialExtension" 0 7596) ("DictionaryOperations" 0 7570) ("Dictionary" 0 7554) ("DesingTreeCategory" 0 7448) ("DequeueAggregate" 0 7436) ("ConvertibleTo" 0 6615) ("ComplexDoubleFloatVector" 0 6586) ("ComplexCategory" 0 6453) ("Complex" 0 6214) ("CommutativeRing" 0 4863) ("CombinatorialOpsCategory" 0 4798) ("Collection" 0 4782) ("CoercibleTo" 0 4430) ("CharacteristicZero" 0 3086) ("Character" 0 3067) ("CancellationAbelianMonoid" 0 3012) ("CachableSet" 0 2969) ("Boolean" 0 2881) ("BlowUpMethodCategory" 0 2512) ("BitAggregate" 0 2473) ("BinaryTreeCategory" 0 2377) ("BinaryRecursiveAggregate" 0 2333) ("BiModule" 0 2291) ("BasicType" 0 2276) ("BasicOperator" 0 2246) ("BalancedPAdicInteger" 0 2220) ("BagAggregate" 0 2202) ("Automorphism" 0 2140) ("AssociationListAggregate" 0 2120) ("ArcTrigonometricFunctionCategory" 0 2082) ("Any" 0 2045) ("AlgebraicallyClosedFunctionSpace" 0 1680) ("AlgebraicallyClosedField" 0 1017) ("AlgebraicNumber" 0 983) ("Algebra" 0 596) ("Aggregate" 0 549) ("AffineSpaceCategory" 0 466) ("AbelianSemiGroup" 0 399) ("AbelianMonoidRing" 0 349) ("AbelianMonoid" 0 124) ("AbelianGroup" 0 20))
\ No newline at end of file
diff --git a/src/share/algebra/interp.daase b/src/share/algebra/interp.daase
index e23063b..2867051 100644
--- a/src/share/algebra/interp.daase
+++ b/src/share/algebra/interp.daase
@@ -1,5 +1,5 @@
 
-(5935638 . 3614189655)       
+(5947754 . 3618694789)       
 ((|sorted?| (((|Boolean|) (|Mapping| (|Boolean|) |#2| |#2|) $) 62) (((|Boolean|) $) NIL)) (|sort!| (($ (|Mapping| (|Boolean|) |#2| |#2|) $) 17) (($ $) NIL)) (|setelt| ((|#2| $ (|Integer|) |#2|) NIL) ((|#2| $ (|UniversalSegment| (|Integer|)) |#2|) 34)) (|reverse!| (($ $) 58)) (|reduce| ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2| |#2|) 40) ((|#2| (|Mapping| |#2| |#2| |#2|) $ |#2|) 38) ((|#2| (|Mapping| |#2| |#2| |#2|) $) 37)) (|position| (((|Integer|) (|Mapping| (|Boolean|) |#2|) $) 22) (((|Integer|) |#2| $) NIL) (((|Integer|) |#2| $ (|Integer|)) 70)) (|parts| (((|List| |#2|) $) 13)) (|merge| (($ (|Mapping| (|Boolean|) |#2| |#2|) $ $) 47) (($ $ $) NIL)) (|map!| (($ (|Mapping| |#2| |#2|) $) 29)) (|map| (($ (|Mapping| |#2| |#2|) $) NIL) (($ (|Mapping| |#2| |#2| |#2|) $ $) 44)) (|insert| (($ |#2| $ (|Integer|)) NIL) (($ $ $ (|Integer|)) 49)) (|find| (((|Union| |#2| "failed") (|Mapping| (|Boolean|) |#2|) $) 24)) (|every?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) 21)) (|elt| ((|#2| $ (|Integer|) |#2|) NIL) ((|#2| $ (|Integer|)) NIL) (($ $ (|UniversalSegment| (|Integer|))) 48)) (|delete| (($ $ (|Integer|)) 55) (($ $ (|UniversalSegment| (|Integer|))) 54)) (|count| (((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#2|) $) 26) (((|NonNegativeInteger|) |#2| $) NIL)) (|copyInto!| (($ $ $ (|Integer|)) 51)) (|copy| (($ $) 50)) (|construct| (($ (|List| |#2|)) 52)) (|concat| (($ $ |#2|) NIL) (($ |#2| $) NIL) (($ $ $) 63) (($ (|List| $)) 61)) (|coerce| (((|OutputForm|) $) 69)) (|any?| (((|Boolean|) (|Mapping| (|Boolean|) |#2|) $) 20)) (= (((|Boolean|) $ $) 64)) (< (((|Boolean|) $ $) 72))) 
 (((|OneDimensionalArrayAggregate&| |#1| |#2|) (CATEGORY |domain| (SIGNATURE = ((|Boolean|) |#1| |#1|)) (SIGNATURE |coerce| ((|OutputForm|) |#1|)) (SIGNATURE < ((|Boolean|) |#1| |#1|)) (SIGNATURE |sort!| (|#1| |#1|)) (SIGNATURE |sort!| (|#1| (|Mapping| (|Boolean|) |#2| |#2|) |#1|)) (SIGNATURE |reverse!| (|#1| |#1|)) (SIGNATURE |copyInto!| (|#1| |#1| |#1| (|Integer|))) (SIGNATURE |sorted?| ((|Boolean|) |#1|)) (SIGNATURE |merge| (|#1| |#1| |#1|)) (SIGNATURE |position| ((|Integer|) |#2| |#1| (|Integer|))) (SIGNATURE |position| ((|Integer|) |#2| |#1|)) (SIGNATURE |position| ((|Integer|) (|Mapping| (|Boolean|) |#2|) |#1|)) (SIGNATURE |sorted?| ((|Boolean|) (|Mapping| (|Boolean|) |#2| |#2|) |#1|)) (SIGNATURE |merge| (|#1| (|Mapping| (|Boolean|) |#2| |#2|) |#1| |#1|)) (SIGNATURE |setelt| (|#2| |#1| (|UniversalSegment| (|Integer|)) |#2|)) (SIGNATURE |insert| (|#1| |#1| |#1| (|Integer|))) (SIGNATURE |insert| (|#1| |#2| |#1| (|Integer|))) (SIGNATURE |delete| (|#1| |#1| (|UniversalSegment| (|Integer|)))) (SIGNATURE |delete| (|#1| |#1| (|Integer|))) (SIGNATURE |elt| (|#1| |#1| (|UniversalSegment| (|Integer|)))) (SIGNATURE |map| (|#1| (|Mapping| |#2| |#2| |#2|) |#1| |#1|)) (SIGNATURE |concat| (|#1| (|List| |#1|))) (SIGNATURE |concat| (|#1| |#1| |#1|)) (SIGNATURE |concat| (|#1| |#2| |#1|)) (SIGNATURE |concat| (|#1| |#1| |#2|)) (SIGNATURE |construct| (|#1| (|List| |#2|))) (SIGNATURE |find| ((|Union| |#2| "failed") (|Mapping| (|Boolean|) |#2|) |#1|)) (SIGNATURE |reduce| (|#2| (|Mapping| |#2| |#2| |#2|) |#1|)) (SIGNATURE |reduce| (|#2| (|Mapping| |#2| |#2| |#2|) |#1| |#2|)) (SIGNATURE |reduce| (|#2| (|Mapping| |#2| |#2| |#2|) |#1| |#2| |#2|)) (SIGNATURE |elt| (|#2| |#1| (|Integer|))) (SIGNATURE |elt| (|#2| |#1| (|Integer|) |#2|)) (SIGNATURE |setelt| (|#2| |#1| (|Integer|) |#2|)) (SIGNATURE |count| ((|NonNegativeInteger|) |#2| |#1|)) (SIGNATURE |parts| ((|List| |#2|) |#1|)) (SIGNATURE |count| ((|NonNegativeInteger|) (|Mapping| (|Boolean|) |#2|) |#1|)) (SIGNATURE |every?| ((|Boolean|) (|Mapping| (|Boolean|) |#2|) |#1|)) (SIGNATURE |any?| ((|Boolean|) (|Mapping| (|Boolean|) |#2|) |#1|)) (SIGNATURE |map!| (|#1| (|Mapping| |#2| |#2|) |#1|)) (SIGNATURE |map| (|#1| (|Mapping| |#2| |#2|) |#1|)) (SIGNATURE |copy| (|#1| |#1|))) (|OneDimensionalArrayAggregate| |#2|) (|Type|)) (T |OneDimensionalArrayAggregate&|)) 
 NIL 
@@ -588,6 +588,14 @@ NIL
 ((|position| (*1 *2 *1) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) (|setPosition| (*1 *2 *1 *3) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|))))) 
 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |position| ((|NonNegativeInteger|) $)) (SIGNATURE |setPosition| ((|Void|) $ (|NonNegativeInteger|))))) 
 (((|BasicType|) . T) ((|CoercibleTo| (|OutputForm|)) . T) ((|OrderedSet|) . T) ((|SetCategory|) . T)) 
+((|specialise| (((|List| (|SparseUnivariatePolynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|Cell| |#1|)) 33)) (|resultantSet| (((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) 61)) (|projectionSet| (((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) 32)) (|principalSubResultantSet| (((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|))) 60)) (|discriminantSet| (((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) 57)) (|cylindricalDecomposition| (((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|))) 16) (((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|))) 17)) (|coefficientSet| (((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|))) 45))) 
+(((|CylindricalAlgebraicDecompositionPackage| |#1|) (CATEGORY |package| (SIGNATURE |cylindricalDecomposition| ((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|)))) (SIGNATURE |cylindricalDecomposition| ((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|)))) (SIGNATURE |projectionSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |coefficientSet| ((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) (SIGNATURE |discriminantSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |resultantSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |principalSubResultantSet| ((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) (SIGNATURE |specialise| ((|List| (|SparseUnivariatePolynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|Cell| |#1|)))) (|RealClosedField|)) (T |CylindricalAlgebraicDecompositionPackage|)) 
+((|specialise| (*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Cell| *5)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *5)))) (|principalSubResultantSet| (*1 *2 *3 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) (|resultantSet| (*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) (|discriminantSet| (*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) (|coefficientSet| (*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) (|projectionSet| (*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) (|cylindricalDecomposition| (*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|Cell| *5))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *5)))) (|cylindricalDecomposition| (*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Cell| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
+(CATEGORY |package| (SIGNATURE |cylindricalDecomposition| ((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|)))) (SIGNATURE |cylindricalDecomposition| ((|List| (|Cell| |#1|)) (|List| (|Polynomial| |#1|)) (|List| (|Symbol|)))) (SIGNATURE |projectionSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |coefficientSet| ((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) (SIGNATURE |discriminantSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |resultantSet| ((|List| (|Polynomial| |#1|)) (|List| (|SparseUnivariatePolynomial| (|Polynomial| |#1|))))) (SIGNATURE |principalSubResultantSet| ((|List| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)) (|SparseUnivariatePolynomial| (|Polynomial| |#1|)))) (SIGNATURE |specialise| ((|List| (|SparseUnivariatePolynomial| |#1|)) (|List| (|Polynomial| |#1|)) (|Cell| |#1|)))) 
+((|squareFreeBasis| (((|List| |#2|) (|List| |#2|)) 13)) (|gcdBasisAdd| (((|List| |#2|) |#2| (|List| |#2|)) 19)) (|gcdBasis| (((|List| |#2|) (|List| |#2|)) 14))) 
+(((|CylindricalAlgebraicDecompositionUtilities| |#1| |#2|) (CATEGORY |package| (SIGNATURE |squareFreeBasis| ((|List| |#2|) (|List| |#2|))) (SIGNATURE |gcdBasis| ((|List| |#2|) (|List| |#2|))) (SIGNATURE |gcdBasisAdd| ((|List| |#2|) |#2| (|List| |#2|)))) (|GcdDomain|) (|UnivariatePolynomialCategory| |#1|)) (T |CylindricalAlgebraicDecompositionUtilities|)) 
+((|gcdBasisAdd| (*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *4 *3)))) (|gcdBasis| (*1 *2 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *3 *4)))) (|squareFreeBasis| (*1 *2 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *3 *4))))) 
+(CATEGORY |package| (SIGNATURE |squareFreeBasis| ((|List| |#2|) (|List| |#2|))) (SIGNATURE |gcdBasis| ((|List| |#2|) (|List| |#2|))) (SIGNATURE |gcdBasisAdd| ((|List| |#2|) |#2| (|List| |#2|)))) 
 ((~= (((|Boolean|) $ $) NIL)) (|zero?| (((|Boolean|) $) NIL)) (|sample| (($) NIL T CONST)) (|retractIfCan| (((|Union| (|NonNegativeInteger|) "failed") $) 38)) (|retract| (((|NonNegativeInteger|) $) 36)) (|recip| (((|Union| $ "failed") $) NIL)) (|one?| (((|Boolean|) $) NIL)) (|min| (($ $ $) NIL)) (|max| (($ $ $) 26)) (|latex| (((|String|) $) NIL)) (|hash| (((|SingleInteger|) $) NIL)) (|generalizedContinuumHypothesisAssumed?| (((|Boolean|)) 39)) (|generalizedContinuumHypothesisAssumed| (((|Boolean|) (|Boolean|)) 41)) (|finite?| (((|Boolean|) $) 23)) (|countable?| (((|Boolean|) $) 35)) (|coerce| (((|OutputForm|) $) 22) (($ (|NonNegativeInteger|)) 14)) (^ (($ $ (|NonNegativeInteger|)) NIL) (($ $ (|PositiveInteger|)) NIL)) (|Zero| (($) 12 T CONST)) (|One| (($) 11 T CONST)) (|Aleph| (($ (|NonNegativeInteger|)) 15)) (>= (((|Boolean|) $ $) NIL)) (> (((|Boolean|) $ $) NIL)) (= (((|Boolean|) $ $) 24)) (<= (((|Boolean|) $ $) NIL)) (< (((|Boolean|) $ $) 25)) (- (((|Union| $ "failed") $ $) 29)) (+ (($ $ $) 27)) (** (($ $ (|NonNegativeInteger|)) NIL) (($ $ (|PositiveInteger|)) NIL) (($ $ $) 34)) (* (($ (|NonNegativeInteger|) $) 32) (($ (|PositiveInteger|) $) NIL) (($ $ $) 30))) 
 (((|CardinalNumber|) (|Join| (|OrderedSet|) (|AbelianMonoid|) (|Monoid|) (|RetractableTo| (|NonNegativeInteger|)) (CATEGORY |domain| (ATTRIBUTE (|commutative| "*")) (SIGNATURE - ((|Union| $ "failed") $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |Aleph| ($ (|NonNegativeInteger|))) (SIGNATURE |finite?| ((|Boolean|) $)) (SIGNATURE |countable?| ((|Boolean|) $)) (SIGNATURE |generalizedContinuumHypothesisAssumed?| ((|Boolean|))) (SIGNATURE |generalizedContinuumHypothesisAssumed| ((|Boolean|) (|Boolean|)))))) (T |CardinalNumber|)) 
 ((- (*1 *1 *1 *1) (|partial| |isDomain| *1 (|CardinalNumber|))) (** (*1 *1 *1 *1) (|isDomain| *1 (|CardinalNumber|))) (|Aleph| (*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CardinalNumber|)))) (|finite?| (*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|)))) (|countable?| (*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|)))) (|generalizedContinuumHypothesisAssumed?| (*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|)))) (|generalizedContinuumHypothesisAssumed| (*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
@@ -616,6 +624,10 @@ NIL
 (((|ComplexDoubleFloatVector|) (|Join| (|VectorCategory| (|Complex| (|DoubleFloat|))) (CATEGORY |domain| (SIGNATURE |qnew| ($ (|Integer|))) (SIGNATURE |vector| ($ (|List| (|Complex| (|DoubleFloat|)))))))) (T |ComplexDoubleFloatVector|)) 
 ((|qnew| (*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ComplexDoubleFloatVector|)))) (|vector| (*1 *1 *2) (AND (|isDomain| *2 (|List| (|Complex| (|DoubleFloat|)))) (|isDomain| *1 (|ComplexDoubleFloatVector|))))) 
 (|Join| (|VectorCategory| (|Complex| (|DoubleFloat|))) (CATEGORY |domain| (SIGNATURE |qnew| ($ (|Integer|))) (SIGNATURE |vector| ($ (|List| (|Complex| (|DoubleFloat|))))))) 
+((|variablesOf| (((|List| (|Symbol|)) $) 23)) (|samplePoint| (((|List| |#1|) $) 32)) (|projection| (((|Union| $ "failed") $) 15)) (|makeCell| (($ (|List| (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|)))) 17) (($ (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|)) $) 18)) (|mainVariableOf| (((|Symbol|) $) 21)) (|hasDimension?| (((|Boolean|) $ (|Symbol|)) 29)) (|dimension| (((|NonNegativeInteger|) $) 28)) (|coerce| (((|OutputForm|) $) 13))) 
+(((|Cell| |#1|) (|Join| (|CoercibleTo| (|OutputForm|)) (CATEGORY |domain| (SIGNATURE |samplePoint| ((|List| |#1|) $)) (SIGNATURE |dimension| ((|NonNegativeInteger|) $)) (SIGNATURE |hasDimension?| ((|Boolean|) $ (|Symbol|))) (SIGNATURE |makeCell| ($ (|List| (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|))))) (SIGNATURE |makeCell| ($ (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|)) $)) (SIGNATURE |mainVariableOf| ((|Symbol|) $)) (SIGNATURE |variablesOf| ((|List| (|Symbol|)) $)) (SIGNATURE |projection| ((|Union| $ "failed") $)))) (|RealClosedField|)) (T |Cell|)) 
+((|samplePoint| (*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) (|dimension| (*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) (|hasDimension?| (*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Cell| *4)) (|ofCategory| *4 (|RealClosedField|)))) (|makeCell| (*1 *1 *2) (AND (|isDomain| *2 (|List| (|SimpleCell| *3 (|SparseUnivariatePolynomial| *3)))) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|Cell| *3)))) (|makeCell| (*1 *1 *2 *1) (AND (|isDomain| *2 (|SimpleCell| *3 (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|Cell| *3)))) (|mainVariableOf| (*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) (|variablesOf| (*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) (|projection| (*1 *1 *1) (|partial| AND (|isDomain| *1 (|Cell| *2)) (|ofCategory| *2 (|RealClosedField|))))) 
+(|Join| (|CoercibleTo| (|OutputForm|)) (CATEGORY |domain| (SIGNATURE |samplePoint| ((|List| |#1|) $)) (SIGNATURE |dimension| ((|NonNegativeInteger|) $)) (SIGNATURE |hasDimension?| ((|Boolean|) $ (|Symbol|))) (SIGNATURE |makeCell| ($ (|List| (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|))))) (SIGNATURE |makeCell| ($ (|SimpleCell| |#1| (|SparseUnivariatePolynomial| |#1|)) $)) (SIGNATURE |mainVariableOf| ((|Symbol|) $)) (SIGNATURE |variablesOf| ((|List| (|Symbol|)) $)) (SIGNATURE |projection| ((|Union| $ "failed") $)))) 
 ((|permutation| (($ $ $) 8)) (|factorial| (($ $) 7)) (|binomial| (($ $ $) 6))) 
 (((|CombinatorialFunctionCategory|) (|Category|)) (T |CombinatorialFunctionCategory|)) 
 ((|permutation| (*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) (|factorial| (*1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) (|binomial| (*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|)))) 
@@ -4514,6 +4526,10 @@ NIL
 (((|SortedCache| |#1|) (CATEGORY |package| (SIGNATURE |clearCache| ((|Void|))) (SIGNATURE |cache| ((|List| |#1|))) (SIGNATURE |enterInCache| (|#1| |#1| (|Mapping| (|Boolean|) |#1|))) (SIGNATURE |enterInCache| (|#1| |#1| (|Mapping| (|Integer|) |#1| |#1|)))) (|CachableSet|)) (T |SortedCache|)) 
 ((|enterInCache| (*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Integer|) *2 *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2)))) (|enterInCache| (*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2)))) (|cache| (*1 *2) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|SortedCache| *3)) (|ofCategory| *3 (|CachableSet|)))) (|clearCache| (*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SortedCache| *3)) (|ofCategory| *3 (|CachableSet|))))) 
 (CATEGORY |package| (SIGNATURE |clearCache| ((|Void|))) (SIGNATURE |cache| ((|List| |#1|))) (SIGNATURE |enterInCache| (|#1| |#1| (|Mapping| (|Boolean|) |#1|))) (SIGNATURE |enterInCache| (|#1| |#1| (|Mapping| (|Integer|) |#1| |#1|)))) 
+((|variableOf| (((|Symbol|) $) 14)) (|stablePol| ((|#2| $) 10)) (|separe| (((|List| |#1|) (|List| |#1|) |#1| |#1|) 33)) (|samplePoint| ((|#1| $) 9)) (|pointToCell| (($ |#1| (|Boolean|) (|Symbol|)) 35)) (|hasDimension?| (((|Boolean|) $) 12)) (|coerce| (((|OutputForm|) $) 22)) (|allSimpleCells| (((|List| $) |#2| (|Symbol|)) 38) (((|List| $) (|List| |#2|) (|Symbol|)) 37))) 
+(((|SimpleCell| |#1| |#2|) (|Join| (|CoercibleTo| (|OutputForm|)) (CATEGORY |domain| (SIGNATURE |allSimpleCells| ((|List| $) |#2| (|Symbol|))) (SIGNATURE |allSimpleCells| ((|List| $) (|List| |#2|) (|Symbol|))) (SIGNATURE |hasDimension?| ((|Boolean|) $)) (SIGNATURE |samplePoint| (|#1| $)) (SIGNATURE |stablePol| (|#2| $)) (SIGNATURE |variableOf| ((|Symbol|) $)) (SIGNATURE |separe| ((|List| |#1|) (|List| |#1|) |#1| |#1|)) (SIGNATURE |pointToCell| ($ |#1| (|Boolean|) (|Symbol|))))) (|RealClosedField|) (|UnivariatePolynomialCategory| |#1|)) (T |SimpleCell|)) 
+((|allSimpleCells| (*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SimpleCell| *5 *3))) (|isDomain| *1 (|SimpleCell| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) (|allSimpleCells| (*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SimpleCell| *5 *6))) (|isDomain| *1 (|SimpleCell| *5 *6)))) (|hasDimension?| (*1 *2 *1) (AND (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) (|samplePoint| (*1 *2 *1) (AND (|ofCategory| *2 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) (|stablePol| (*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|SimpleCell| *3 *2)) (|ofCategory| *3 (|RealClosedField|)))) (|variableOf| (*1 *2 *1) (AND (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) (|separe| (*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) (|pointToCell| (*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *2 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2))))) 
+(|Join| (|CoercibleTo| (|OutputForm|)) (CATEGORY |domain| (SIGNATURE |allSimpleCells| ((|List| $) |#2| (|Symbol|))) (SIGNATURE |allSimpleCells| ((|List| $) (|List| |#2|) (|Symbol|))) (SIGNATURE |hasDimension?| ((|Boolean|) $)) (SIGNATURE |samplePoint| (|#1| $)) (SIGNATURE |stablePol| (|#2| $)) (SIGNATURE |variableOf| ((|Symbol|) $)) (SIGNATURE |separe| ((|List| |#1|) (|List| |#1|) |#1| |#1|)) (SIGNATURE |pointToCell| ($ |#1| (|Boolean|) (|Symbol|))))) 
 ((|structuralConstants| (((|Vector| (|Matrix| |#1|)) (|List| (|Matrix| |#1|))) 41) (((|Vector| (|Matrix| (|Polynomial| |#1|))) (|List| (|Symbol|)) (|Matrix| (|Polynomial| |#1|))) 60) (((|Vector| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|)) (|Matrix| (|Fraction| (|Polynomial| |#1|)))) 76)) (|coordinates| (((|Vector| |#1|) (|Matrix| |#1|) (|List| (|Matrix| |#1|))) 35))) 
 (((|StructuralConstantsPackage| |#1|) (CATEGORY |package| (SIGNATURE |structuralConstants| ((|Vector| (|Matrix| (|Fraction| (|Polynomial| |#1|)))) (|List| (|Symbol|)) (|Matrix| (|Fraction| (|Polynomial| |#1|))))) (SIGNATURE |structuralConstants| ((|Vector| (|Matrix| (|Polynomial| |#1|))) (|List| (|Symbol|)) (|Matrix| (|Polynomial| |#1|)))) (SIGNATURE |structuralConstants| ((|Vector| (|Matrix| |#1|)) (|List| (|Matrix| |#1|)))) (SIGNATURE |coordinates| ((|Vector| |#1|) (|Matrix| |#1|) (|List| (|Matrix| |#1|))))) (|Field|)) (T |StructuralConstantsPackage|)) 
 ((|coordinates| (*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Matrix| *5))) (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|StructuralConstantsPackage| *5)))) (|structuralConstants| (*1 *2 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|StructuralConstantsPackage| *4)))) (|structuralConstants| (*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Polynomial| *5)))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Polynomial| *5))))) (|structuralConstants| (*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5))))))) 
@@ -5371,4 +5387,4 @@ NIL
 NIL 
 NIL 
 NIL 
-((|Category| 5935623 5935628 5935633 "NIL" NIL T NIL (NIL) NIL NIL NIL) (|Union| 5935608 5935613 5935618 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Record| 5935593 5935598 5935603 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Mapping| 5935578 5935583 5935588 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Enumeration| 5935563 5935568 5935573 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|IntegerMod| 5934293 5935323 5935471 "ZMOD" 5935476 NIL ZMOD (NIL NIL) |domain| NIL NIL) (|IntegerLinearDependence| 5932647 5932910 5933315 "ZLINDEP" 5933996 NIL ZLINDEP (NIL T) |package| NIL NIL) (|ZeroDimensionalSolvePackage| 5912797 5915901 5919605 "ZDSOLVE" 5929153 NIL ZDSOLVE (NIL T NIL NIL) |package| NIL NIL) (|ParadoxicalCombinatorsForStreams| 5911656 5911836 5912143 "YSTREAM" 5912584 NIL YSTREAM (NIL T) |package| NIL NIL) (|XRecursivePolynomial| 5908313 5910431 5910786 "XRPOLY" 5911391 NIL XRPOLY (NIL T T) |domain| NIL NIL) (|XPolynomialRing| 5902952 5904679 5905589 "XPR" 5907486 NIL XPR (NIL T T) |domain| NIL NIL) (|XPolynomial| 5899583 5901840 5902181 "XPOLY" 5902663 NIL XPOLY (NIL T) |domain| NIL NIL) (|XPolynomialsCat| 5896294 5898190 5898284 "XPOLYC" 5898804 NIL XPOLYC (NIL T T) |category| NIL 5899013) (|XPBWPolynomial| 5890402 5893604 5894290 "XPBWPOLY" 5895697 NIL XPBWPOLY (NIL T T) |domain| NIL NIL) (|ExtensionField| 5883747 5887124 5887197 "XF" 5888350 NIL XF (NIL T) |category| NIL 5889130) (|ExtensionField&| 5883101 5883238 5883535 "XF-" 5883540 NIL XF- (NIL T T) |domain| NIL NIL) (|XFreeAlgebra| 5875823 5877585 5877673 "XFALG" 5881339 NIL XFALG (NIL T T) |category| NIL 5882564) (|XExponentialPackage| 5874306 5874464 5874824 "XEXPPKG" 5875631 NIL XEXPPKG (NIL T T T) |package| NIL NIL) (|XDistributedPolynomial| 5871562 5874027 5874211 "XDPOLY" 5874216 NIL XDPOLY (NIL T T) |domain| NIL NIL) (|XAlgebra| 5869982 5870773 5870833 "XALG" 5870925 NIL XALG (NIL T) |category| NIL 5871100) (|WuWenTsunTriangularSet| 5859952 5866303 5867133 "WUTSET" 5869341 NIL WUTSET (NIL T T T T) |domain| NIL NIL) (|WeightedPolynomials| 5856506 5857568 5858139 "WP" 5859629 NIL WP (NIL T T T T NIL NIL NIL) |domain| NIL NIL) (|WildFunctionFieldIntegralBasis| 5854662 5854917 5855425 "WFFINTBS" 5856222 NIL WFFINTBS (NIL T T T T) |package| NIL NIL) (|WeierstrassPreparation| 5850960 5851669 5852502 "WEIER" 5853904 NIL WEIER (NIL T) |package| NIL NIL) (|VectorSpace| 5849739 5850259 5850326 "VSPACE" 5850546 NIL VSPACE (NIL T) |category| NIL 5850664) (|VectorSpace&| 5849526 5849549 5849682 "VSPACE-" 5849687 NIL VSPACE- (NIL T T) |domain| NIL NIL) (|Void| 5849150 5849205 5849313 "VOID" 5849442 T VOID (NIL) |domain| NIL NIL) (|ViewportPackage| 5845735 5846367 5847141 "VIEW" 5848422 T VIEW (NIL) |package| NIL NIL) (|ViewDefaultsPackage| 5838439 5839615 5841247 "VIEWDEF" 5844157 T VIEWDEF (NIL) |package| NIL NIL) (|ThreeDimensionalViewport| 5820972 5824092 5827667 "VIEW3D" 5834928 T VIEW3D (NIL) |domain| NIL NIL) (|TwoDimensionalViewport| 5808206 5810638 5813287 "VIEW2D" 5818383 T VIEW2D (NIL) |domain| NIL NIL) (|Vector| 5801844 5807862 5807997 "VECTOR" 5808113 NIL VECTOR (NIL T) |domain| NIL NIL) (|VectorFunctions2| 5799814 5800136 5800581 "VECTOR2" 5801475 NIL VECTOR2 (NIL T T) |package| NIL NIL) (|VectorCategory| 5790508 5796405 5796477 "VECTCAT" 5798151 NIL VECTCAT (NIL T) |category| NIL 5798934) (|VectorCategory&| 5789214 5789506 5790049 "VECTCAT-" 5790054 NIL VECTCAT- (NIL T T) |domain| NIL NIL) (|Variable| 5788455 5788666 5788859 "VARIABLE" 5789069 NIL VARIABLE (NIL NIL) |domain| NIL NIL) (|UnivariateTaylorSeriesCZero| 5776222 5784656 5785509 "UTSZ" 5787702 NIL UTSZ (NIL T NIL) |domain| NIL NIL) (|TaylorSolve| 5775464 5775531 5775807 "UTSSOL" 5776131 NIL UTSSOL (NIL T T T) |package| NIL NIL) (|UTSodetools| 5773289 5773492 5773947 "UTSODETL" 5775206 NIL UTSODETL (NIL T T T T) |package| NIL NIL) (|UnivariateTaylorSeriesODESolver| 5769061 5769657 5770477 "UTSODE" 5772634 NIL UTSODE (NIL T T) |package| NIL NIL) (|UnivariateTaylorSeries| 5756629 5765067 5765920 "UTS" 5768308 NIL UTS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateTaylorSeriesCategory| 5742755 5750576 5750680 "UTSCAT" 5752793 NIL UTSCAT (NIL T) |category| NIL 5754039) (|UnivariateTaylorSeriesCategory&| 5739242 5740055 5741471 "UTSCAT-" 5741476 NIL UTSCAT- (NIL T T) |domain| NIL NIL) (|UnivariateTaylorSeriesFunctions2| 5738550 5738600 5738872 "UTS2" 5739168 NIL UTS2 (NIL T T T T) |package| NIL NIL) (|UnaryRecursiveAggregate| 5729719 5733320 5733410 "URAGG" 5737029 NIL URAGG (NIL T) |category| NIL 5738116) (|UnaryRecursiveAggregate&| 5725390 5726494 5728162 "URAGG-" 5728167 NIL URAGG- (NIL T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesWithExponentialSingularity| 5718111 5722747 5723679 "UPXSSING" 5724813 NIL UPXSSING (NIL T T NIL NIL) |domain| NIL NIL) (|UnivariatePuiseuxSeries| 5706369 5716601 5717097 "UPXS" 5717717 NIL UPXS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariatePuiseuxSeriesConstructor| 5696460 5706104 5706306 "UPXSCONS" 5706311 NIL UPXSCONS (NIL T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesConstructorCategory| 5681547 5691140 5691315 "UPXSCCA" 5692754 NIL UPXSCCA (NIL T T) |category| NIL 5693168) (|UnivariatePuiseuxSeriesConstructorCategory&| 5680904 5681014 5681390 "UPXSCCA-" 5681395 NIL UPXSCCA- (NIL T T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesCategory| 5666088 5675375 5675481 "UPXSCAT" 5676716 NIL UPXSCAT (NIL T) |category| NIL 5677688) (|UnivariatePuiseuxSeriesFunctions2| 5665116 5665242 5665554 "UPXS2" 5665938 NIL UPXS2 (NIL T T NIL NIL NIL NIL) |package| NIL NIL) (|UnivariatePolynomialSquareFree| 5662959 5663276 5663844 "UPSQFREE" 5664765 NIL UPSQFREE (NIL T T) |package| NIL NIL) (|UnivariatePowerSeriesCategory| 5653547 5657681 5657813 "UPSCAT" 5660008 NIL UPSCAT (NIL T T) |category| NIL 5661099) (|UnivariatePowerSeriesCategory&| 5652196 5652509 5653110 "UPSCAT-" 5653115 NIL UPSCAT- (NIL T T T) |domain| NIL NIL) (|UnivariatePolynomialCategory| 5628240 5641125 5641225 "UPOLYC" 5645342 NIL UPOLYC (NIL T) |category| NIL 5647435) (|UnivariatePolynomialCategory&| 5612859 5617006 5622686 "UPOLYC-" 5622691 NIL UPOLYC- (NIL T T) |domain| NIL NIL) (|UnivariatePolynomialCategoryFunctions2| 5612157 5612207 5612487 "UPOLYC2" 5612785 NIL UPOLYC2 (NIL T T T T) |package| NIL NIL) (|UnivariatePolynomial| 5598378 5611401 5611654 "UP" 5611990 NIL UP (NIL NIL T) |domain| NIL NIL) (|UnivariatePolynomialMultiplicationPackage| 5597063 5597226 5597578 "UPMP" 5598181 NIL UPMP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialDivisionPackage| 5596259 5596370 5596658 "UPDIVP" 5596928 NIL UPDIVP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialDecompositionPackage| 5593432 5593822 5594451 "UPDECOMP" 5595825 NIL UPDECOMP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialCommonDenominator| 5591907 5592065 5592450 "UPCDEN" 5593240 NIL UPCDEN (NIL T T T) |package| NIL NIL) (|UnivariatePolynomialFunctions2| 5591067 5591177 5591447 "UP2" 5591773 NIL UP2 (NIL NIL T NIL T) |package| NIL NIL) (|UniversalSegment| 5588985 5589818 5590253 "UNISEG" 5590694 NIL UNISEG (NIL T) |domain| NIL NIL) (|UniversalSegmentFunctions2| 5587682 5587874 5588215 "UNISEG2" 5588740 NIL UNISEG2 (NIL T T) |package| NIL NIL) (|UnivariateFactorize| 5586124 5586372 5586758 "UNIFACT" 5587400 NIL UNIFACT (NIL T) |package| NIL NIL) (|UnivariateLaurentSeries| 5561973 5584736 5585171 "ULS" 5585791 NIL ULS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateLaurentSeriesConstructor| 5545115 5561709 5561910 "ULSCONS" 5561915 NIL ULSCONS (NIL T T) |domain| NIL NIL) (|UnivariateLaurentSeriesConstructorCategory| 5519566 5536222 5536396 "ULSCCAT" 5537976 NIL ULSCCAT (NIL T T) |category| NIL 5538466) (|UnivariateLaurentSeriesConstructorCategory&| 5518027 5518350 5519067 "ULSCCAT-" 5519072 NIL ULSCCAT- (NIL T T T) |domain| NIL NIL) (|UnivariateLaurentSeriesCategory| 5502862 5511959 5512065 "ULSCAT" 5513727 NIL ULSCAT (NIL T) |category| NIL 5514889) (|UnivariateLaurentSeriesFunctions2| 5501890 5502016 5502328 "ULS2" 5502712 NIL ULS2 (NIL T T NIL NIL NIL NIL) |package| NIL NIL) (|UnivariateFormalPowerSeries| 5489860 5498356 5499228 "UFPS" 5501102 NIL UFPS (NIL T) |domain| NIL NIL) (|UnivariateFormalPowerSeriesFunctions| 5489134 5489268 5489528 "UFPS1" 5489702 NIL UFPS1 (NIL T) |package| NIL NIL) (|UniqueFactorizationDomain| 5486553 5487968 5488048 "UFD" 5488453 T UFD (NIL) |category| NIL 5488653) (|UniqueFactorizationDomain&| 5486176 5486241 5486446 "UFD-" 5486451 NIL UFD- (NIL T) |domain| NIL NIL) (|UserDefinedVariableOrdering| 5484624 5484883 5485272 "UDVO" 5485857 T UDVO (NIL) |package| NIL NIL) (|UserDefinedPartialOrdering| 5481221 5481745 5482453 "UDPO" 5484005 NIL UDPO (NIL T) |package| NIL NIL) (|U8Vector| 5475064 5481092 5481170 "U8VEC" 5481175 T U8VEC (NIL) |domain| NIL NIL) (|U8Matrix| 5469345 5474675 5474841 "U8MAT" 5474930 T U8MAT (NIL) |domain| NIL NIL) (|U32Vector| 5463186 5469214 5469294 "U32VEC" 5469299 T U32VEC (NIL) |domain| NIL NIL) (|U32Matrix| 5457448 5462790 5462960 "U32MAT" 5463050 T U32MAT (NIL) |domain| NIL NIL) (|U16Vector| 5451289 5457317 5457397 "U16VEC" 5457402 T U16VEC (NIL) |domain| NIL NIL) (|U16Matrix| 5445551 5450893 5451063 "U16MAT" 5451153 T U16MAT (NIL) |domain| NIL NIL) (|Type| 5445454 5445459 5445497 "TYPE" 5445502 T TYPE (NIL) |category| NIL NIL) (|TwoFactorize| 5442838 5443366 5443997 "TWOFACT" 5444892 NIL TWOFACT (NIL T) |package| NIL NIL) (|Tuple| 5441375 5441838 5442171 "TUPLE" 5442545 NIL TUPLE (NIL T) |domain| NIL NIL) (|TubePlotTools| 5437389 5438261 5439239 "TUBETOOL" 5440439 T TUBETOOL (NIL) |package| NIL NIL) (|TubePlot| 5435454 5435740 5436144 "TUBE" 5437054 NIL TUBE (NIL T) |domain| NIL NIL) (|TaylorSeries| 5427811 5433737 5434207 "TS" 5435038 NIL TS (NIL T) |domain| NIL NIL) (|TriangularSetCategory| 5408093 5413892 5414096 "TSETCAT" 5424875 NIL TSETCAT (NIL T T T T) |category| NIL 5427289) (|TriangularSetCategory&| 5400325 5402490 5405409 "TSETCAT-" 5405414 NIL TSETCAT- (NIL T T T T T) |domain| NIL NIL) (|TranscendentalManipulations| 5390044 5391125 5392584 "TRMANIP" 5399051 NIL TRMANIP (NIL T T) |package| NIL NIL) (|TriangularMatrixOperations| 5388955 5389045 5389367 "TRIMAT" 5389925 NIL TRIMAT (NIL T T T T) |package| NIL NIL) (|TrigonometricManipulations| 5384533 5384827 5385511 "TRIGMNIP" 5388554 NIL TRIGMNIP (NIL T T) |package| NIL NIL) (|TrigonometricFunctionCategory| 5383729 5383842 5383930 "TRIGCAT" 5384359 T TRIGCAT (NIL) |category| NIL NIL) (|TrigonometricFunctionCategory&| 5383248 5383327 5383583 "TRIGCAT-" 5383588 NIL TRIGCAT- (NIL T) |domain| NIL NIL) (|Tree| 5378701 5381414 5381882 "TREE" 5382825 NIL TREE (NIL T) |domain| NIL NIL) (|TranscendentalFunctionCategory| 5377571 5378122 5378212 "TRANFUN" 5378283 T TRANFUN (NIL) |category| NIL 5378501) (|TranscendentalFunctionCategory&| 5376583 5376788 5377236 "TRANFUN-" 5377241 NIL TRANFUN- (NIL T) |domain| NIL NIL) (|TopLevelThreeSpace| 5376174 5376235 5376373 "TOPSP" 5376497 T TOPSP (NIL) |package| NIL NIL) (|ToolsForSign| 5375177 5375332 5375575 "TOOLSIGN" 5375985 NIL TOOLSIGN (NIL T) |package| NIL NIL) (|TextFile| 5373160 5373859 5374255 "TEXTFILE" 5374813 T TEXTFILE (NIL) |domain| NIL NIL) (|TexFormat| 5369969 5370647 5371336 "TEX" 5372505 T TEX (NIL) |domain| NIL NIL) (|TexFormat1| 5369615 5369655 5369776 "TEX1" 5369905 NIL TEX1 (NIL T) |package| NIL NIL) (|TemplateUtilities| 5368954 5369059 5369243 "TEMUTL" 5369481 T TEMUTL (NIL) |package| NIL NIL) (|TabulatedComputationPackage| 5365688 5366081 5366655 "TBCMPPK" 5368492 NIL TBCMPPK (NIL T T) |package| NIL NIL) (|TableAggregate| 5354485 5362817 5362917 "TBAGG" 5363585 NIL TBAGG (NIL T T) |category| NIL 5363885) (|TableAggregate&| 5347780 5349696 5352149 "TBAGG-" 5352154 NIL TBAGG- (NIL T T T) |domain| NIL NIL) (|TangentExpansions| 5346736 5346893 5347149 "TANEXP" 5347589 NIL TANEXP (NIL T) |package| NIL NIL) (|Table| 5338067 5346483 5346641 "TABLE" 5346646 NIL TABLE (NIL T T) |domain| NIL NIL) (|Tableau| 5337168 5337297 5337511 "TABLEAU" 5337904 NIL TABLEAU (NIL T) |domain| NIL NIL) (|TableauxBumpers| 5329892 5331365 5332988 "TABLBUMP" 5335611 NIL TABLBUMP (NIL T) |package| NIL NIL) (|SystemSolvePackage| 5323978 5325066 5326364 "SYSSOLP" 5328670 NIL SYSSOLP (NIL T) |package| NIL NIL) (|SymbolTable| 5319497 5320382 5321413 "SYMTAB" 5322985 T SYMTAB (NIL) |domain| NIL NIL) (|TheSymbolTable| 5311752 5313062 5314722 "SYMS" 5317881 T SYMS (NIL) |domain| NIL NIL) (|SymmetricPolynomial| 5307648 5310786 5311191 "SYMPOLY" 5311415 NIL SYMPOLY (NIL T) |domain| NIL NIL) (|SymmetricFunctions| 5306874 5306974 5307181 "SYMFUNC" 5307507 NIL SYMFUNC (NIL T) |package| NIL NIL) (|Symbol| 5300938 5302648 5303949 "SYMBOL" 5305601 T SYMBOL (NIL) |domain| NIL NIL) (|Switch| 5291964 5294262 5296678 "SWITCH" 5298550 T SWITCH (NIL) |domain| NIL NIL) (|SparseUnivariateTaylorSeries| 5281728 5289885 5290433 "SUTS" 5291528 NIL SUTS (NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariatePuiseuxSeries| 5269871 5280164 5280684 "SUPXS" 5281322 NIL SUPXS (NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariatePolynomial| 5256106 5269125 5269390 "SUP" 5269688 NIL SUP (NIL T) |domain| NIL NIL) (|SupFractionFactorizer| 5254309 5254574 5255041 "SUPFRACF" 5255812 NIL SUPFRACF (NIL T T T T) |package| NIL NIL) (|SparseUnivariatePolynomialExpressions| 5238986 5253840 5254124 "SUPEXPR" 5254129 NIL SUPEXPR (NIL T) |domain| NIL NIL) (|SparseUnivariatePolynomialFunctions2| 5238204 5238316 5238568 "SUP2" 5238850 NIL SUP2 (NIL T T) |package| NIL NIL) (|RationalFunctionSum| 5235409 5235859 5236504 "SUMRF" 5237691 NIL SUMRF (NIL T) |package| NIL NIL) (|FunctionSpaceSum| 5234042 5234122 5234536 "SUMFS" 5235292 NIL SUMFS (NIL T T) |package| NIL NIL) (|SparseUnivariateLaurentSeries| 5209145 5232612 5233065 "SULS" 5233703 NIL SULS (NIL T NIL NIL) |domain| NIL NIL) (|SuchThat| 5208160 5208399 5208611 "SUCH" 5209007 NIL SUCH (NIL T T) |domain| NIL NIL) (|SubSpace| 5197713 5199291 5201052 "SUBSPACE" 5206470 NIL SUBSPACE (NIL NIL T) |domain| NIL NIL) (|SubResultantPackage| 5196648 5196788 5197094 "SUBRESP" 5197528 NIL SUBRESP (NIL T T) |package| NIL NIL) (|StreamTranscendentalFunctions| 5186727 5188252 5190047 "STTF" 5194969 NIL STTF (NIL T) |package| NIL NIL) (|StreamTranscendentalFunctionsNonCommutative| 5177542 5178851 5180458 "STTFNC" 5185264 NIL STTFNC (NIL T) |package| NIL NIL) (|StreamTaylorSeriesOperations| 5164508 5166907 5169443 "STTAYLOR" 5175092 NIL STTAYLOR (NIL T) |package| NIL NIL) (|StringTable| 5155308 5164252 5164407 "STRTBL" 5164412 NIL STRTBL (NIL T) |domain| NIL NIL) (|String| 5148178 5155235 5155283 "STRING" 5155288 T STRING (NIL) |domain| NIL NIL) (|StringCategory| 5140009 5146980 5147038 "STRICAT" 5147134 T STRICAT (NIL) |category| |String| 5147250) (|Stream| 5129245 5136062 5137056 "STREAM" 5139057 NIL STREAM (NIL T) |domain| NIL NIL) (|StreamFunctions3| 5128540 5128633 5128840 "STREAM3" 5129128 NIL STREAM3 (NIL T T T) |package| NIL NIL) (|StreamFunctions2| 5127081 5127304 5127637 "STREAM2" 5128283 NIL STREAM2 (NIL T T) |package| NIL NIL) (|StreamFunctions1| 5126610 5126674 5126824 "STREAM1" 5126993 NIL STREAM1 (NIL T) |package| NIL NIL) (|StreamTensor| 5126074 5126161 5126326 "STNSR" 5126499 NIL STNSR (NIL T) |package| NIL NIL) (|StreamInfiniteProduct| 5124276 5124553 5124983 "STINPROD" 5125758 NIL STINPROD (NIL T) |package| NIL NIL) (|StepThrough| 5123667 5123892 5123944 "STEP" 5124066 T STEP (NIL) |category| NIL 5124194) (|SparseTable| 5115096 5123512 5123632 "STBL" 5123637 NIL STBL (NIL T T NIL) |domain| NIL NIL) (|StreamAggregate| 5108079 5113833 5113907 "STAGG" 5114180 NIL STAGG (NIL T) |category| NIL 5114366) (|StreamAggregate&| 5104973 5105704 5106935 "STAGG-" 5106940 NIL STAGG- (NIL T T) |domain| NIL NIL) (|Stack| 5094976 5097138 5098848 "STACK" 5103310 NIL STACK (NIL T) |domain| NIL NIL) (|SquareFreeRegularTriangularSet| 5083912 5091498 5092307 "SREGSET" 5094367 NIL SREGSET (NIL T T T T) |domain| NIL NIL) (|SquareFreeRegularSetDecompositionPackage| 5071288 5073120 5075410 "SRDCMPK" 5081910 NIL SRDCMPK (NIL T T T T T) |package| NIL NIL) (|StringAggregate| 5059834 5066808 5066868 "SRAGG" 5069112 T SRAGG (NIL) |category| NIL 5070183) (|StringAggregate&| 5058327 5058690 5059296 "SRAGG-" 5059301 NIL SRAGG- (NIL T) |domain| NIL NIL) (|SquareMatrix| 5050132 5056582 5057263 "SQMATRIX" 5057728 NIL SQMATRIX (NIL NIL T) |domain| NIL NIL) (|SplittingTree| 5040226 5044557 5045742 "SPLTREE" 5049077 NIL SPLTREE (NIL T T) |domain| NIL NIL) (|SplittingNode| 5033780 5034627 5035630 "SPLNODE" 5039353 NIL SPLNODE (NIL T T) |domain| NIL NIL) (|SpecialFunctionCategory| 5032226 5032494 5032570 "SPFCAT" 5033411 T SPFCAT (NIL) |category| NIL NIL) (|SpecialOutputPackage| 5029985 5030298 5030796 "SPECOUT" 5031784 T SPECOUT (NIL) |package| NIL NIL) (|ThreeSpaceCategory| 5017129 5019581 5019661 "SPACEC" 5027012 NIL SPACEC (NIL T) |category| |ThreeSpace| 5029903) (|ThreeSpace| 5014550 5017016 5017095 "SPACE3" 5017100 NIL SPACE3 (NIL T) |domain| NIL NIL) (|SortPackage| 5012389 5012619 5013105 "SORTPAK" 5014250 NIL SORTPAK (NIL T T) |package| NIL NIL) (|TransSolvePackage| 5008927 5009385 5010119 "SOLVETRA" 5011848 NIL SOLVETRA (NIL T) |package| NIL NIL) (|TransSolvePackageService| 5006793 5007271 5007890 "SOLVESER" 5008420 NIL SOLVESER (NIL T) |package| NIL NIL) (|RadicalSolvePackage| 4998439 4999806 5001532 "SOLVERAD" 5005193 NIL SOLVERAD (NIL T) |package| NIL NIL) (|PolynomialSolveByFormulas| 4991791 4992497 4993543 "SOLVEFOR" 4997592 NIL SOLVEFOR (NIL T T) |package| NIL NIL) (|SquareFreeNormalizedTriangularSetCategory| 4983561 4990646 4990885 "SNTSCAT" 4990890 NIL SNTSCAT (NIL T T T T) |category| NIL 4991027) (|SparseMultivariateTaylorSeries| 4974709 4980528 4981184 "SMTS" 4983079 NIL SMTS (NIL T T T) |domain| NIL NIL) (|SparseMultivariatePolynomial| 4966100 4974478 4974644 "SMP" 4974649 NIL SMP (NIL T T) |domain| NIL NIL) (|SmithNormalForm| 4963173 4963543 4964139 "SMITH" 4965686 NIL SMITH (NIL T T T T) |package| NIL NIL) (|SquareMatrixCategory| 4952128 4958161 4958359 "SMATCAT" 4960901 NIL SMATCAT (NIL NIL T T T) |category| NIL 4961741) (|SquareMatrixCategory&| 4947351 4948501 4950428 "SMATCAT-" 4950433 NIL SMATCAT- (NIL T NIL T T T) |domain| NIL NIL) (|StackAggregate| 4944104 4946210 4946282 "SKAGG" 4946700 NIL SKAGG (NIL T) |category| NIL 4946923) (|SingleInteger| 4938613 4942729 4943169 "SINT" 4943706 T SINT (NIL) |domain| NIL NIL) (|SimplifyAlgebraicNumberConvertPackage| 4938095 4938165 4938349 "SIMPAN" 4938519 T SIMPAN (NIL) |package| NIL NIL) (|RationalFunctionSign| 4936149 4936495 4936968 "SIGNRF" 4937697 NIL SIGNRF (NIL T) |package| NIL NIL) (|ElementaryFunctionSign| 4933934 4934140 4934692 "SIGNEF" 4935891 NIL SIGNEF (NIL T T) |package| NIL NIL) (|SturmHabichtPackage| 4929448 4930291 4931286 "SHP" 4933040 NIL SHP (NIL T NIL) |package| NIL NIL) (|SplitHomogeneousDirectProduct| 4920724 4929206 4929406 "SHDP" 4929411 NIL SHDP (NIL NIL NIL T) |domain| NIL NIL) (|SemiGroup| 4919963 4920207 4920255 "SGROUP" 4920493 T SGROUP (NIL) |category| NIL 4920642) (|SemiGroup&| 4919601 4919675 4919844 "SGROUP-" 4919849 NIL SGROUP- (NIL T) |domain| NIL NIL) (|SymmetricGroupCombinatoricFunctions| 4913848 4914991 4916318 "SGCF" 4918360 T SGCF (NIL) |package| NIL NIL) (|SquareFreeRegularTriangularSetCategory| 4905825 4912910 4913143 "SFRTCAT" 4913148 NIL SFRTCAT (NIL T T T T) |category| |SquareFreeRegularTriangularSet| 4913215) (|SquareFreeRegularTriangularSetGcdPackage| 4893838 4895275 4897145 "SFRGCD" 4904233 NIL SFRGCD (NIL T T T T T) |package| NIL NIL) (|SquareFreeQuasiComponentPackage| 4881595 4883092 4884980 "SFQCMPK" 4892210 NIL SFQCMPK (NIL T T T T T) |package| NIL NIL) (|SimpleFortranProgram| 4880892 4881027 4881252 "SFORT" 4881474 NIL SFORT (NIL T T) |domain| NIL NIL) (|SExpressionOf| 4879806 4880640 4880837 "SEXOF" 4880842 NIL SEXOF (NIL T T T T T) |domain| NIL NIL) (|SExpression| 4878641 4879583 4879711 "SEX" 4879716 T SEX (NIL) |domain| NIL NIL) (|SExpressionCategory| 4869604 4870432 4870605 "SEXCAT" 4877633 NIL SEXCAT (NIL T T T T T) |category| NIL 4878559) (|Set| 4865608 4869498 4869570 "SET" 4869575 NIL SET (NIL T) |domain| NIL NIL) (|SetOfMIntegersInOneToN| 4862403 4863160 4863784 "SETMN" 4865094 NIL SETMN (NIL NIL NIL) |domain| NIL NIL) (|SetCategory| 4861799 4861955 4862007 "SETCAT" 4862192 T SETCAT (NIL) |category| NIL 4862343) (|SetCategory&| 4861459 4861527 4861691 "SETCAT-" 4861696 NIL SETCAT- (NIL T) |domain| NIL NIL) (|SetCategoryWithDegree| 4860907 4861103 4861175 "SETCATD" 4861286 T SETCATD (NIL) |category| NIL 4861377) (|SetAggregate| 4855511 4858424 4858499 "SETAGG" 4859942 NIL SETAGG (NIL T) |category| NIL 4860473) (|SetAggregate&| 4854741 4854882 4855239 "SETAGG-" 4855244 NIL SETAGG- (NIL T T) |domain| NIL NIL) (|SegmentExpansionCategory| 4853528 4853850 4853980 "SEGXCAT" 4854513 NIL SEGXCAT (NIL T T) |category| NIL 4854692) (|Segment| 4852269 4853011 4853289 "SEG" 4853294 NIL SEG (NIL T) |domain| NIL NIL) (|SegmentCategory| 4850711 4850941 4851015 "SEGCAT" 4851927 NIL SEGCAT (NIL T) |category| NIL 4852251) (|SegmentBinding| 4849323 4849751 4850057 "SEGBIND" 4850463 NIL SEGBIND (NIL T) |domain| NIL NIL) (|SegmentBindingFunctions2| 4848673 4848761 4848965 "SEGBIND2" 4849211 NIL SEGBIND2 (NIL T T) |package| NIL NIL) (|SegmentFunctions2| 4847522 4847685 4847979 "SEG2" 4848457 NIL SEG2 (NIL T T) |package| NIL NIL) (|SequentialDifferentialVariable| 4846698 4847343 4847478 "SDVAR" 4847483 NIL SDVAR (NIL T) |domain| NIL NIL) (|SequentialDifferentialPolynomial| 4833383 4846117 4846452 "SDPOL" 4846457 NIL SDPOL (NIL T) |domain| NIL NIL) (|StochasticDifferential| 4826142 4827690 4828921 "SD" 4832260 NIL SD (NIL T) |domain| NIL NIL) (|StructuralConstantsPackage| 4823750 4824142 4824704 "SCPKG" 4825663 NIL SCPKG (NIL T) |package| NIL NIL) (|SortedCache| 4822495 4822673 4822967 "SCACHE" 4823515 NIL SCACHE (NIL T) |package| NIL NIL) (|SingletonAsOrderedSet| 4821694 4822061 4822226 "SAOS" 4822388 T SAOS (NIL) |domain| NIL NIL) (|SAERationalFunctionAlgFactor| 4820818 4820862 4821236 "SAERFFC" 4821626 NIL SAERFFC (NIL T T T) |package| NIL NIL) (|SimpleAlgebraicExtension| 4811995 4820607 4820781 "SAE" 4820786 NIL SAE (NIL T T NIL) |domain| NIL NIL) (|SimpleAlgebraicExtensionAlgFactor| 4811164 4811208 4811562 "SAEFACT" 4811927 NIL SAEFACT (NIL T T T) |package| NIL NIL) (|RationalUnivariateRepresentationPackage| 4808093 4808626 4809385 "RURPK" 4810581 NIL RURPK (NIL T NIL) |package| NIL NIL) (|Ruleset| 4805919 4806267 4806765 "RULESET" 4807843 NIL RULESET (NIL T T T) |domain| NIL NIL) (|RewriteRule| 4801311 4801949 4802685 "RULE" 4805439 NIL RULE (NIL T T T) |domain| NIL NIL) (|RuleCalled| 4800803 4800992 4801124 "RULECOLD" 4801231 NIL RULECOLD (NIL NIL) |domain| NIL NIL) (|RegularTriangularSetGcdPackage| 4791717 4792806 4794283 "RSETGCD" 4799584 NIL RSETGCD (NIL T T T T T) |package| NIL NIL) (|RegularTriangularSetCategory| 4773710 4780795 4781008 "RSETCAT" 4789442 NIL RSETCAT (NIL T T T T) |category| NIL 4791143) (|RegularTriangularSetCategory&| 4770660 4771363 4772662 "RSETCAT-" 4772667 NIL RSETCAT- (NIL T T T T T) |domain| NIL NIL) (|RegularSetDecompositionPackage| 4758259 4760103 4762375 "RSDCMPK" 4768646 NIL RSDCMPK (NIL T T T T T) |package| NIL NIL) (|RealRootCharacterizationCategory| 4754670 4755247 4755425 "RRCC" 4757645 NIL RRCC (NIL T T) |category| |RightOpenIntervalRootCharacterization| 4758177) (|RealRootCharacterizationCategory&| 4753639 4753870 4754376 "RRCC-" 4754381 NIL RRCC- (NIL T T T) |domain| NIL NIL) (|RecursivePolynomialCategory| 4708545 4722850 4723001 "RPOLCAT" 4744331 NIL RPOLCAT (NIL T T T) |category| NIL 4749486) (|RecursivePolynomialCategory&| 4695625 4698881 4703806 "RPOLCAT-" 4703811 NIL RPOLCAT- (NIL T T T T) |domain| NIL NIL) (|RoutinesTable| 4682196 4692231 4693183 "ROUTINE" 4694715 T ROUTINE (NIL) |domain| NIL NIL) (|RomanNumeral| 4677512 4681405 4681687 "ROMAN" 4681954 T ROMAN (NIL) |domain| NIL NIL) (|RightOpenIntervalRootCharacterization| 4674514 4675261 4675751 "ROIRC" 4677195 NIL ROIRC (NIL T T) |domain| NIL NIL) (|RealNumberSystem| 4668876 4672070 4672132 "RNS" 4672662 T RNS (NIL) |category| NIL 4673153) (|RealNumberSystem&| 4666476 4667031 4667914 "RNS-" 4668069 NIL RNS- (NIL T) |domain| NIL NIL) (|Rng| 4665670 4666182 4666218 "RNG" 4666223 T RNG (NIL) |category| NIL 4666264) (|RightModule| 4664806 4665250 4665315 "RMODULE" 4665405 NIL RMODULE (NIL T) |category| NIL 4665478) (|RectangularMatrixCategoryFunctions2| 4662724 4662835 4663430 "RMCAT2" 4664666 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) |package| NIL NIL) (|RectangularMatrix| 4657851 4661312 4661865 "RMATRIX" 4662291 NIL RMATRIX (NIL NIL NIL T) |domain| NIL NIL) (|RectangularMatrixCategory| 4645974 4649095 4649331 "RMATCAT" 4655763 NIL RMATCAT (NIL NIL NIL T T T) |category| NIL 4657279) (|RectangularMatrixCategory&| 4644864 4645095 4645672 "RMATCAT-" 4645677 NIL RMATCAT- (NIL T NIL NIL T T T) |domain| NIL NIL) (|RationalInterpolation| 4644068 4644201 4644447 "RINTERP" 4644707 NIL RINTERP (NIL NIL T) |package| NIL NIL) (|Ring| 4642652 4643397 4643435 "RING" 4643620 T RING (NIL) |category| NIL 4643802) (|Ring&| 4642339 4642399 4642543 "RING-" 4642548 NIL RING- (NIL T) |domain| NIL NIL) (|RandomIntegerDistributions| 4640391 4640739 4641196 "RIDIST" 4641950 T RIDIST (NIL) |package| NIL NIL) (|RegularChain| 4621870 4639272 4639716 "RGCHAIN" 4640031 NIL RGCHAIN (NIL T NIL) |domain| NIL NIL) (|RootsFindingPackage| 4619765 4620157 4620658 "RFP" 4621438 NIL RFP (NIL T) |package| NIL NIL) (|RationalFunction| 4614500 4615516 4616695 "RF" 4618658 NIL RF (NIL T) |package| NIL NIL) (|RationalFunctionFactorizer| 4613801 4613909 4614134 "RFFACTOR" 4614368 NIL RFFACTOR (NIL T) |package| NIL NIL) (|RationalFunctionFactor| 4613283 4613327 4613533 "RFFACT" 4613733 NIL RFFACT (NIL T) |package| NIL NIL) (|RandomFloatDistributions| 4609761 4610377 4611131 "RFDIST" 4612593 T RFDIST (NIL) |package| NIL NIL) (|RetractSolvePackage| 4608812 4608952 4609250 "RETSOL" 4609597 NIL RETSOL (NIL T T) |package| NIL NIL) (|RetractableTo| 4608190 4608291 4608361 "RETRACT" 4608663 NIL RETRACT (NIL T) |category| NIL NIL) (|RetractableTo&| 4607960 4607989 4608130 "RETRACT-" 4608135 NIL RETRACT- (NIL T T) |domain| NIL NIL) (|Result| 4597904 4607320 4607560 "RESULT" 4607748 T RESULT (NIL) |domain| NIL NIL) (|ResidueRing| 4595777 4596651 4596974 "RESRING" 4597749 NIL RESRING (NIL T T T T NIL) |domain| NIL NIL) (|ResolveLatticeCompletion| 4595193 4595248 4595422 "RESLATC" 4595681 NIL RESLATC (NIL T) |package| NIL NIL) (|RepeatedSquaring| 4594686 4594734 4594927 "REPSQ" 4595120 NIL REPSQ (NIL T) |package| NIL NIL) (|RadicalEigenPackage| 4590133 4591114 4592203 "REP" 4593651 T REP (NIL) |package| NIL NIL) (|RepeatedDoubling| 4589618 4589668 4589863 "REPDB" 4590058 NIL REPDB (NIL T) |package| NIL NIL) (|RepresentationPackage2| 4580141 4582009 4583862 "REP2" 4587839 NIL REP2 (NIL T) |package| NIL NIL) (|RepresentationPackage1| 4573803 4574858 4576293 "REP1" 4578780 NIL REP1 (NIL T) |package| NIL NIL) (|RegularTriangularSet| 4562880 4570465 4571244 "REGSET" 4573204 NIL REGSET (NIL T T T T) |domain| NIL NIL) (|Reference| 4561279 4561684 4562029 "REF" 4562583 NIL REF (NIL T) |domain| NIL NIL) (|ReductionOfOrder| 4560267 4560386 4560670 "REDORDER" 4561115 NIL REDORDER (NIL T T) |package| NIL NIL) (|RecurrenceOperator| 4554710 4555363 4556383 "RECOP" 4559561 NIL RECOP (NIL T T) |package| NIL NIL) (|RealClosure| 4548168 4553020 4553527 "RECLOS" 4554298 NIL RECLOS (NIL T) |domain| NIL NIL) (|RealSolvePackage| 4546641 4546908 4547267 "REALSOLV" 4547857 T REALSOLV (NIL) |package| NIL NIL) (|RealConstant| 4546376 4546433 4546487 "REAL" 4546492 T REAL (NIL) |category| NIL 4546564) (|RealZeroPackageQ| 4540761 4541959 4543370 "REAL0Q" 4545076 NIL REAL0Q (NIL T) |package| NIL NIL) (|RealZeroPackage| 4533687 4535170 4536861 "REAL0" 4539166 NIL REAL0 (NIL T) |package| NIL NIL) (|ReducedDivisor| 4532621 4532729 4533100 "RDIV" 4533555 NIL RDIV (NIL T T T T T) |package| NIL NIL) (|RandomDistributions| 4531127 4531369 4531720 "RDIST" 4532345 NIL RDIST (NIL T) |package| NIL NIL) (|TranscendentalRischDESystem| 4528940 4529325 4529929 "RDETRS" 4530713 NIL RDETRS (NIL T T) |package| NIL NIL) (|TranscendentalRischDE| 4525753 4526327 4527113 "RDETR" 4528332 NIL RDETR (NIL T T) |package| NIL NIL) (|ElementaryRischDESystem| 4523647 4523997 4524671 "RDEEFS" 4525379 NIL RDEEFS (NIL T T) |package| NIL NIL) (|ElementaryRischDE| 4521426 4521807 4522500 "RDEEF" 4523242 NIL RDEEF (NIL T T) |package| NIL NIL) (|RealClosedField| 4511854 4516166 4516226 "RCFIELD" 4518552 T RCFIELD (NIL) |category| NIL 4519965) (|RealClosedField&| 4508429 4509284 4510529 "RCFIELD-" 4510682 NIL RCFIELD- (NIL T) |domain| NIL NIL) (|RecursiveAggregate| 4502967 4505454 4505534 "RCAGG" 4507349 NIL RCAGG (NIL T) |category| NIL 4508029) (|RecursiveAggregate&| 4502456 4502561 4502812 "RCAGG-" 4502817 NIL RCAGG- (NIL T T) |domain| NIL NIL) (|RationalRetractions| 4501305 4501469 4501770 "RATRET" 4502257 NIL RATRET (NIL T) |package| NIL NIL) (|RationalFactorize| 4500482 4500577 4500814 "RATFACT" 4501181 NIL RATFACT (NIL T) |package| NIL NIL) (|RandomNumberSource| 4499346 4499506 4499774 "RANDSRC" 4500266 T RANDSRC (NIL) |package| NIL NIL) (|RadixUtilities| 4498899 4498963 4499096 "RADUTIL" 4499257 T RADUTIL (NIL) |package| NIL NIL) (|RadixExpansion| 4487745 4496751 4497314 "RADIX" 4498397 NIL RADIX (NIL NIL) |domain| NIL NIL) (|RadicalFunctionField| 4475041 4487415 4487698 "RADFF" 4487703 NIL RADFF (NIL T T T NIL NIL) |domain| NIL NIL) (|RadicalCategory| 4474481 4474577 4474637 "RADCAT" 4474900 T RADCAT (NIL) |category| NIL NIL) (|RadicalCategory&| 4474149 4474207 4474378 "RADCAT-" 4474383 NIL RADCAT- (NIL T) |domain| NIL NIL) (|Queue| 4463765 4465991 4467767 "QUEUE" 4472420 NIL QUEUE (NIL T) |domain| NIL NIL) (|Quaternion| 4458880 4463641 4463731 "QUAT" 4463736 NIL QUAT (NIL T) |domain| NIL NIL) (|QuaternionCategoryFunctions2| 4458204 4458254 4458516 "QUATCT2" 4458806 NIL QUATCT2 (NIL T T T T) |package| NIL NIL) (|QuaternionCategory| 4448570 4453269 4453360 "QUATCAT" 4454873 NIL QUATCAT (NIL T) |category| |Quaternion| 4456088) (|QuaternionCategory&| 4442719 4444117 4446298 "QUATCAT-" 4446501 NIL QUATCAT- (NIL T T) |domain| NIL NIL) (|QueueAggregate| 4439150 4441312 4441384 "QUAGG" 4442001 NIL QUAGG (NIL T) |category| NIL 4442291) (|QuadraticForm| 4437527 4438124 4438419 "QFORM" 4438937 NIL QFORM (NIL NIL T) |domain| NIL NIL) (|QuotientFieldCategory| 4423265 4431168 4431264 "QFCAT" 4432597 NIL QFCAT (NIL T) |category| NIL 4434242) (|QuotientFieldCategory&| 4416244 4417953 4420565 "QFCAT-" 4420773 NIL QFCAT- (NIL T T) |domain| NIL NIL) (|QuotientFieldCategoryFunctions2| 4415551 4415601 4415873 "QFCAT2" 4416170 NIL QFCAT2 (NIL T T T T) |package| NIL NIL) (|QueryEquation| 4414695 4414840 4415065 "QEQUAT" 4415368 T QEQUAT (NIL) |domain| NIL NIL) (|QuasiComponentPackage| 4402652 4404149 4406017 "QCMPACK" 4413067 NIL QCMPACK (NIL T T T T T) |package| NIL NIL) (|QuasiAlgebraicSet| 4398324 4398905 4399636 "QALGSET" 4402086 NIL QALGSET (NIL T T T T) |domain| NIL NIL) (|QuasiAlgebraicSet2| 4396585 4396995 4397534 "QALGSET2" 4397890 NIL QALGSET2 (NIL NIL NIL) |package| NIL NIL) (|PAdicWildFunctionFieldIntegralBasis| 4394275 4394571 4395138 "PWFFINTB" 4396255 NIL PWFFINTB (NIL T T T T) |package| NIL NIL) (|PushVariables| 4391300 4391495 4392048 "PUSHVAR" 4394012 NIL PUSHVAR (NIL T T T T) |package| NIL NIL) (|PartialTranscendentalFunctions| 4384112 4385480 4385610 "PTRANFN" 4389706 NIL PTRANFN (NIL T) |category| NIL NIL) (|PointPackage| 4381808 4382154 4382618 "PTPACK" 4383702 NIL PTPACK (NIL T) |package| NIL NIL) (|PointFunctions2| 4381257 4381327 4381495 "PTFUNC2" 4381714 NIL PTFUNC2 (NIL T T) |package| NIL NIL) (|PointCategory| 4373409 4379423 4379493 "PTCAT" 4380094 NIL PTCAT (NIL T) |category| |Point| 4380347) (|PolynomialSquareFree| 4372765 4372813 4373056 "PSQFR" 4373337 NIL PSQFR (NIL T T T T) |package| NIL NIL) (|PseudoLinearNormalForm| 4370590 4371006 4371531 "PSEUDLIN" 4372315 NIL PSEUDLIN (NIL T) |package| NIL NIL) (|PolynomialSetUtilitiesPackage| 4346480 4349938 4353743 "PSETPK" 4366988 NIL PSETPK (NIL T T T T) |package| NIL NIL) (|PolynomialSetCategory| 4334602 4338483 4338677 "PSETCAT" 4344740 NIL PSETCAT (NIL T T T T) |category| NIL 4346010) (|PolynomialSetCategory&| 4331358 4332235 4333531 "PSETCAT-" 4333536 NIL PSETCAT- (NIL T T T T T) |domain| NIL NIL) (|PlottableSpaceCurveCategory| 4330178 4330426 4330510 "PSCURVE" 4331023 T PSCURVE (NIL) |category| |Plot3D| 4331318) (|PowerSeriesCategory| 4324454 4326507 4326639 "PSCAT" 4328251 NIL PSCAT (NIL T T T) |category| NIL 4328633) (|PowerSeriesCategory&| 4323147 4323411 4324012 "PSCAT-" 4324017 NIL PSCAT- (NIL T T T T) |domain| NIL NIL) (|Partition| 4321176 4321957 4322331 "PRTITION" 4322807 T PRTITION (NIL) |domain| NIL NIL) (|ProjectiveSpaceCategory| 4316322 4317219 4317310 "PRSPCAT" 4320101 NIL PRSPCAT (NIL T) |category| NIL 4321062) (|PseudoRemainderSequence| 4297715 4300878 4304308 "PRS" 4313021 NIL PRS (NIL T T) |package| NIL NIL) (|PriorityQueueAggregate| 4294634 4296693 4296787 "PRQAGG" 4297119 NIL PRQAGG (NIL T) |category| |Heap| 4297287) (|ProjectiveSpace| 4293568 4294472 4294595 "PROJSP" 4294600 NIL PROJSP (NIL NIL T) |domain| NIL NIL) (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| 4291976 4293262 4293489 "PROJPLPS" 4293494 NIL PROJPLPS (NIL T) |domain| NIL NIL) (|ProjectivePlane| 4290916 4291842 4291937 "PROJPL" 4291942 NIL PROJPL (NIL T) |domain| NIL NIL) (|Product| 4281940 4288167 4289373 "PRODUCT" 4289782 NIL PRODUCT (NIL T T) |domain| NIL NIL) (|PolynomialRing| 4277965 4280997 4281395 "PR" 4281630 NIL PR (NIL T T) |domain| NIL NIL) (|ProjectiveAlgebraicSetPackage| 4275212 4275451 4276013 "PRJALGPK" 4277687 NIL PRJALGPK (NIL T NIL T T T) |package| NIL NIL) (|PrintPackage| 4274874 4274917 4275025 "PRINT" 4275144 T PRINT (NIL) |package| NIL NIL) (|IntegerPrimesPackage| 4273761 4273903 4274169 "PRIMES" 4274693 NIL PRIMES (NIL T) |package| NIL NIL) (|PrimitiveElement| 4270483 4271115 4271918 "PRIMELT" 4273053 NIL PRIMELT (NIL T) |package| NIL NIL) (|PrimitiveFunctionCategory| 4269985 4270053 4270133 "PRIMCAT" 4270363 T PRIMCAT (NIL) |category| NIL NIL) (|PrimitiveArray| 4264557 4269844 4269941 "PRIMARR" 4269946 NIL PRIMARR (NIL T) |domain| NIL NIL) (|PrimitiveArrayFunctions2| 4262898 4263161 4263550 "PRIMARR2" 4264260 NIL PRIMARR2 (NIL T T) |package| NIL NIL) (|PrecomputedAssociatedEquations| 4262118 4262214 4262491 "PREASSOC" 4262778 NIL PREASSOC (NIL T T) |package| NIL NIL) (|PlottablePlaneCurveCategory| 4261161 4261361 4261445 "PPCURVE" 4261836 T PPCURVE (NIL) |category| NIL 4262078) (|U32VectorPolynomialOperations| 4251091 4252987 4255135 "POLYVEC" 4259087 T POLYVEC (NIL) |package| NIL NIL) (|PolynomialRoots| 4246681 4247283 4248238 "POLYROOT" 4250434 NIL POLYROOT (NIL T T T T T) |package| NIL NIL) (|Polynomial| 4237269 4246035 4246293 "POLY" 4246473 NIL POLY (NIL T) |domain| NIL NIL) (|PolynomialCategoryLifting| 4236221 4236293 4236703 "POLYLIFT" 4237173 NIL POLYLIFT (NIL T T T T T) |package| NIL NIL) (|PolynomialCategoryQuotientFunctions| 4229714 4230375 4231443 "POLYCATQ" 4235481 NIL POLYCATQ (NIL T T T T T) |package| NIL NIL) (|PolynomialCategory| 4207404 4215600 4215733 "POLYCAT" 4222629 NIL POLYCAT (NIL T T T) |category| NIL 4225883) (|PolynomialCategory&| 4196933 4199753 4203658 "POLYCAT-" 4203663 NIL POLYCAT- (NIL T T T T) |domain| NIL NIL) (|PolynomialToUnivariatePolynomial| 4196159 4196272 4196519 "POLY2UP" 4196796 NIL POLY2UP (NIL NIL T) |package| NIL NIL) (|PolynomialFunctions2| 4195553 4195633 4195821 "POLY2" 4196055 NIL POLY2 (NIL T T) |package| NIL NIL) (|RealPolynomialUtilitiesPackage| 4193063 4193438 4193957 "POLUTIL" 4195168 NIL POLUTIL (NIL T T) |package| NIL NIL) (|PolToPol| 4189598 4190225 4190972 "POLTOPOL" 4192387 NIL POLTOPOL (NIL NIL T) |package| NIL NIL) (|Point| 4183411 4189505 4189569 "POINT" 4189574 NIL POINT (NIL T) |domain| NIL NIL) (|PolynomialNumberTheoryFunctions| 4179463 4180187 4181053 "PNTHEORY" 4182623 T PNTHEORY (NIL) |package| NIL NIL) (|PatternMatchTools| 4176700 4177199 4177917 "PMTOOLS" 4178935 NIL PMTOOLS (NIL T T T) |package| NIL NIL) (|PatternMatchSymbol| 4175950 4176083 4176313 "PMSYM" 4176543 NIL PMSYM (NIL T) |package| NIL NIL) (|PatternMatchQuotientFieldCategory| 4174970 4175085 4175457 "PMQFCAT" 4175811 NIL PMQFCAT (NIL T T T) |package| NIL NIL) (|AttachPredicates| 4173867 4174040 4174317 "PMPRED" 4174755 NIL PMPRED (NIL T) |package| NIL NIL) (|FunctionSpaceAttachPredicates| 4172816 4172933 4173228 "PMPREDFS" 4173708 NIL PMPREDFS (NIL T T T) |package| NIL NIL) (|PatternMatchPolynomialCategory| 4170292 4170641 4171353 "PMPLCAT" 4172405 NIL PMPLCAT (NIL T T T T T) |package| NIL NIL) (|PatternMatchListAggregate| 4169403 4169536 4169839 "PMLSAGG" 4170135 NIL PMLSAGG (NIL T T T) |package| NIL NIL) (|PatternMatchKernel| 4168437 4168563 4168907 "PMKERNEL" 4169253 NIL PMKERNEL (NIL T T) |package| NIL NIL) (|PatternMatchIntegerNumberSystem| 4167640 4167776 4168043 "PMINS" 4168277 NIL PMINS (NIL T) |package| NIL NIL) (|PatternMatchFunctionSpace| 4166540 4166655 4167084 "PMFS" 4167501 NIL PMFS (NIL T T T) |package| NIL NIL) (|PatternMatchPushDown| 4165111 4165308 4165695 "PMDOWN" 4166314 NIL PMDOWN (NIL T T T) |package| NIL NIL) (|PatternMatchAssertions| 4163638 4163882 4164225 "PMASS" 4164828 T PMASS (NIL) |package| NIL NIL) (|FunctionSpaceAssertions| 4162415 4162547 4162828 "PMASSFS" 4163467 NIL PMASSFS (NIL T T) |package| NIL NIL) (|PolynomialPackageForCurve| 4158068 4158417 4159129 "PLPKCRV" 4161952 NIL PLPKCRV (NIL T T T NIL T) |package| NIL NIL) (|PlotTools| 4157490 4157596 4157760 "PLOTTOOL" 4157938 T PLOTTOOL (NIL) |package| NIL NIL) (|Plot| 4148092 4150123 4152272 "PLOT" 4155365 T PLOT (NIL) |domain| NIL NIL) (|Plot3D| 4140626 4142417 4144189 "PLOT3D" 4146348 T PLOT3D (NIL) |domain| NIL NIL) (|PlotFunctions1| 4138859 4139102 4139488 "PLOT1" 4140321 NIL PLOT1 (NIL T) |package| NIL NIL) (|ParametricLinearEquations| 4099952 4106347 4113341 "PLEQN" 4132122 NIL PLEQN (NIL T T T T) |package| NIL NIL) (|Plcs| 4098930 4099809 4099917 "PLCS" 4099922 NIL PLCS (NIL T T) |domain| NIL NIL) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| 4097365 4098498 4098779 "PLACESPS" 4098784 NIL PLACESPS (NIL T) |domain| NIL NIL) (|Places| 4096212 4097185 4097294 "PLACES" 4097299 NIL PLACES (NIL T) |domain| NIL NIL) (|PlacesCategory| 4090748 4091621 4091734 "PLACESC" 4095235 NIL PLACESC (NIL T T) |category| NIL 4096098) (|PolynomialInterpolation| 4089543 4089738 4090071 "PINTERP" 4090508 NIL PINTERP (NIL NIL T) |package| NIL NIL) (|PolynomialInterpolationAlgorithms| 4088929 4088998 4089231 "PINTERPA" 4089450 NIL PINTERPA (NIL T T) |package| NIL NIL) (|PositiveInteger| 4087870 4088552 4088733 "PI" 4088794 T PI (NIL) |domain| NIL NIL) (|PrincipalIdealDomain| 4085349 4086793 4086863 "PID" 4087170 T PID (NIL) |category| NIL 4087389) (|PiCoercions| 4084887 4084935 4085093 "PICOERCE" 4085277 NIL PICOERCE (NIL T) |package| NIL NIL) (|PolyGroebner| 4083779 4083985 4084280 "PGROEB" 4084651 NIL PGROEB (NIL T) |package| NIL NIL) (|PermutationGroupExamples| 4074892 4076412 4078305 "PGE" 4081950 T PGE (NIL) |package| NIL NIL) (|PolynomialGcdPackage| 4071140 4071585 4072316 "PGCD" 4074338 NIL PGCD (NIL T T T T) |package| NIL NIL) (|PartialFractionPackage| 4069894 4070055 4070382 "PFRPAC" 4070930 NIL PFRPAC (NIL T) |package| NIL NIL) (|PartialFraction| 4064428 4067178 4067828 "PFR" 4069315 NIL PFR (NIL T) |domain| NIL NIL) (|PointsOfFiniteOrderTools| 4061503 4061837 4062414 "PFOTOOLS" 4064034 NIL PFOTOOLS (NIL T T) |package| NIL NIL) (|PackageForPoly| 4051981 4052965 4054274 "PFORP" 4060382 NIL PFORP (NIL T T T NIL) |package| NIL NIL) (|PointsOfFiniteOrderRational| 4049221 4049602 4050272 "PFOQ" 4051566 NIL PFOQ (NIL T T T) |package| NIL NIL) (|PointsOfFiniteOrder| 4046405 4046726 4047386 "PFO" 4048866 NIL PFO (NIL T T T T T) |package| NIL NIL) (|PrimeField| 4041000 4046139 4046300 "PF" 4046305 NIL PF (NIL NIL) |domain| NIL NIL) (|PolynomialFactorizationExplicit| 4036036 4038147 4038239 "PFECAT" 4039580 T PFECAT (NIL) |category| NIL 4040483) (|PolynomialFactorizationExplicit&| 4034749 4035098 4035625 "PFECAT-" 4035630 NIL PFECAT- (NIL T) |domain| NIL NIL) (|PolynomialFactorizationByRecursionUnivariate| 4031173 4031750 4032557 "PFBRU" 4034130 NIL PFBRU (NIL T T) |package| NIL NIL) (|PolynomialFactorizationByRecursion| 4026182 4026951 4027987 "PFBR" 4030358 NIL PFBR (NIL T T T T) |package| NIL NIL) (|Permutation| 4019943 4021859 4022938 "PERM" 4025162 NIL PERM (NIL T) |domain| NIL NIL) (|PermutationGroup| 4011956 4013308 4014801 "PERMGRP" 4018519 NIL PERMGRP (NIL T) |domain| NIL NIL) (|PermutationCategory| 4009307 4010484 4010573 "PERMCAT" 4011336 NIL PERMCAT (NIL T) |category| |Permutation| 4011749) (|Permanent| 4008724 4008780 4008995 "PERMAN" 4009227 NIL PERMAN (NIL NIL T) |package| NIL NIL) (|PendantTree| 4005094 4008022 4008241 "PENDTREE" 4008564 NIL PENDTREE (NIL T) |domain| NIL NIL) (|PartialDifferentialRing| 4002013 4003054 4003151 "PDRING" 4004364 NIL PDRING (NIL T) |category| NIL 4004813) (|PartialDifferentialRing&| 4000643 4000943 4001537 "PDRING-" 4001542 NIL PDRING- (NIL T T) |domain| NIL NIL) (|NumericalPDEProblem| 3996436 3997482 3998527 "PDEPROB" 3999652 T PDEPROB (NIL) |domain| NIL NIL) (|AnnaPartialDifferentialEquationPackage| 3992157 3992968 3993962 "PDEPACK" 3995534 T PDEPACK (NIL) |package| NIL NIL) (|PolynomialDecomposition| 3990199 3990488 3990950 "PDECOMP" 3991815 NIL PDECOMP (NIL T T) |package| NIL NIL) (|PartialDifferentialEquationsSolverCategory| 3986581 3987728 3987842 "PDECAT" 3989069 T PDECAT (NIL) |category| NIL 3990117) (|PolynomialComposition| 3986143 3986180 3986356 "PCOMP" 3986520 NIL PCOMP (NIL T T) |package| NIL NIL) (|PoincareBirkhoffWittLyndonBasis| 3983113 3983870 3984421 "PBWLB" 3985684 NIL PBWLB (NIL T) |domain| NIL NIL) (|Pattern| 3971620 3973709 3975813 "PATTERN" 3981047 NIL PATTERN (NIL T) |domain| NIL NIL) (|PatternFunctions2| 3971019 3971093 3971283 "PATTERN2" 3971522 NIL PATTERN2 (NIL T T) |package| NIL NIL) (|PatternFunctions1| 3967396 3967945 3968677 "PATTERN1" 3970372 NIL PATTERN1 (NIL T T) |package| NIL NIL) (|PatternMatchResult| 3963299 3964012 3964758 "PATRES" 3966744 NIL PATRES (NIL T T) |domain| NIL NIL) (|PatternMatchResultFunctions2| 3962483 3962589 3962854 "PATRES2" 3963169 NIL PATRES2 (NIL T T T) |package| NIL NIL) (|PatternMatch| 3959181 3959702 3960301 "PATMATCH" 3962016 NIL PATMATCH (NIL T T T) |package| NIL NIL) (|PatternMatchable| 3958405 3958664 3958747 "PATMAB" 3958942 NIL PATMAB (NIL T) |category| NIL 3959099) (|PatternMatchListResult| 3955839 3956265 3956735 "PATLRES" 3958065 NIL PATLRES (NIL T T T) |domain| NIL NIL) (|Patternable| 3955111 3955296 3955362 "PATAB" 3955367 NIL PATAB (NIL T) |category| NIL 3955646) (|PartitionsAndPermutations| 3950960 3951738 3952695 "PARTPERM" 3954220 T PARTPERM (NIL) |package| NIL NIL) (|ParametricSurface| 3950320 3950410 3950593 "PARSURF" 3950841 NIL PARSURF (NIL T) |domain| NIL NIL) (|ParametricSurfaceFunctions2| 3949637 3949731 3949947 "PARSU2" 3950202 NIL PARSU2 (NIL T T) |package| NIL NIL) (|ParametricSpaceCurve| 3948993 3949081 3949268 "PARSCURV" 3949520 NIL PARSCURV (NIL T) |domain| NIL NIL) (|ParametricSpaceCurveFunctions2| 3948277 3948377 3948605 "PARSC2" 3948869 NIL PARSC2 (NIL T T) |package| NIL NIL) (|ParametricPlaneCurve| 3947651 3947734 3947916 "PARPCURV" 3948165 NIL PARPCURV (NIL T) |domain| NIL NIL) (|ParametricPlaneCurveFunctions2| 3946935 3947035 3947263 "PARPC2" 3947527 NIL PARPC2 (NIL T T) |package| NIL NIL) (|ParametrizationPackage| 3944138 3944271 3944834 "PARAMP" 3946715 NIL PARAMP (NIL T NIL T T T T T) |package| NIL NIL) (|PolynomialAN2Expression| 3943153 3943318 3943585 "PAN2EXPR" 3943933 T PAN2EXPR (NIL) |package| NIL NIL) (|Palette| 3941454 3941836 3942184 "PALETTE" 3942835 T PALETTE (NIL) |domain| NIL NIL) (|PackageForAlgebraicFunctionField| 3917300 3921225 3925452 "PAFF" 3937377 NIL PAFF (NIL T NIL T) |package| NIL NIL) (|PackageForAlgebraicFunctionFieldOverFiniteField| 3884535 3890410 3896306 "PAFFFF" 3911598 NIL PAFFFF (NIL T NIL T) |package| NIL NIL) (|PAdicRationalConstructor| 3874925 3883058 3883463 "PADICRC" 3884246 NIL PADICRC (NIL NIL T) |domain| NIL NIL) (|PAdicRational| 3863839 3873711 3874076 "PADICRAT" 3874619 NIL PADICRAT (NIL NIL) |domain| NIL NIL) (|PAdicInteger| 3861382 3863715 3863803 "PADIC" 3863808 NIL PADIC (NIL NIL) |domain| NIL NIL) (|PAdicIntegerCategory| 3856890 3859163 3859250 "PADICCT" 3860304 NIL PADICCT (NIL NIL) |category| NIL 3860815) (|PadeApproximantPackage| 3854943 3855321 3855838 "PADEPAC" 3856474 NIL PADEPAC (NIL T NIL NIL) |package| NIL NIL) (|PadeApproximants| 3853424 3853656 3854068 "PADE" 3854682 NIL PADE (NIL T T T) |package| NIL NIL) (|PseudoAlgebraicClosureOfRationalNumber| 3847602 3852445 3852790 "PACRAT" 3853171 T PACRAT (NIL) |domain| NIL NIL) (|PseudoAlgebraicClosureOfRationalNumberCategory| 3841186 3845877 3845999 "PACRATC" 3846004 T PACRATC (NIL) |category| NIL 3846203) (|PseudoAlgebraicClosureOfPerfectFieldCategory| 3834126 3837061 3837179 "PACPERC" 3839433 T PACPERC (NIL) |category| NIL 3840326) (|PseudoAlgebraicClosureOfFiniteField| 3828814 3833552 3833813 "PACOFF" 3833980 NIL PACOFF (NIL T) |domain| NIL NIL) (|PseudoAlgebraicClosureOfFiniteFieldCategory| 3823449 3827530 3827646 "PACFFC" 3827651 T PACFFC (NIL) |category| NIL 3827734) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| 3816345 3822506 3822869 "PACEXT" 3823242 NIL PACEXT (NIL NIL) |domain| NIL NIL) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| 3807749 3813790 3813928 "PACEXTC" 3813933 T PACEXTC (NIL) |category| NIL 3814117) (|OrdinaryWeightedPolynomials| 3804698 3805801 3806328 "OWP" 3807396 NIL OWP (NIL T NIL NIL NIL) |domain| NIL NIL) (|OrderedVariableList| 3803323 3803984 3804311 "OVAR" 3804450 NIL OVAR (NIL NIL) |domain| NIL NIL) (|OutputPackage| 3802167 3802328 3802593 "OUT" 3803100 T OUT (NIL) |package| NIL NIL) (|OutputForm| 3786417 3788966 3792157 "OUTFORM" 3799012 T OUTFORM (NIL) |domain| NIL NIL) (|OrdSetInts| 3785600 3785969 3786123 "OSI" 3786299 T OSI (NIL) |domain| NIL NIL) (|OrthogonalPolynomialFunctions| 3783136 3783523 3784088 "ORTHPOL" 3785134 NIL ORTHPOL (NIL T) |package| NIL NIL) (|UnivariateSkewPolynomial| 3779385 3782520 3782783 "OREUP" 3783021 NIL OREUP (NIL NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariateSkewPolynomial| 3775597 3778757 3779032 "ORESUP" 3779254 NIL ORESUP (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateSkewPolynomialCategoryOps| 3771390 3772112 3773023 "OREPCTO" 3774833 NIL OREPCTO (NIL T T) |package| NIL NIL) (|UnivariateSkewPolynomialCategory| 3761316 3764362 3764470 "OREPCAT" 3768948 NIL OREPCAT (NIL T) |category| NIL 3770693) (|UnivariateSkewPolynomialCategory&| 3757109 3758170 3759812 "OREPCAT-" 3759817 NIL OREPCAT- (NIL T T) |domain| NIL NIL) (|OrderedSet| 3755986 3756294 3756344 "ORDSET" 3756799 T ORDSET (NIL) |category| NIL 3757027) (|OrderedSet&| 3755382 3755509 3755774 "ORDSET-" 3755779 NIL ORDSET- (NIL T) |domain| NIL NIL) (|OrderedRing| 3753331 3754347 3754399 "ORDRING" 3754729 T ORDRING (NIL) |category| NIL 3754942) (|OrderedRing&| 3752793 3752915 3753151 "ORDRING-" 3753156 NIL ORDRING- (NIL T) |domain| NIL NIL) (|OrderedMonoid| 3751969 3752556 3752612 "ORDMON" 3752617 T ORDMON (NIL) |category| NIL 3752653) (|OrderingFunctions| 3750556 3750752 3751090 "ORDFUNS" 3751739 NIL ORDFUNS (NIL NIL T) |package| NIL NIL) (|OrderedFinite| 3749861 3750339 3750395 "ORDFIN" 3750400 T ORDFIN (NIL) |category| NIL 3750436) (|OrderedCompletion| 3744393 3747316 3748028 "ORDCOMP" 3749220 NIL ORDCOMP (NIL T) |domain| NIL NIL) (|OrderedCompletionFunctions2| 3742973 3743204 3743584 "ORDCOMP2" 3744125 NIL ORDCOMP2 (NIL T T) |package| NIL NIL) (|NumericalOptimizationProblem| 3737253 3738608 3740012 "OPTPROB" 3741641 T OPTPROB (NIL) |domain| NIL NIL) (|AnnaNumericalOptimizationPackage| 3731498 3732551 3733840 "OPTPACK" 3736044 T OPTPACK (NIL) |package| NIL NIL) (|NumericalOptimizationCategory| 3727672 3728808 3728896 "OPTCAT" 3730331 T OPTCAT (NIL) |category| NIL 3731416) (|OperationsQuery| 3727245 3727308 3727442 "OPQUERY" 3727584 T OPQUERY (NIL) |package| NIL NIL) (|Operator| 3722857 3724475 3725302 "OP" 3726464 NIL OP (NIL T) |domain| NIL NIL) (|OnePointCompletion| 3717880 3720728 3721357 "ONECOMP" 3722301 NIL ONECOMP (NIL T) |domain| NIL NIL) (|OnePointCompletionFunctions2| 3716521 3716730 3717090 "ONECOMP2" 3717634 NIL ONECOMP2 (NIL T T) |package| NIL NIL) (|OpenMathServerPackage| 3715431 3715608 3715877 "OMSERVER" 3716310 T OMSERVER (NIL) |package| NIL NIL) (|OrderedMultisetAggregate| 3710901 3714475 3714573 "OMSAGG" 3714684 NIL OMSAGG (NIL T) |category| NIL 3714803) (|OpenMathPackage| 3708560 3708957 3709459 "OMPKG" 3710445 T OMPKG (NIL) |package| NIL NIL) (|OpenMath| 3707644 3707793 3707839 "OM" 3708324 T OM (NIL) |category| NIL NIL) (|OppositeMonogenicLinearOperator| 3705390 3706799 3707127 "OMLO" 3707446 NIL OMLO (NIL T T) |domain| NIL NIL) (|ExpressionToOpenMath| 3703529 3703754 3704161 "OMEXPR" 3705090 NIL OMEXPR (NIL T) |package| NIL NIL) (|OpenMathError| 3702402 3702716 3702970 "OMERR" 3703317 T OMERR (NIL) |domain| NIL NIL) (|OpenMathErrorKind| 3700996 3701333 3701642 "OMERRK" 3702143 T OMERRK (NIL) |domain| NIL NIL) (|OpenMathEncoding| 3700044 3700321 3700551 "OMENC" 3700814 T OMENC (NIL) |domain| NIL NIL) (|OpenMathDevice| 3690187 3691854 3693800 "OMDEV" 3698142 T OMDEV (NIL) |domain| NIL NIL) (|OpenMathConnection| 3688430 3688722 3689116 "OMCONN" 3689845 T OMCONN (NIL) |domain| NIL NIL) (|OrderedIntegralDomain| 3686430 3687688 3687760 "OINTDOM" 3687765 T OINTDOM (NIL) |category| NIL 3687810) (|OrderedFreeMonoid| 3679812 3681386 3682526 "OFMONOID" 3685360 NIL OFMONOID (NIL T) |domain| NIL NIL) (|OrderlyDifferentialVariable| 3678993 3679639 3679768 "ODVAR" 3679773 NIL ODVAR (NIL T) |domain| NIL NIL) (|OrdinaryDifferentialRing| 3674932 3678115 3678437 "ODR" 3678804 NIL ODR (NIL T T NIL) |domain| NIL NIL) (|OrderlyDifferentialPolynomial| 3661779 3674369 3674692 "ODPOL" 3674697 NIL ODPOL (NIL T) |domain| NIL NIL) (|OrderedDirectProduct| 3653039 3661522 3661737 "ODP" 3661742 NIL ODP (NIL NIL T NIL) |domain| NIL NIL) (|ODETools| 3650884 3651196 3651671 "ODETOOLS" 3652668 NIL ODETOOLS (NIL T T) |package| NIL NIL) (|SystemODESolver| 3646569 3647394 3648392 "ODESYS" 3650004 NIL ODESYS (NIL T T) |package| NIL NIL) (|RationalRicDE| 3636628 3638308 3640254 "ODERTRIC" 3644828 NIL ODERTRIC (NIL T T) |package| NIL NIL) (|ReduceLODE| 3635604 3635706 3636076 "ODERED" 3636502 NIL ODERED (NIL T T T T T) |package| NIL NIL) (|RationalLODE| 3629816 3630749 3632003 "ODERAT" 3634553 NIL ODERAT (NIL T T) |package| NIL NIL) (|PrimitiveRatRicDE| 3624121 3624775 3625806 "ODEPRRIC" 3629095 NIL ODEPRRIC (NIL T T T T) |package| NIL NIL) (|NumericalODEProblem| 3620883 3621686 3622489 "ODEPROB" 3623372 T ODEPROB (NIL) |domain| NIL NIL) (|PrimitiveRatDE| 3614333 3614966 3616068 "ODEPRIM" 3620085 NIL ODEPRIM (NIL T T T T) |package| NIL NIL) (|PureAlgebraicLODE| 3612955 3613111 3613606 "ODEPAL" 3614153 NIL ODEPAL (NIL T T T T) |package| NIL NIL) (|AnnaOrdinaryDifferentialEquationPackage| 3606656 3607825 3609231 "ODEPACK" 3611643 T ODEPACK (NIL) |package| NIL NIL) (|ODEIntegration| 3604709 3604836 3605305 "ODEINT" 3606495 NIL ODEINT (NIL T T) |package| NIL NIL) (|ODEIntensityFunctionsTable| 3596257 3598226 3600312 "ODEIFTBL" 3602691 T ODEIFTBL (NIL) |domain| NIL NIL) (|ElementaryFunctionODESolver| 3588266 3589304 3590805 "ODEEF" 3595090 NIL ODEEF (NIL T T) |package| NIL NIL) (|ConstantLODE| 3586985 3587095 3587590 "ODECONST" 3588132 NIL ODECONST (NIL T T T) |package| NIL NIL) (|OrdinaryDifferentialEquationsSolverCategory| 3584089 3584994 3585110 "ODECAT" 3586097 T ODECAT (NIL) |category| NIL 3586903) (|Octonion| 3579735 3583569 3583789 "OCT" 3583926 NIL OCT (NIL T) |domain| NIL NIL) (|OctonionCategoryFunctions2| 3579073 3579123 3579377 "OCTCT2" 3579661 NIL OCTCT2 (NIL T T T T) |package| NIL NIL) (|OctonionCategory| 3571191 3574454 3574541 "OC" 3576603 NIL OC (NIL T) |category| |Octonion| 3577875) (|OctonionCategory&| 3567107 3568082 3569590 "OC-" 3569789 NIL OC- (NIL T T) |domain| NIL NIL) (|OrderedCancellationAbelianMonoid| 3566159 3566688 3566782 "OCAMON" 3566787 T OCAMON (NIL) |category| NIL 3566852) (|OrderedAbelianSemiGroup| 3565402 3565881 3565957 "OASGP" 3565962 T OASGP (NIL) |category| NIL 3566005) (|OrderedAbelianMonoidSup| 3564314 3564864 3564940 "OAMONS" 3565011 T OAMONS (NIL) |category| NIL 3565104) (|OrderedAbelianMonoid| 3563516 3563995 3564065 "OAMON" 3564070 T OAMON (NIL) |category| NIL 3564126) (|OrderedAbelianGroup| 3562478 3563058 3563126 "OAGROUP" 3563131 T OAGROUP (NIL) |category| NIL 3563195) (|NumericTubePlot| 3561921 3561991 3562168 "NUMTUBE" 3562384 NIL NUMTUBE (NIL T) |package| NIL NIL) (|NumericalQuadrature| 3552538 3554674 3556928 "NUMQUAD" 3559721 T NUMQUAD (NIL) |package| NIL NIL) (|NumericalOrdinaryDifferentialEquations| 3546244 3547608 3549131 "NUMODE" 3551107 T NUMODE (NIL) |package| NIL NIL) (|NumericalIntegrationCategory| 3542043 3543312 3543398 "NUMINT" 3544945 T NUMINT (NIL) |category| NIL 3546162) (|NumberFormats| 3540060 3540409 3540849 "NUMFMT" 3541645 T NUMFMT (NIL) |package| NIL NIL) (|Numeric| 3516442 3520953 3525346 "NUMERIC" 3535730 NIL NUMERIC (NIL T) |package| NIL NIL) (|NormalizedTriangularSetCategory| 3508433 3515518 3515737 "NTSCAT" 3515742 NIL NTSCAT (NIL T T T T) |category| NIL 3515809) (|NumberTheoreticPolynomialFunctions| 3506897 3507161 3507542 "NTPOLFN" 3508161 NIL NTPOLFN (NIL T) |package| NIL NIL) (|NewSparseUnivariatePolynomial| 3486507 3500923 3502336 "NSUP" 3505572 NIL NSUP (NIL T) |domain| NIL NIL) (|NewSparseUnivariatePolynomialFunctions2| 3485692 3485810 3486074 "NSUP2" 3486365 NIL NSUP2 (NIL T T) |package| NIL NIL) (|NewSparseMultivariatePolynomial| 3470477 3485179 3485489 "NSMP" 3485494 NIL NSMP (NIL T T) |domain| NIL NIL) (|NeitherSparseOrDensePowerSeries| 3453691 3469729 3470045 "NSDPS" 3470254 NIL NSDPS (NIL T) |domain| NIL NIL) (|NumericRealEigenPackage| 3450971 3451440 3452079 "NREP" 3453154 NIL NREP (NIL T) |package| NIL NIL) (|NewtonPolygon| 3446561 3447271 3448221 "NPOLYGON" 3450207 NIL NPOLYGON (NIL T T T NIL) |package| NIL NIL) (|NPCoef| 3444227 3444593 3445180 "NPCOEF" 3446166 NIL NPCOEF (NIL T T T T T) |package| NIL NIL) (|NottinghamGroup| 3443133 3443782 3443960 "NOTTING" 3444124 NIL NOTTING (NIL T) |domain| NIL NIL) (|NormRetractPackage| 3441157 3441348 3441809 "NORMRETR" 3442908 NIL NORMRETR (NIL T T T T NIL) |package| NIL NIL) (|NormalizationPackage| 3437827 3438198 3438851 "NORMPK" 3440742 NIL NORMPK (NIL T T T T T) |package| NIL NIL) (|NormInMonogenicAlgebra| 3437222 3437251 3437505 "NORMMA" 3437774 NIL NORMMA (NIL T T T T) |package| NIL NIL) (|None| 3436999 3437159 3437200 "NONE" 3437205 T NONE (NIL) |domain| NIL NIL) (|NoneFunctions1| 3436668 3436702 3436819 "NONE1" 3436940 NIL NONE1 (NIL T) |package| NIL NIL) (|NonLinearFirstOrderODESolver| 3435582 3435665 3436108 "NODE1" 3436561 NIL NODE1 (NIL T T) |package| NIL NIL) (|NonNegativeInteger| 3433139 3434199 3434619 "NNI" 3435214 T NNI (NIL) |domain| NIL NIL) (|NonLinearSolvePackage| 3430500 3430970 3431588 "NLINSOL" 3432603 NIL NLINSOL (NIL T) |package| NIL NIL) (|NumericalIntegrationProblem| 3424399 3425851 3427350 "NIPROB" 3429071 T NIPROB (NIL) |domain| NIL NIL) (|NumberFieldIntegralBasis| 3422297 3422637 3423165 "NFINTBAS" 3424025 NIL NFINTBAS (NIL T T) |package| NIL NIL) (|NewtonInterpolation| 3421769 3421840 3422013 "NEWTON" 3422202 NIL NEWTON (NIL T) |package| NIL NIL) (|NonCommutativeOperatorDivision| 3419538 3419839 3420318 "NCODIV" 3421419 NIL NCODIV (NIL T T) |package| NIL NIL) (|NumericContinuedFraction| 3419002 3419073 3419261 "NCNTFRAC" 3419443 NIL NCNTFRAC (NIL T) |package| NIL NIL) (|NumericComplexEigenPackage| 3415808 3416391 3417150 "NCEP" 3418351 NIL NCEP (NIL T) |package| NIL NIL) (|NonAssociativeRing| 3414094 3415108 3415174 "NASRING" 3415387 T NASRING (NIL) |category| NIL 3415548) (|NonAssociativeRing&| 3413739 3413799 3413985 "NASRING-" 3413990 NIL NASRING- (NIL T) |domain| NIL NIL) (|NonAssociativeRng| 3412430 3413088 3413152 "NARNG" 3413369 T NARNG (NIL) |category| NIL 3413531) (|NonAssociativeRng&| 3411942 3412034 3412269 "NARNG-" 3412274 NIL NARNG- (NIL T) |domain| NIL NIL) (|NAGLinkSupportPackage| 3409842 3410182 3410651 "NAGSP" 3411531 T NAGSP (NIL) |package| NIL NIL) (|NagSpecialFunctionsPackage| 3394520 3397196 3400149 "NAGS" 3406957 T NAGS (NIL) |package| NIL NIL) (|NagLapack| 3392125 3392618 3393184 "NAGF07" 3393988 T NAGF07 (NIL) |package| NIL NIL) (|NagLinearEquationSolvingPackage| 3382799 3384932 3387217 "NAGF04" 3389918 T NAGF04 (NIL) |package| NIL NIL) (|NagEigenPackage| 3371155 3373783 3376567 "NAGF02" 3380061 T NAGF02 (NIL) |package| NIL NIL) (|NagMatrixOperationsPackage| 3363020 3364831 3366779 "NAGF01" 3369275 T NAGF01 (NIL) |package| NIL NIL) (|NagOptimisationPackage| 3352415 3355031 3357766 "NAGE04" 3360345 T NAGE04 (NIL) |package| NIL NIL) (|NagFittingPackage| 3337018 3340710 3344561 "NAGE02" 3348614 T NAGE02 (NIL) |package| NIL NIL) (|NagInterpolationPackage| 3329827 3331475 3333254 "NAGE01" 3335301 T NAGE01 (NIL) |package| NIL NIL) (|NagPartialDifferentialEquationsPackage| 3325875 3326814 3327879 "NAGD03" 3328854 T NAGD03 (NIL) |package| NIL NIL) (|NagOrdinaryDifferentialEquationsPackage| 3312737 3315732 3318896 "NAGD02" 3322805 T NAGD02 (NIL) |package| NIL NIL) (|NagIntegrationPackage| 3302603 3304900 3307334 "NAGD01" 3310361 T NAGD01 (NIL) |package| NIL NIL) (|NagSeriesSummationPackage| 3296070 3297404 3298883 "NAGC06" 3301190 T NAGC06 (NIL) |package| NIL NIL) (|NagRootFindingPackage| 3293588 3294097 3294698 "NAGC05" 3295527 T NAGC05 (NIL) |package| NIL NIL) (|NagPolynomialRootsPackage| 3292482 3292669 3292951 "NAGC02" 3293372 T NAGC02 (NIL) |package| NIL NIL) (|NonAssociativeAlgebra| 3291024 3291762 3291859 "NAALG" 3292020 NIL NAALG (NIL T) |category| NIL 3292142) (|NonAssociativeAlgebra&| 3290687 3290738 3290939 "NAALG-" 3290944 NIL NAALG- (NIL T T) |domain| NIL NIL) (|MyUnivariatePolynomial| 3276053 3289183 3289664 "MYUP" 3290296 NIL MYUP (NIL NIL T) |domain| NIL NIL) (|MyExpression| 3261819 3273346 3274031 "MYEXPR" 3275481 NIL MYEXPR (NIL NIL T) |domain| NIL NIL) (|MultivariateSquareFree| 3250419 3252334 3254523 "MULTSQFR" 3259811 NIL MULTSQFR (NIL T T T T) |package| NIL NIL) (|MultivariateFactorize| 3249010 3249146 3249533 "MULTFACT" 3250243 NIL MULTFACT (NIL T T T T) |package| NIL NIL) (|MultivariateTaylorSeriesCategory| 3238050 3243467 3243595 "MTSCAT" 3245707 NIL MTSCAT (NIL T T) |category| NIL 3246687) (|MergeThing| 3237592 3237664 3237816 "MTHING" 3237954 NIL MTHING (NIL T) |package| NIL NIL) (|MoreSystemCommands| 3237220 3237267 3237391 "MSYSCMD" 3237520 T MSYSCMD (NIL) |package| NIL NIL) (|Multiset| 3231468 3235160 3235697 "MSET" 3236736 NIL MSET (NIL T) |domain| NIL NIL) (|MultisetAggregate| 3227279 3230762 3230847 "MSETAGG" 3230852 NIL MSETAGG (NIL T) |category| |Multiset| 3230911) (|MonoidRing| 3221001 3223134 3224277 "MRING" 3226202 NIL MRING (NIL T T) |domain| NIL NIL) (|MonoidRingFunctions2| 3220311 3220401 3220615 "MRF2" 3220887 NIL MRF2 (NIL T T T) |package| NIL NIL) (|MRationalFactorize| 3219587 3219631 3219917 "MRATFAC" 3220243 NIL MRATFAC (NIL T T T T) |package| NIL NIL) (|MPolyCatRationalFunctionFactorizer| 3215125 3215553 3216333 "MPRFF" 3219105 NIL MPRFF (NIL T T T T) |package| NIL NIL) (|MultivariatePolynomial| 3205272 3214805 3215012 "MPOLY" 3215017 NIL MPOLY (NIL NIL T) |domain| NIL NIL) (|MPolyCatPolyFactorizer| 3204350 3204394 3204781 "MPCPF" 3205204 NIL MPCPF (NIL T T T T) |package| NIL NIL) (|MPolyCatFunctions3| 3203484 3203534 3203866 "MPC3" 3204276 NIL MPC3 (NIL T T T T T T T) |package| NIL NIL) (|MPolyCatFunctions2| 3202091 3202185 3202559 "MPC2" 3203362 NIL MPC2 (NIL T T T T T T T) |package| NIL NIL) (|MonomialExtensionTools| 3199400 3199856 3200469 "MONOTOOL" 3201596 NIL MONOTOOL (NIL T T) |package| NIL NIL) (|Monoid| 3198115 3198550 3198592 "MONOID" 3199016 T MONOID (NIL) |category| NIL 3199298) (|Monoid&| 3197171 3197404 3197780 "MONOID-" 3197785 NIL MONOID- (NIL T) |domain| NIL NIL) (|MonogenicAlgebra| 3183145 3191735 3191866 "MONOGEN" 3193242 NIL MONOGEN (NIL T T) |category| NIL 3193999) (|MonogenicAlgebra&| 3178725 3179742 3181396 "MONOGEN-" 3181645 NIL MONOGEN- (NIL T T T) |domain| NIL NIL) (|MonadWithUnit| 3176906 3177492 3177548 "MONADWU" 3178222 T MONADWU (NIL) |category| NIL 3178627) (|MonadWithUnit&| 3175793 3176058 3176513 "MONADWU-" 3176518 NIL MONADWU- (NIL T) |domain| NIL NIL) (|Monad| 3174826 3175126 3175166 "MONAD" 3175501 T MONAD (NIL) |category| NIL 3175711) (|Monad&| 3174286 3174416 3174640 "MONAD-" 3174645 NIL MONAD- (NIL T) |domain| NIL NIL) (|MoebiusTransform| 3171747 3172569 3173000 "MOEBIUS" 3173918 NIL MOEBIUS (NIL T) |domain| NIL NIL) (|Module| 3170906 3171366 3171433 "MODULE" 3171438 NIL MODULE (NIL T) |category| NIL 3171473) (|Module&| 3170263 3170393 3170685 "MODULE-" 3170690 NIL MODULE- (NIL T T) |domain| NIL NIL) (|ModularRing| 3166851 3167741 3168217 "MODRING" 3170012 NIL MODRING (NIL T T NIL NIL NIL) |domain| NIL NIL) (|ModuleOperator| 3162047 3163639 3164503 "MODOP" 3166070 NIL MODOP (NIL T T) |domain| NIL NIL) (|ModuleMonomial| 3159383 3159910 3160426 "MODMONOM" 3161749 NIL MODMONOM (NIL T T NIL) |domain| NIL NIL) (|ModMonic| 3142706 3156297 3156970 "MODMON" 3158799 NIL MODMON (NIL T T) |domain| NIL NIL) (|ModularField| 3138524 3140910 3141320 "MODFIELD" 3142523 NIL MODFIELD (NIL T T NIL NIL NIL) |domain| NIL NIL) (|MathMLFormat| 3136941 3137311 3137640 "MMLFORM" 3138235 T MMLFORM (NIL) |domain| NIL NIL) (|MultipleMap| 3136028 3136078 3136436 "MMAP" 3136867 NIL MMAP (NIL T T T T T T) |package| NIL NIL) (|MonogenicLinearOperator| 3133144 3134225 3134315 "MLO" 3135132 NIL MLO (NIL T) |category| NIL 3135566) (|MultivariateLifting| 3128283 3129199 3130324 "MLIFT" 3132194 NIL MLIFT (NIL T T T T) |package| NIL NIL) (|MakeUnaryCompiledFunction| 3127194 3127321 3127608 "MKUCFUNC" 3128127 NIL MKUCFUNC (NIL T T T) |package| NIL NIL) (|MakeRecord| 3126641 3126724 3126896 "MKRECORD" 3127086 NIL MKRECORD (NIL T T) |package| NIL NIL) (|MakeFunction| 3125159 3125363 3125723 "MKFUNC" 3126358 NIL MKFUNC (NIL T) |package| NIL NIL) (|MakeFloatCompiledFunction| 3123918 3124104 3124444 "MKFLCFN" 3124922 NIL MKFLCFN (NIL T) |package| NIL NIL) (|MakeCachableSet| 3123104 3123553 3123717 "MKCHSET" 3123821 NIL MKCHSET (NIL T) |domain| NIL NIL) (|MakeBinaryCompiledFunction| 3121861 3122010 3122335 "MKBCFUNC" 3122926 NIL MKBCFUNC (NIL T T T T) |package| NIL NIL) (|MachineInteger| 3116985 3120947 3121249 "MINT" 3121603 T MINT (NIL) |domain| NIL NIL) (|ModularHermitianRowReduction| 3114971 3115306 3115782 "MHROWRED" 3116606 NIL MHROWRED (NIL T) |package| NIL NIL) (|MachineFloat| 3107345 3111992 3112865 "MFLOAT" 3114138 T MFLOAT (NIL) |domain| NIL NIL) (|MultFiniteFactorize| 3106027 3106164 3106519 "MFINFACT" 3107169 NIL MFINFACT (NIL T T T T) |package| NIL NIL) (|MeshCreationRoutinesForThreeDimensions| 3098516 3100206 3102068 "MESH" 3104257 T MESH (NIL) |package| NIL NIL) (|ModularDistinctDegreeFactorizer| 3095808 3096223 3096815 "MDDFACT" 3098052 NIL MDDFACT (NIL T) |package| NIL NIL) (|MultiDictionary| 3091114 3094435 3094516 "MDAGG" 3094979 NIL MDAGG (NIL T) |category| NIL 3095241) (|MachineComplex| 3072946 3089842 3090237 "MCMPLX" 3090763 T MCMPLX (NIL) |domain| NIL NIL) (|MatrixCommonDenominator| 3071410 3071622 3071991 "MCDEN" 3072699 NIL MCDEN (NIL T T) |package| NIL NIL) (|MultiVariableCalculusFunctions| 3067296 3067681 3068387 "MCALCFN" 3070971 NIL MCALCFN (NIL T T T T) |package| NIL NIL) (|StorageEfficientMatrixOperations| 3063481 3064200 3065088 "MATSTOR" 3066502 NIL MATSTOR (NIL T) |package| NIL NIL) (|Matrix| 3057655 3062537 3062905 "MATRIX" 3063155 NIL MATRIX (NIL T) |domain| NIL NIL) (|MatrixLinearAlgebraFunctions| 3050071 3051062 3052221 "MATLIN" 3056704 NIL MATLIN (NIL T T T T) |package| NIL NIL) (|MatrixCategory| 3032287 3036859 3037005 "MATCAT" 3047179 NIL MATCAT (NIL T T T) |category| NIL 3049618) (|MatrixCategory&| 3026463 3027983 3030218 "MATCAT-" 3030223 NIL MATCAT- (NIL T T T T) |domain| NIL NIL) (|MatrixCategoryFunctions2| 3024060 3024247 3024790 "MATCAT2" 3026234 NIL MATCAT2 (NIL T T T T T T T T) |package| NIL NIL) (|MappingPackage4| 3022099 3022476 3022973 "MAPPKG4" 3023644 NIL MAPPKG4 (NIL T T) |package| NIL NIL) (|MappingPackage3| 3019011 3019460 3020067 "MAPPKG3" 3021601 NIL MAPPKG3 (NIL T T T) |package| NIL NIL) (|MappingPackage2| 3017358 3017590 3017949 "MAPPKG2" 3018740 NIL MAPPKG2 (NIL T T) |package| NIL NIL) (|MappingPackage1| 3014859 3015273 3015825 "MAPPKG1" 3016873 NIL MAPPKG1 (NIL T) |package| NIL NIL) (|MappingPackageInternalHacks3| 3014194 3014267 3014499 "MAPHACK3" 3014762 NIL MAPHACK3 (NIL T T T) |package| NIL NIL) (|MappingPackageInternalHacks2| 3013522 3013585 3013793 "MAPHACK2" 3014100 NIL MAPHACK2 (NIL T T) |package| NIL NIL) (|MappingPackageInternalHacks1| 3012456 3012624 3012915 "MAPHACK1" 3013324 NIL MAPHACK1 (NIL T) |package| NIL NIL) (|MatrixManipulation| 3000111 3001534 3003417 "MAMA" 3010751 NIL MAMA (NIL T T T T) |package| NIL NIL) (|Magma| 2997313 2998029 2998516 "MAGMA" 2999670 NIL MAGMA (NIL T) |domain| NIL NIL) (|ModularAlgebraicGcdOperations| 2994471 2994974 2995090 "MAGCDOC" 2996719 NIL MAGCDOC (NIL T T) |category| NIL NIL) (|ThreeDimensionalMatrix| 2988417 2991052 2991972 "M3D" 2993632 NIL M3D (NIL T) |domain| NIL NIL) (|LazyStreamAggregate| 2979681 2985667 2985749 "LZSTAGG" 2987137 NIL LZSTAGG (NIL T) |category| NIL 2987656) (|LazyStreamAggregate&| 2973681 2975280 2977530 "LZSTAGG-" 2977535 NIL LZSTAGG- (NIL T T) |domain| NIL NIL) (|LyndonWord| 2968900 2969963 2970828 "LWORD" 2972872 NIL LWORD (NIL T) |domain| NIL NIL) (|LieSquareMatrix| 2958714 2968459 2968725 "LSQM" 2968730 NIL LSQM (NIL NIL T) |domain| NIL NIL) (|LinearSystemPolynomialPackage| 2957467 2957648 2958047 "LSPP" 2958509 NIL LSPP (NIL T T T T) |package| NIL NIL) (|LinearSystemMatrixPackage| 2953667 2954055 2954811 "LSMP" 2957025 NIL LSMP (NIL T T T T) |package| NIL NIL) (|LinearSystemMatrixPackage1| 2949014 2949885 2950923 "LSMP1" 2952712 NIL LSMP1 (NIL T) |package| NIL NIL) (|ListAggregate| 2940373 2947715 2947785 "LSAGG" 2947880 NIL LSAGG (NIL T) |category| NIL 2948033) (|ListAggregate&| 2935708 2936916 2938685 "LSAGG-" 2938690 NIL LSAGG- (NIL T T) |domain| NIL NIL) (|LiePolynomial| 2932077 2934163 2934607 "LPOLY" 2935351 NIL LPOLY (NIL T T) |domain| NIL NIL) (|LinearPolynomialEquationByFractions| 2931002 2931202 2931553 "LPEFRAC" 2931853 NIL LPEFRAC (NIL T) |package| NIL NIL) (|LocalParametrizationOfSimplePointPackage| 2926408 2926746 2927526 "LPARSPT" 2930601 NIL LPARSPT (NIL T NIL T T T T T) |package| NIL NIL) (|LeftOreRing| 2924889 2925720 2925772 "LORER" 2925923 T LORER (NIL) |category| NIL 2926059) (|LinesOpPack| 2922487 2922952 2923519 "LOP" 2924375 NIL LOP (NIL T) |package| NIL NIL) (|Localize| 2920199 2921136 2921500 "LO" 2922241 NIL LO (NIL T T T) |domain| NIL NIL) (|Logic| 2919763 2919874 2919914 "LOGIC" 2920060 T LOGIC (NIL) |category| NIL 2920176) (|Logic&| 2919580 2919603 2919702 "LOGIC-" 2919707 NIL LOGIC- (NIL T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperatorsOps| 2917977 2918184 2918589 "LODOOPS" 2919339 NIL LODOOPS (NIL T T) |package| NIL NIL) (|LinearOrdinaryDifferentialOperator| 2914332 2917741 2917919 "LODO" 2917924 NIL LODO (NIL T NIL) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperatorFactorizer| 2910939 2911476 2912307 "LODOF" 2913768 NIL LODOF (NIL T T) |package| NIL NIL) (|LinearOrdinaryDifferentialOperatorCategory| 2905414 2908760 2908888 "LODOCAT" 2909810 NIL LODOCAT (NIL T) |category| NIL 2910166) (|LinearOrdinaryDifferentialOperatorCategory&| 2904930 2905000 2905291 "LODOCAT-" 2905296 NIL LODOCAT- (NIL T T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperator2| 2901120 2904557 2904841 "LODO2" 2904846 NIL LODO2 (NIL T T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperator1| 2897479 2900897 2901062 "LODO1" 2901067 NIL LODO1 (NIL T) |domain| NIL NIL) (|ElementaryFunctionLODESolver| 2895345 2895540 2896166 "LODEEF" 2897246 NIL LODEEF (NIL T T T) |package| NIL NIL) (|LocalPowerSeriesCategory| 2884115 2889993 2890086 "LOCPOWC" 2892765 NIL LOCPOWC (NIL T) |category| |NeitherSparseOrDensePowerSeries| 2893735) (|LinearAggregate| 2877102 2881150 2881224 "LNAGG" 2882792 NIL LNAGG (NIL T) |category| NIL 2883489) (|LinearAggregate&| 2875897 2876163 2876676 "LNAGG-" 2876681 NIL LNAGG- (NIL T T) |domain| NIL NIL) (|ListMonoidOps| 2869654 2870689 2871730 "LMOPS" 2874952 NIL LMOPS (NIL T T NIL) |domain| NIL NIL) (|LeftModule| 2868793 2869237 2869300 "LMODULE" 2869389 NIL LMODULE (NIL T) |category| NIL 2869462) (|ListMultiDictionary| 2864703 2868126 2868369 "LMDICT" 2868625 NIL LMDICT (NIL T) |domain| NIL NIL) (|LinearSystemFromPowerSeriesPackage| 2863040 2863262 2863656 "LISYSER" 2864447 NIL LISYSER (NIL T T) |package| NIL NIL) (|List| 2853524 2861477 2861909 "LIST" 2862646 NIL LIST (NIL T) |domain| NIL NIL) (|ListFunctions3| 2852849 2852936 2853133 "LIST3" 2853413 NIL LIST3 (NIL T T T) |package| NIL NIL) (|ListFunctions2| 2851440 2851653 2851972 "LIST2" 2852602 NIL LIST2 (NIL T T) |package| NIL NIL) (|ListToMap| 2848796 2849169 2849710 "LIST2MAP" 2850968 NIL LIST2MAP (NIL T T) |package| NIL NIL) (|LinearlyExplicitRingOver| 2846871 2847770 2847862 "LINEXP" 2848291 NIL LINEXP (NIL T) |category| NIL 2848515) (|LinearDependence| 2844637 2844986 2845475 "LINDEP" 2846493 NIL LINDEP (NIL T T) |package| NIL NIL) (|RationalFunctionLimitPackage| 2838862 2840094 2841498 "LIMITRF" 2843324 NIL LIMITRF (NIL T) |package| NIL NIL) (|PowerSeriesLimitPackage| 2835661 2836126 2836910 "LIMITPS" 2838355 NIL LIMITPS (NIL T T) |package| NIL NIL) (|AssociatedLieAlgebra| 2826179 2834681 2835148 "LIE" 2835311 NIL LIE (NIL T T) |domain| NIL NIL) (|LieAlgebra| 2824842 2825372 2825447 "LIECAT" 2825684 NIL LIECAT (NIL T) |category| NIL 2825883) (|LieAlgebra&| 2824622 2824645 2824785 "LIECAT-" 2824790 NIL LIECAT- (NIL T T) |domain| NIL NIL) (|Library| 2814222 2823678 2823961 "LIB" 2824369 T LIB (NIL) |domain| NIL NIL) (|LinGroebnerPackage| 2804555 2806579 2808782 "LGROBP" 2812115 NIL LGROBP (NIL NIL T) |package| NIL NIL) (|LiouvillianFunction| 2799966 2800364 2801048 "LF" 2804065 NIL LF (NIL T T) |package| NIL NIL) (|LiouvillianFunctionCategory| 2797967 2798747 2798831 "LFCAT" 2799394 T LFCAT (NIL) |category| NIL 2799689) (|LexTriangularPackage| 2791118 2792539 2794131 "LEXTRIPK" 2796475 NIL LEXTRIPK (NIL T NIL) |package| NIL NIL) (|LieExponentials| 2785683 2786844 2787686 "LEXP" 2790437 NIL LEXP (NIL T T NIL) |domain| NIL NIL) (|LeadingCoefDetermination| 2783122 2783559 2784210 "LEADCDET" 2785217 NIL LEADCDET (NIL T T T T) |package| NIL NIL) (|LazardSetSolvingPackage| 2781544 2781647 2782091 "LAZM3PK" 2782990 NIL LAZM3PK (NIL T T T T T T) |package| NIL NIL) (|LaurentPolynomial| 2773318 2777904 2778873 "LAUPOL" 2780692 NIL LAUPOL (NIL T T) |domain| NIL NIL) (|LaplaceTransform| 2772400 2772454 2772844 "LAPLACE" 2773240 NIL LAPLACE (NIL T T) |package| NIL NIL) (|LocalAlgebra| 2769572 2771050 2771408 "LA" 2772169 NIL LA (NIL T T T) |domain| NIL NIL) (|LeftAlgebra| 2768238 2769013 2769079 "LALG" 2769174 NIL LALG (NIL T) |category| NIL 2769265) (|LeftAlgebra&| 2767804 2767879 2768096 "LALG-" 2768101 NIL LALG- (NIL T T) |domain| NIL NIL) (|Kovacic| 2765773 2766081 2766642 "KOVACIC" 2767455 NIL KOVACIC (NIL T T) |package| NIL NIL) (|ConvertibleTo| 2765515 2765543 2765613 "KONVERT" 2765711 NIL KONVERT (NIL T) |category| NIL NIL) (|CoercibleTo| 2765266 2765293 2765359 "KOERCE" 2765454 NIL KOERCE (NIL T) |category| NIL NIL) (|Kernel| 2761697 2762747 2763408 "KERNEL" 2764653 NIL KERNEL (NIL T) |domain| NIL NIL) (|KernelFunctions2| 2760844 2760959 2761191 "KERNEL2" 2761553 NIL KERNEL2 (NIL T T) |package| NIL NIL) (|KeyedDictionary| 2752261 2758462 2758564 "KDAGG" 2759209 NIL KDAGG (NIL T T) |category| NIL 2759495) (|KeyedDictionary&| 2751597 2751747 2752064 "KDAGG-" 2752069 NIL KDAGG- (NIL T T T) |domain| NIL NIL) (|KeyedAccessFile| 2742209 2751019 2751290 "KAFILE" 2751393 NIL KAFILE (NIL T) |domain| NIL NIL) (|AssociatedJordanAlgebra| 2732718 2741220 2741693 "JORDAN" 2741859 NIL JORDAN (NIL T T) |domain| NIL NIL) (|IndexedAggregate| 2727241 2729879 2729976 "IXAGG" 2731598 NIL IXAGG (NIL T T) |category| NIL 2732253) (|IndexedAggregate&| 2725815 2726167 2726762 "IXAGG-" 2726767 NIL IXAGG- (NIL T T T) |domain| NIL NIL) (|IndexedVector| 2719698 2725687 2725785 "IVECTOR" 2725790 NIL IVECTOR (NIL T NIL) |domain| NIL NIL) (|InfiniteTuple| 2717736 2718067 2718506 "ITUPLE" 2719315 NIL ITUPLE (NIL T) |domain| NIL NIL) (|InnerTrigonometricManipulations| 2714691 2714907 2715488 "ITRIGMNP" 2717477 NIL ITRIGMNP (NIL T T T) |package| NIL NIL) (|InfiniteTupleFunctions3| 2712697 2712989 2713435 "ITFUN3" 2714349 NIL ITFUN3 (NIL T T T) |package| NIL NIL) (|InfiniteTupleFunctions2| 2712058 2712144 2712344 "ITFUN2" 2712587 NIL ITFUN2 (NIL T T) |package| NIL NIL) (|InnerTaylorSeries| 2708692 2710153 2710658 "ITAYLOR" 2711617 NIL ITAYLOR (NIL T) |domain| NIL NIL) (|InnerSparseUnivariatePowerSeries| 2691112 2698368 2700227 "ISUPS" 2706927 NIL ISUPS (NIL T) |domain| NIL NIL) (|InnerPolySum| 2689733 2689899 2690262 "ISUMP" 2690909 NIL ISUMP (NIL T T T T) |package| NIL NIL) (|IndexedString| 2682343 2689393 2689537 "ISTRING" 2689648 NIL ISTRING (NIL NIL) |domain| NIL NIL) (|InternalRationalUnivariateRepresentationPackage| 2680741 2680841 2681310 "IRURPK" 2682214 NIL IRURPK (NIL T T T T T) |package| NIL NIL) (|IrrRepSymNatPackage| 2678619 2678980 2679494 "IRSN" 2680281 T IRSN (NIL) |package| NIL NIL) (|IntegrationResultRFToFunction| 2674820 2675440 2676280 "IRRF2F" 2677967 NIL IRRF2F (NIL T) |package| NIL NIL) (|IrredPolyOverFiniteField| 2674197 2674285 2674490 "IRREDFFX" 2674708 NIL IRREDFFX (NIL T) |package| NIL NIL) (|IntegerRoots| 2671657 2672072 2672629 "IROOT" 2673709 NIL IROOT (NIL T) |package| NIL NIL) (|IntegrationResult| 2666565 2667974 2669040 "IR" 2670656 NIL IR (NIL T) |domain| NIL NIL) (|IntegrationResultFunctions2| 2663197 2663828 2664622 "IR2" 2665871 NIL IR2 (NIL T T) |package| NIL NIL) (|IntegrationResultToFunction| 2661191 2661381 2661880 "IR2F" 2662973 NIL IR2F (NIL T T) |package| NIL NIL) (|InternalPrintPackage| 2660840 2660881 2661002 "IPRNTPK" 2661126 T IPRNTPK (NIL) |package| NIL NIL) (|InnerPrimeField| 2655456 2660564 2660735 "IPF" 2660740 NIL IPF (NIL NIL) |domain| NIL NIL) (|InnerPAdicInteger| 2652997 2655305 2655420 "IPADIC" 2655425 NIL IPADIC (NIL NIL NIL) |domain| NIL NIL) (|InverseLaplaceTransform| 2651907 2651987 2652445 "INVLAPLA" 2652893 NIL INVLAPLA (NIL T T) |package| NIL NIL) (|TranscendentalIntegration| 2636372 2639640 2643105 "INTTR" 2648566 NIL INTTR (NIL T T) |package| NIL NIL) (|IntegrationTools| 2630600 2631676 2632943 "INTTOOLS" 2635201 NIL INTTOOLS (NIL T T) |package| NIL NIL) (|IntegerSolveLinearPolynomialEquation| 2629583 2629793 2630115 "INTSLPE" 2630366 T INTSLPE (NIL) |package| NIL NIL) (|Interval| 2626898 2629419 2629551 "INTRVL" 2629556 NIL INTRVL (NIL T) |domain| NIL NIL) (|RationalFunctionIntegration| 2622749 2623565 2624576 "INTRF" 2626043 NIL INTRF (NIL T) |package| NIL NIL) (|IntegerRetractions| 2621745 2621880 2622137 "INTRET" 2622579 NIL INTRET (NIL T) |package| NIL NIL) (|RationalIntegration| 2618479 2619030 2619794 "INTRAT" 2621155 NIL INTRAT (NIL T T) |package| NIL NIL) (|PatternMatchIntegration| 2613647 2614530 2615557 "INTPM" 2617729 NIL INTPM (NIL T T) |package| NIL NIL) (|PureAlgebraicIntegration| 2608181 2608976 2610150 "INTPAF" 2612796 NIL INTPAF (NIL T T T) |package| NIL NIL) (|AnnaNumericalIntegrationPackage| 2599711 2601269 2603128 "INTPACK" 2606400 T INTPACK (NIL) |package| NIL NIL) (|Integer| 2595223 2599176 2599432 "INT" 2599485 T INT (NIL) |domain| NIL NIL) (|TranscendentalHermiteIntegration| 2594025 2594231 2594599 "INTHERTR" 2594993 NIL INTHERTR (NIL T T) |package| NIL NIL) (|AlgebraicHermiteIntegration| 2593013 2593123 2593487 "INTHERAL" 2593891 NIL INTHERAL (NIL T T T T) |package| NIL NIL) (|IntegerNumberTheoryFunctions| 2588996 2589721 2590602 "INTHEORY" 2592204 T INTHEORY (NIL) |package| NIL NIL) (|GenusZeroIntegration| 2573513 2576012 2578935 "INTG0" 2586388 NIL INTG0 (NIL T T T) |package| NIL NIL) (|IntegrationFunctionsTable| 2550803 2556294 2561910 "INTFTBL" 2567963 T INTFTBL (NIL) |domain| NIL NIL) (|InterpolateFormsPackage| 2547092 2547417 2548156 "INTFRSP" 2550439 NIL INTFRSP (NIL T NIL T T T T T T) |package| NIL NIL) (|IntegerFactorizationPackage| 2545719 2545913 2546245 "INTFACT" 2546859 NIL INTFACT (NIL T) |package| NIL NIL) (|InterfaceGroebnerPackage| 2545006 2545057 2545332 "INTERGB" 2545644 NIL INTERGB (NIL T NIL T T T) |package| NIL NIL) (|ElementaryIntegration| 2540558 2541144 2542068 "INTEF" 2544378 NIL INTEF (NIL T T) |package| NIL NIL) (|IntegralDomain| 2538277 2539264 2539322 "INTDOM" 2539809 T INTDOM (NIL) |category| NIL 2540144) (|IntegralDomain&| 2537355 2537586 2537964 "INTDOM-" 2537969 NIL INTDOM- (NIL T) |domain| NIL NIL) (|IntersectionDivisorPackage| 2534758 2534910 2535620 "INTDIVP" 2537174 NIL INTDIVP (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|IntervalCategory| 2529089 2531567 2531702 "INTCAT" 2533410 NIL INTCAT (NIL T) |category| |Interval| 2533956) (|IntegerBits| 2528201 2528358 2528589 "INTBIT" 2528896 T INTBIT (NIL) |package| NIL NIL) (|AlgebraicIntegrate| 2525579 2525819 2526431 "INTALG" 2527930 NIL INTALG (NIL T T T T T) |package| NIL NIL) (|AlgebraicIntegration| 2524462 2524631 2524994 "INTAF" 2525386 NIL INTAF (NIL T T) |package| NIL NIL) (|InnerTable| 2515689 2524105 2524367 "INTABL" 2524372 NIL INTABL (NIL T T T) |domain| NIL NIL) (|IntegerNumberSystem| 2507597 2511352 2511420 "INS" 2513183 T INS (NIL) |category| NIL 2514443) (|IntegerNumberSystem&| 2503152 2504289 2505905 "INS-" 2506066 NIL INS- (NIL T) |domain| NIL NIL) (|InnerPolySign| 2501167 2501492 2501980 "INPSIGN" 2502763 NIL INPSIGN (NIL T T) |package| NIL NIL) (|InfiniteProductPrimeField| 2499412 2499601 2500005 "INPRODPF" 2500939 NIL INPRODPF (NIL T T) |package| NIL NIL) (|InfiniteProductFiniteField| 2497152 2497341 2497826 "INPRODFF" 2499184 NIL INPRODFF (NIL T T T T) |package| NIL NIL) (|InnerMultFact| 2494968 2495299 2495864 "INNMFACT" 2496782 NIL INNMFACT (NIL T T T T) |package| NIL NIL) (|InnerModularGcd| 2493534 2493664 2494002 "INMODGCD" 2494804 NIL INMODGCD (NIL T T NIL NIL) |package| NIL NIL) (|InnerNumericFloatSolvePackage| 2491018 2491367 2491919 "INFSP" 2493130 NIL INFSP (NIL T T T) |package| NIL NIL) (|InfiniteProductCharacteristicZero| 2489251 2489440 2489851 "INFPROD0" 2490790 NIL INFPROD0 (NIL T T) |package| NIL NIL) (|InputForm| 2484769 2486249 2487063 "INFORM" 2488458 T INFORM (NIL) |domain| NIL NIL) (|InputFormFunctions1| 2484076 2484167 2484355 "INFORM1" 2484649 NIL INFORM1 (NIL T) |package| NIL NIL) (|Infinity| 2483121 2483295 2483536 "INFINITY" 2483867 T INFINITY (NIL) |package| NIL NIL) (|InfinitlyClosePoint| 2479017 2480541 2481176 "INFCLSPT" 2482883 NIL INFCLSPT (NIL T NIL T T T T T T T) |domain| NIL NIL) (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| 2473886 2476690 2477561 "INFCLSPS" 2478362 NIL INFCLSPS (NIL T NIL T) |domain| NIL NIL) (|InfinitlyClosePointCategory| 2458998 2460414 2460850 "INFCLCT" 2472353 NIL INFCLCT (NIL T NIL T T T T T T T) |category| NIL 2473772) (|InnerNumericEigenPackage| 2456572 2456975 2457546 "INEP" 2458561 NIL INEP (NIL T T T) |package| NIL NIL) (|IndexedExponents| 2455486 2456301 2456468 "INDE" 2456473 NIL INDE (NIL T) |domain| NIL NIL) (|IncrementingMaps| 2454716 2454812 2455031 "INCRMAPS" 2455361 NIL INCRMAPS (NIL T) |package| NIL NIL) (|InnerNormalBasisFieldFunctions| 2446421 2447787 2449377 "INBFF" 2453231 NIL INBFF (NIL T) |package| NIL NIL) (|IndexedMatrix| 2441231 2446164 2446335 "IMATRIX" 2446340 NIL IMATRIX (NIL T NIL NIL) |domain| NIL NIL) (|InnerMatrixQuotientFieldFunctions| 2438763 2438930 2439511 "IMATQF" 2441014 NIL IMATQF (NIL T T T T T T T T) |package| NIL NIL) (|InnerMatrixLinearAlgebraFunctions| 2435403 2435734 2436343 "IMATLIN" 2438362 NIL IMATLIN (NIL T T T T) |package| NIL NIL) (|IndexedList| 2427880 2435281 2435374 "ILIST" 2435379 NIL ILIST (NIL T NIL) |domain| NIL NIL) (|InnerIndexedTwoDimensionalArray| 2424937 2427581 2427827 "IIARRAY2" 2427832 NIL IIARRAY2 (NIL T NIL NIL T T) |domain| NIL NIL) (|InnerFiniteField| 2417403 2424714 2424872 "IFF" 2424877 NIL IFF (NIL NIL NIL) |domain| NIL NIL) (|IndexedFlexibleArray| 2410086 2416048 2416439 "IFARRAY" 2417099 NIL IFARRAY (NIL T NIL) |domain| NIL NIL) (|InnerFreeAbelianMonoid| 2408971 2409873 2410040 "IFAMON" 2410045 NIL IFAMON (NIL T T NIL) |domain| NIL NIL) (|InnerEvalable| 2408359 2408429 2408520 "IEVALAB" 2408849 NIL IEVALAB (NIL T T) |category| NIL NIL) (|InnerEvalable&| 2407927 2408000 2408233 "IEVALAB-" 2408238 NIL IEVALAB- (NIL T T T) |domain| NIL NIL) (|IndexedDirectProductObject| 2407396 2407725 2407878 "IDPO" 2407883 NIL IDPO (NIL T T) |domain| NIL NIL) (|IndexedDirectProductOrderedAbelianMonoidSup| 2406332 2407074 2407310 "IDPOAMS" 2407315 NIL IDPOAMS (NIL T T) |domain| NIL NIL) (|IndexedDirectProductOrderedAbelianMonoid| 2405355 2406025 2406249 "IDPOAM" 2406254 NIL IDPOAM (NIL T T) |domain| NIL NIL) (|IndexedDirectProductCategory| 2403755 2404078 2404205 "IDPC" 2405029 NIL IDPC (NIL T T) |category| NIL 2405273) (|IndexedDirectProductAbelianMonoid| 2402978 2403483 2403679 "IDPAM" 2403684 NIL IDPAM (NIL T T) |domain| NIL NIL) (|IndexedDirectProductAbelianGroup| 2402097 2402711 2402903 "IDPAG" 2402908 NIL IDPAG (NIL T T) |domain| NIL NIL) (|IdealDecompositionPackage| 2393635 2395562 2397651 "IDECOMP" 2400127 NIL IDECOMP (NIL NIL NIL) |package| NIL NIL) (|PolynomialIdeals| 2381545 2382890 2384499 "IDEAL" 2392185 NIL IDEAL (NIL T T T T) |domain| NIL NIL) (|InfClsPt| 2378105 2379998 2380518 "ICP" 2381127 NIL ICP (NIL T NIL T) |domain| NIL NIL) (|InnerCommonDenominator| 2376497 2376655 2377039 "ICDEN" 2377913 NIL ICDEN (NIL T T T T) |package| NIL NIL) (|IndexCard| 2375253 2375693 2375926 "ICARD" 2376298 T ICARD (NIL) |domain| NIL NIL) (|IntegralBasisPolynomialTools| 2371403 2371962 2372769 "IBPTOOLS" 2374632 NIL IBPTOOLS (NIL T T T T) |package| NIL NIL) (|IndexedBits| 2364938 2370838 2371015 "IBITS" 2371281 NIL IBITS (NIL NIL) |domain| NIL NIL) (|IntegralBasisTools| 2359425 2360228 2361330 "IBATOOL" 2364062 NIL IBATOOL (NIL T T T) |package| NIL NIL) (|ChineseRemainderToolsForIntegralBases| 2355660 2356347 2357273 "IBACHIN" 2358704 NIL IBACHIN (NIL T T T) |package| NIL NIL) (|IndexedTwoDimensionalArray| 2352497 2355299 2355535 "IARRAY2" 2355540 NIL IARRAY2 (NIL T NIL NIL) |domain| NIL NIL) (|IndexedOneDimensionalArray| 2347032 2352315 2352453 "IARRAY1" 2352458 NIL IARRAY1 (NIL T NIL) |domain| NIL NIL) (|InnerAlgebraicNumber| 2337297 2343745 2344759 "IAN" 2346074 T IAN (NIL) |domain| NIL NIL) (|InnerAlgFactor| 2336406 2336485 2336811 "IALGFACT" 2337194 NIL IALGFACT (NIL T T T T) |package| NIL NIL) (|HyperbolicFunctionCategory| 2335608 2335727 2335809 "HYPCAT" 2336226 T HYPCAT (NIL) |category| NIL NIL) (|HyperbolicFunctionCategory&| 2334960 2335083 2335396 "HYPCAT-" 2335401 NIL HYPCAT- (NIL T) |domain| NIL NIL) (|HTMLFormat| 2333391 2333761 2334086 "HTMLFORM" 2334671 T HTMLFORM (NIL) |domain| NIL NIL) (|HomogeneousAggregate| 2328426 2330304 2330388 "HOAGG" 2332125 NIL HOAGG (NIL T) |category| NIL 2333027) (|HomogeneousAggregate&| 2326343 2326886 2327707 "HOAGG-" 2327712 NIL HOAGG- (NIL T T) |domain| NIL NIL) (|HexadecimalExpansion| 2316502 2325308 2325632 "HEXADEC" 2326075 T HEXADEC (NIL) |domain| NIL NIL) (|HeuGcd| 2314505 2314788 2315198 "HEUGCD" 2316170 NIL HEUGCD (NIL T) |package| NIL NIL) (|HyperellipticFiniteDivisor| 2313257 2314178 2314453 "HELLFDIV" 2314458 NIL HELLFDIV (NIL T T T T) |domain| NIL NIL) (|Heap| 2303583 2305702 2307364 "HEAP" 2311639 NIL HEAP (NIL T) |domain| NIL NIL) (|HomogeneousDirectProduct| 2294897 2303379 2303541 "HDP" 2303546 NIL HDP (NIL NIL T) |domain| NIL NIL) (|HomogeneousDistributedMultivariatePolynomial| 2284483 2294152 2294494 "HDMP" 2294698 NIL HDMP (NIL NIL T) |domain| NIL NIL) (|HallBasis| 2283298 2283535 2283841 "HB" 2284211 T HB (NIL) |package| NIL NIL) (|HashTable| 2274612 2283021 2283203 "HASHTBL" 2283208 NIL HASHTBL (NIL T T NIL) |domain| NIL NIL) (|Pi| 2271223 2273875 2274233 "HACKPI" 2274274 T HACKPI (NIL) |domain| NIL NIL) (|GuessUnivariatePolynomial| 2239027 2245809 2253088 "GUESSUP" 2264026 NIL GUESSUP (NIL NIL) |package| NIL NIL) (|GuessPolynomial| 2184309 2197428 2210194 "GUESSP" 2226307 T GUESSP (NIL) |package| NIL NIL) (|Guess| 2125013 2134089 2143670 "GUESS" 2175290 NIL GUESS (NIL T T T T NIL NIL) |package| NIL NIL) (|GuessInteger| 2075560 2087299 2098859 "GUESSINT" 2113493 T GUESSINT (NIL) |package| NIL NIL) (|GuessFinite| 2030022 2039836 2050083 "GUESSF" 2065419 NIL GUESSF (NIL T) |package| NIL NIL) (|GuessFiniteFunctions| 2029496 2029548 2029748 "GUESSF1" 2029946 NIL GUESSF1 (NIL T) |package| NIL NIL) (|GuessAlgebraicNumber| 1981395 1992469 2003866 "GUESSAN" 2018155 T GUESSAN (NIL) |package| NIL NIL) (|GeneralTriangularSet| 1975239 1981111 1981343 "GTSET" 1981348 NIL GTSET (NIL T T T T) |domain| NIL NIL) (|GeneralSparseTable| 1966624 1975036 1975204 "GSTBL" 1975209 NIL GSTBL (NIL T T T NIL) |domain| NIL NIL) (|GeneralUnivariatePowerSeries| 1955429 1964973 1965433 "GSERIES" 1966276 NIL GSERIES (NIL T NIL NIL) |domain| NIL NIL) (|Group| 1954086 1954658 1954698 "GROUP" 1955068 T GROUP (NIL) |category| NIL 1955310) (|Group&| 1952825 1953128 1953626 "GROUP-" 1953631 NIL GROUP- (NIL T) |domain| NIL NIL) (|GroebnerSolve| 1949609 1950248 1951026 "GROEBSOL" 1952152 NIL GROEBSOL (NIL NIL T T) |package| NIL NIL) (|GradedModule| 1947932 1948220 1948322 "GRMOD" 1949298 NIL GRMOD (NIL T T) |category| NIL 1949527) (|GradedModule&| 1947617 1947649 1947849 "GRMOD-" 1947854 NIL GRMOD- (NIL T T T) |domain| NIL NIL) (|GraphImage| 1940110 1941607 1943271 "GRIMAGE" 1945989 T GRIMAGE (NIL) |domain| NIL NIL) (|GraphicsDefaults| 1937327 1937729 1938359 "GRDEF" 1939528 T GRDEF (NIL) |package| NIL NIL) (|GrayCode| 1936334 1936532 1936791 "GRAY" 1937100 T GRAY (NIL) |package| NIL NIL) (|GradedAlgebra| 1935221 1935649 1935753 "GRALG" 1936042 NIL GRALG (NIL T T) |category| NIL 1936190) (|GradedAlgebra&| 1934749 1934823 1935082 "GRALG-" 1935087 NIL GRALG- (NIL T T T) |domain| NIL NIL) (|GeneralPolynomialSet| 1929992 1933942 1934294 "GPOLSET" 1934572 NIL GPOLSET (NIL T T T T) |domain| NIL NIL) (|GeneralPackageForAlgebraicFunctionField| 1895275 1897477 1900278 "GPAFF" 1927746 NIL GPAFF (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|GosperSummationMethod| 1894147 1894226 1894682 "GOSPER" 1895172 NIL GOSPER (NIL T T T T T) |package| NIL NIL) (|GuessOption| 1888084 1889331 1890605 "GOPT" 1892911 T GOPT (NIL) |domain| NIL NIL) (|GuessOptionFunctions0| 1880017 1881648 1883320 "GOPT0" 1886470 T GOPT0 (NIL) |domain| NIL NIL) (|GeneralModulePolynomial| 1872864 1873722 1874599 "GMODPOL" 1879537 NIL GMODPOL (NIL NIL T T T NIL T) |domain| NIL NIL) (|GeneralHenselPackage| 1871189 1871437 1871843 "GHENSEL" 1872582 NIL GHENSEL (NIL T T) |package| NIL NIL) (|GenerateUnivariatePowerSeries| 1859693 1861049 1862900 "GENUPS" 1869632 NIL GENUPS (NIL T T) |package| NIL NIL) (|GenUFactorize| 1859041 1859147 1859344 "GENUFACT" 1859563 NIL GENUFACT (NIL T) |package| NIL NIL) (|GeneralPolynomialGcdPackage| 1857693 1857853 1858249 "GENPGCD" 1858852 NIL GENPGCD (NIL T T T T) |package| NIL NIL) (|GeneralizedMultivariateFactorize| 1856709 1856753 1857168 "GENMFACT" 1857625 NIL GENMFACT (NIL T T T T T) |package| NIL NIL) (|GenExEuclid| 1854324 1854673 1855172 "GENEEZ" 1856316 NIL GENEEZ (NIL T T) |package| NIL NIL) (|GnuDraw| 1851910 1852355 1852905 "GDRAW" 1853804 T GDRAW (NIL) |package| NIL NIL) (|GeneralDistributedMultivariatePolynomial| 1841918 1851149 1851490 "GDMP" 1851769 NIL GDMP (NIL NIL T T) |domain| NIL NIL) (|GenericNonAssociativeAlgebra| 1823172 1830255 1832333 "GCNAALG" 1840019 NIL GCNAALG (NIL T NIL NIL NIL) |domain| NIL NIL) (|GcdDomain| 1820671 1821950 1821998 "GCDDOM" 1822399 T GCDDOM (NIL) |category| NIL 1822711) (|GcdDomain&| 1819489 1819785 1820253 "GCDDOM-" 1820258 NIL GCDDOM- (NIL T) |domain| NIL NIL) (|GroebnerPackage| 1817330 1817553 1818018 "GB" 1819185 NIL GB (NIL T T T T) |package| NIL NIL) (|GroebnerInternalPackage| 1799778 1802808 1806154 "GBINTERN" 1814161 NIL GBINTERN (NIL T T T T) |package| NIL NIL) (|GroebnerFactorizationPackage| 1795854 1796231 1796972 "GBF" 1799262 NIL GBF (NIL T T T T) |package| NIL NIL) (|EuclideanGroebnerBasisPackage| 1793584 1793802 1794298 "GBEUCLID" 1795553 NIL GBEUCLID (NIL T T T T) |package| NIL NIL) (|GaussianFactorizationPackage| 1792407 1792598 1792895 "GAUSSFAC" 1793359 T GAUSSFAC (NIL) |package| NIL NIL) (|GaloisGroupUtilities| 1789045 1789639 1790321 "GALUTIL" 1791795 NIL GALUTIL (NIL T) |package| NIL NIL) (|GaloisGroupPolynomialUtilities| 1785863 1786277 1786883 "GALPOLYU" 1788572 NIL GALPOLYU (NIL T T) |package| NIL NIL) (|GaloisGroupFactorizationUtilities| 1780298 1780715 1781522 "GALFACTU" 1785332 NIL GALFACTU (NIL T T T) |package| NIL NIL) (|GaloisGroupFactorizer| 1764548 1767096 1770155 "GALFACT" 1777347 NIL GALFACT (NIL T) |package| NIL NIL) (|FortranVectorFunctionCategory| 1760019 1760993 1761081 "FVFUN" 1763249 T FVFUN (NIL) |category| NIL 1764460) (|FortranVectorCategory| 1758773 1759037 1759109 "FVC" 1759619 T FVC (NIL) |category| NIL 1759931) (|FunctionCalled| 1758253 1758442 1758582 "FUNCTION" 1758693 NIL FUNCTION (NIL NIL) |domain| NIL NIL) (|FortranType| 1754321 1755141 1756013 "FT" 1757419 T FT (NIL) |domain| NIL NIL) (|FortranTemplate| 1752314 1753004 1753404 "FTEM" 1753967 T FTEM (NIL) |domain| NIL NIL) (|FunctionSpaceUnivariatePolynomialFactor| 1748824 1749338 1750150 "FSUPFACT" 1751745 NIL FSUPFACT (NIL T T T) |package| NIL NIL) (|FortranScalarType| 1746198 1746590 1747159 "FST" 1748305 T FST (NIL) |domain| NIL NIL) (|FunctionSpaceReduce| 1744650 1744817 1745192 "FSRED" 1745983 NIL FSRED (NIL T T) |package| NIL NIL) (|FunctionSpacePrimitiveElement| 1742228 1742650 1743311 "FSPRMELT" 1744162 NIL FSPRMELT (NIL T T) |package| NIL NIL) (|FunctionalSpecialFunction| 1734394 1735250 1736402 "FSPECF" 1741218 NIL FSPECF (NIL T T) |package| NIL NIL) (|FunctionSpace| 1706651 1718851 1718927 "FS" 1725704 NIL FS (NIL T) |category| NIL 1729412) (|FunctionSpace&| 1689813 1693988 1700081 "FS-" 1700650 NIL FS- (NIL T T) |domain| NIL NIL) (|FunctionSpaceIntegration| 1688785 1688855 1689276 "FSINT" 1689720 NIL FSINT (NIL T T) |package| NIL NIL) (|FourierSeries| 1686156 1687071 1687560 "FSERIES" 1688455 NIL FSERIES (NIL T T) |domain| NIL NIL) (|FunctionSpaceComplexIntegration| 1683945 1684142 1684685 "FSCINT" 1685925 NIL FSCINT (NIL T T) |package| NIL NIL) (|FiniteSetAggregate| 1678332 1682177 1682264 "FSAGG" 1682962 NIL FSAGG (NIL T) |category| NIL 1683358) (|FiniteSetAggregate&| 1674966 1675767 1677009 "FSAGG-" 1677198 NIL FSAGG- (NIL T T) |domain| NIL NIL) (|FiniteSetAggregateFunctions2| 1673358 1673526 1673908 "FSAGG2" 1674764 NIL FSAGG2 (NIL T T T T) |package| NIL NIL) (|FunctionSpaceToUnivariatePowerSeries| 1669138 1669487 1670491 "FS2UPS" 1672976 NIL FS2UPS (NIL T T T T T NIL) |package| NIL NIL) (|FunctionSpaceFunctions2| 1668445 1668495 1668763 "FS2" 1669064 NIL FS2 (NIL T T T T) |package| NIL NIL) (|FunctionSpaceToExponentialExpansion| 1666445 1666667 1667244 "FS2EXPXP" 1668195 NIL FS2EXPXP (NIL T T NIL NIL) |package| NIL NIL) (|FactoredFunctionUtilities| 1665433 1665603 1665892 "FRUTIL" 1666246 NIL FRUTIL (NIL T) |package| NIL NIL) (|Factored| 1652350 1658223 1660325 "FR" 1663387 NIL FR (NIL T) |domain| NIL NIL) (|FramedNonAssociativeAlgebra| 1643848 1647803 1647912 "FRNAALG" 1650840 NIL FRNAALG (NIL T) |category| NIL 1651926) (|FramedNonAssociativeAlgebra&| 1636343 1637866 1640056 "FRNAALG-" 1641797 NIL FRNAALG- (NIL T T) |domain| NIL NIL) (|FramedNonAssociativeAlgebraFunctions2| 1635604 1635654 1635952 "FRNAAF2" 1636269 NIL FRNAAF2 (NIL T T T T) |package| NIL NIL) (|FramedModule| 1632979 1633607 1634072 "FRMOD" 1635337 NIL FRMOD (NIL T T T T NIL) |domain| NIL NIL) (|FractionalIdeal| 1629128 1629962 1630492 "FRIDEAL" 1632664 NIL FRIDEAL (NIL T T T T) |domain| NIL NIL) (|FractionalIdealFunctions2| 1627650 1627770 1628318 "FRIDEAL2" 1628984 NIL FRIDEAL2 (NIL T T T T T T T T) |package| NIL NIL) (|FullyRetractableTo| 1626475 1627076 1627156 "FRETRCT" 1627161 NIL FRETRCT (NIL T) |category| NIL 1627446) (|FullyRetractableTo&| 1625105 1625415 1625993 "FRETRCT-" 1625998 NIL FRETRCT- (NIL T T) |domain| NIL NIL) (|FramedAlgebra| 1620562 1622174 1622299 "FRAMALG" 1624062 NIL FRAMALG (NIL T T) |category| NIL 1624535) (|FramedAlgebra&| 1617576 1618187 1619222 "FRAMALG-" 1619672 NIL FRAMALG- (NIL T T T) |domain| NIL NIL) (|Fraction| 1608428 1616785 1617206 "FRAC" 1617211 NIL FRAC (NIL T) |domain| NIL NIL) (|FractionFunctions2| 1607804 1607880 1608080 "FRAC2" 1608328 NIL FRAC2 (NIL T T) |package| NIL NIL) (|FactoredFunctions2| 1607180 1607256 1607456 "FR2" 1607704 NIL FR2 (NIL T T) |package| NIL NIL) (|FloatingPointSystem| 1598309 1602575 1602643 "FPS" 1604756 T FPS (NIL) |category| NIL 1605792) (|FloatingPointSystem&| 1597240 1597426 1597760 "FPS-" 1598060 NIL FPS- (NIL T) |domain| NIL NIL) (|FieldOfPrimeCharacteristic| 1593039 1595488 1595570 "FPC" 1596048 T FPC (NIL) |category| NIL 1596348) (|FieldOfPrimeCharacteristic&| 1592609 1592676 1592908 "FPC-" 1592913 NIL FPC- (NIL T) |domain| NIL NIL) (|FullyPatternMatchable| 1590800 1591748 1591834 "FPATMAB" 1591839 NIL FPATMAB (NIL T) |category| NIL 1592091) (|FullPartialFractionExpansion| 1586664 1587316 1588076 "FPARFRAC" 1590202 NIL FPARFRAC (NIL T T) |domain| NIL NIL) (|FortranProgram| 1579204 1580003 1581193 "FORTRAN" 1585649 NIL FORTRAN (NIL NIL NIL NIL NIL) |domain| NIL NIL) (|FortranPackage| 1575759 1576457 1577280 "FORT" 1578425 T FORT (NIL) |package| NIL NIL) (|FortranFunctionCategory| 1571728 1572570 1572646 "FORTFN" 1574592 T FORTFN (NIL) |category| NIL 1575671) (|FortranProgramCategory| 1571302 1571376 1571450 "FORTCAT" 1571560 T FORTCAT (NIL) |category| NIL 1571673) (|ScriptFormulaFormat| 1568261 1568895 1569544 "FORMULA" 1570707 T FORMULA (NIL) |domain| NIL NIL) (|ScriptFormulaFormat1| 1567837 1567887 1568038 "FORMULA1" 1568187 NIL FORMULA1 (NIL T) |package| NIL NIL) (|FindOrderFinite| 1566935 1567016 1567347 "FORDER" 1567732 NIL FORDER (NIL T T T T) |package| NIL NIL) (|FortranOutputStackPackage| 1565106 1565389 1565814 "FOP" 1566576 T FOP (NIL) |package| NIL NIL) (|FreeNilpotentLie| 1562722 1563652 1564033 "FNLA" 1564854 NIL FNLA (NIL NIL NIL T) |domain| NIL NIL) (|FileNameCategory| 1560646 1561147 1561209 "FNCAT" 1562177 T FNCAT (NIL) |category| |FileName| 1562640) (|FileName| 1560060 1560565 1560619 "FNAME" 1560624 T FNAME (NIL) |domain| NIL NIL) (|FortranMachineTypeCategory| 1558153 1559403 1559485 "FMTC" 1559490 T FMTC (NIL) |category| NIL 1559564) (|FreeMonoid| 1552618 1554187 1555170 "FMONOID" 1557227 NIL FMONOID (NIL T) |domain| NIL NIL) (|FreeModule| 1551547 1552195 1552439 "FM" 1552444 NIL FM (NIL T T) |domain| NIL NIL) (|FortranMatrixFunctionCategory| 1547018 1547992 1548080 "FMFUN" 1550248 T FMFUN (NIL) |category| NIL 1551459) (|FortranMatrixCategory| 1545772 1546036 1546108 "FMC" 1546618 T FMC (NIL) |category| NIL 1546930) (|FreeModuleCat| 1541451 1542524 1542615 "FMCAT" 1544655 NIL FMCAT (NIL T T) |category| NIL 1545420) (|FreeModule1| 1539970 1541082 1541240 "FM1" 1541365 NIL FM1 (NIL T T) |domain| NIL NIL) (|FloatingRealPackage| 1536283 1536918 1537740 "FLOATRP" 1539242 NIL FLOATRP (NIL T) |package| NIL NIL) (|Float| 1526212 1532102 1533325 "FLOAT" 1535086 T FLOAT (NIL) |domain| NIL NIL) (|FloatingComplexPackage| 1521813 1522602 1523608 "FLOATCP" 1525306 NIL FLOATCP (NIL T) |package| NIL NIL) (|FullyLinearlyExplicitRingOver| 1519936 1521100 1521202 "FLINEXP" 1521207 NIL FLINEXP (NIL T) |category| NIL 1521397) (|FullyLinearlyExplicitRingOver&| 1518633 1518949 1519507 "FLINEXP-" 1519512 NIL FLINEXP- (NIL T T) |domain| NIL NIL) (|FiniteLinearAggregateSort| 1516994 1517191 1517599 "FLASORT" 1518402 NIL FLASORT (NIL T T) |package| NIL NIL) (|FreeLieAlgebra| 1512392 1513508 1513611 "FLALG" 1515908 NIL FLALG (NIL T T) |category| |LiePolynomial| 1516672) (|FiniteLinearAggregate| 1503081 1508291 1508377 "FLAGG" 1510613 NIL FLAGG (NIL T) |category| NIL 1511593) (|FiniteLinearAggregate&| 1501219 1501666 1502426 "FLAGG-" 1502431 NIL FLAGG- (NIL T T) |domain| NIL NIL) (|FiniteLinearAggregateFunctions2| 1499628 1499796 1500176 "FLAGG2" 1501017 NIL FLAGG2 (NIL T T T T) |package| NIL NIL) (|FiniteRankAlgebra| 1494466 1495840 1495973 "FINRALG" 1498269 NIL FINRALG (NIL T T) |category| NIL 1499096) (|FiniteRankAlgebra&| 1493164 1493482 1494050 "FINRALG-" 1494055 NIL FINRALG- (NIL T T T) |domain| NIL NIL) (|Finite| 1492061 1492387 1492429 "FINITE" 1492841 T FINITE (NIL) |category| NIL 1493082) (|Finite&| 1491777 1491832 1491967 "FINITE-" 1491972 NIL FINITE- (NIL T) |domain| NIL NIL) (|FiniteRankNonAssociativeAlgebra| 1477505 1480812 1480929 "FINAALG" 1488778 NIL FINAALG (NIL T) |category| NIL 1491400) (|FiniteRankNonAssociativeAlgebra&| 1468333 1470062 1472230 "FINAALG-" 1475488 NIL FINAALG- (NIL T T) |domain| NIL NIL) (|File| 1467471 1467945 1468108 "FILE" 1468215 NIL FILE (NIL T) |domain| NIL NIL) (|FileCategory| 1465207 1465603 1465699 "FILECAT" 1467043 NIL FILECAT (NIL T T) |category| NIL 1467389) (|Field| 1461881 1464090 1464130 "FIELD" 1464179 T FIELD (NIL) |category| NIL 1464363) (|Field&| 1459940 1460449 1461184 "FIELD-" 1461189 NIL FIELD- (NIL T) |domain| NIL NIL) (|FreeGroup| 1456696 1457752 1458299 "FGROUP" 1459448 NIL FGROUP (NIL T) |domain| NIL NIL) (|FGLMIfCanPackage| 1455196 1455444 1455818 "FGLMICPK" 1456414 NIL FGLMICPK (NIL T NIL) |package| NIL NIL) (|FiniteFieldExtension| 1448910 1455001 1455151 "FFX" 1455156 NIL FFX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldSquareFreeDecomposition| 1448016 1448098 1448365 "FFSQFR" 1448799 NIL FFSQFR (NIL T T) |package| NIL NIL) (|FiniteFieldSolveLinearPolynomialEquation| 1447154 1447250 1447581 "FFSLPE" 1447896 NIL FFSLPE (NIL T T T) |package| NIL NIL) (|FiniteFieldPolynomialPackage| 1437548 1439348 1441366 "FFPOLY" 1445237 NIL FFPOLY (NIL T) |package| NIL NIL) (|FiniteFieldPolynomialPackage2| 1436489 1436566 1437011 "FFPOLY2" 1437447 NIL FFPOLY2 (NIL T T) |package| NIL NIL) (|FiniteFieldExtensionByPolynomial| 1430189 1436254 1436444 "FFP" 1436449 NIL FFP (NIL T NIL) |domain| NIL NIL) (|FiniteField| 1422980 1429986 1430129 "FF" 1430134 NIL FF (NIL NIL NIL) |domain| NIL NIL) (|FiniteFieldNormalBasisExtension| 1415234 1421548 1421985 "FFNBX" 1422675 NIL FFNBX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldNormalBasisExtensionByPolynomial| 1407107 1413399 1413968 "FFNBP" 1414929 NIL FFNBP (NIL T NIL) |domain| NIL NIL) (|FiniteFieldNormalBasis| 1398369 1405628 1406088 "FFNB" 1406757 NIL FFNB (NIL NIL NIL) |domain| NIL NIL) (|FunctionFieldIntegralBasis| 1396491 1396746 1397272 "FFINTBAS" 1398085 NIL FFINTBAS (NIL T T T) |package| NIL NIL) (|FiniteFieldCategory| 1390164 1393503 1393571 "FFIELDC" 1394762 T FFIELDC (NIL) |category| NIL 1395496) (|FiniteFieldCategory&| 1387729 1388366 1389305 "FFIELDC-" 1389310 NIL FFIELDC- (NIL T) |domain| NIL NIL) (|FiniteFieldHomomorphisms| 1386853 1386901 1387170 "FFHOM" 1387641 NIL FFHOM (NIL T T T) |package| NIL NIL) (|FiniteFieldFunctions| 1382425 1383301 1384311 "FFF" 1385928 NIL FFF (NIL T) |package| NIL NIL) (|FractionFreeFastGaussian| 1373666 1375140 1376900 "FFFG" 1380831 NIL FFFG (NIL T T) |package| NIL NIL) (|FractionFreeFastGaussianFractions| 1370907 1371328 1372067 "FFFGF" 1373191 NIL FFFGF (NIL T T T) |package| NIL NIL) (|FiniteFieldFactorizationWithSizeParseBySideEffect| 1368220 1368529 1369073 "FFFACTSE" 1370549 NIL FFFACTSE (NIL T T) |package| NIL NIL) (|FiniteFieldFactorization| 1365733 1366042 1366536 "FFFACTOR" 1367862 NIL FFFACTOR (NIL T T) |package| NIL NIL) (|FiniteFieldCyclicGroupExtension| 1358955 1365108 1365376 "FFCGX" 1365597 NIL FFCGX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldCyclicGroupExtensionByPolynomial| 1352135 1358264 1358572 "FFCGP" 1358819 NIL FFCGP (NIL T NIL) |domain| NIL NIL) (|FiniteFieldCyclicGroup| 1344451 1351519 1351780 "FFCG" 1351984 NIL FFCG (NIL NIL NIL) |domain| NIL NIL) (|FunctionFieldCategory| 1312541 1326163 1326371 "FFCAT" 1337919 NIL FFCAT (NIL T T T) |category| NIL 1340423) (|FunctionFieldCategory&| 1304023 1305554 1307792 "FFCAT-" 1310543 NIL FFCAT- (NIL T T T T) |domain| NIL NIL) (|FunctionFieldCategoryFunctions2| 1302799 1302849 1303361 "FFCAT2" 1303949 NIL FFCAT2 (NIL T T T T T T T T) |package| NIL NIL) (|FortranExpression| 1285680 1290816 1292806 "FEXPR" 1300945 NIL FEXPR (NIL NIL NIL T) |domain| NIL NIL) (|FullyEvalableOver| 1284323 1284851 1284936 "FEVALAB" 1285078 NIL FEVALAB (NIL T) |category| NIL 1285434) (|FullyEvalableOver&| 1283224 1283463 1283943 "FEVALAB-" 1283948 NIL FEVALAB- (NIL T T) |domain| NIL NIL) (|FiniteDivisor| 1281062 1282061 1282431 "FDIV" 1283056 NIL FDIV (NIL T T T T) |domain| NIL NIL) (|FiniteDivisorCategory| 1275894 1276796 1277033 "FDIVCAT" 1280227 NIL FDIVCAT (NIL T T T T) |category| NIL 1280870) (|FiniteDivisorCategory&| 1275449 1275488 1275824 "FDIVCAT-" 1275829 NIL FDIVCAT- (NIL T T T T T) |domain| NIL NIL) (|FiniteDivisorFunctions2| 1274030 1274146 1274668 "FDIV2" 1275309 NIL FDIV2 (NIL T T T T T T T T) |package| NIL NIL) (|FortranCodePackage1| 1271501 1271977 1272566 "FCPAK1" 1273495 T FCPAK1 (NIL) |package| NIL NIL) (|FourierComponent| 1270253 1270672 1270906 "FCOMP" 1271335 NIL FCOMP (NIL T) |domain| NIL NIL) (|FortranCode| 1245771 1250482 1255845 "FC" 1264928 T FC (NIL) |domain| NIL NIL) (|FiniteAlgebraicExtensionField| 1233168 1239179 1239282 "FAXF" 1242954 NIL FAXF (NIL T) |category| NIL 1244301) (|FiniteAlgebraicExtensionField&| 1227778 1228939 1230587 "FAXF-" 1231655 NIL FAXF- (NIL T T) |domain| NIL NIL) (|FlexibleArray| 1220600 1226589 1226949 "FARRAY" 1227474 NIL FARRAY (NIL T) |domain| NIL NIL) (|FiniteAbelianMonoidRing| 1213052 1215934 1216054 "FAMR" 1218090 NIL FAMR (NIL T T) |category| NIL 1218820) (|FiniteAbelianMonoidRing&| 1211430 1211822 1212510 "FAMR-" 1212515 NIL FAMR- (NIL T T T) |domain| NIL NIL) (|FiniteAbelianMonoidRingFunctions2| 1210671 1210721 1211021 "FAMR2" 1211356 NIL FAMR2 (NIL T T T T T) |package| NIL NIL) (|FreeAbelianMonoid| 1209434 1210477 1210607 "FAMONOID" 1210612 NIL FAMONOID (NIL T) |domain| NIL NIL) (|FreeAbelianMonoidCategory| 1205676 1206565 1206701 "FAMONC" 1208642 NIL FAMONC (NIL T T) |category| NIL 1209236) (|FreeAbelianGroup| 1203862 1205224 1205482 "FAGROUP" 1205487 NIL FAGROUP (NIL T) |domain| NIL NIL) (|FactoringUtilities| 1199332 1199967 1200818 "FACUTIL" 1203173 NIL FACUTIL (NIL T T T T) |package| NIL NIL) (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| 1197824 1198049 1198485 "FACTRN" 1199078 NIL FACTRN (NIL T) |package| NIL NIL) (|FactoredFunctions| 1196355 1196627 1197002 "FACTFUNC" 1197523 NIL FACTFUNC (NIL T) |package| NIL NIL) (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| 1194791 1195016 1195476 "FACTEXT" 1196101 NIL FACTEXT (NIL T) |package| NIL NIL) (|ExponentialOfUnivariatePuiseuxSeries| 1183606 1193309 1193761 "EXPUPXS" 1194492 NIL EXPUPXS (NIL T NIL NIL) |domain| NIL NIL) (|ExpressionTubePlot| 1178766 1179803 1180975 "EXPRTUBE" 1182486 T EXPRTUBE (NIL) |package| NIL NIL) (|ExpressionSolve| 1177093 1177235 1177692 "EXPRSOL" 1178595 NIL EXPRSOL (NIL T T T T) |package| NIL NIL) (|ExpressionSpaceODESolver| 1170427 1171299 1172556 "EXPRODE" 1176008 NIL EXPRODE (NIL T T) |package| NIL NIL) (|Expression| 1148188 1167659 1168549 "EXPR" 1169593 NIL EXPR (NIL T) |domain| NIL NIL) (|ExpressionToUnivariatePowerSeries| 1137217 1138004 1139391 "EXPR2UPS" 1147098 NIL EXPR2UPS (NIL T T) |package| NIL NIL) (|ExpressionFunctions2| 1136587 1136667 1136867 "EXPR2" 1137113 NIL EXPR2 (NIL T T) |package| NIL NIL) (|ExponentialExpansion| 1119624 1134790 1135420 "EXPEXPAN" 1136254 NIL EXPEXPAN (NIL T T NIL NIL) |domain| NIL NIL) (|Export3D| 1119158 1119232 1119362 "EXP3D" 1119526 T EXP3D (NIL) |package| NIL NIL) (|Exit| 1118935 1119095 1119136 "EXIT" 1119141 T EXIT (NIL) |domain| NIL NIL) (|EvaluateCycleIndicators| 1118235 1118337 1118567 "EVALCYC" 1118809 NIL EVALCYC (NIL T) |package| NIL NIL) (|Evalable| 1117569 1117704 1117771 "EVALAB" 1118041 NIL EVALAB (NIL T) |category| NIL 1118198) (|Evalable&| 1116889 1117030 1117336 "EVALAB-" 1117341 NIL EVALAB- (NIL T T) |domain| NIL NIL) (|EuclideanDomain| 1112971 1114856 1114916 "EUCDOM" 1115819 T EUCDOM (NIL) |category| NIL 1116377) (|EuclideanDomain&| 1110766 1111337 1112188 "EUCDOM-" 1112193 NIL EUCDOM- (NIL T) |domain| NIL NIL) (|ExpertSystemToolsPackage| 1091294 1095257 1099504 "ESTOOLS" 1106583 T ESTOOLS (NIL) |package| NIL NIL) (|ExpertSystemToolsPackage2| 1090705 1090777 1090967 "ESTOOLS2" 1091198 NIL ESTOOLS2 (NIL T T) |package| NIL NIL) (|ExpertSystemToolsPackage1| 1090277 1090327 1090488 "ESTOOLS1" 1090631 NIL ESTOOLS1 (NIL T) |package| NIL NIL) (|ExpressionSpace| 1080735 1083079 1083139 "ES" 1087814 T ES (NIL) |category| NIL 1090049) (|ExpressionSpace&| 1073400 1075174 1077834 "ES-" 1078148 NIL ES- (NIL T) |domain| NIL NIL) (|ExpertSystemContinuityPackage| 1066564 1067905 1069410 "ESCONT" 1071969 T ESCONT (NIL) |package| NIL NIL) (|ExpertSystemContinuityPackage1| 1066081 1066127 1066315 "ESCONT1" 1066494 NIL ESCONT1 (NIL NIL NIL) |package| NIL NIL) (|ExpressionSpaceFunctions2| 1065511 1065572 1065773 "ES2" 1065996 NIL ES2 (NIL T T) |package| NIL NIL) (|ExpressionSpaceFunctions1| 1064900 1064972 1065173 "ES1" 1065415 NIL ES1 (NIL T T) |package| NIL NIL) (|ErrorFunctions| 1063725 1063886 1064160 "ERROR" 1064670 T ERROR (NIL) |package| NIL NIL) (|EqTable| 1055052 1063468 1063630 "EQTBL" 1063635 NIL EQTBL (NIL T T) |domain| NIL NIL) (|Equation| 1044367 1048248 1050254 "EQ" 1053092 NIL EQ (NIL T) |domain| NIL NIL) (|EquationFunctions2| 1043783 1043859 1044039 "EQ2" 1044267 NIL EQ2 (NIL T T) |package| NIL NIL) (|EigenPackage| 1035730 1037442 1039328 "EP" 1041956 NIL EP (NIL T) |package| NIL NIL) (|EntireRing| 1034516 1035261 1035311 "ENTIRER" 1035316 T ENTIRER (NIL) |category| NIL 1035402) (|EuclideanModularRing| 1029003 1031090 1031670 "EMR" 1034222 NIL EMR (NIL T T T NIL NIL NIL) |domain| NIL NIL) (|EltableAggregate| 1027720 1027952 1028049 "ELTAGG" 1028690 NIL ELTAGG (NIL T T) |category| NIL 1028972) (|EltableAggregate&| 1027322 1027390 1027613 "ELTAGG-" 1027618 NIL ELTAGG- (NIL T T T) |domain| NIL NIL) (|Eltable| 1027022 1027051 1027130 "ELTAB" 1027258 NIL ELTAB (NIL T T) |category| NIL NIL) (|EllipticFunctionsUnivariateTaylorSeries| 1025544 1025698 1026045 "ELFUTS" 1026829 NIL ELFUTS (NIL T T) |package| NIL NIL) (|ElementaryFunctionCategory| 1025098 1025154 1025236 "ELEMFUN" 1025443 T ELEMFUN (NIL) |category| NIL NIL) (|ElementaryFunctionCategory&| 1024860 1024881 1025040 "ELEMFUN-" 1025045 NIL ELEMFUN- (NIL T) |domain| NIL NIL) (|ExtensibleLinearAggregate| 1017142 1021685 1021779 "ELAGG" 1023482 NIL ELAGG (NIL T) |category| NIL 1024203) (|ExtensibleLinearAggregate&| 1014693 1015249 1016254 "ELAGG-" 1016259 NIL ELAGG- (NIL T T) |domain| NIL NIL) (|ElementaryFunctionsUnivariatePuiseuxSeries| 1001088 1003239 1004500 "EFUPXS" 1013727 NIL EFUPXS (NIL T T T T) |domain| NIL NIL) (|ElementaryFunctionsUnivariateLaurentSeries| 989147 991300 992515 "EFULS" 1000122 NIL EFULS (NIL T T T) |domain| NIL NIL) (|ElementaryFunctionStructurePackage| 984218 984680 985533 "EFSTRUC" 988598 NIL EFSTRUC (NIL T T) |package| NIL NIL) (|ElementaryFunction| 966134 967892 970093 "EF" 982174 NIL EF (NIL T T) |package| NIL NIL) (|ExtAlgBasis| 964760 965235 965506 "EAB" 965901 T EAB (NIL) |domain| NIL NIL) (|e04ucfAnnaType| 963495 964641 964720 "E04UCFA" 964725 T E04UCFA (NIL) |domain| NIL NIL) (|e04nafAnnaType| 962230 963376 963455 "E04NAFA" 963460 T E04NAFA (NIL) |domain| NIL NIL) (|e04mbfAnnaType| 960965 962111 962190 "E04MBFA" 962195 T E04MBFA (NIL) |domain| NIL NIL) (|e04jafAnnaType| 959700 960846 960925 "E04JAFA" 960930 T E04JAFA (NIL) |domain| NIL NIL) (|e04gcfAnnaType| 958437 959581 959660 "E04GCFA" 959665 T E04GCFA (NIL) |domain| NIL NIL) (|e04fdfAnnaType| 957174 958318 958397 "E04FDFA" 958402 T E04FDFA (NIL) |domain| NIL NIL) (|e04dgfAnnaType| 955909 957055 957134 "E04DGFA" 957139 T E04DGFA (NIL) |domain| NIL NIL) (|e04AgentsPackage| 945587 947895 950361 "E04AGNT" 953491 T E04AGNT (NIL) |package| NIL NIL) (|DifferentialVariableCategory| 943352 943979 944085 "DVARCAT" 945076 NIL DVARCAT (NIL T) |category| NIL 945455) (|DifferentialVariableCategory&| 942084 942372 942928 "DVARCAT-" 942933 NIL DVARCAT- (NIL T T) |domain| NIL NIL) (|DesingTreePackage| 928627 929344 930681 "DTP" 941258 NIL DTP (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|DesingTree| 924887 927613 927895 "DSTREE" 928402 NIL DSTREE (NIL T) |domain| NIL NIL) (|DesingTreeCategory| 921207 923765 923852 "DSTRCAT" 924226 NIL DSTRCAT (NIL T) |category| |DesingTree| 924453) (|DifferentialSparseMultivariatePolynomial| 910070 920735 921055 "DSMP" 921060 NIL DSMP (NIL T T T) |domain| NIL NIL) (|DrawOption| 901644 903314 905124 "DROPT" 908296 T DROPT (NIL) |domain| NIL NIL) (|DrawOptionFunctions1| 901104 901184 901358 "DROPT1" 901540 NIL DROPT1 (NIL T) |package| NIL NIL) (|DrawOptionFunctions0| 892845 894633 896576 "DROPT0" 899217 T DROPT0 (NIL) |package| NIL NIL) (|TopLevelDrawFunctionsForPoints| 889605 890217 890999 "DRAWPT" 892139 T DRAWPT (NIL) |package| NIL NIL) (|TopLevelDrawFunctions| 878873 880686 882874 "DRAW" 887537 NIL DRAW (NIL T) |package| NIL NIL) (|DrawNumericHack| 878179 878268 878503 "DRAWHACK" 878760 NIL DRAWHACK (NIL T) |package| NIL NIL) (|DrawComplex| 875644 876174 876786 "DRAWCX" 877605 T DRAWCX (NIL) |package| NIL NIL) (|TopLevelDrawFunctionsForAlgebraicCurves| 874690 874800 875134 "DRAWCURV" 875510 NIL DRAWCURV (NIL T T) |package| NIL NIL) (|TopLevelDrawFunctionsForCompiledFunctions| 855402 859207 863485 "DRAWCFUN" 870510 T DRAWCFUN (NIL) |package| NIL NIL) (|DequeueAggregate| 850751 853323 853399 "DQAGG" 854469 NIL DQAGG (NIL T) |category| |Dequeue| 854914) (|DifferentialPolynomialCategory| 830981 841264 841465 "DPOLCAT" 845549 NIL DPOLCAT (NIL T T T T) |category| NIL 846543) (|DifferentialPolynomialCategory&| 823062 824926 828075 "DPOLCAT-" 828080 NIL DPOLCAT- (NIL T T T T T) |domain| NIL NIL) (|DirectProductModule| 812922 822804 822991 "DPMO" 822996 NIL DPMO (NIL NIL T T) |domain| NIL NIL) (|DirectProductMatrixModule| 802621 812519 812831 "DPMM" 812836 NIL DPMM (NIL NIL T T T) |domain| NIL NIL) (|DistributedMultivariatePolynomial| 792339 801931 802240 "DMP" 802433 NIL DMP (NIL NIL T) |domain| NIL NIL) (|DiscreteLogarithmPackage| 791540 791652 791948 "DLP" 792203 NIL DLP (NIL T) |package| NIL NIL) (|DataList| 782565 790152 790493 "DLIST" 791251 NIL DLIST (NIL T) |domain| NIL NIL) (|DoublyLinkedAggregate| 777937 780735 780821 "DLAGG" 781778 NIL DLAGG (NIL T) |category| NIL 782131) (|DivisionRing| 775968 776884 776938 "DIVRING" 777170 T DIVRING (NIL) |category| NIL 777341) (|DivisionRing&| 774414 774787 775407 "DIVRING-" 775412 NIL DIVRING- (NIL T) |domain| NIL NIL) (|Divisor| 772260 773760 773980 "DIV" 774255 NIL DIV (NIL T) |domain| NIL NIL) (|DivisorCategory| 768399 769785 769866 "DIVCAT" 771315 NIL DIVCAT (NIL T) |category| |Divisor| 771847) (|DisplayPackage| 765520 765988 766613 "DISPLAY" 767818 T DISPLAY (NIL) |package| NIL NIL) (|DirichletRing| 761632 763314 763970 "DIRRING" 764920 NIL DIRRING (NIL T) |domain| NIL NIL) (|DirectProduct| 753010 761469 761590 "DIRPROD" 761595 NIL DIRPROD (NIL NIL T) |domain| NIL NIL) (|DirectProductFunctions2| 751138 751421 751856 "DIRPROD2" 752693 NIL DIRPROD2 (NIL NIL T T) |package| NIL NIL) (|DirectProductCategory| 735676 744110 744224 "DIRPCAT" 744933 NIL DIRPCAT (NIL NIL T) |category| NIL 746280) (|DirectProductCategory&| 731282 732199 733680 "DIRPCAT-" 734338 NIL DIRPCAT- (NIL T NIL T) |domain| NIL NIL) (|DiophantineSolutionPackage| 730109 730351 730685 "DIOSP" 731016 T DIOSP (NIL) |package| NIL NIL) (|DictionaryOperations| 725180 728329 728420 "DIOPS" 729217 NIL DIOPS (NIL T) |category| NIL 729578) (|DictionaryOperations&| 724482 724625 724957 "DIOPS-" 724962 NIL DIOPS- (NIL T T) |domain| NIL NIL) (|DifferentialRing| 722746 723603 723665 "DIFRING" 724008 T DIFRING (NIL) |category| NIL 724201) (|DifferentialRing&| 722152 722267 722542 "DIFRING-" 722547 NIL DIFRING- (NIL T) |domain| NIL NIL) (|DifferentialExtension| 718594 720503 720589 "DIFEXT" 721232 NIL DIFEXT (NIL T) |category| NIL 721725) (|DifferentialExtension&| 715927 716553 717626 "DIFEXT-" 717631 NIL DIFEXT- (NIL T T) |domain| NIL NIL) (|Dictionary| 712094 715243 715314 "DIAGG" 715319 NIL DIAGG (NIL T) |category| NIL 715360) (|Dictionary&| 711202 711401 711787 "DIAGG-" 711792 NIL DIAGG- (NIL T T) |domain| NIL NIL) (|DenavitHartenbergMatrix| 704328 709336 709793 "DHMATRIX" 710866 NIL DHMATRIX (NIL T) |domain| NIL NIL) (|DoubleFloatVector| 696589 703983 704133 "DFVEC" 704228 T DFVEC (NIL) |domain| NIL NIL) (|DoubleFloatSpecialFunctions| 683790 686356 689335 "DFSFUN" 693680 T DFSFUN (NIL) |package| NIL NIL) (|DoubleFloatMatrix| 677582 683330 683536 "DFMAT" 683634 T DFMAT (NIL) |domain| NIL NIL) (|DoubleFloat| 668940 674784 675616 "DFLOAT" 676788 T DFLOAT (NIL) |domain| NIL NIL) (|DefiniteIntegrationTools| 665365 665857 666674 "DFINTTLS" 668392 NIL DFINTTLS (NIL T T) |package| NIL NIL) (|DeRhamComplex| 660551 661961 662692 "DERHAM" 664739 NIL DERHAM (NIL T NIL) |domain| NIL NIL) (|Dequeue| 647482 650095 652331 "DEQUEUE" 658366 NIL DEQUEUE (NIL T) |domain| NIL NIL) (|DegreeReductionPackage| 645993 646228 646614 "DEGRED" 647218 NIL DEGRED (NIL T T) |package| NIL NIL) (|RationalFunctionDefiniteIntegration| 639758 640931 642414 "DEFINTRF" 644739 NIL DEFINTRF (NIL T) |package| NIL NIL) (|ElementaryFunctionDefiniteIntegration| 635367 636051 637137 "DEFINTEF" 639026 NIL DEFINTEF (NIL T T) |package| NIL NIL) (|DecimalExpansion| 625534 634344 634664 "DECIMAL" 635095 T DECIMAL (NIL) |domain| NIL NIL) (|DistinctDegreeFactorize| 621039 621718 622595 "DDFACT" 624791 NIL DDFACT (NIL T T) |package| NIL NIL) (|DoubleResultantPackage| 620251 620313 620619 "DBLRESP" 620953 NIL DBLRESP (NIL T T T T) |package| NIL NIL) (|Database| 616740 617162 617742 "DBASE" 619870 NIL DBASE (NIL T) |domain| NIL NIL) (|d03fafAnnaType| 615439 616595 616687 "D03FAFA" 616692 T D03FAFA (NIL) |domain| NIL NIL) (|d03eefAnnaType| 614139 615294 615386 "D03EEFA" 615391 T D03EEFA (NIL) |domain| NIL NIL) (|d03AgentsPackage| 610783 611517 612338 "D03AGNT" 613366 T D03AGNT (NIL) |package| NIL NIL) (|d02ejfAnnaType| 609723 610636 610729 "D02EJFA" 610734 T D02EJFA (NIL) |domain| NIL NIL) (|d02cjfAnnaType| 608663 609576 609669 "D02CJFA" 609674 T D02CJFA (NIL) |domain| NIL NIL) (|d02bhfAnnaType| 607603 608516 608609 "D02BHFA" 608614 T D02BHFA (NIL) |domain| NIL NIL) (|d02bbfAnnaType| 606543 607456 607549 "D02BBFA" 607554 T D02BBFA (NIL) |domain| NIL NIL) (|d02AgentsPackage| 595662 598106 600699 "D02AGNT" 603998 T D02AGNT (NIL) |package| NIL NIL) (|d01WeightsPackage| 591890 592748 593690 "D01WGTS" 594770 T D01WGTS (NIL) |package| NIL NIL) (|d01TransformFunctionType| 590474 591753 591851 "D01TRNS" 591856 T D01TRNS (NIL) |domain| NIL NIL) (|d01gbfAnnaType| 589078 590357 590435 "D01GBFA" 590440 T D01GBFA (NIL) |domain| NIL NIL) (|d01fcfAnnaType| 587682 588961 589039 "D01FCFA" 589044 T D01FCFA (NIL) |domain| NIL NIL) (|d01asfAnnaType| 586286 587565 587643 "D01ASFA" 587648 T D01ASFA (NIL) |domain| NIL NIL) (|d01aqfAnnaType| 584890 586169 586247 "D01AQFA" 586252 T D01AQFA (NIL) |domain| NIL NIL) (|d01apfAnnaType| 583494 584773 584851 "D01APFA" 584856 T D01APFA (NIL) |domain| NIL NIL) (|d01anfAnnaType| 582098 583377 583455 "D01ANFA" 583460 T D01ANFA (NIL) |domain| NIL NIL) (|d01amfAnnaType| 580702 581981 582059 "D01AMFA" 582064 T D01AMFA (NIL) |domain| NIL NIL) (|d01alfAnnaType| 579306 580585 580663 "D01ALFA" 580668 T D01ALFA (NIL) |domain| NIL NIL) (|d01akfAnnaType| 577910 579189 579267 "D01AKFA" 579272 T D01AKFA (NIL) |domain| NIL NIL) (|d01ajfAnnaType| 576514 577793 577871 "D01AJFA" 577876 T D01AJFA (NIL) |domain| NIL NIL) (|d01AgentsPackage| 566637 568816 571117 "D01AGNT" 574261 T D01AGNT (NIL) |package| NIL NIL) (|CyclotomicPolynomialPackage| 565101 565383 565769 "CYCLOTOM" 566321 T CYCLOTOM (NIL) |package| NIL NIL) (|CycleIndicators| 558827 560160 561623 "CYCLES" 563684 T CYCLES (NIL) |package| NIL NIL) (|CoerceVectorMatrixPackage| 557664 557855 558166 "CVMP" 558607 NIL CVMP (NIL T) |package| NIL NIL) (|ComplexTrigonometricManipulations| 553188 553526 554245 "CTRIGMNP" 557218 NIL CTRIGMNP (NIL T T) |package| NIL NIL) (|CyclicStreamTools| 552048 552202 552488 "CSTTOOLS" 553000 NIL CSTTOOLS (NIL T T) |package| NIL NIL) (|ComplexRootFindingPackage| 544851 545711 546919 "CRFP" 551001 NIL CRFP (NIL T T) |package| NIL NIL) (|CRApackage| 543362 543599 543957 "CRAPACK" 544554 NIL CRAPACK (NIL T) |package| NIL NIL) (|ComplexPatternMatch| 542239 542408 542782 "CPMATCH" 543153 NIL CPMATCH (NIL T T T) |package| NIL NIL) (|CharacteristicPolynomialInMonogenicalAlgebra| 541576 541625 541906 "CPIMA" 542166 NIL CPIMA (NIL T T T) |package| NIL NIL) (|CoordinateSystems| 535272 536220 537392 "COORDSYS" 540533 NIL COORDSYS (NIL T) |package| NIL NIL) (|ContinuedFraction| 528665 531665 532519 "CONTFRAC" 534493 NIL CONTFRAC (NIL T) |domain| NIL NIL) (|CommutativeRing| 527438 528183 528243 "COMRING" 528248 T COMRING (NIL) |category| NIL 528337) (|SubSpaceComponentProperty| 525951 526300 526630 "COMPPROP" 527174 T COMPPROP (NIL) |domain| NIL NIL) (|ComplexPattern| 525357 525401 525633 "COMPLPAT" 525883 NIL COMPLPAT (NIL T T T) |package| NIL NIL) (|Complex| 509683 525051 525229 "COMPLEX" 525234 NIL COMPLEX (NIL T) |domain| NIL NIL) (|ComplexFunctions2| 509066 509140 509338 "COMPLEX2" 509585 NIL COMPLEX2 (NIL T T) |package| NIL NIL) (|ComplexFactorization| 508536 508580 508784 "COMPFACT" 508998 NIL COMPFACT (NIL T T) |package| NIL NIL) (|ComplexCategory| 482561 498732 498817 "COMPCAT" 500767 NIL COMPCAT (NIL T) |category| NIL 503112) (|ComplexCategory&| 466019 470250 476087 "COMPCAT-" 476827 NIL COMPCAT- (NIL T T) |domain| NIL NIL) (|Comparable| 465511 465703 465753 "COMPAR" 465850 T COMPAR (NIL) |category| NIL 465937) (|CommuteUnivariatePolynomialCategory| 464961 464990 465229 "COMMUPC" 465458 NIL COMMUPC (NIL T T T) |package| NIL NIL) (|CommonOperators| 464581 464633 464755 "COMMONOP" 464885 T COMMONOP (NIL) |package| NIL NIL) (|Commutator| 463969 464175 464323 "COMM" 464469 T COMM (NIL) |domain| NIL NIL) (|CombinatorialOpsCategory| 462635 462896 462974 "COMBOPC" 463609 T COMBOPC (NIL) |category| NIL 463926) (|IntegerCombinatoricFunctions| 460731 460988 461400 "COMBINAT" 462324 NIL COMBINAT (NIL T) |package| NIL NIL) (|CombinatorialFunction| 454330 455049 456050 "COMBF" 459864 NIL COMBF (NIL T T) |package| NIL NIL) (|Color| 452520 452938 453326 "COLOR" 453968 T COLOR (NIL) |domain| NIL NIL) (|ComplexRootPackage| 451876 451939 452180 "CMPLXRT" 452433 NIL CMPLXRT (NIL T T) |package| NIL NIL) (|TwoDimensionalPlotClipping| 444933 446454 448143 "CLIP" 450255 T CLIP (NIL) |package| NIL NIL) (|CliffordAlgebra| 442400 443419 443825 "CLIF" 444646 NIL CLIF (NIL NIL T NIL) |domain| NIL NIL) (|Collection| 436788 439538 439602 "CLAGG" 441132 NIL CLAGG (NIL T) |category| NIL 441923) (|Collection&| 434434 435074 435967 "CLAGG-" 435972 NIL CLAGG- (NIL T T) |domain| NIL NIL) (|ComplexIntegerSolveLinearPolynomialEquation| 433329 433518 433892 "CINTSLPE" 434221 NIL CINTSLPE (NIL T T) |package| NIL NIL) (|ChangeOfVariable| 429129 429773 430648 "CHVAR" 432636 NIL CHVAR (NIL T T T) |package| NIL NIL) (|CharacteristicZero| 428013 428758 428824 "CHARZ" 428829 T CHARZ (NIL) |category| NIL 428848) (|CharacteristicPolynomialPackage| 427492 427557 427749 "CHARPOL" 427924 NIL CHARPOL (NIL T) |package| NIL NIL) (|CharacteristicNonZero| 426177 426967 427039 "CHARNZ" 427122 T CHARNZ (NIL) |category| NIL 427211) (|Character| 423147 424038 424601 "CHAR" 425648 T CHAR (NIL) |domain| NIL NIL) (|CombinatorialFunctionCategory| 422613 422693 422781 "CFCAT" 423022 T CFCAT (NIL) |category| NIL NIL) (|ComplexDoubleFloatVector| 413009 421973 422211 "CDFVEC" 422439 T CDFVEC (NIL) |domain| NIL NIL) (|ComplexDoubleFloatMatrix| 405720 412476 412722 "CDFMAT" 412827 T CDFMAT (NIL) |domain| NIL NIL) (|CommonDenominator| 404324 404481 404819 "CDEN" 405528 NIL CDEN (NIL T T T) |package| NIL NIL) (|CharacterClass| 397862 402786 403306 "CCLASS" 403848 T CCLASS (NIL) |domain| NIL NIL) (|CartesianTensor| 389762 390999 392236 "CARTEN" 396741 NIL CARTEN (NIL NIL NIL T) |domain| NIL NIL) (|CartesianTensorFunctions2| 388205 388418 388821 "CARTEN2" 389520 NIL CARTEN2 (NIL NIL NIL T T) |package| NIL NIL) (|CardinalNumber| 385363 386547 387073 "CARD" 387723 T CARD (NIL) |domain| NIL NIL) (|CachableSet| 384401 384811 384863 "CACHSET" 385103 T CACHSET (NIL) |category| NIL 385260) (|CancellationAbelianMonoid| 383615 383992 384072 "CABMON" 384165 T CABMON (NIL) |category| NIL 384268) (|BinaryTree| 380150 383089 383276 "BTREE" 383485 NIL BTREE (NIL T) |domain| NIL NIL) (|BinaryTournament| 376527 379493 379732 "BTOURN" 379979 NIL BTOURN (NIL T) |domain| NIL NIL) (|BinaryTreeCategory| 372844 375694 375781 "BTCAT" 375894 NIL BTCAT (NIL T) |category| NIL 376053) (|BinaryTreeCategory&| 372326 372429 372688 "BTCAT-" 372693 NIL BTCAT- (NIL T T) |domain| NIL NIL) (|BitAggregate| 365009 370774 370828 "BTAGG" 371220 T BTAGG (NIL) |category| NIL 371494) (|BitAggregate&| 364315 364452 364760 "BTAGG-" 364765 NIL BTAGG- (NIL T) |domain| NIL NIL) (|BinarySearchTree| 359996 363062 363441 "BSTREE" 364004 NIL BSTREE (NIL T) |domain| NIL NIL) (|BasicStochasticDifferential| 357468 358134 358649 "BSD" 359551 T BSD (NIL) |domain| NIL NIL) (|BrillhartTests| 355619 355855 356275 "BRILL" 357142 NIL BRILL (NIL T) |package| NIL NIL) (|BinaryRecursiveAggregate| 350771 353594 353686 "BRAGG" 354811 NIL BRAGG (NIL T) |category| NIL 355185) (|BinaryRecursiveAggregate&| 348774 349257 350071 "BRAGG-" 350076 NIL BRAGG- (NIL T T) |domain| NIL NIL) (|BalancedPAdicRational| 336816 347496 347885 "BPADICRT" 348460 NIL BPADICRT (NIL NIL) |domain| NIL NIL) (|BalancedPAdicInteger| 334343 336676 336780 "BPADIC" 336785 NIL BPADIC (NIL NIL) |domain| NIL NIL) (|BoundIntegerRoots| 333769 333813 334041 "BOUNDZRO" 334275 NIL BOUNDZRO (NIL T T) |package| NIL NIL) (|BasicOperator| 326469 328003 329489 "BOP" 332325 T BOP (NIL) |domain| NIL NIL) (|BasicOperatorFunctions1| 322244 322960 323888 "BOP1" 325624 NIL BOP1 (NIL T) |package| NIL NIL) (|Boolean| 320040 320866 321302 "BOOLEAN" 321838 T BOOLEAN (NIL) |domain| NIL NIL) (|BiModule| 319129 319589 319663 "BMODULE" 319668 NIL BMODULE (NIL T T) |category| NIL 319795) (|BlowUpPackage| 312783 313854 315191 "BLUPPACK" 318012 NIL BLUPPACK (NIL T NIL T T T) |package| NIL NIL) (|BlowUpWithQuadTrans| 311905 312546 312689 "BLQT" 312694 T BLQT (NIL) |domain| NIL NIL) (|BlowUpMethodCategory| 309451 310082 310152 "BLMETCT" 311246 T BLMETCT (NIL) |category| NIL 311823) (|BlowUpWithHamburgerNoether| 308566 309204 309359 "BLHN" 309364 T BLHN (NIL) |domain| NIL NIL) (|BlasLevelOne| 298333 300640 303091 "BLAS1" 306155 T BLAS1 (NIL) |package| NIL NIL) (|Bits| 292070 297975 298104 "BITS" 298228 T BITS (NIL) |domain| NIL NIL) (|BinaryFile| 290593 291224 291513 "BINFILE" 291817 T BINFILE (NIL) |domain| NIL NIL) (|BinaryExpansion| 280774 289582 289898 "BINARY" 290323 T BINARY (NIL) |domain| NIL NIL) (|BagAggregate| 277681 279671 279739 "BGAGG" 280146 NIL BGAGG (NIL T) |category| NIL 280374) (|BagAggregate&| 277439 277473 277616 "BGAGG-" 277621 NIL BGAGG- (NIL T T) |domain| NIL NIL) (|BasicFunctions| 276083 276456 276796 "BFUNCT" 277143 T BFUNCT (NIL) |domain| NIL NIL) (|BezoutMatrix| 273749 274005 274487 "BEZOUT" 275809 NIL BEZOUT (NIL T T T T T) |package| NIL NIL) (|Bezier| 272242 272538 272910 "BEZIER" 273419 NIL BEZIER (NIL T) |package| NIL NIL) (|BalancedBinaryTree| 267076 270286 270847 "BBTREE" 271754 NIL BBTREE (NIL T) |domain| NIL NIL) (|BasicType| 266705 266761 266809 "BASTYPE" 266981 T BASTYPE (NIL) |category| NIL NIL) (|BasicType&| 266495 266525 266640 "BASTYPE-" 266645 NIL BASTYPE- (NIL T) |domain| NIL NIL) (|BalancedFactorisation| 265390 265498 265813 "BALFACT" 266332 NIL BALFACT (NIL T T) |package| NIL NIL) (|AxiomServer| 264347 264529 264784 "AXSERV" 265173 T AXSERV (NIL) |package| NIL NIL) (|Automorphism| 262654 263408 263705 "AUTOMOR" 264104 NIL AUTOMOR (NIL T) |domain| NIL NIL) (|UnitsKnownAttribute| 262527 262532 262600 "ATUNIKN" 262605 T ATUNIKN (NIL) |category| NIL NIL) (|AttributeRegistry| 261869 261874 261938 "ATTREG" 261943 T ATTREG (NIL) |category| NIL NIL) (|AttributeButtons| 258975 259559 260194 "ATTRBUT" 261282 T ATTRBUT (NIL) |domain| NIL NIL) (|ShallowlyMutableAttribute| 258836 258841 258921 "ATSHMUT" 258926 T ATSHMUT (NIL) |category| NIL NIL) (|ArcTrigonometricFunctionCategory| 257990 258109 258203 "ATRIG" 258656 T ATRIG (NIL) |category| NIL NIL) (|ArcTrigonometricFunctionCategory&| 257652 257695 257902 "ATRIG-" 257907 NIL ATRIG- (NIL T) |domain| NIL NIL) (|PartiallyOrderedSetAttribute| 257507 257512 257598 "ATPOSET" 257603 T ATPOSET (NIL) |category| NIL NIL) (|NoZeroDivisorsAttribute| 257372 257377 257453 "ATNZDIV" 257458 T ATNZDIV (NIL) |category| NIL NIL) (|NullSquareAttribute| 257245 257250 257318 "ATNULSQ" 257323 T ATNULSQ (NIL) |category| NIL NIL) (|NotherianAttribute| 257120 257125 257191 "ATNOTHR" 257196 T ATNOTHR (NIL) |category| NIL NIL) (|MultiplicativeValuationAttribute| 256967 256972 257066 "ATMULVA" 257071 T ATMULVA (NIL) |category| NIL NIL) (|LeftUnitaryAttribute| 256838 256843 256913 "ATLUNIT" 256918 T ATLUNIT (NIL) |category| NIL NIL) (|LazyRepresentationAttribute| 256695 256700 256784 "ATLR" 256789 T ATLR (NIL) |category| NIL NIL) (|JacobiIdentityAttribute| 256560 256565 256641 "ATJACID" 256646 T ATJACID (NIL) |category| NIL NIL) (|FiniteAggregateAttribute| 256423 256428 256506 "ATFINAG" 256511 T ATFINAG (NIL) |category| NIL NIL) (|CanonicalUnitNormalAttribute| 256278 256283 256369 "ATCUNOR" 256374 T ATCUNOR (NIL) |category| NIL NIL) (|CommutativeStarAttribute| 256141 256146 256224 "ATCS" 256229 T ATCS (NIL) |category| NIL NIL) (|CentralAttribute| 256020 256025 256087 "ATCENRL" 256092 T ATCENRL (NIL) |category| NIL NIL) (|CanonicalAttribute| 255895 255900 255966 "ATCANON" 255971 T ATCANON (NIL) |category| NIL NIL) (|CanonicalClosedAttribute| 255758 255763 255841 "ATCANCL" 255846 T ATCANCL (NIL) |category| NIL NIL) (|ArbitraryPrecisionAttribute| 255615 255620 255704 "ATARBPR" 255709 T ATARBPR (NIL) |category| NIL NIL) (|ArbitraryExponentAttribute| 255474 255479 255561 "ATARBEX" 255566 T ATARBEX (NIL) |category| NIL NIL) (|ApproximateAttribute| 255345 255350 255420 "ATAPPRO" 255425 T ATAPPRO (NIL) |category| NIL NIL) (|AdditiveValuationAttribute| 255204 255209 255291 "ATADDVA" 255296 T ATADDVA (NIL) |category| NIL NIL) (|ArrayStack| 245017 247184 248909 "ASTACK" 253536 NIL ASTACK (NIL T) |domain| NIL NIL) (|AssociatedEquations| 242420 242868 243501 "ASSOCEQ" 244519 NIL ASSOCEQ (NIL T T) |package| NIL NIL) (|Asp9| 240912 241853 242063 "ASP9" 242250 NIL ASP9 (NIL NIL) |domain| NIL NIL) (|Asp8| 240546 240813 240880 "ASP8" 240885 NIL ASP8 (NIL NIL) |domain| NIL NIL) (|Asp80| 238781 239886 240130 "ASP80" 240344 NIL ASP80 (NIL NIL) |domain| NIL NIL) (|Asp7| 237080 238169 238396 "ASP7" 238594 NIL ASP7 (NIL NIL) |domain| NIL NIL) (|Asp78| 235417 236495 236714 "ASP78" 236903 NIL ASP78 (NIL NIL) |domain| NIL NIL) (|Asp77| 233753 234832 235051 "ASP77" 235240 NIL ASP77 (NIL NIL) |domain| NIL NIL) (|Asp74| 232049 233138 233367 "ASP74" 233566 NIL ASP74 (NIL NIL) |domain| NIL NIL) (|Asp73| 230347 231434 231663 "ASP73" 231862 NIL ASP73 (NIL NIL) |domain| NIL NIL) (|Asp6| 228686 229765 229982 "ASP6" 230170 NIL ASP6 (NIL NIL) |domain| NIL NIL) (|Asp55| 227016 228101 228320 "ASP55" 228509 NIL ASP55 (NIL NIL) |domain| NIL NIL) (|Asp50| 225347 226428 226648 "ASP50" 226838 NIL ASP50 (NIL NIL) |domain| NIL NIL) (|Asp4| 223879 224810 225010 "ASP4" 225187 NIL ASP4 (NIL NIL) |domain| NIL NIL) (|Asp49| 222408 223339 223541 "ASP49" 223719 NIL ASP49 (NIL NIL) |domain| NIL NIL) (|Asp42| 220552 221663 221938 "ASP42" 222207 NIL ASP42 (NIL NIL NIL NIL) |domain| NIL NIL) (|Asp41| 218705 219813 220086 "ASP41" 220353 NIL ASP41 (NIL NIL NIL NIL) |domain| NIL NIL) (|Asp35| 217038 218120 218339 "ASP35" 218528 NIL ASP35 (NIL NIL) |domain| NIL NIL) (|Asp34| 216670 216937 217006 "ASP34" 217011 NIL ASP34 (NIL NIL) |domain| NIL NIL) (|Asp33| 216222 216314 216455 "ASP33" 216571 NIL ASP33 (NIL NIL) |domain| NIL NIL) (|Asp31| 214515 215607 215836 "ASP31" 216035 NIL ASP31 (NIL NIL) |domain| NIL NIL) (|Asp30| 214147 214414 214483 "ASP30" 214488 NIL ASP30 (NIL NIL) |domain| NIL NIL) (|Asp29| 213697 213791 213932 "ASP29" 214048 NIL ASP29 (NIL NIL) |domain| NIL NIL) (|Asp28| 213329 213596 213665 "ASP28" 213670 NIL ASP28 (NIL NIL) |domain| NIL NIL) (|Asp27| 212961 213228 213297 "ASP27" 213302 NIL ASP27 (NIL NIL) |domain| NIL NIL) (|Asp24| 211486 212418 212621 "ASP24" 212800 NIL ASP24 (NIL NIL) |domain| NIL NIL) (|Asp20| 209768 210862 211094 "ASP20" 211296 NIL ASP20 (NIL NIL) |domain| NIL NIL) (|Asp1| 208300 209231 209431 "ASP1" 209608 NIL ASP1 (NIL NIL) |domain| NIL NIL) (|Asp19| 206625 207712 207932 "ASP19" 208122 NIL ASP19 (NIL NIL) |domain| NIL NIL) (|Asp12| 206177 206269 206410 "ASP12" 206526 NIL ASP12 (NIL NIL) |domain| NIL NIL) (|Asp10| 204411 205514 205759 "ASP10" 205974 NIL ASP10 (NIL NIL) |domain| NIL NIL) (|TwoDimensionalArray| 201270 204024 204249 "ARRAY2" 204254 NIL ARRAY2 (NIL T) |domain| NIL NIL) (|OneDimensionalArray| 195159 200535 200789 "ARRAY1" 201084 NIL ARRAY1 (NIL T) |domain| NIL NIL) (|OneDimensionalArrayFunctions2| 193375 193663 194087 "ARRAY12" 194837 NIL ARRAY12 (NIL T T) |package| NIL NIL) (|TwoDimensionalArrayCategory| 183671 186279 186451 "ARR2CAT" 191766 NIL ARR2CAT (NIL T T T) |category| NIL 192975) (|TwoDimensionalArrayCategory&| 179838 180860 182368 "ARR2CAT-" 182373 NIL ARR2CAT- (NIL T T T T) |domain| NIL NIL) (|ApplyRules| 177722 177928 178437 "APPRULE" 179583 NIL APPRULE (NIL T T T) |package| NIL NIL) (|ApplyUnivariateSkewPolynomial| 177093 177150 177391 "APPLYORE" 177641 NIL APPLYORE (NIL T T T) |package| NIL NIL) (|ApplicationProgramInterface| 175651 175869 176201 "API" 176831 T API (NIL) |package| NIL NIL) (|Any| 174083 174471 174795 "ANY" 175349 T ANY (NIL) |domain| NIL NIL) (|AnyFunctions1| 172933 173099 173360 "ANY1" 173878 NIL ANY1 (NIL T) |package| NIL NIL) (|AntiSymm| 169143 170384 170948 "ANTISYM" 172440 NIL ANTISYM (NIL T NIL) |domain| NIL NIL) (|AnonymousFunction| 168892 169054 169121 "ANON" 169126 T ANON (NIL) |domain| NIL NIL) (|AlgebraicNumber| 159460 165887 166849 "AN" 167976 T AN (NIL) |domain| NIL NIL) (|AbelianMonoidRing| 153584 155485 155593 "AMR" 157017 NIL AMR (NIL T T) |category| NIL 157953) (|AbelianMonoidRing&| 152263 152558 153135 "AMR-" 153140 NIL AMR- (NIL T T T) |domain| NIL NIL) (|AssociationList| 131828 152090 152218 "ALIST" 152223 NIL ALIST (NIL T T) |domain| NIL NIL) (|AlgebraGivenByStructuralConstants| 127001 131087 131416 "ALGSC" 131678 NIL ALGSC (NIL T NIL NIL NIL) |domain| NIL NIL) (|AlgebraPackage| 120277 121187 122332 "ALGPKG" 125966 NIL ALGPKG (NIL T T) |package| NIL NIL) (|AlgebraicMultFact| 118768 118962 119357 "ALGMFACT" 120043 NIL ALGMFACT (NIL T T T) |package| NIL NIL) (|AlgebraicManipulations| 111091 112039 113114 "ALGMANIP" 118067 NIL ALGMANIP (NIL T T) |package| NIL NIL) (|AlgebraicFunctionField| 97882 110316 110634 "ALGFF" 110957 NIL ALGFF (NIL T T T NIL) |domain| NIL NIL) (|AlgFactor| 96410 96599 96930 "ALGFACT" 97643 NIL ALGFACT (NIL T) |package| NIL NIL) (|Algebra| 94976 95767 95836 "ALGEBRA" 95938 NIL ALGEBRA (NIL T) |category| NIL 96025) (|Algebra&| 94543 94618 94834 "ALGEBRA-" 94839 NIL ALGEBRA- (NIL T T) |domain| NIL NIL) (|AssociationListAggregate| 70289 91056 91176 "ALAGG" 91399 NIL ALAGG (NIL T T) |category| |AssociationList| 91625) (|ArcHyperbolicFunctionCategory| 69449 69574 69662 "AHYP" 70103 T AHYP (NIL) |category| NIL NIL) (|Aggregate| 67687 68056 68104 "AGG" 68958 T AGG (NIL) |category| NIL 69431) (|Aggregate&| 66746 66993 67365 "AGG-" 67370 NIL AGG- (NIL T) |domain| NIL NIL) (|AffineSpaceCategory| 62636 63427 63510 "AFSPCAT" 65807 NIL AFSPCAT (NIL T) |category| NIL 66632) (|AlgebraicFunction| 58425 59087 59831 "AF" 62018 NIL AF (NIL T T) |package| NIL NIL) (|AffineSpace| 57480 58279 58390 "AFFSP" 58395 NIL AFFSP (NIL NIL T) |domain| NIL NIL) (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| 56013 57190 57405 "AFFPLPS" 57410 NIL AFFPLPS (NIL T) |domain| NIL NIL) (|AffinePlane| 55078 55895 55978 "AFFPL" 55983 NIL AFFPL (NIL T) |domain| NIL NIL) (|AffineAlgebraicSetComputeWithResultant| 48512 49389 50647 "AFALGRES" 54122 NIL AFALGRES (NIL T NIL T T T) |package| NIL NIL) (|AffineAlgebraicSetComputeWithGroebnerBasis| 45978 46239 46844 "AFALGGRO" 48217 NIL AFALGGRO (NIL T NIL T T T) |package| NIL NIL) (|PlaneAlgebraicCurvePlot| 44687 45081 45400 "ACPLOT" 45721 T ACPLOT (NIL) |domain| NIL NIL) (|AlgebraicallyClosedFunctionSpace| 28628 39906 40048 "ACFS" 41463 NIL ACFS (NIL T) |category| |Expression| 41846) (|AlgebraicallyClosedFunctionSpace&| 25328 26092 27446 "ACFS-" 27451 NIL ACFS- (NIL T T) |domain| NIL NIL) (|AlgebraicallyClosedField| 18951 21835 21913 "ACF" 23646 T ACF (NIL) |category| NIL 24442) (|AlgebraicallyClosedField&| 16600 17188 18117 "ACF-" 18122 NIL ACF- (NIL T) |domain| NIL NIL) (|AbelianSemiGroup| 15981 16189 16251 "ABELSG" 16410 T ABELSG (NIL) |category| NIL 16518) (|AbelianSemiGroup&| 15728 15766 15909 "ABELSG-" 15914 NIL ABELSG- (NIL T) |domain| NIL NIL) (|AbelianMonoid| 14733 15060 15116 "ABELMON" 15417 T ABELMON (NIL) |category| NIL 15619) (|AbelianMonoid&| 14172 14295 14545 "ABELMON-" 14550 NIL ABELMON- (NIL T) |domain| NIL NIL) (|AbelianGroup| 13194 13622 13676 "ABELGRP" 13869 T ABELGRP (NIL) |category| NIL 14003) (|AbelianGroup&| 12401 12575 12914 "ABELGRP-" 12919 NIL ABELGRP- (NIL T) |domain| NIL NIL) (|OneDimensionalArrayAggregate| 6156 11366 11466 "A1AGG" 11471 NIL A1AGG (NIL T) |category| NIL 11565) (|OneDimensionalArrayAggregate&| 30 1630 3956 "A1AGG-" 3961 NIL A1AGG- (NIL T T) |domain| NIL NIL)) 
\ No newline at end of file
+((|Category| 5947739 5947744 5947749 "NIL" NIL T NIL (NIL) NIL NIL NIL) (|Union| 5947724 5947729 5947734 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Record| 5947709 5947714 5947719 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Mapping| 5947694 5947699 5947704 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|Enumeration| 5947679 5947684 5947689 "NIL" NIL NIL NIL (NIL) |domain| NIL NIL) (|IntegerMod| 5946409 5947439 5947587 "ZMOD" 5947592 NIL ZMOD (NIL NIL) |domain| NIL NIL) (|IntegerLinearDependence| 5944763 5945026 5945431 "ZLINDEP" 5946112 NIL ZLINDEP (NIL T) |package| NIL NIL) (|ZeroDimensionalSolvePackage| 5924913 5928017 5931721 "ZDSOLVE" 5941269 NIL ZDSOLVE (NIL T NIL NIL) |package| NIL NIL) (|ParadoxicalCombinatorsForStreams| 5923772 5923952 5924259 "YSTREAM" 5924700 NIL YSTREAM (NIL T) |package| NIL NIL) (|XRecursivePolynomial| 5920429 5922547 5922902 "XRPOLY" 5923507 NIL XRPOLY (NIL T T) |domain| NIL NIL) (|XPolynomialRing| 5915068 5916795 5917705 "XPR" 5919602 NIL XPR (NIL T T) |domain| NIL NIL) (|XPolynomial| 5911699 5913956 5914297 "XPOLY" 5914779 NIL XPOLY (NIL T) |domain| NIL NIL) (|XPolynomialsCat| 5908410 5910306 5910400 "XPOLYC" 5910920 NIL XPOLYC (NIL T T) |category| NIL 5911129) (|XPBWPolynomial| 5902518 5905720 5906406 "XPBWPOLY" 5907813 NIL XPBWPOLY (NIL T T) |domain| NIL NIL) (|ExtensionField| 5895863 5899240 5899313 "XF" 5900466 NIL XF (NIL T) |category| NIL 5901246) (|ExtensionField&| 5895217 5895354 5895651 "XF-" 5895656 NIL XF- (NIL T T) |domain| NIL NIL) (|XFreeAlgebra| 5887939 5889701 5889789 "XFALG" 5893455 NIL XFALG (NIL T T) |category| NIL 5894680) (|XExponentialPackage| 5886422 5886580 5886940 "XEXPPKG" 5887747 NIL XEXPPKG (NIL T T T) |package| NIL NIL) (|XDistributedPolynomial| 5883678 5886143 5886327 "XDPOLY" 5886332 NIL XDPOLY (NIL T T) |domain| NIL NIL) (|XAlgebra| 5882098 5882889 5882949 "XALG" 5883041 NIL XALG (NIL T) |category| NIL 5883216) (|WuWenTsunTriangularSet| 5872068 5878419 5879249 "WUTSET" 5881457 NIL WUTSET (NIL T T T T) |domain| NIL NIL) (|WeightedPolynomials| 5868622 5869684 5870255 "WP" 5871745 NIL WP (NIL T T T T NIL NIL NIL) |domain| NIL NIL) (|WildFunctionFieldIntegralBasis| 5866778 5867033 5867541 "WFFINTBS" 5868338 NIL WFFINTBS (NIL T T T T) |package| NIL NIL) (|WeierstrassPreparation| 5863076 5863785 5864618 "WEIER" 5866020 NIL WEIER (NIL T) |package| NIL NIL) (|VectorSpace| 5861855 5862375 5862442 "VSPACE" 5862662 NIL VSPACE (NIL T) |category| NIL 5862780) (|VectorSpace&| 5861642 5861665 5861798 "VSPACE-" 5861803 NIL VSPACE- (NIL T T) |domain| NIL NIL) (|Void| 5861266 5861321 5861429 "VOID" 5861558 T VOID (NIL) |domain| NIL NIL) (|ViewportPackage| 5857851 5858483 5859257 "VIEW" 5860538 T VIEW (NIL) |package| NIL NIL) (|ViewDefaultsPackage| 5850555 5851731 5853363 "VIEWDEF" 5856273 T VIEWDEF (NIL) |package| NIL NIL) (|ThreeDimensionalViewport| 5833088 5836208 5839783 "VIEW3D" 5847044 T VIEW3D (NIL) |domain| NIL NIL) (|TwoDimensionalViewport| 5820322 5822754 5825403 "VIEW2D" 5830499 T VIEW2D (NIL) |domain| NIL NIL) (|Vector| 5813960 5819978 5820113 "VECTOR" 5820229 NIL VECTOR (NIL T) |domain| NIL NIL) (|VectorFunctions2| 5811930 5812252 5812697 "VECTOR2" 5813591 NIL VECTOR2 (NIL T T) |package| NIL NIL) (|VectorCategory| 5802624 5808521 5808593 "VECTCAT" 5810267 NIL VECTCAT (NIL T) |category| NIL 5811050) (|VectorCategory&| 5801330 5801622 5802165 "VECTCAT-" 5802170 NIL VECTCAT- (NIL T T) |domain| NIL NIL) (|Variable| 5800571 5800782 5800975 "VARIABLE" 5801185 NIL VARIABLE (NIL NIL) |domain| NIL NIL) (|UnivariateTaylorSeriesCZero| 5788338 5796772 5797625 "UTSZ" 5799818 NIL UTSZ (NIL T NIL) |domain| NIL NIL) (|TaylorSolve| 5787580 5787647 5787923 "UTSSOL" 5788247 NIL UTSSOL (NIL T T T) |package| NIL NIL) (|UTSodetools| 5785405 5785608 5786063 "UTSODETL" 5787322 NIL UTSODETL (NIL T T T T) |package| NIL NIL) (|UnivariateTaylorSeriesODESolver| 5781177 5781773 5782593 "UTSODE" 5784750 NIL UTSODE (NIL T T) |package| NIL NIL) (|UnivariateTaylorSeries| 5768745 5777183 5778036 "UTS" 5780424 NIL UTS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateTaylorSeriesCategory| 5754871 5762692 5762796 "UTSCAT" 5764909 NIL UTSCAT (NIL T) |category| NIL 5766155) (|UnivariateTaylorSeriesCategory&| 5751358 5752171 5753587 "UTSCAT-" 5753592 NIL UTSCAT- (NIL T T) |domain| NIL NIL) (|UnivariateTaylorSeriesFunctions2| 5750666 5750716 5750988 "UTS2" 5751284 NIL UTS2 (NIL T T T T) |package| NIL NIL) (|UnaryRecursiveAggregate| 5741835 5745436 5745526 "URAGG" 5749145 NIL URAGG (NIL T) |category| NIL 5750232) (|UnaryRecursiveAggregate&| 5737506 5738610 5740278 "URAGG-" 5740283 NIL URAGG- (NIL T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesWithExponentialSingularity| 5730227 5734863 5735795 "UPXSSING" 5736929 NIL UPXSSING (NIL T T NIL NIL) |domain| NIL NIL) (|UnivariatePuiseuxSeries| 5718485 5728717 5729213 "UPXS" 5729833 NIL UPXS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariatePuiseuxSeriesConstructor| 5708576 5718220 5718422 "UPXSCONS" 5718427 NIL UPXSCONS (NIL T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesConstructorCategory| 5693663 5703256 5703431 "UPXSCCA" 5704870 NIL UPXSCCA (NIL T T) |category| NIL 5705284) (|UnivariatePuiseuxSeriesConstructorCategory&| 5693020 5693130 5693506 "UPXSCCA-" 5693511 NIL UPXSCCA- (NIL T T T) |domain| NIL NIL) (|UnivariatePuiseuxSeriesCategory| 5678204 5687491 5687597 "UPXSCAT" 5688832 NIL UPXSCAT (NIL T) |category| NIL 5689804) (|UnivariatePuiseuxSeriesFunctions2| 5677232 5677358 5677670 "UPXS2" 5678054 NIL UPXS2 (NIL T T NIL NIL NIL NIL) |package| NIL NIL) (|UnivariatePolynomialSquareFree| 5675075 5675392 5675960 "UPSQFREE" 5676881 NIL UPSQFREE (NIL T T) |package| NIL NIL) (|UnivariatePowerSeriesCategory| 5665663 5669797 5669929 "UPSCAT" 5672124 NIL UPSCAT (NIL T T) |category| NIL 5673215) (|UnivariatePowerSeriesCategory&| 5664312 5664625 5665226 "UPSCAT-" 5665231 NIL UPSCAT- (NIL T T T) |domain| NIL NIL) (|UnivariatePolynomialCategory| 5640356 5653241 5653341 "UPOLYC" 5657458 NIL UPOLYC (NIL T) |category| NIL 5659551) (|UnivariatePolynomialCategory&| 5624975 5629122 5634802 "UPOLYC-" 5634807 NIL UPOLYC- (NIL T T) |domain| NIL NIL) (|UnivariatePolynomialCategoryFunctions2| 5624273 5624323 5624603 "UPOLYC2" 5624901 NIL UPOLYC2 (NIL T T T T) |package| NIL NIL) (|UnivariatePolynomial| 5610494 5623517 5623770 "UP" 5624106 NIL UP (NIL NIL T) |domain| NIL NIL) (|UnivariatePolynomialMultiplicationPackage| 5609179 5609342 5609694 "UPMP" 5610297 NIL UPMP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialDivisionPackage| 5608375 5608486 5608774 "UPDIVP" 5609044 NIL UPDIVP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialDecompositionPackage| 5605548 5605938 5606567 "UPDECOMP" 5607941 NIL UPDECOMP (NIL T T) |package| NIL NIL) (|UnivariatePolynomialCommonDenominator| 5604023 5604181 5604566 "UPCDEN" 5605356 NIL UPCDEN (NIL T T T) |package| NIL NIL) (|UnivariatePolynomialFunctions2| 5603183 5603293 5603563 "UP2" 5603889 NIL UP2 (NIL NIL T NIL T) |package| NIL NIL) (|UniversalSegment| 5601101 5601934 5602369 "UNISEG" 5602810 NIL UNISEG (NIL T) |domain| NIL NIL) (|UniversalSegmentFunctions2| 5599798 5599990 5600331 "UNISEG2" 5600856 NIL UNISEG2 (NIL T T) |package| NIL NIL) (|UnivariateFactorize| 5598240 5598488 5598874 "UNIFACT" 5599516 NIL UNIFACT (NIL T) |package| NIL NIL) (|UnivariateLaurentSeries| 5574089 5596852 5597287 "ULS" 5597907 NIL ULS (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateLaurentSeriesConstructor| 5557231 5573825 5574026 "ULSCONS" 5574031 NIL ULSCONS (NIL T T) |domain| NIL NIL) (|UnivariateLaurentSeriesConstructorCategory| 5531682 5548338 5548512 "ULSCCAT" 5550092 NIL ULSCCAT (NIL T T) |category| NIL 5550582) (|UnivariateLaurentSeriesConstructorCategory&| 5530143 5530466 5531183 "ULSCCAT-" 5531188 NIL ULSCCAT- (NIL T T T) |domain| NIL NIL) (|UnivariateLaurentSeriesCategory| 5514978 5524075 5524181 "ULSCAT" 5525843 NIL ULSCAT (NIL T) |category| NIL 5527005) (|UnivariateLaurentSeriesFunctions2| 5514006 5514132 5514444 "ULS2" 5514828 NIL ULS2 (NIL T T NIL NIL NIL NIL) |package| NIL NIL) (|UnivariateFormalPowerSeries| 5501976 5510472 5511344 "UFPS" 5513218 NIL UFPS (NIL T) |domain| NIL NIL) (|UnivariateFormalPowerSeriesFunctions| 5501250 5501384 5501644 "UFPS1" 5501818 NIL UFPS1 (NIL T) |package| NIL NIL) (|UniqueFactorizationDomain| 5498669 5500084 5500164 "UFD" 5500569 T UFD (NIL) |category| NIL 5500769) (|UniqueFactorizationDomain&| 5498292 5498357 5498562 "UFD-" 5498567 NIL UFD- (NIL T) |domain| NIL NIL) (|UserDefinedVariableOrdering| 5496740 5496999 5497388 "UDVO" 5497973 T UDVO (NIL) |package| NIL NIL) (|UserDefinedPartialOrdering| 5493337 5493861 5494569 "UDPO" 5496121 NIL UDPO (NIL T) |package| NIL NIL) (|U8Vector| 5487180 5493208 5493286 "U8VEC" 5493291 T U8VEC (NIL) |domain| NIL NIL) (|U8Matrix| 5481461 5486791 5486957 "U8MAT" 5487046 T U8MAT (NIL) |domain| NIL NIL) (|U32Vector| 5475302 5481330 5481410 "U32VEC" 5481415 T U32VEC (NIL) |domain| NIL NIL) (|U32Matrix| 5469564 5474906 5475076 "U32MAT" 5475166 T U32MAT (NIL) |domain| NIL NIL) (|U16Vector| 5463405 5469433 5469513 "U16VEC" 5469518 T U16VEC (NIL) |domain| NIL NIL) (|U16Matrix| 5457667 5463009 5463179 "U16MAT" 5463269 T U16MAT (NIL) |domain| NIL NIL) (|Type| 5457570 5457575 5457613 "TYPE" 5457618 T TYPE (NIL) |category| NIL NIL) (|TwoFactorize| 5454954 5455482 5456113 "TWOFACT" 5457008 NIL TWOFACT (NIL T) |package| NIL NIL) (|Tuple| 5453491 5453954 5454287 "TUPLE" 5454661 NIL TUPLE (NIL T) |domain| NIL NIL) (|TubePlotTools| 5449505 5450377 5451355 "TUBETOOL" 5452555 T TUBETOOL (NIL) |package| NIL NIL) (|TubePlot| 5447570 5447856 5448260 "TUBE" 5449170 NIL TUBE (NIL T) |domain| NIL NIL) (|TaylorSeries| 5439927 5445853 5446323 "TS" 5447154 NIL TS (NIL T) |domain| NIL NIL) (|TriangularSetCategory| 5420209 5426008 5426212 "TSETCAT" 5436991 NIL TSETCAT (NIL T T T T) |category| NIL 5439405) (|TriangularSetCategory&| 5412441 5414606 5417525 "TSETCAT-" 5417530 NIL TSETCAT- (NIL T T T T T) |domain| NIL NIL) (|TranscendentalManipulations| 5402160 5403241 5404700 "TRMANIP" 5411167 NIL TRMANIP (NIL T T) |package| NIL NIL) (|TriangularMatrixOperations| 5401071 5401161 5401483 "TRIMAT" 5402041 NIL TRIMAT (NIL T T T T) |package| NIL NIL) (|TrigonometricManipulations| 5396649 5396943 5397627 "TRIGMNIP" 5400670 NIL TRIGMNIP (NIL T T) |package| NIL NIL) (|TrigonometricFunctionCategory| 5395845 5395958 5396046 "TRIGCAT" 5396475 T TRIGCAT (NIL) |category| NIL NIL) (|TrigonometricFunctionCategory&| 5395364 5395443 5395699 "TRIGCAT-" 5395704 NIL TRIGCAT- (NIL T) |domain| NIL NIL) (|Tree| 5390817 5393530 5393998 "TREE" 5394941 NIL TREE (NIL T) |domain| NIL NIL) (|TranscendentalFunctionCategory| 5389687 5390238 5390328 "TRANFUN" 5390399 T TRANFUN (NIL) |category| NIL 5390617) (|TranscendentalFunctionCategory&| 5388699 5388904 5389352 "TRANFUN-" 5389357 NIL TRANFUN- (NIL T) |domain| NIL NIL) (|TopLevelThreeSpace| 5388290 5388351 5388489 "TOPSP" 5388613 T TOPSP (NIL) |package| NIL NIL) (|ToolsForSign| 5387293 5387448 5387691 "TOOLSIGN" 5388101 NIL TOOLSIGN (NIL T) |package| NIL NIL) (|TextFile| 5385276 5385975 5386371 "TEXTFILE" 5386929 T TEXTFILE (NIL) |domain| NIL NIL) (|TexFormat| 5382085 5382763 5383452 "TEX" 5384621 T TEX (NIL) |domain| NIL NIL) (|TexFormat1| 5381731 5381771 5381892 "TEX1" 5382021 NIL TEX1 (NIL T) |package| NIL NIL) (|TemplateUtilities| 5381070 5381175 5381359 "TEMUTL" 5381597 T TEMUTL (NIL) |package| NIL NIL) (|TabulatedComputationPackage| 5377804 5378197 5378771 "TBCMPPK" 5380608 NIL TBCMPPK (NIL T T) |package| NIL NIL) (|TableAggregate| 5366601 5374933 5375033 "TBAGG" 5375701 NIL TBAGG (NIL T T) |category| NIL 5376001) (|TableAggregate&| 5359896 5361812 5364265 "TBAGG-" 5364270 NIL TBAGG- (NIL T T T) |domain| NIL NIL) (|TangentExpansions| 5358852 5359009 5359265 "TANEXP" 5359705 NIL TANEXP (NIL T) |package| NIL NIL) (|Table| 5350183 5358599 5358757 "TABLE" 5358762 NIL TABLE (NIL T T) |domain| NIL NIL) (|Tableau| 5349284 5349413 5349627 "TABLEAU" 5350020 NIL TABLEAU (NIL T) |domain| NIL NIL) (|TableauxBumpers| 5342008 5343481 5345104 "TABLBUMP" 5347727 NIL TABLBUMP (NIL T) |package| NIL NIL) (|SystemSolvePackage| 5336094 5337182 5338480 "SYSSOLP" 5340786 NIL SYSSOLP (NIL T) |package| NIL NIL) (|SymbolTable| 5331613 5332498 5333529 "SYMTAB" 5335101 T SYMTAB (NIL) |domain| NIL NIL) (|TheSymbolTable| 5323868 5325178 5326838 "SYMS" 5329997 T SYMS (NIL) |domain| NIL NIL) (|SymmetricPolynomial| 5319764 5322902 5323307 "SYMPOLY" 5323531 NIL SYMPOLY (NIL T) |domain| NIL NIL) (|SymmetricFunctions| 5318990 5319090 5319297 "SYMFUNC" 5319623 NIL SYMFUNC (NIL T) |package| NIL NIL) (|Symbol| 5313054 5314764 5316065 "SYMBOL" 5317717 T SYMBOL (NIL) |domain| NIL NIL) (|Switch| 5304080 5306378 5308794 "SWITCH" 5310666 T SWITCH (NIL) |domain| NIL NIL) (|SparseUnivariateTaylorSeries| 5293844 5302001 5302549 "SUTS" 5303644 NIL SUTS (NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariatePuiseuxSeries| 5281987 5292280 5292800 "SUPXS" 5293438 NIL SUPXS (NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariatePolynomial| 5268222 5281241 5281506 "SUP" 5281804 NIL SUP (NIL T) |domain| NIL NIL) (|SupFractionFactorizer| 5266425 5266690 5267157 "SUPFRACF" 5267928 NIL SUPFRACF (NIL T T T T) |package| NIL NIL) (|SparseUnivariatePolynomialExpressions| 5251102 5265956 5266240 "SUPEXPR" 5266245 NIL SUPEXPR (NIL T) |domain| NIL NIL) (|SparseUnivariatePolynomialFunctions2| 5250320 5250432 5250684 "SUP2" 5250966 NIL SUP2 (NIL T T) |package| NIL NIL) (|RationalFunctionSum| 5247525 5247975 5248620 "SUMRF" 5249807 NIL SUMRF (NIL T) |package| NIL NIL) (|FunctionSpaceSum| 5246158 5246238 5246652 "SUMFS" 5247408 NIL SUMFS (NIL T T) |package| NIL NIL) (|SparseUnivariateLaurentSeries| 5221261 5244728 5245181 "SULS" 5245819 NIL SULS (NIL T NIL NIL) |domain| NIL NIL) (|SuchThat| 5220276 5220515 5220727 "SUCH" 5221123 NIL SUCH (NIL T T) |domain| NIL NIL) (|SubSpace| 5209829 5211407 5213168 "SUBSPACE" 5218586 NIL SUBSPACE (NIL NIL T) |domain| NIL NIL) (|SubResultantPackage| 5208764 5208904 5209210 "SUBRESP" 5209644 NIL SUBRESP (NIL T T) |package| NIL NIL) (|StreamTranscendentalFunctions| 5198843 5200368 5202163 "STTF" 5207085 NIL STTF (NIL T) |package| NIL NIL) (|StreamTranscendentalFunctionsNonCommutative| 5189658 5190967 5192574 "STTFNC" 5197380 NIL STTFNC (NIL T) |package| NIL NIL) (|StreamTaylorSeriesOperations| 5176624 5179023 5181559 "STTAYLOR" 5187208 NIL STTAYLOR (NIL T) |package| NIL NIL) (|StringTable| 5167424 5176368 5176523 "STRTBL" 5176528 NIL STRTBL (NIL T) |domain| NIL NIL) (|String| 5160294 5167351 5167399 "STRING" 5167404 T STRING (NIL) |domain| NIL NIL) (|StringCategory| 5152125 5159096 5159154 "STRICAT" 5159250 T STRICAT (NIL) |category| |String| 5159366) (|Stream| 5141361 5148178 5149172 "STREAM" 5151173 NIL STREAM (NIL T) |domain| NIL NIL) (|StreamFunctions3| 5140656 5140749 5140956 "STREAM3" 5141244 NIL STREAM3 (NIL T T T) |package| NIL NIL) (|StreamFunctions2| 5139197 5139420 5139753 "STREAM2" 5140399 NIL STREAM2 (NIL T T) |package| NIL NIL) (|StreamFunctions1| 5138726 5138790 5138940 "STREAM1" 5139109 NIL STREAM1 (NIL T) |package| NIL NIL) (|StreamTensor| 5138190 5138277 5138442 "STNSR" 5138615 NIL STNSR (NIL T) |package| NIL NIL) (|StreamInfiniteProduct| 5136392 5136669 5137099 "STINPROD" 5137874 NIL STINPROD (NIL T) |package| NIL NIL) (|StepThrough| 5135783 5136008 5136060 "STEP" 5136182 T STEP (NIL) |category| NIL 5136310) (|SparseTable| 5127212 5135628 5135748 "STBL" 5135753 NIL STBL (NIL T T NIL) |domain| NIL NIL) (|StreamAggregate| 5120195 5125949 5126023 "STAGG" 5126296 NIL STAGG (NIL T) |category| NIL 5126482) (|StreamAggregate&| 5117089 5117820 5119051 "STAGG-" 5119056 NIL STAGG- (NIL T T) |domain| NIL NIL) (|Stack| 5107092 5109254 5110964 "STACK" 5115426 NIL STACK (NIL T) |domain| NIL NIL) (|SquareFreeRegularTriangularSet| 5096028 5103614 5104423 "SREGSET" 5106483 NIL SREGSET (NIL T T T T) |domain| NIL NIL) (|SquareFreeRegularSetDecompositionPackage| 5083404 5085236 5087526 "SRDCMPK" 5094026 NIL SRDCMPK (NIL T T T T T) |package| NIL NIL) (|StringAggregate| 5071950 5078924 5078984 "SRAGG" 5081228 T SRAGG (NIL) |category| NIL 5082299) (|StringAggregate&| 5070443 5070806 5071412 "SRAGG-" 5071417 NIL SRAGG- (NIL T) |domain| NIL NIL) (|SquareMatrix| 5062248 5068698 5069379 "SQMATRIX" 5069844 NIL SQMATRIX (NIL NIL T) |domain| NIL NIL) (|SplittingTree| 5052342 5056673 5057858 "SPLTREE" 5061193 NIL SPLTREE (NIL T T) |domain| NIL NIL) (|SplittingNode| 5045896 5046743 5047746 "SPLNODE" 5051469 NIL SPLNODE (NIL T T) |domain| NIL NIL) (|SpecialFunctionCategory| 5044342 5044610 5044686 "SPFCAT" 5045527 T SPFCAT (NIL) |category| NIL NIL) (|SpecialOutputPackage| 5042101 5042414 5042912 "SPECOUT" 5043900 T SPECOUT (NIL) |package| NIL NIL) (|ThreeSpaceCategory| 5029245 5031697 5031777 "SPACEC" 5039128 NIL SPACEC (NIL T) |category| |ThreeSpace| 5042019) (|ThreeSpace| 5026666 5029132 5029211 "SPACE3" 5029216 NIL SPACE3 (NIL T) |domain| NIL NIL) (|SortPackage| 5024505 5024735 5025221 "SORTPAK" 5026366 NIL SORTPAK (NIL T T) |package| NIL NIL) (|TransSolvePackage| 5021043 5021501 5022235 "SOLVETRA" 5023964 NIL SOLVETRA (NIL T) |package| NIL NIL) (|TransSolvePackageService| 5018909 5019387 5020006 "SOLVESER" 5020536 NIL SOLVESER (NIL T) |package| NIL NIL) (|RadicalSolvePackage| 5010555 5011922 5013648 "SOLVERAD" 5017309 NIL SOLVERAD (NIL T) |package| NIL NIL) (|PolynomialSolveByFormulas| 5003907 5004613 5005659 "SOLVEFOR" 5009708 NIL SOLVEFOR (NIL T T) |package| NIL NIL) (|SquareFreeNormalizedTriangularSetCategory| 4995677 5002762 5003001 "SNTSCAT" 5003006 NIL SNTSCAT (NIL T T T T) |category| NIL 5003143) (|SparseMultivariateTaylorSeries| 4986825 4992644 4993300 "SMTS" 4995195 NIL SMTS (NIL T T T) |domain| NIL NIL) (|SparseMultivariatePolynomial| 4978216 4986594 4986760 "SMP" 4986765 NIL SMP (NIL T T) |domain| NIL NIL) (|SmithNormalForm| 4975289 4975659 4976255 "SMITH" 4977802 NIL SMITH (NIL T T T T) |package| NIL NIL) (|SquareMatrixCategory| 4964244 4970277 4970475 "SMATCAT" 4973017 NIL SMATCAT (NIL NIL T T T) |category| NIL 4973857) (|SquareMatrixCategory&| 4959467 4960617 4962544 "SMATCAT-" 4962549 NIL SMATCAT- (NIL T NIL T T T) |domain| NIL NIL) (|StackAggregate| 4956220 4958326 4958398 "SKAGG" 4958816 NIL SKAGG (NIL T) |category| NIL 4959039) (|SingleInteger| 4950729 4954845 4955285 "SINT" 4955822 T SINT (NIL) |domain| NIL NIL) (|SimplifyAlgebraicNumberConvertPackage| 4950211 4950281 4950465 "SIMPAN" 4950635 T SIMPAN (NIL) |package| NIL NIL) (|RationalFunctionSign| 4948265 4948611 4949084 "SIGNRF" 4949813 NIL SIGNRF (NIL T) |package| NIL NIL) (|ElementaryFunctionSign| 4946050 4946256 4946808 "SIGNEF" 4948007 NIL SIGNEF (NIL T T) |package| NIL NIL) (|SturmHabichtPackage| 4941564 4942407 4943402 "SHP" 4945156 NIL SHP (NIL T NIL) |package| NIL NIL) (|SplitHomogeneousDirectProduct| 4932840 4941322 4941522 "SHDP" 4941527 NIL SHDP (NIL NIL NIL T) |domain| NIL NIL) (|SemiGroup| 4932079 4932323 4932371 "SGROUP" 4932609 T SGROUP (NIL) |category| NIL 4932758) (|SemiGroup&| 4931717 4931791 4931960 "SGROUP-" 4931965 NIL SGROUP- (NIL T) |domain| NIL NIL) (|SymmetricGroupCombinatoricFunctions| 4925964 4927107 4928434 "SGCF" 4930476 T SGCF (NIL) |package| NIL NIL) (|SquareFreeRegularTriangularSetCategory| 4917941 4925026 4925259 "SFRTCAT" 4925264 NIL SFRTCAT (NIL T T T T) |category| |SquareFreeRegularTriangularSet| 4925331) (|SquareFreeRegularTriangularSetGcdPackage| 4905954 4907391 4909261 "SFRGCD" 4916349 NIL SFRGCD (NIL T T T T T) |package| NIL NIL) (|SquareFreeQuasiComponentPackage| 4893711 4895208 4897096 "SFQCMPK" 4904326 NIL SFQCMPK (NIL T T T T T) |package| NIL NIL) (|SimpleFortranProgram| 4893008 4893143 4893368 "SFORT" 4893590 NIL SFORT (NIL T T) |domain| NIL NIL) (|SExpressionOf| 4891922 4892756 4892953 "SEXOF" 4892958 NIL SEXOF (NIL T T T T T) |domain| NIL NIL) (|SExpression| 4890757 4891699 4891827 "SEX" 4891832 T SEX (NIL) |domain| NIL NIL) (|SExpressionCategory| 4881720 4882548 4882721 "SEXCAT" 4889749 NIL SEXCAT (NIL T T T T T) |category| NIL 4890675) (|Set| 4877724 4881614 4881686 "SET" 4881691 NIL SET (NIL T) |domain| NIL NIL) (|SetOfMIntegersInOneToN| 4874519 4875276 4875900 "SETMN" 4877210 NIL SETMN (NIL NIL NIL) |domain| NIL NIL) (|SetCategory| 4873915 4874071 4874123 "SETCAT" 4874308 T SETCAT (NIL) |category| NIL 4874459) (|SetCategory&| 4873575 4873643 4873807 "SETCAT-" 4873812 NIL SETCAT- (NIL T) |domain| NIL NIL) (|SetCategoryWithDegree| 4873023 4873219 4873291 "SETCATD" 4873402 T SETCATD (NIL) |category| NIL 4873493) (|SetAggregate| 4867627 4870540 4870615 "SETAGG" 4872058 NIL SETAGG (NIL T) |category| NIL 4872589) (|SetAggregate&| 4866857 4866998 4867355 "SETAGG-" 4867360 NIL SETAGG- (NIL T T) |domain| NIL NIL) (|SegmentExpansionCategory| 4865644 4865966 4866096 "SEGXCAT" 4866629 NIL SEGXCAT (NIL T T) |category| NIL 4866808) (|Segment| 4864385 4865127 4865405 "SEG" 4865410 NIL SEG (NIL T) |domain| NIL NIL) (|SegmentCategory| 4862827 4863057 4863131 "SEGCAT" 4864043 NIL SEGCAT (NIL T) |category| NIL 4864367) (|SegmentBinding| 4861439 4861867 4862173 "SEGBIND" 4862579 NIL SEGBIND (NIL T) |domain| NIL NIL) (|SegmentBindingFunctions2| 4860789 4860877 4861081 "SEGBIND2" 4861327 NIL SEGBIND2 (NIL T T) |package| NIL NIL) (|SegmentFunctions2| 4859638 4859801 4860095 "SEG2" 4860573 NIL SEG2 (NIL T T) |package| NIL NIL) (|SequentialDifferentialVariable| 4858814 4859459 4859594 "SDVAR" 4859599 NIL SDVAR (NIL T) |domain| NIL NIL) (|SequentialDifferentialPolynomial| 4845499 4858233 4858568 "SDPOL" 4858573 NIL SDPOL (NIL T) |domain| NIL NIL) (|StochasticDifferential| 4838258 4839806 4841037 "SD" 4844376 NIL SD (NIL T) |domain| NIL NIL) (|StructuralConstantsPackage| 4835866 4836258 4836820 "SCPKG" 4837779 NIL SCPKG (NIL T) |package| NIL NIL) (|SimpleCell| 4832845 4833219 4833780 "SCELL" 4835409 NIL SCELL (NIL T T) |domain| NIL NIL) (|SortedCache| 4831590 4831768 4832062 "SCACHE" 4832610 NIL SCACHE (NIL T) |package| NIL NIL) (|SingletonAsOrderedSet| 4830789 4831156 4831321 "SAOS" 4831483 T SAOS (NIL) |domain| NIL NIL) (|SAERationalFunctionAlgFactor| 4829913 4829957 4830331 "SAERFFC" 4830721 NIL SAERFFC (NIL T T T) |package| NIL NIL) (|SimpleAlgebraicExtension| 4821090 4829702 4829876 "SAE" 4829881 NIL SAE (NIL T T NIL) |domain| NIL NIL) (|SimpleAlgebraicExtensionAlgFactor| 4820259 4820303 4820657 "SAEFACT" 4821022 NIL SAEFACT (NIL T T T) |package| NIL NIL) (|RationalUnivariateRepresentationPackage| 4817188 4817721 4818480 "RURPK" 4819676 NIL RURPK (NIL T NIL) |package| NIL NIL) (|Ruleset| 4815014 4815362 4815860 "RULESET" 4816938 NIL RULESET (NIL T T T) |domain| NIL NIL) (|RewriteRule| 4810406 4811044 4811780 "RULE" 4814534 NIL RULE (NIL T T T) |domain| NIL NIL) (|RuleCalled| 4809898 4810087 4810219 "RULECOLD" 4810326 NIL RULECOLD (NIL NIL) |domain| NIL NIL) (|RegularTriangularSetGcdPackage| 4800812 4801901 4803378 "RSETGCD" 4808679 NIL RSETGCD (NIL T T T T T) |package| NIL NIL) (|RegularTriangularSetCategory| 4782805 4789890 4790103 "RSETCAT" 4798537 NIL RSETCAT (NIL T T T T) |category| NIL 4800238) (|RegularTriangularSetCategory&| 4779755 4780458 4781757 "RSETCAT-" 4781762 NIL RSETCAT- (NIL T T T T T) |domain| NIL NIL) (|RegularSetDecompositionPackage| 4767354 4769198 4771470 "RSDCMPK" 4777741 NIL RSDCMPK (NIL T T T T T) |package| NIL NIL) (|RealRootCharacterizationCategory| 4763765 4764342 4764520 "RRCC" 4766740 NIL RRCC (NIL T T) |category| |RightOpenIntervalRootCharacterization| 4767272) (|RealRootCharacterizationCategory&| 4762734 4762965 4763471 "RRCC-" 4763476 NIL RRCC- (NIL T T T) |domain| NIL NIL) (|RecursivePolynomialCategory| 4717640 4731945 4732096 "RPOLCAT" 4753426 NIL RPOLCAT (NIL T T T) |category| NIL 4758581) (|RecursivePolynomialCategory&| 4704720 4707976 4712901 "RPOLCAT-" 4712906 NIL RPOLCAT- (NIL T T T T) |domain| NIL NIL) (|RoutinesTable| 4691291 4701326 4702278 "ROUTINE" 4703810 T ROUTINE (NIL) |domain| NIL NIL) (|RomanNumeral| 4686607 4690500 4690782 "ROMAN" 4691049 T ROMAN (NIL) |domain| NIL NIL) (|RightOpenIntervalRootCharacterization| 4683609 4684356 4684846 "ROIRC" 4686290 NIL ROIRC (NIL T T) |domain| NIL NIL) (|RealNumberSystem| 4677971 4681165 4681227 "RNS" 4681757 T RNS (NIL) |category| NIL 4682248) (|RealNumberSystem&| 4675571 4676126 4677009 "RNS-" 4677164 NIL RNS- (NIL T) |domain| NIL NIL) (|Rng| 4674765 4675277 4675313 "RNG" 4675318 T RNG (NIL) |category| NIL 4675359) (|RightModule| 4673901 4674345 4674410 "RMODULE" 4674500 NIL RMODULE (NIL T) |category| NIL 4674573) (|RectangularMatrixCategoryFunctions2| 4671819 4671930 4672525 "RMCAT2" 4673761 NIL RMCAT2 (NIL NIL NIL T T T T T T T T) |package| NIL NIL) (|RectangularMatrix| 4666946 4670407 4670960 "RMATRIX" 4671386 NIL RMATRIX (NIL NIL NIL T) |domain| NIL NIL) (|RectangularMatrixCategory| 4655069 4658190 4658426 "RMATCAT" 4664858 NIL RMATCAT (NIL NIL NIL T T T) |category| NIL 4666374) (|RectangularMatrixCategory&| 4653959 4654190 4654767 "RMATCAT-" 4654772 NIL RMATCAT- (NIL T NIL NIL T T T) |domain| NIL NIL) (|RationalInterpolation| 4653163 4653296 4653542 "RINTERP" 4653802 NIL RINTERP (NIL NIL T) |package| NIL NIL) (|Ring| 4651747 4652492 4652530 "RING" 4652715 T RING (NIL) |category| NIL 4652897) (|Ring&| 4651434 4651494 4651638 "RING-" 4651643 NIL RING- (NIL T) |domain| NIL NIL) (|RandomIntegerDistributions| 4649486 4649834 4650291 "RIDIST" 4651045 T RIDIST (NIL) |package| NIL NIL) (|RegularChain| 4630965 4648367 4648811 "RGCHAIN" 4649126 NIL RGCHAIN (NIL T NIL) |domain| NIL NIL) (|RootsFindingPackage| 4628860 4629252 4629753 "RFP" 4630533 NIL RFP (NIL T) |package| NIL NIL) (|RationalFunction| 4623595 4624611 4625790 "RF" 4627753 NIL RF (NIL T) |package| NIL NIL) (|RationalFunctionFactorizer| 4622896 4623004 4623229 "RFFACTOR" 4623463 NIL RFFACTOR (NIL T) |package| NIL NIL) (|RationalFunctionFactor| 4622378 4622422 4622628 "RFFACT" 4622828 NIL RFFACT (NIL T) |package| NIL NIL) (|RandomFloatDistributions| 4618856 4619472 4620226 "RFDIST" 4621688 T RFDIST (NIL) |package| NIL NIL) (|RetractSolvePackage| 4617907 4618047 4618345 "RETSOL" 4618692 NIL RETSOL (NIL T T) |package| NIL NIL) (|RetractableTo| 4617285 4617386 4617456 "RETRACT" 4617758 NIL RETRACT (NIL T) |category| NIL NIL) (|RetractableTo&| 4617055 4617084 4617225 "RETRACT-" 4617230 NIL RETRACT- (NIL T T) |domain| NIL NIL) (|Result| 4606999 4616415 4616655 "RESULT" 4616843 T RESULT (NIL) |domain| NIL NIL) (|ResidueRing| 4604872 4605746 4606069 "RESRING" 4606844 NIL RESRING (NIL T T T T NIL) |domain| NIL NIL) (|ResolveLatticeCompletion| 4604288 4604343 4604517 "RESLATC" 4604776 NIL RESLATC (NIL T) |package| NIL NIL) (|RepeatedSquaring| 4603781 4603829 4604022 "REPSQ" 4604215 NIL REPSQ (NIL T) |package| NIL NIL) (|RadicalEigenPackage| 4599228 4600209 4601298 "REP" 4602746 T REP (NIL) |package| NIL NIL) (|RepeatedDoubling| 4598713 4598763 4598958 "REPDB" 4599153 NIL REPDB (NIL T) |package| NIL NIL) (|RepresentationPackage2| 4589236 4591104 4592957 "REP2" 4596934 NIL REP2 (NIL T) |package| NIL NIL) (|RepresentationPackage1| 4582898 4583953 4585388 "REP1" 4587875 NIL REP1 (NIL T) |package| NIL NIL) (|RegularTriangularSet| 4571975 4579560 4580339 "REGSET" 4582299 NIL REGSET (NIL T T T T) |domain| NIL NIL) (|Reference| 4570374 4570779 4571124 "REF" 4571678 NIL REF (NIL T) |domain| NIL NIL) (|ReductionOfOrder| 4569362 4569481 4569765 "REDORDER" 4570210 NIL REDORDER (NIL T T) |package| NIL NIL) (|RecurrenceOperator| 4563805 4564458 4565478 "RECOP" 4568656 NIL RECOP (NIL T T) |package| NIL NIL) (|RealClosure| 4557263 4562115 4562622 "RECLOS" 4563393 NIL RECLOS (NIL T) |domain| NIL NIL) (|RealSolvePackage| 4555736 4556003 4556362 "REALSOLV" 4556952 T REALSOLV (NIL) |package| NIL NIL) (|RealConstant| 4555471 4555528 4555582 "REAL" 4555587 T REAL (NIL) |category| NIL 4555659) (|RealZeroPackageQ| 4549856 4551054 4552465 "REAL0Q" 4554171 NIL REAL0Q (NIL T) |package| NIL NIL) (|RealZeroPackage| 4542782 4544265 4545956 "REAL0" 4548261 NIL REAL0 (NIL T) |package| NIL NIL) (|ReducedDivisor| 4541716 4541824 4542195 "RDIV" 4542650 NIL RDIV (NIL T T T T T) |package| NIL NIL) (|RandomDistributions| 4540222 4540464 4540815 "RDIST" 4541440 NIL RDIST (NIL T) |package| NIL NIL) (|TranscendentalRischDESystem| 4538035 4538420 4539024 "RDETRS" 4539808 NIL RDETRS (NIL T T) |package| NIL NIL) (|TranscendentalRischDE| 4534848 4535422 4536208 "RDETR" 4537427 NIL RDETR (NIL T T) |package| NIL NIL) (|ElementaryRischDESystem| 4532742 4533092 4533766 "RDEEFS" 4534474 NIL RDEEFS (NIL T T) |package| NIL NIL) (|ElementaryRischDE| 4530521 4530902 4531595 "RDEEF" 4532337 NIL RDEEF (NIL T T) |package| NIL NIL) (|RealClosedField| 4520949 4525261 4525321 "RCFIELD" 4527647 T RCFIELD (NIL) |category| NIL 4529060) (|RealClosedField&| 4517524 4518379 4519624 "RCFIELD-" 4519777 NIL RCFIELD- (NIL T) |domain| NIL NIL) (|RecursiveAggregate| 4512062 4514549 4514629 "RCAGG" 4516444 NIL RCAGG (NIL T) |category| NIL 4517124) (|RecursiveAggregate&| 4511551 4511656 4511907 "RCAGG-" 4511912 NIL RCAGG- (NIL T T) |domain| NIL NIL) (|RationalRetractions| 4510400 4510564 4510865 "RATRET" 4511352 NIL RATRET (NIL T) |package| NIL NIL) (|RationalFactorize| 4509577 4509672 4509909 "RATFACT" 4510276 NIL RATFACT (NIL T) |package| NIL NIL) (|RandomNumberSource| 4508441 4508601 4508869 "RANDSRC" 4509361 T RANDSRC (NIL) |package| NIL NIL) (|RadixUtilities| 4507994 4508058 4508191 "RADUTIL" 4508352 T RADUTIL (NIL) |package| NIL NIL) (|RadixExpansion| 4496840 4505846 4506409 "RADIX" 4507492 NIL RADIX (NIL NIL) |domain| NIL NIL) (|RadicalFunctionField| 4484136 4496510 4496793 "RADFF" 4496798 NIL RADFF (NIL T T T NIL NIL) |domain| NIL NIL) (|RadicalCategory| 4483576 4483672 4483732 "RADCAT" 4483995 T RADCAT (NIL) |category| NIL NIL) (|RadicalCategory&| 4483244 4483302 4483473 "RADCAT-" 4483478 NIL RADCAT- (NIL T) |domain| NIL NIL) (|Queue| 4472860 4475086 4476862 "QUEUE" 4481515 NIL QUEUE (NIL T) |domain| NIL NIL) (|Quaternion| 4467975 4472736 4472826 "QUAT" 4472831 NIL QUAT (NIL T) |domain| NIL NIL) (|QuaternionCategoryFunctions2| 4467299 4467349 4467611 "QUATCT2" 4467901 NIL QUATCT2 (NIL T T T T) |package| NIL NIL) (|QuaternionCategory| 4457665 4462364 4462455 "QUATCAT" 4463968 NIL QUATCAT (NIL T) |category| |Quaternion| 4465183) (|QuaternionCategory&| 4451814 4453212 4455393 "QUATCAT-" 4455596 NIL QUATCAT- (NIL T T) |domain| NIL NIL) (|QueueAggregate| 4448245 4450407 4450479 "QUAGG" 4451096 NIL QUAGG (NIL T) |category| NIL 4451386) (|QuadraticForm| 4446622 4447219 4447514 "QFORM" 4448032 NIL QFORM (NIL NIL T) |domain| NIL NIL) (|QuotientFieldCategory| 4432360 4440263 4440359 "QFCAT" 4441692 NIL QFCAT (NIL T) |category| NIL 4443337) (|QuotientFieldCategory&| 4425339 4427048 4429660 "QFCAT-" 4429868 NIL QFCAT- (NIL T T) |domain| NIL NIL) (|QuotientFieldCategoryFunctions2| 4424646 4424696 4424968 "QFCAT2" 4425265 NIL QFCAT2 (NIL T T T T) |package| NIL NIL) (|QueryEquation| 4423790 4423935 4424160 "QEQUAT" 4424463 T QEQUAT (NIL) |domain| NIL NIL) (|QuasiComponentPackage| 4411747 4413244 4415112 "QCMPACK" 4422162 NIL QCMPACK (NIL T T T T T) |package| NIL NIL) (|QuasiAlgebraicSet| 4407419 4408000 4408731 "QALGSET" 4411181 NIL QALGSET (NIL T T T T) |domain| NIL NIL) (|QuasiAlgebraicSet2| 4405680 4406090 4406629 "QALGSET2" 4406985 NIL QALGSET2 (NIL NIL NIL) |package| NIL NIL) (|PAdicWildFunctionFieldIntegralBasis| 4403370 4403666 4404233 "PWFFINTB" 4405350 NIL PWFFINTB (NIL T T T T) |package| NIL NIL) (|PushVariables| 4400395 4400590 4401143 "PUSHVAR" 4403107 NIL PUSHVAR (NIL T T T T) |package| NIL NIL) (|PartialTranscendentalFunctions| 4393207 4394575 4394705 "PTRANFN" 4398801 NIL PTRANFN (NIL T) |category| NIL NIL) (|PointPackage| 4390903 4391249 4391713 "PTPACK" 4392797 NIL PTPACK (NIL T) |package| NIL NIL) (|PointFunctions2| 4390352 4390422 4390590 "PTFUNC2" 4390809 NIL PTFUNC2 (NIL T T) |package| NIL NIL) (|PointCategory| 4382504 4388518 4388588 "PTCAT" 4389189 NIL PTCAT (NIL T) |category| |Point| 4389442) (|PolynomialSquareFree| 4381860 4381908 4382151 "PSQFR" 4382432 NIL PSQFR (NIL T T T T) |package| NIL NIL) (|PseudoLinearNormalForm| 4379685 4380101 4380626 "PSEUDLIN" 4381410 NIL PSEUDLIN (NIL T) |package| NIL NIL) (|PolynomialSetUtilitiesPackage| 4355575 4359033 4362838 "PSETPK" 4376083 NIL PSETPK (NIL T T T T) |package| NIL NIL) (|PolynomialSetCategory| 4343697 4347578 4347772 "PSETCAT" 4353835 NIL PSETCAT (NIL T T T T) |category| NIL 4355105) (|PolynomialSetCategory&| 4340453 4341330 4342626 "PSETCAT-" 4342631 NIL PSETCAT- (NIL T T T T T) |domain| NIL NIL) (|PlottableSpaceCurveCategory| 4339273 4339521 4339605 "PSCURVE" 4340118 T PSCURVE (NIL) |category| |Plot3D| 4340413) (|PowerSeriesCategory| 4333549 4335602 4335734 "PSCAT" 4337346 NIL PSCAT (NIL T T T) |category| NIL 4337728) (|PowerSeriesCategory&| 4332242 4332506 4333107 "PSCAT-" 4333112 NIL PSCAT- (NIL T T T T) |domain| NIL NIL) (|Partition| 4330271 4331052 4331426 "PRTITION" 4331902 T PRTITION (NIL) |domain| NIL NIL) (|ProjectiveSpaceCategory| 4325417 4326314 4326405 "PRSPCAT" 4329196 NIL PRSPCAT (NIL T) |category| NIL 4330157) (|PseudoRemainderSequence| 4306810 4309973 4313403 "PRS" 4322116 NIL PRS (NIL T T) |package| NIL NIL) (|PriorityQueueAggregate| 4303729 4305788 4305882 "PRQAGG" 4306214 NIL PRQAGG (NIL T) |category| |Heap| 4306382) (|ProjectiveSpace| 4302663 4303567 4303690 "PROJSP" 4303695 NIL PROJSP (NIL NIL T) |domain| NIL NIL) (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| 4301071 4302357 4302584 "PROJPLPS" 4302589 NIL PROJPLPS (NIL T) |domain| NIL NIL) (|ProjectivePlane| 4300011 4300937 4301032 "PROJPL" 4301037 NIL PROJPL (NIL T) |domain| NIL NIL) (|Product| 4291035 4297262 4298468 "PRODUCT" 4298877 NIL PRODUCT (NIL T T) |domain| NIL NIL) (|PolynomialRing| 4287060 4290092 4290490 "PR" 4290725 NIL PR (NIL T T) |domain| NIL NIL) (|ProjectiveAlgebraicSetPackage| 4284307 4284546 4285108 "PRJALGPK" 4286782 NIL PRJALGPK (NIL T NIL T T T) |package| NIL NIL) (|PrintPackage| 4283969 4284012 4284120 "PRINT" 4284239 T PRINT (NIL) |package| NIL NIL) (|IntegerPrimesPackage| 4282856 4282998 4283264 "PRIMES" 4283788 NIL PRIMES (NIL T) |package| NIL NIL) (|PrimitiveElement| 4279578 4280210 4281013 "PRIMELT" 4282148 NIL PRIMELT (NIL T) |package| NIL NIL) (|PrimitiveFunctionCategory| 4279080 4279148 4279228 "PRIMCAT" 4279458 T PRIMCAT (NIL) |category| NIL NIL) (|PrimitiveArray| 4273652 4278939 4279036 "PRIMARR" 4279041 NIL PRIMARR (NIL T) |domain| NIL NIL) (|PrimitiveArrayFunctions2| 4271993 4272256 4272645 "PRIMARR2" 4273355 NIL PRIMARR2 (NIL T T) |package| NIL NIL) (|PrecomputedAssociatedEquations| 4271213 4271309 4271586 "PREASSOC" 4271873 NIL PREASSOC (NIL T T) |package| NIL NIL) (|PlottablePlaneCurveCategory| 4270256 4270456 4270540 "PPCURVE" 4270931 T PPCURVE (NIL) |category| NIL 4271173) (|U32VectorPolynomialOperations| 4260186 4262082 4264230 "POLYVEC" 4268182 T POLYVEC (NIL) |package| NIL NIL) (|PolynomialRoots| 4255776 4256378 4257333 "POLYROOT" 4259529 NIL POLYROOT (NIL T T T T T) |package| NIL NIL) (|Polynomial| 4246364 4255130 4255388 "POLY" 4255568 NIL POLY (NIL T) |domain| NIL NIL) (|PolynomialCategoryLifting| 4245316 4245388 4245798 "POLYLIFT" 4246268 NIL POLYLIFT (NIL T T T T T) |package| NIL NIL) (|PolynomialCategoryQuotientFunctions| 4238809 4239470 4240538 "POLYCATQ" 4244576 NIL POLYCATQ (NIL T T T T T) |package| NIL NIL) (|PolynomialCategory| 4216499 4224695 4224828 "POLYCAT" 4231724 NIL POLYCAT (NIL T T T) |category| NIL 4234978) (|PolynomialCategory&| 4206028 4208848 4212753 "POLYCAT-" 4212758 NIL POLYCAT- (NIL T T T T) |domain| NIL NIL) (|PolynomialToUnivariatePolynomial| 4205254 4205367 4205614 "POLY2UP" 4205891 NIL POLY2UP (NIL NIL T) |package| NIL NIL) (|PolynomialFunctions2| 4204648 4204728 4204916 "POLY2" 4205150 NIL POLY2 (NIL T T) |package| NIL NIL) (|RealPolynomialUtilitiesPackage| 4202158 4202533 4203052 "POLUTIL" 4204263 NIL POLUTIL (NIL T T) |package| NIL NIL) (|PolToPol| 4198693 4199320 4200067 "POLTOPOL" 4201482 NIL POLTOPOL (NIL NIL T) |package| NIL NIL) (|Point| 4192506 4198600 4198664 "POINT" 4198669 NIL POINT (NIL T) |domain| NIL NIL) (|PolynomialNumberTheoryFunctions| 4188558 4189282 4190148 "PNTHEORY" 4191718 T PNTHEORY (NIL) |package| NIL NIL) (|PatternMatchTools| 4185795 4186294 4187012 "PMTOOLS" 4188030 NIL PMTOOLS (NIL T T T) |package| NIL NIL) (|PatternMatchSymbol| 4185045 4185178 4185408 "PMSYM" 4185638 NIL PMSYM (NIL T) |package| NIL NIL) (|PatternMatchQuotientFieldCategory| 4184065 4184180 4184552 "PMQFCAT" 4184906 NIL PMQFCAT (NIL T T T) |package| NIL NIL) (|AttachPredicates| 4182962 4183135 4183412 "PMPRED" 4183850 NIL PMPRED (NIL T) |package| NIL NIL) (|FunctionSpaceAttachPredicates| 4181911 4182028 4182323 "PMPREDFS" 4182803 NIL PMPREDFS (NIL T T T) |package| NIL NIL) (|PatternMatchPolynomialCategory| 4179387 4179736 4180448 "PMPLCAT" 4181500 NIL PMPLCAT (NIL T T T T T) |package| NIL NIL) (|PatternMatchListAggregate| 4178498 4178631 4178934 "PMLSAGG" 4179230 NIL PMLSAGG (NIL T T T) |package| NIL NIL) (|PatternMatchKernel| 4177532 4177658 4178002 "PMKERNEL" 4178348 NIL PMKERNEL (NIL T T) |package| NIL NIL) (|PatternMatchIntegerNumberSystem| 4176735 4176871 4177138 "PMINS" 4177372 NIL PMINS (NIL T) |package| NIL NIL) (|PatternMatchFunctionSpace| 4175635 4175750 4176179 "PMFS" 4176596 NIL PMFS (NIL T T T) |package| NIL NIL) (|PatternMatchPushDown| 4174206 4174403 4174790 "PMDOWN" 4175409 NIL PMDOWN (NIL T T T) |package| NIL NIL) (|PatternMatchAssertions| 4172733 4172977 4173320 "PMASS" 4173923 T PMASS (NIL) |package| NIL NIL) (|FunctionSpaceAssertions| 4171510 4171642 4171923 "PMASSFS" 4172562 NIL PMASSFS (NIL T T) |package| NIL NIL) (|PolynomialPackageForCurve| 4167163 4167512 4168224 "PLPKCRV" 4171047 NIL PLPKCRV (NIL T T T NIL T) |package| NIL NIL) (|PlotTools| 4166585 4166691 4166855 "PLOTTOOL" 4167033 T PLOTTOOL (NIL) |package| NIL NIL) (|Plot| 4157187 4159218 4161367 "PLOT" 4164460 T PLOT (NIL) |domain| NIL NIL) (|Plot3D| 4149721 4151512 4153284 "PLOT3D" 4155443 T PLOT3D (NIL) |domain| NIL NIL) (|PlotFunctions1| 4147954 4148197 4148583 "PLOT1" 4149416 NIL PLOT1 (NIL T) |package| NIL NIL) (|ParametricLinearEquations| 4109047 4115442 4122436 "PLEQN" 4141217 NIL PLEQN (NIL T T T T) |package| NIL NIL) (|Plcs| 4108025 4108904 4109012 "PLCS" 4109017 NIL PLCS (NIL T T) |domain| NIL NIL) (|PlacesOverPseudoAlgebraicClosureOfFiniteField| 4106460 4107593 4107874 "PLACESPS" 4107879 NIL PLACESPS (NIL T) |domain| NIL NIL) (|Places| 4105307 4106280 4106389 "PLACES" 4106394 NIL PLACES (NIL T) |domain| NIL NIL) (|PlacesCategory| 4099843 4100716 4100829 "PLACESC" 4104330 NIL PLACESC (NIL T T) |category| NIL 4105193) (|PolynomialInterpolation| 4098638 4098833 4099166 "PINTERP" 4099603 NIL PINTERP (NIL NIL T) |package| NIL NIL) (|PolynomialInterpolationAlgorithms| 4098024 4098093 4098326 "PINTERPA" 4098545 NIL PINTERPA (NIL T T) |package| NIL NIL) (|PositiveInteger| 4096965 4097647 4097828 "PI" 4097889 T PI (NIL) |domain| NIL NIL) (|PrincipalIdealDomain| 4094444 4095888 4095958 "PID" 4096265 T PID (NIL) |category| NIL 4096484) (|PiCoercions| 4093982 4094030 4094188 "PICOERCE" 4094372 NIL PICOERCE (NIL T) |package| NIL NIL) (|PolyGroebner| 4092874 4093080 4093375 "PGROEB" 4093746 NIL PGROEB (NIL T) |package| NIL NIL) (|PermutationGroupExamples| 4083987 4085507 4087400 "PGE" 4091045 T PGE (NIL) |package| NIL NIL) (|PolynomialGcdPackage| 4080235 4080680 4081411 "PGCD" 4083433 NIL PGCD (NIL T T T T) |package| NIL NIL) (|PartialFractionPackage| 4078989 4079150 4079477 "PFRPAC" 4080025 NIL PFRPAC (NIL T) |package| NIL NIL) (|PartialFraction| 4073523 4076273 4076923 "PFR" 4078410 NIL PFR (NIL T) |domain| NIL NIL) (|PointsOfFiniteOrderTools| 4070598 4070932 4071509 "PFOTOOLS" 4073129 NIL PFOTOOLS (NIL T T) |package| NIL NIL) (|PackageForPoly| 4061076 4062060 4063369 "PFORP" 4069477 NIL PFORP (NIL T T T NIL) |package| NIL NIL) (|PointsOfFiniteOrderRational| 4058316 4058697 4059367 "PFOQ" 4060661 NIL PFOQ (NIL T T T) |package| NIL NIL) (|PointsOfFiniteOrder| 4055500 4055821 4056481 "PFO" 4057961 NIL PFO (NIL T T T T T) |package| NIL NIL) (|PrimeField| 4050095 4055234 4055395 "PF" 4055400 NIL PF (NIL NIL) |domain| NIL NIL) (|PolynomialFactorizationExplicit| 4045131 4047242 4047334 "PFECAT" 4048675 T PFECAT (NIL) |category| NIL 4049578) (|PolynomialFactorizationExplicit&| 4043844 4044193 4044720 "PFECAT-" 4044725 NIL PFECAT- (NIL T) |domain| NIL NIL) (|PolynomialFactorizationByRecursionUnivariate| 4040268 4040845 4041652 "PFBRU" 4043225 NIL PFBRU (NIL T T) |package| NIL NIL) (|PolynomialFactorizationByRecursion| 4035277 4036046 4037082 "PFBR" 4039453 NIL PFBR (NIL T T T T) |package| NIL NIL) (|Permutation| 4029038 4030954 4032033 "PERM" 4034257 NIL PERM (NIL T) |domain| NIL NIL) (|PermutationGroup| 4021051 4022403 4023896 "PERMGRP" 4027614 NIL PERMGRP (NIL T) |domain| NIL NIL) (|PermutationCategory| 4018402 4019579 4019668 "PERMCAT" 4020431 NIL PERMCAT (NIL T) |category| |Permutation| 4020844) (|Permanent| 4017819 4017875 4018090 "PERMAN" 4018322 NIL PERMAN (NIL NIL T) |package| NIL NIL) (|PendantTree| 4014189 4017117 4017336 "PENDTREE" 4017659 NIL PENDTREE (NIL T) |domain| NIL NIL) (|PartialDifferentialRing| 4011108 4012149 4012246 "PDRING" 4013459 NIL PDRING (NIL T) |category| NIL 4013908) (|PartialDifferentialRing&| 4009738 4010038 4010632 "PDRING-" 4010637 NIL PDRING- (NIL T T) |domain| NIL NIL) (|NumericalPDEProblem| 4005531 4006577 4007622 "PDEPROB" 4008747 T PDEPROB (NIL) |domain| NIL NIL) (|AnnaPartialDifferentialEquationPackage| 4001252 4002063 4003057 "PDEPACK" 4004629 T PDEPACK (NIL) |package| NIL NIL) (|PolynomialDecomposition| 3999294 3999583 4000045 "PDECOMP" 4000910 NIL PDECOMP (NIL T T) |package| NIL NIL) (|PartialDifferentialEquationsSolverCategory| 3995676 3996823 3996937 "PDECAT" 3998164 T PDECAT (NIL) |category| NIL 3999212) (|PolynomialComposition| 3995238 3995275 3995451 "PCOMP" 3995615 NIL PCOMP (NIL T T) |package| NIL NIL) (|PoincareBirkhoffWittLyndonBasis| 3992208 3992965 3993516 "PBWLB" 3994779 NIL PBWLB (NIL T) |domain| NIL NIL) (|Pattern| 3980715 3982804 3984908 "PATTERN" 3990142 NIL PATTERN (NIL T) |domain| NIL NIL) (|PatternFunctions2| 3980114 3980188 3980378 "PATTERN2" 3980617 NIL PATTERN2 (NIL T T) |package| NIL NIL) (|PatternFunctions1| 3976491 3977040 3977772 "PATTERN1" 3979467 NIL PATTERN1 (NIL T T) |package| NIL NIL) (|PatternMatchResult| 3972394 3973107 3973853 "PATRES" 3975839 NIL PATRES (NIL T T) |domain| NIL NIL) (|PatternMatchResultFunctions2| 3971578 3971684 3971949 "PATRES2" 3972264 NIL PATRES2 (NIL T T T) |package| NIL NIL) (|PatternMatch| 3968276 3968797 3969396 "PATMATCH" 3971111 NIL PATMATCH (NIL T T T) |package| NIL NIL) (|PatternMatchable| 3967500 3967759 3967842 "PATMAB" 3968037 NIL PATMAB (NIL T) |category| NIL 3968194) (|PatternMatchListResult| 3964934 3965360 3965830 "PATLRES" 3967160 NIL PATLRES (NIL T T T) |domain| NIL NIL) (|Patternable| 3964206 3964391 3964457 "PATAB" 3964462 NIL PATAB (NIL T) |category| NIL 3964741) (|PartitionsAndPermutations| 3960055 3960833 3961790 "PARTPERM" 3963315 T PARTPERM (NIL) |package| NIL NIL) (|ParametricSurface| 3959415 3959505 3959688 "PARSURF" 3959936 NIL PARSURF (NIL T) |domain| NIL NIL) (|ParametricSurfaceFunctions2| 3958732 3958826 3959042 "PARSU2" 3959297 NIL PARSU2 (NIL T T) |package| NIL NIL) (|ParametricSpaceCurve| 3958088 3958176 3958363 "PARSCURV" 3958615 NIL PARSCURV (NIL T) |domain| NIL NIL) (|ParametricSpaceCurveFunctions2| 3957372 3957472 3957700 "PARSC2" 3957964 NIL PARSC2 (NIL T T) |package| NIL NIL) (|ParametricPlaneCurve| 3956746 3956829 3957011 "PARPCURV" 3957260 NIL PARPCURV (NIL T) |domain| NIL NIL) (|ParametricPlaneCurveFunctions2| 3956030 3956130 3956358 "PARPC2" 3956622 NIL PARPC2 (NIL T T) |package| NIL NIL) (|ParametrizationPackage| 3953233 3953366 3953929 "PARAMP" 3955810 NIL PARAMP (NIL T NIL T T T T T) |package| NIL NIL) (|PolynomialAN2Expression| 3952248 3952413 3952680 "PAN2EXPR" 3953028 T PAN2EXPR (NIL) |package| NIL NIL) (|Palette| 3950549 3950931 3951279 "PALETTE" 3951930 T PALETTE (NIL) |domain| NIL NIL) (|PackageForAlgebraicFunctionField| 3926395 3930320 3934547 "PAFF" 3946472 NIL PAFF (NIL T NIL T) |package| NIL NIL) (|PackageForAlgebraicFunctionFieldOverFiniteField| 3893630 3899505 3905401 "PAFFFF" 3920693 NIL PAFFFF (NIL T NIL T) |package| NIL NIL) (|PAdicRationalConstructor| 3884020 3892153 3892558 "PADICRC" 3893341 NIL PADICRC (NIL NIL T) |domain| NIL NIL) (|PAdicRational| 3872934 3882806 3883171 "PADICRAT" 3883714 NIL PADICRAT (NIL NIL) |domain| NIL NIL) (|PAdicInteger| 3870477 3872810 3872898 "PADIC" 3872903 NIL PADIC (NIL NIL) |domain| NIL NIL) (|PAdicIntegerCategory| 3865985 3868258 3868345 "PADICCT" 3869399 NIL PADICCT (NIL NIL) |category| NIL 3869910) (|PadeApproximantPackage| 3864038 3864416 3864933 "PADEPAC" 3865569 NIL PADEPAC (NIL T NIL NIL) |package| NIL NIL) (|PadeApproximants| 3862519 3862751 3863163 "PADE" 3863777 NIL PADE (NIL T T T) |package| NIL NIL) (|PseudoAlgebraicClosureOfRationalNumber| 3856697 3861540 3861885 "PACRAT" 3862266 T PACRAT (NIL) |domain| NIL NIL) (|PseudoAlgebraicClosureOfRationalNumberCategory| 3850281 3854972 3855094 "PACRATC" 3855099 T PACRATC (NIL) |category| NIL 3855298) (|PseudoAlgebraicClosureOfPerfectFieldCategory| 3843221 3846156 3846274 "PACPERC" 3848528 T PACPERC (NIL) |category| NIL 3849421) (|PseudoAlgebraicClosureOfFiniteField| 3837909 3842647 3842908 "PACOFF" 3843075 NIL PACOFF (NIL T) |domain| NIL NIL) (|PseudoAlgebraicClosureOfFiniteFieldCategory| 3832544 3836625 3836741 "PACFFC" 3836746 T PACFFC (NIL) |category| NIL 3836829) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| 3825440 3831601 3831964 "PACEXT" 3832337 NIL PACEXT (NIL NIL) |domain| NIL NIL) (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory| 3816844 3822885 3823023 "PACEXTC" 3823028 T PACEXTC (NIL) |category| NIL 3823212) (|OrdinaryWeightedPolynomials| 3813793 3814896 3815423 "OWP" 3816491 NIL OWP (NIL T NIL NIL NIL) |domain| NIL NIL) (|OrderedVariableList| 3812418 3813079 3813406 "OVAR" 3813545 NIL OVAR (NIL NIL) |domain| NIL NIL) (|OutputPackage| 3811262 3811423 3811688 "OUT" 3812195 T OUT (NIL) |package| NIL NIL) (|OutputForm| 3795512 3798061 3801252 "OUTFORM" 3808107 T OUTFORM (NIL) |domain| NIL NIL) (|OrdSetInts| 3794695 3795064 3795218 "OSI" 3795394 T OSI (NIL) |domain| NIL NIL) (|OrthogonalPolynomialFunctions| 3792231 3792618 3793183 "ORTHPOL" 3794229 NIL ORTHPOL (NIL T) |package| NIL NIL) (|UnivariateSkewPolynomial| 3788480 3791615 3791878 "OREUP" 3792116 NIL OREUP (NIL NIL T NIL NIL) |domain| NIL NIL) (|SparseUnivariateSkewPolynomial| 3784692 3787852 3788127 "ORESUP" 3788349 NIL ORESUP (NIL T NIL NIL) |domain| NIL NIL) (|UnivariateSkewPolynomialCategoryOps| 3780485 3781207 3782118 "OREPCTO" 3783928 NIL OREPCTO (NIL T T) |package| NIL NIL) (|UnivariateSkewPolynomialCategory| 3770411 3773457 3773565 "OREPCAT" 3778043 NIL OREPCAT (NIL T) |category| NIL 3779788) (|UnivariateSkewPolynomialCategory&| 3766204 3767265 3768907 "OREPCAT-" 3768912 NIL OREPCAT- (NIL T T) |domain| NIL NIL) (|OrderedSet| 3765081 3765389 3765439 "ORDSET" 3765894 T ORDSET (NIL) |category| NIL 3766122) (|OrderedSet&| 3764477 3764604 3764869 "ORDSET-" 3764874 NIL ORDSET- (NIL T) |domain| NIL NIL) (|OrderedRing| 3762426 3763442 3763494 "ORDRING" 3763824 T ORDRING (NIL) |category| NIL 3764037) (|OrderedRing&| 3761888 3762010 3762246 "ORDRING-" 3762251 NIL ORDRING- (NIL T) |domain| NIL NIL) (|OrderedMonoid| 3761064 3761651 3761707 "ORDMON" 3761712 T ORDMON (NIL) |category| NIL 3761748) (|OrderingFunctions| 3759651 3759847 3760185 "ORDFUNS" 3760834 NIL ORDFUNS (NIL NIL T) |package| NIL NIL) (|OrderedFinite| 3758956 3759434 3759490 "ORDFIN" 3759495 T ORDFIN (NIL) |category| NIL 3759531) (|OrderedCompletion| 3753488 3756411 3757123 "ORDCOMP" 3758315 NIL ORDCOMP (NIL T) |domain| NIL NIL) (|OrderedCompletionFunctions2| 3752068 3752299 3752679 "ORDCOMP2" 3753220 NIL ORDCOMP2 (NIL T T) |package| NIL NIL) (|NumericalOptimizationProblem| 3746348 3747703 3749107 "OPTPROB" 3750736 T OPTPROB (NIL) |domain| NIL NIL) (|AnnaNumericalOptimizationPackage| 3740593 3741646 3742935 "OPTPACK" 3745139 T OPTPACK (NIL) |package| NIL NIL) (|NumericalOptimizationCategory| 3736767 3737903 3737991 "OPTCAT" 3739426 T OPTCAT (NIL) |category| NIL 3740511) (|OperationsQuery| 3736340 3736403 3736537 "OPQUERY" 3736679 T OPQUERY (NIL) |package| NIL NIL) (|Operator| 3731952 3733570 3734397 "OP" 3735559 NIL OP (NIL T) |domain| NIL NIL) (|OnePointCompletion| 3726975 3729823 3730452 "ONECOMP" 3731396 NIL ONECOMP (NIL T) |domain| NIL NIL) (|OnePointCompletionFunctions2| 3725616 3725825 3726185 "ONECOMP2" 3726729 NIL ONECOMP2 (NIL T T) |package| NIL NIL) (|OpenMathServerPackage| 3724526 3724703 3724972 "OMSERVER" 3725405 T OMSERVER (NIL) |package| NIL NIL) (|OrderedMultisetAggregate| 3719996 3723570 3723668 "OMSAGG" 3723779 NIL OMSAGG (NIL T) |category| NIL 3723898) (|OpenMathPackage| 3717655 3718052 3718554 "OMPKG" 3719540 T OMPKG (NIL) |package| NIL NIL) (|OpenMath| 3716739 3716888 3716934 "OM" 3717419 T OM (NIL) |category| NIL NIL) (|OppositeMonogenicLinearOperator| 3714485 3715894 3716222 "OMLO" 3716541 NIL OMLO (NIL T T) |domain| NIL NIL) (|ExpressionToOpenMath| 3712624 3712849 3713256 "OMEXPR" 3714185 NIL OMEXPR (NIL T) |package| NIL NIL) (|OpenMathError| 3711497 3711811 3712065 "OMERR" 3712412 T OMERR (NIL) |domain| NIL NIL) (|OpenMathErrorKind| 3710091 3710428 3710737 "OMERRK" 3711238 T OMERRK (NIL) |domain| NIL NIL) (|OpenMathEncoding| 3709139 3709416 3709646 "OMENC" 3709909 T OMENC (NIL) |domain| NIL NIL) (|OpenMathDevice| 3699282 3700949 3702895 "OMDEV" 3707237 T OMDEV (NIL) |domain| NIL NIL) (|OpenMathConnection| 3697525 3697817 3698211 "OMCONN" 3698940 T OMCONN (NIL) |domain| NIL NIL) (|OrderedIntegralDomain| 3695525 3696783 3696855 "OINTDOM" 3696860 T OINTDOM (NIL) |category| NIL 3696905) (|OrderedFreeMonoid| 3688907 3690481 3691621 "OFMONOID" 3694455 NIL OFMONOID (NIL T) |domain| NIL NIL) (|OrderlyDifferentialVariable| 3688088 3688734 3688863 "ODVAR" 3688868 NIL ODVAR (NIL T) |domain| NIL NIL) (|OrdinaryDifferentialRing| 3684027 3687210 3687532 "ODR" 3687899 NIL ODR (NIL T T NIL) |domain| NIL NIL) (|OrderlyDifferentialPolynomial| 3670874 3683464 3683787 "ODPOL" 3683792 NIL ODPOL (NIL T) |domain| NIL NIL) (|OrderedDirectProduct| 3662134 3670617 3670832 "ODP" 3670837 NIL ODP (NIL NIL T NIL) |domain| NIL NIL) (|ODETools| 3659979 3660291 3660766 "ODETOOLS" 3661763 NIL ODETOOLS (NIL T T) |package| NIL NIL) (|SystemODESolver| 3655664 3656489 3657487 "ODESYS" 3659099 NIL ODESYS (NIL T T) |package| NIL NIL) (|RationalRicDE| 3645723 3647403 3649349 "ODERTRIC" 3653923 NIL ODERTRIC (NIL T T) |package| NIL NIL) (|ReduceLODE| 3644699 3644801 3645171 "ODERED" 3645597 NIL ODERED (NIL T T T T T) |package| NIL NIL) (|RationalLODE| 3638911 3639844 3641098 "ODERAT" 3643648 NIL ODERAT (NIL T T) |package| NIL NIL) (|PrimitiveRatRicDE| 3633216 3633870 3634901 "ODEPRRIC" 3638190 NIL ODEPRRIC (NIL T T T T) |package| NIL NIL) (|NumericalODEProblem| 3629978 3630781 3631584 "ODEPROB" 3632467 T ODEPROB (NIL) |domain| NIL NIL) (|PrimitiveRatDE| 3623428 3624061 3625163 "ODEPRIM" 3629180 NIL ODEPRIM (NIL T T T T) |package| NIL NIL) (|PureAlgebraicLODE| 3622050 3622206 3622701 "ODEPAL" 3623248 NIL ODEPAL (NIL T T T T) |package| NIL NIL) (|AnnaOrdinaryDifferentialEquationPackage| 3615751 3616920 3618326 "ODEPACK" 3620738 T ODEPACK (NIL) |package| NIL NIL) (|ODEIntegration| 3613804 3613931 3614400 "ODEINT" 3615590 NIL ODEINT (NIL T T) |package| NIL NIL) (|ODEIntensityFunctionsTable| 3605352 3607321 3609407 "ODEIFTBL" 3611786 T ODEIFTBL (NIL) |domain| NIL NIL) (|ElementaryFunctionODESolver| 3597361 3598399 3599900 "ODEEF" 3604185 NIL ODEEF (NIL T T) |package| NIL NIL) (|ConstantLODE| 3596080 3596190 3596685 "ODECONST" 3597227 NIL ODECONST (NIL T T T) |package| NIL NIL) (|OrdinaryDifferentialEquationsSolverCategory| 3593184 3594089 3594205 "ODECAT" 3595192 T ODECAT (NIL) |category| NIL 3595998) (|Octonion| 3588830 3592664 3592884 "OCT" 3593021 NIL OCT (NIL T) |domain| NIL NIL) (|OctonionCategoryFunctions2| 3588168 3588218 3588472 "OCTCT2" 3588756 NIL OCTCT2 (NIL T T T T) |package| NIL NIL) (|OctonionCategory| 3580286 3583549 3583636 "OC" 3585698 NIL OC (NIL T) |category| |Octonion| 3586970) (|OctonionCategory&| 3576202 3577177 3578685 "OC-" 3578884 NIL OC- (NIL T T) |domain| NIL NIL) (|OrderedCancellationAbelianMonoid| 3575254 3575783 3575877 "OCAMON" 3575882 T OCAMON (NIL) |category| NIL 3575947) (|OrderedAbelianSemiGroup| 3574497 3574976 3575052 "OASGP" 3575057 T OASGP (NIL) |category| NIL 3575100) (|OrderedAbelianMonoidSup| 3573409 3573959 3574035 "OAMONS" 3574106 T OAMONS (NIL) |category| NIL 3574199) (|OrderedAbelianMonoid| 3572611 3573090 3573160 "OAMON" 3573165 T OAMON (NIL) |category| NIL 3573221) (|OrderedAbelianGroup| 3571573 3572153 3572221 "OAGROUP" 3572226 T OAGROUP (NIL) |category| NIL 3572290) (|NumericTubePlot| 3571016 3571086 3571263 "NUMTUBE" 3571479 NIL NUMTUBE (NIL T) |package| NIL NIL) (|NumericalQuadrature| 3561633 3563769 3566023 "NUMQUAD" 3568816 T NUMQUAD (NIL) |package| NIL NIL) (|NumericalOrdinaryDifferentialEquations| 3555339 3556703 3558226 "NUMODE" 3560202 T NUMODE (NIL) |package| NIL NIL) (|NumericalIntegrationCategory| 3551138 3552407 3552493 "NUMINT" 3554040 T NUMINT (NIL) |category| NIL 3555257) (|NumberFormats| 3549155 3549504 3549944 "NUMFMT" 3550740 T NUMFMT (NIL) |package| NIL NIL) (|Numeric| 3525537 3530048 3534441 "NUMERIC" 3544825 NIL NUMERIC (NIL T) |package| NIL NIL) (|NormalizedTriangularSetCategory| 3517528 3524613 3524832 "NTSCAT" 3524837 NIL NTSCAT (NIL T T T T) |category| NIL 3524904) (|NumberTheoreticPolynomialFunctions| 3515992 3516256 3516637 "NTPOLFN" 3517256 NIL NTPOLFN (NIL T) |package| NIL NIL) (|NewSparseUnivariatePolynomial| 3495602 3510018 3511431 "NSUP" 3514667 NIL NSUP (NIL T) |domain| NIL NIL) (|NewSparseUnivariatePolynomialFunctions2| 3494787 3494905 3495169 "NSUP2" 3495460 NIL NSUP2 (NIL T T) |package| NIL NIL) (|NewSparseMultivariatePolynomial| 3479572 3494274 3494584 "NSMP" 3494589 NIL NSMP (NIL T T) |domain| NIL NIL) (|NeitherSparseOrDensePowerSeries| 3462786 3478824 3479140 "NSDPS" 3479349 NIL NSDPS (NIL T) |domain| NIL NIL) (|NumericRealEigenPackage| 3460066 3460535 3461174 "NREP" 3462249 NIL NREP (NIL T) |package| NIL NIL) (|NewtonPolygon| 3455656 3456366 3457316 "NPOLYGON" 3459302 NIL NPOLYGON (NIL T T T NIL) |package| NIL NIL) (|NPCoef| 3453322 3453688 3454275 "NPCOEF" 3455261 NIL NPCOEF (NIL T T T T T) |package| NIL NIL) (|NottinghamGroup| 3452228 3452877 3453055 "NOTTING" 3453219 NIL NOTTING (NIL T) |domain| NIL NIL) (|NormRetractPackage| 3450252 3450443 3450904 "NORMRETR" 3452003 NIL NORMRETR (NIL T T T T NIL) |package| NIL NIL) (|NormalizationPackage| 3446922 3447293 3447946 "NORMPK" 3449837 NIL NORMPK (NIL T T T T T) |package| NIL NIL) (|NormInMonogenicAlgebra| 3446317 3446346 3446600 "NORMMA" 3446869 NIL NORMMA (NIL T T T T) |package| NIL NIL) (|None| 3446094 3446254 3446295 "NONE" 3446300 T NONE (NIL) |domain| NIL NIL) (|NoneFunctions1| 3445763 3445797 3445914 "NONE1" 3446035 NIL NONE1 (NIL T) |package| NIL NIL) (|NonLinearFirstOrderODESolver| 3444677 3444760 3445203 "NODE1" 3445656 NIL NODE1 (NIL T T) |package| NIL NIL) (|NonNegativeInteger| 3442234 3443294 3443714 "NNI" 3444309 T NNI (NIL) |domain| NIL NIL) (|NonLinearSolvePackage| 3439595 3440065 3440683 "NLINSOL" 3441698 NIL NLINSOL (NIL T) |package| NIL NIL) (|NumericalIntegrationProblem| 3433494 3434946 3436445 "NIPROB" 3438166 T NIPROB (NIL) |domain| NIL NIL) (|NumberFieldIntegralBasis| 3431392 3431732 3432260 "NFINTBAS" 3433120 NIL NFINTBAS (NIL T T) |package| NIL NIL) (|NewtonInterpolation| 3430864 3430935 3431108 "NEWTON" 3431297 NIL NEWTON (NIL T) |package| NIL NIL) (|NonCommutativeOperatorDivision| 3428633 3428934 3429413 "NCODIV" 3430514 NIL NCODIV (NIL T T) |package| NIL NIL) (|NumericContinuedFraction| 3428097 3428168 3428356 "NCNTFRAC" 3428538 NIL NCNTFRAC (NIL T) |package| NIL NIL) (|NumericComplexEigenPackage| 3424903 3425486 3426245 "NCEP" 3427446 NIL NCEP (NIL T) |package| NIL NIL) (|NonAssociativeRing| 3423189 3424203 3424269 "NASRING" 3424482 T NASRING (NIL) |category| NIL 3424643) (|NonAssociativeRing&| 3422834 3422894 3423080 "NASRING-" 3423085 NIL NASRING- (NIL T) |domain| NIL NIL) (|NonAssociativeRng| 3421525 3422183 3422247 "NARNG" 3422464 T NARNG (NIL) |category| NIL 3422626) (|NonAssociativeRng&| 3421037 3421129 3421364 "NARNG-" 3421369 NIL NARNG- (NIL T) |domain| NIL NIL) (|NAGLinkSupportPackage| 3418937 3419277 3419746 "NAGSP" 3420626 T NAGSP (NIL) |package| NIL NIL) (|NagSpecialFunctionsPackage| 3403615 3406291 3409244 "NAGS" 3416052 T NAGS (NIL) |package| NIL NIL) (|NagLapack| 3401220 3401713 3402279 "NAGF07" 3403083 T NAGF07 (NIL) |package| NIL NIL) (|NagLinearEquationSolvingPackage| 3391894 3394027 3396312 "NAGF04" 3399013 T NAGF04 (NIL) |package| NIL NIL) (|NagEigenPackage| 3380250 3382878 3385662 "NAGF02" 3389156 T NAGF02 (NIL) |package| NIL NIL) (|NagMatrixOperationsPackage| 3372115 3373926 3375874 "NAGF01" 3378370 T NAGF01 (NIL) |package| NIL NIL) (|NagOptimisationPackage| 3361510 3364126 3366861 "NAGE04" 3369440 T NAGE04 (NIL) |package| NIL NIL) (|NagFittingPackage| 3346113 3349805 3353656 "NAGE02" 3357709 T NAGE02 (NIL) |package| NIL NIL) (|NagInterpolationPackage| 3338922 3340570 3342349 "NAGE01" 3344396 T NAGE01 (NIL) |package| NIL NIL) (|NagPartialDifferentialEquationsPackage| 3334970 3335909 3336974 "NAGD03" 3337949 T NAGD03 (NIL) |package| NIL NIL) (|NagOrdinaryDifferentialEquationsPackage| 3321832 3324827 3327991 "NAGD02" 3331900 T NAGD02 (NIL) |package| NIL NIL) (|NagIntegrationPackage| 3311698 3313995 3316429 "NAGD01" 3319456 T NAGD01 (NIL) |package| NIL NIL) (|NagSeriesSummationPackage| 3305165 3306499 3307978 "NAGC06" 3310285 T NAGC06 (NIL) |package| NIL NIL) (|NagRootFindingPackage| 3302683 3303192 3303793 "NAGC05" 3304622 T NAGC05 (NIL) |package| NIL NIL) (|NagPolynomialRootsPackage| 3301577 3301764 3302046 "NAGC02" 3302467 T NAGC02 (NIL) |package| NIL NIL) (|NonAssociativeAlgebra| 3300119 3300857 3300954 "NAALG" 3301115 NIL NAALG (NIL T) |category| NIL 3301237) (|NonAssociativeAlgebra&| 3299782 3299833 3300034 "NAALG-" 3300039 NIL NAALG- (NIL T T) |domain| NIL NIL) (|MyUnivariatePolynomial| 3285148 3298278 3298759 "MYUP" 3299391 NIL MYUP (NIL NIL T) |domain| NIL NIL) (|MyExpression| 3270914 3282441 3283126 "MYEXPR" 3284576 NIL MYEXPR (NIL NIL T) |domain| NIL NIL) (|MultivariateSquareFree| 3259514 3261429 3263618 "MULTSQFR" 3268906 NIL MULTSQFR (NIL T T T T) |package| NIL NIL) (|MultivariateFactorize| 3258105 3258241 3258628 "MULTFACT" 3259338 NIL MULTFACT (NIL T T T T) |package| NIL NIL) (|MultivariateTaylorSeriesCategory| 3247145 3252562 3252690 "MTSCAT" 3254802 NIL MTSCAT (NIL T T) |category| NIL 3255782) (|MergeThing| 3246687 3246759 3246911 "MTHING" 3247049 NIL MTHING (NIL T) |package| NIL NIL) (|MoreSystemCommands| 3246315 3246362 3246486 "MSYSCMD" 3246615 T MSYSCMD (NIL) |package| NIL NIL) (|Multiset| 3240563 3244255 3244792 "MSET" 3245831 NIL MSET (NIL T) |domain| NIL NIL) (|MultisetAggregate| 3236374 3239857 3239942 "MSETAGG" 3239947 NIL MSETAGG (NIL T) |category| |Multiset| 3240006) (|MonoidRing| 3230096 3232229 3233372 "MRING" 3235297 NIL MRING (NIL T T) |domain| NIL NIL) (|MonoidRingFunctions2| 3229406 3229496 3229710 "MRF2" 3229982 NIL MRF2 (NIL T T T) |package| NIL NIL) (|MRationalFactorize| 3228682 3228726 3229012 "MRATFAC" 3229338 NIL MRATFAC (NIL T T T T) |package| NIL NIL) (|MPolyCatRationalFunctionFactorizer| 3224220 3224648 3225428 "MPRFF" 3228200 NIL MPRFF (NIL T T T T) |package| NIL NIL) (|MultivariatePolynomial| 3214367 3223900 3224107 "MPOLY" 3224112 NIL MPOLY (NIL NIL T) |domain| NIL NIL) (|MPolyCatPolyFactorizer| 3213445 3213489 3213876 "MPCPF" 3214299 NIL MPCPF (NIL T T T T) |package| NIL NIL) (|MPolyCatFunctions3| 3212579 3212629 3212961 "MPC3" 3213371 NIL MPC3 (NIL T T T T T T T) |package| NIL NIL) (|MPolyCatFunctions2| 3211186 3211280 3211654 "MPC2" 3212457 NIL MPC2 (NIL T T T T T T T) |package| NIL NIL) (|MonomialExtensionTools| 3208495 3208951 3209564 "MONOTOOL" 3210691 NIL MONOTOOL (NIL T T) |package| NIL NIL) (|Monoid| 3207210 3207645 3207687 "MONOID" 3208111 T MONOID (NIL) |category| NIL 3208393) (|Monoid&| 3206266 3206499 3206875 "MONOID-" 3206880 NIL MONOID- (NIL T) |domain| NIL NIL) (|MonogenicAlgebra| 3192240 3200830 3200961 "MONOGEN" 3202337 NIL MONOGEN (NIL T T) |category| NIL 3203094) (|MonogenicAlgebra&| 3187820 3188837 3190491 "MONOGEN-" 3190740 NIL MONOGEN- (NIL T T T) |domain| NIL NIL) (|MonadWithUnit| 3186001 3186587 3186643 "MONADWU" 3187317 T MONADWU (NIL) |category| NIL 3187722) (|MonadWithUnit&| 3184888 3185153 3185608 "MONADWU-" 3185613 NIL MONADWU- (NIL T) |domain| NIL NIL) (|Monad| 3183921 3184221 3184261 "MONAD" 3184596 T MONAD (NIL) |category| NIL 3184806) (|Monad&| 3183381 3183511 3183735 "MONAD-" 3183740 NIL MONAD- (NIL T) |domain| NIL NIL) (|MoebiusTransform| 3180842 3181664 3182095 "MOEBIUS" 3183013 NIL MOEBIUS (NIL T) |domain| NIL NIL) (|Module| 3180001 3180461 3180528 "MODULE" 3180533 NIL MODULE (NIL T) |category| NIL 3180568) (|Module&| 3179358 3179488 3179780 "MODULE-" 3179785 NIL MODULE- (NIL T T) |domain| NIL NIL) (|ModularRing| 3175946 3176836 3177312 "MODRING" 3179107 NIL MODRING (NIL T T NIL NIL NIL) |domain| NIL NIL) (|ModuleOperator| 3171142 3172734 3173598 "MODOP" 3175165 NIL MODOP (NIL T T) |domain| NIL NIL) (|ModuleMonomial| 3168478 3169005 3169521 "MODMONOM" 3170844 NIL MODMONOM (NIL T T NIL) |domain| NIL NIL) (|ModMonic| 3151801 3165392 3166065 "MODMON" 3167894 NIL MODMON (NIL T T) |domain| NIL NIL) (|ModularField| 3147619 3150005 3150415 "MODFIELD" 3151618 NIL MODFIELD (NIL T T NIL NIL NIL) |domain| NIL NIL) (|MathMLFormat| 3146036 3146406 3146735 "MMLFORM" 3147330 T MMLFORM (NIL) |domain| NIL NIL) (|MultipleMap| 3145123 3145173 3145531 "MMAP" 3145962 NIL MMAP (NIL T T T T T T) |package| NIL NIL) (|MonogenicLinearOperator| 3142239 3143320 3143410 "MLO" 3144227 NIL MLO (NIL T) |category| NIL 3144661) (|MultivariateLifting| 3137378 3138294 3139419 "MLIFT" 3141289 NIL MLIFT (NIL T T T T) |package| NIL NIL) (|MakeUnaryCompiledFunction| 3136289 3136416 3136703 "MKUCFUNC" 3137222 NIL MKUCFUNC (NIL T T T) |package| NIL NIL) (|MakeRecord| 3135736 3135819 3135991 "MKRECORD" 3136181 NIL MKRECORD (NIL T T) |package| NIL NIL) (|MakeFunction| 3134254 3134458 3134818 "MKFUNC" 3135453 NIL MKFUNC (NIL T) |package| NIL NIL) (|MakeFloatCompiledFunction| 3133013 3133199 3133539 "MKFLCFN" 3134017 NIL MKFLCFN (NIL T) |package| NIL NIL) (|MakeCachableSet| 3132199 3132648 3132812 "MKCHSET" 3132916 NIL MKCHSET (NIL T) |domain| NIL NIL) (|MakeBinaryCompiledFunction| 3130956 3131105 3131430 "MKBCFUNC" 3132021 NIL MKBCFUNC (NIL T T T T) |package| NIL NIL) (|MachineInteger| 3126080 3130042 3130344 "MINT" 3130698 T MINT (NIL) |domain| NIL NIL) (|ModularHermitianRowReduction| 3124066 3124401 3124877 "MHROWRED" 3125701 NIL MHROWRED (NIL T) |package| NIL NIL) (|MachineFloat| 3116440 3121087 3121960 "MFLOAT" 3123233 T MFLOAT (NIL) |domain| NIL NIL) (|MultFiniteFactorize| 3115122 3115259 3115614 "MFINFACT" 3116264 NIL MFINFACT (NIL T T T T) |package| NIL NIL) (|MeshCreationRoutinesForThreeDimensions| 3107611 3109301 3111163 "MESH" 3113352 T MESH (NIL) |package| NIL NIL) (|ModularDistinctDegreeFactorizer| 3104903 3105318 3105910 "MDDFACT" 3107147 NIL MDDFACT (NIL T) |package| NIL NIL) (|MultiDictionary| 3100209 3103530 3103611 "MDAGG" 3104074 NIL MDAGG (NIL T) |category| NIL 3104336) (|MachineComplex| 3082041 3098937 3099332 "MCMPLX" 3099858 T MCMPLX (NIL) |domain| NIL NIL) (|MatrixCommonDenominator| 3080505 3080717 3081086 "MCDEN" 3081794 NIL MCDEN (NIL T T) |package| NIL NIL) (|MultiVariableCalculusFunctions| 3076391 3076776 3077482 "MCALCFN" 3080066 NIL MCALCFN (NIL T T T T) |package| NIL NIL) (|StorageEfficientMatrixOperations| 3072576 3073295 3074183 "MATSTOR" 3075597 NIL MATSTOR (NIL T) |package| NIL NIL) (|Matrix| 3066750 3071632 3072000 "MATRIX" 3072250 NIL MATRIX (NIL T) |domain| NIL NIL) (|MatrixLinearAlgebraFunctions| 3059166 3060157 3061316 "MATLIN" 3065799 NIL MATLIN (NIL T T T T) |package| NIL NIL) (|MatrixCategory| 3041382 3045954 3046100 "MATCAT" 3056274 NIL MATCAT (NIL T T T) |category| NIL 3058713) (|MatrixCategory&| 3035558 3037078 3039313 "MATCAT-" 3039318 NIL MATCAT- (NIL T T T T) |domain| NIL NIL) (|MatrixCategoryFunctions2| 3033155 3033342 3033885 "MATCAT2" 3035329 NIL MATCAT2 (NIL T T T T T T T T) |package| NIL NIL) (|MappingPackage4| 3031194 3031571 3032068 "MAPPKG4" 3032739 NIL MAPPKG4 (NIL T T) |package| NIL NIL) (|MappingPackage3| 3028106 3028555 3029162 "MAPPKG3" 3030696 NIL MAPPKG3 (NIL T T T) |package| NIL NIL) (|MappingPackage2| 3026453 3026685 3027044 "MAPPKG2" 3027835 NIL MAPPKG2 (NIL T T) |package| NIL NIL) (|MappingPackage1| 3023954 3024368 3024920 "MAPPKG1" 3025968 NIL MAPPKG1 (NIL T) |package| NIL NIL) (|MappingPackageInternalHacks3| 3023289 3023362 3023594 "MAPHACK3" 3023857 NIL MAPHACK3 (NIL T T T) |package| NIL NIL) (|MappingPackageInternalHacks2| 3022617 3022680 3022888 "MAPHACK2" 3023195 NIL MAPHACK2 (NIL T T) |package| NIL NIL) (|MappingPackageInternalHacks1| 3021551 3021719 3022010 "MAPHACK1" 3022419 NIL MAPHACK1 (NIL T) |package| NIL NIL) (|MatrixManipulation| 3009206 3010629 3012512 "MAMA" 3019846 NIL MAMA (NIL T T T T) |package| NIL NIL) (|Magma| 3006408 3007124 3007611 "MAGMA" 3008765 NIL MAGMA (NIL T) |domain| NIL NIL) (|ModularAlgebraicGcdOperations| 3003566 3004069 3004185 "MAGCDOC" 3005814 NIL MAGCDOC (NIL T T) |category| NIL NIL) (|ThreeDimensionalMatrix| 2997512 3000147 3001067 "M3D" 3002727 NIL M3D (NIL T) |domain| NIL NIL) (|LazyStreamAggregate| 2988776 2994762 2994844 "LZSTAGG" 2996232 NIL LZSTAGG (NIL T) |category| NIL 2996751) (|LazyStreamAggregate&| 2982776 2984375 2986625 "LZSTAGG-" 2986630 NIL LZSTAGG- (NIL T T) |domain| NIL NIL) (|LyndonWord| 2977995 2979058 2979923 "LWORD" 2981967 NIL LWORD (NIL T) |domain| NIL NIL) (|LieSquareMatrix| 2967809 2977554 2977820 "LSQM" 2977825 NIL LSQM (NIL NIL T) |domain| NIL NIL) (|LinearSystemPolynomialPackage| 2966562 2966743 2967142 "LSPP" 2967604 NIL LSPP (NIL T T T T) |package| NIL NIL) (|LinearSystemMatrixPackage| 2962762 2963150 2963906 "LSMP" 2966120 NIL LSMP (NIL T T T T) |package| NIL NIL) (|LinearSystemMatrixPackage1| 2958109 2958980 2960018 "LSMP1" 2961807 NIL LSMP1 (NIL T) |package| NIL NIL) (|ListAggregate| 2949468 2956810 2956880 "LSAGG" 2956975 NIL LSAGG (NIL T) |category| NIL 2957128) (|ListAggregate&| 2944803 2946011 2947780 "LSAGG-" 2947785 NIL LSAGG- (NIL T T) |domain| NIL NIL) (|LiePolynomial| 2941172 2943258 2943702 "LPOLY" 2944446 NIL LPOLY (NIL T T) |domain| NIL NIL) (|LinearPolynomialEquationByFractions| 2940097 2940297 2940648 "LPEFRAC" 2940948 NIL LPEFRAC (NIL T) |package| NIL NIL) (|LocalParametrizationOfSimplePointPackage| 2935503 2935841 2936621 "LPARSPT" 2939696 NIL LPARSPT (NIL T NIL T T T T T) |package| NIL NIL) (|LeftOreRing| 2933984 2934815 2934867 "LORER" 2935018 T LORER (NIL) |category| NIL 2935154) (|LinesOpPack| 2931582 2932047 2932614 "LOP" 2933470 NIL LOP (NIL T) |package| NIL NIL) (|Localize| 2929294 2930231 2930595 "LO" 2931336 NIL LO (NIL T T T) |domain| NIL NIL) (|Logic| 2928858 2928969 2929009 "LOGIC" 2929155 T LOGIC (NIL) |category| NIL 2929271) (|Logic&| 2928675 2928698 2928797 "LOGIC-" 2928802 NIL LOGIC- (NIL T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperatorsOps| 2927072 2927279 2927684 "LODOOPS" 2928434 NIL LODOOPS (NIL T T) |package| NIL NIL) (|LinearOrdinaryDifferentialOperator| 2923427 2926836 2927014 "LODO" 2927019 NIL LODO (NIL T NIL) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperatorFactorizer| 2920034 2920571 2921402 "LODOF" 2922863 NIL LODOF (NIL T T) |package| NIL NIL) (|LinearOrdinaryDifferentialOperatorCategory| 2914509 2917855 2917983 "LODOCAT" 2918905 NIL LODOCAT (NIL T) |category| NIL 2919261) (|LinearOrdinaryDifferentialOperatorCategory&| 2914025 2914095 2914386 "LODOCAT-" 2914391 NIL LODOCAT- (NIL T T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperator2| 2910215 2913652 2913936 "LODO2" 2913941 NIL LODO2 (NIL T T) |domain| NIL NIL) (|LinearOrdinaryDifferentialOperator1| 2906574 2909992 2910157 "LODO1" 2910162 NIL LODO1 (NIL T) |domain| NIL NIL) (|ElementaryFunctionLODESolver| 2904440 2904635 2905261 "LODEEF" 2906341 NIL LODEEF (NIL T T T) |package| NIL NIL) (|LocalPowerSeriesCategory| 2893210 2899088 2899181 "LOCPOWC" 2901860 NIL LOCPOWC (NIL T) |category| |NeitherSparseOrDensePowerSeries| 2902830) (|LinearAggregate| 2886197 2890245 2890319 "LNAGG" 2891887 NIL LNAGG (NIL T) |category| NIL 2892584) (|LinearAggregate&| 2884992 2885258 2885771 "LNAGG-" 2885776 NIL LNAGG- (NIL T T) |domain| NIL NIL) (|ListMonoidOps| 2878749 2879784 2880825 "LMOPS" 2884047 NIL LMOPS (NIL T T NIL) |domain| NIL NIL) (|LeftModule| 2877888 2878332 2878395 "LMODULE" 2878484 NIL LMODULE (NIL T) |category| NIL 2878557) (|ListMultiDictionary| 2873798 2877221 2877464 "LMDICT" 2877720 NIL LMDICT (NIL T) |domain| NIL NIL) (|LinearSystemFromPowerSeriesPackage| 2872135 2872357 2872751 "LISYSER" 2873542 NIL LISYSER (NIL T T) |package| NIL NIL) (|List| 2862619 2870572 2871004 "LIST" 2871741 NIL LIST (NIL T) |domain| NIL NIL) (|ListFunctions3| 2861944 2862031 2862228 "LIST3" 2862508 NIL LIST3 (NIL T T T) |package| NIL NIL) (|ListFunctions2| 2860535 2860748 2861067 "LIST2" 2861697 NIL LIST2 (NIL T T) |package| NIL NIL) (|ListToMap| 2857891 2858264 2858805 "LIST2MAP" 2860063 NIL LIST2MAP (NIL T T) |package| NIL NIL) (|LinearlyExplicitRingOver| 2855966 2856865 2856957 "LINEXP" 2857386 NIL LINEXP (NIL T) |category| NIL 2857610) (|LinearDependence| 2853732 2854081 2854570 "LINDEP" 2855588 NIL LINDEP (NIL T T) |package| NIL NIL) (|RationalFunctionLimitPackage| 2847957 2849189 2850593 "LIMITRF" 2852419 NIL LIMITRF (NIL T) |package| NIL NIL) (|PowerSeriesLimitPackage| 2844756 2845221 2846005 "LIMITPS" 2847450 NIL LIMITPS (NIL T T) |package| NIL NIL) (|AssociatedLieAlgebra| 2835274 2843776 2844243 "LIE" 2844406 NIL LIE (NIL T T) |domain| NIL NIL) (|LieAlgebra| 2833937 2834467 2834542 "LIECAT" 2834779 NIL LIECAT (NIL T) |category| NIL 2834978) (|LieAlgebra&| 2833717 2833740 2833880 "LIECAT-" 2833885 NIL LIECAT- (NIL T T) |domain| NIL NIL) (|Library| 2823317 2832773 2833056 "LIB" 2833464 T LIB (NIL) |domain| NIL NIL) (|LinGroebnerPackage| 2813650 2815674 2817877 "LGROBP" 2821210 NIL LGROBP (NIL NIL T) |package| NIL NIL) (|LiouvillianFunction| 2809061 2809459 2810143 "LF" 2813160 NIL LF (NIL T T) |package| NIL NIL) (|LiouvillianFunctionCategory| 2807062 2807842 2807926 "LFCAT" 2808489 T LFCAT (NIL) |category| NIL 2808784) (|LexTriangularPackage| 2800213 2801634 2803226 "LEXTRIPK" 2805570 NIL LEXTRIPK (NIL T NIL) |package| NIL NIL) (|LieExponentials| 2794778 2795939 2796781 "LEXP" 2799532 NIL LEXP (NIL T T NIL) |domain| NIL NIL) (|LeadingCoefDetermination| 2792217 2792654 2793305 "LEADCDET" 2794312 NIL LEADCDET (NIL T T T T) |package| NIL NIL) (|LazardSetSolvingPackage| 2790639 2790742 2791186 "LAZM3PK" 2792085 NIL LAZM3PK (NIL T T T T T T) |package| NIL NIL) (|LaurentPolynomial| 2782413 2786999 2787968 "LAUPOL" 2789787 NIL LAUPOL (NIL T T) |domain| NIL NIL) (|LaplaceTransform| 2781495 2781549 2781939 "LAPLACE" 2782335 NIL LAPLACE (NIL T T) |package| NIL NIL) (|LocalAlgebra| 2778667 2780145 2780503 "LA" 2781264 NIL LA (NIL T T T) |domain| NIL NIL) (|LeftAlgebra| 2777333 2778108 2778174 "LALG" 2778269 NIL LALG (NIL T) |category| NIL 2778360) (|LeftAlgebra&| 2776899 2776974 2777191 "LALG-" 2777196 NIL LALG- (NIL T T) |domain| NIL NIL) (|Kovacic| 2774868 2775176 2775737 "KOVACIC" 2776550 NIL KOVACIC (NIL T T) |package| NIL NIL) (|ConvertibleTo| 2774610 2774638 2774708 "KONVERT" 2774806 NIL KONVERT (NIL T) |category| NIL NIL) (|CoercibleTo| 2774361 2774388 2774454 "KOERCE" 2774549 NIL KOERCE (NIL T) |category| NIL NIL) (|Kernel| 2770792 2771842 2772503 "KERNEL" 2773748 NIL KERNEL (NIL T) |domain| NIL NIL) (|KernelFunctions2| 2769939 2770054 2770286 "KERNEL2" 2770648 NIL KERNEL2 (NIL T T) |package| NIL NIL) (|KeyedDictionary| 2761356 2767557 2767659 "KDAGG" 2768304 NIL KDAGG (NIL T T) |category| NIL 2768590) (|KeyedDictionary&| 2760692 2760842 2761159 "KDAGG-" 2761164 NIL KDAGG- (NIL T T T) |domain| NIL NIL) (|KeyedAccessFile| 2751304 2760114 2760385 "KAFILE" 2760488 NIL KAFILE (NIL T) |domain| NIL NIL) (|AssociatedJordanAlgebra| 2741813 2750315 2750788 "JORDAN" 2750954 NIL JORDAN (NIL T T) |domain| NIL NIL) (|IndexedAggregate| 2736336 2738974 2739071 "IXAGG" 2740693 NIL IXAGG (NIL T T) |category| NIL 2741348) (|IndexedAggregate&| 2734910 2735262 2735857 "IXAGG-" 2735862 NIL IXAGG- (NIL T T T) |domain| NIL NIL) (|IndexedVector| 2728793 2734782 2734880 "IVECTOR" 2734885 NIL IVECTOR (NIL T NIL) |domain| NIL NIL) (|InfiniteTuple| 2726831 2727162 2727601 "ITUPLE" 2728410 NIL ITUPLE (NIL T) |domain| NIL NIL) (|InnerTrigonometricManipulations| 2723786 2724002 2724583 "ITRIGMNP" 2726572 NIL ITRIGMNP (NIL T T T) |package| NIL NIL) (|InfiniteTupleFunctions3| 2721792 2722084 2722530 "ITFUN3" 2723444 NIL ITFUN3 (NIL T T T) |package| NIL NIL) (|InfiniteTupleFunctions2| 2721153 2721239 2721439 "ITFUN2" 2721682 NIL ITFUN2 (NIL T T) |package| NIL NIL) (|InnerTaylorSeries| 2717787 2719248 2719753 "ITAYLOR" 2720712 NIL ITAYLOR (NIL T) |domain| NIL NIL) (|InnerSparseUnivariatePowerSeries| 2700207 2707463 2709322 "ISUPS" 2716022 NIL ISUPS (NIL T) |domain| NIL NIL) (|InnerPolySum| 2698828 2698994 2699357 "ISUMP" 2700004 NIL ISUMP (NIL T T T T) |package| NIL NIL) (|IndexedString| 2691438 2698488 2698632 "ISTRING" 2698743 NIL ISTRING (NIL NIL) |domain| NIL NIL) (|InternalRationalUnivariateRepresentationPackage| 2689836 2689936 2690405 "IRURPK" 2691309 NIL IRURPK (NIL T T T T T) |package| NIL NIL) (|IrrRepSymNatPackage| 2687714 2688075 2688589 "IRSN" 2689376 T IRSN (NIL) |package| NIL NIL) (|IntegrationResultRFToFunction| 2683915 2684535 2685375 "IRRF2F" 2687062 NIL IRRF2F (NIL T) |package| NIL NIL) (|IrredPolyOverFiniteField| 2683292 2683380 2683585 "IRREDFFX" 2683803 NIL IRREDFFX (NIL T) |package| NIL NIL) (|IntegerRoots| 2680752 2681167 2681724 "IROOT" 2682804 NIL IROOT (NIL T) |package| NIL NIL) (|IntegrationResult| 2675660 2677069 2678135 "IR" 2679751 NIL IR (NIL T) |domain| NIL NIL) (|IntegrationResultFunctions2| 2672292 2672923 2673717 "IR2" 2674966 NIL IR2 (NIL T T) |package| NIL NIL) (|IntegrationResultToFunction| 2670286 2670476 2670975 "IR2F" 2672068 NIL IR2F (NIL T T) |package| NIL NIL) (|InternalPrintPackage| 2669935 2669976 2670097 "IPRNTPK" 2670221 T IPRNTPK (NIL) |package| NIL NIL) (|InnerPrimeField| 2664551 2669659 2669830 "IPF" 2669835 NIL IPF (NIL NIL) |domain| NIL NIL) (|InnerPAdicInteger| 2662092 2664400 2664515 "IPADIC" 2664520 NIL IPADIC (NIL NIL NIL) |domain| NIL NIL) (|InverseLaplaceTransform| 2661002 2661082 2661540 "INVLAPLA" 2661988 NIL INVLAPLA (NIL T T) |package| NIL NIL) (|TranscendentalIntegration| 2645467 2648735 2652200 "INTTR" 2657661 NIL INTTR (NIL T T) |package| NIL NIL) (|IntegrationTools| 2639695 2640771 2642038 "INTTOOLS" 2644296 NIL INTTOOLS (NIL T T) |package| NIL NIL) (|IntegerSolveLinearPolynomialEquation| 2638678 2638888 2639210 "INTSLPE" 2639461 T INTSLPE (NIL) |package| NIL NIL) (|Interval| 2635993 2638514 2638646 "INTRVL" 2638651 NIL INTRVL (NIL T) |domain| NIL NIL) (|RationalFunctionIntegration| 2631844 2632660 2633671 "INTRF" 2635138 NIL INTRF (NIL T) |package| NIL NIL) (|IntegerRetractions| 2630840 2630975 2631232 "INTRET" 2631674 NIL INTRET (NIL T) |package| NIL NIL) (|RationalIntegration| 2627574 2628125 2628889 "INTRAT" 2630250 NIL INTRAT (NIL T T) |package| NIL NIL) (|PatternMatchIntegration| 2622742 2623625 2624652 "INTPM" 2626824 NIL INTPM (NIL T T) |package| NIL NIL) (|PureAlgebraicIntegration| 2617276 2618071 2619245 "INTPAF" 2621891 NIL INTPAF (NIL T T T) |package| NIL NIL) (|AnnaNumericalIntegrationPackage| 2608806 2610364 2612223 "INTPACK" 2615495 T INTPACK (NIL) |package| NIL NIL) (|Integer| 2604318 2608271 2608527 "INT" 2608580 T INT (NIL) |domain| NIL NIL) (|TranscendentalHermiteIntegration| 2603120 2603326 2603694 "INTHERTR" 2604088 NIL INTHERTR (NIL T T) |package| NIL NIL) (|AlgebraicHermiteIntegration| 2602108 2602218 2602582 "INTHERAL" 2602986 NIL INTHERAL (NIL T T T T) |package| NIL NIL) (|IntegerNumberTheoryFunctions| 2598091 2598816 2599697 "INTHEORY" 2601299 T INTHEORY (NIL) |package| NIL NIL) (|GenusZeroIntegration| 2582608 2585107 2588030 "INTG0" 2595483 NIL INTG0 (NIL T T T) |package| NIL NIL) (|IntegrationFunctionsTable| 2559898 2565389 2571005 "INTFTBL" 2577058 T INTFTBL (NIL) |domain| NIL NIL) (|InterpolateFormsPackage| 2556187 2556512 2557251 "INTFRSP" 2559534 NIL INTFRSP (NIL T NIL T T T T T T) |package| NIL NIL) (|IntegerFactorizationPackage| 2554814 2555008 2555340 "INTFACT" 2555954 NIL INTFACT (NIL T) |package| NIL NIL) (|InterfaceGroebnerPackage| 2554101 2554152 2554427 "INTERGB" 2554739 NIL INTERGB (NIL T NIL T T T) |package| NIL NIL) (|ElementaryIntegration| 2549653 2550239 2551163 "INTEF" 2553473 NIL INTEF (NIL T T) |package| NIL NIL) (|IntegralDomain| 2547372 2548359 2548417 "INTDOM" 2548904 T INTDOM (NIL) |category| NIL 2549239) (|IntegralDomain&| 2546450 2546681 2547059 "INTDOM-" 2547064 NIL INTDOM- (NIL T) |domain| NIL NIL) (|IntersectionDivisorPackage| 2543853 2544005 2544715 "INTDIVP" 2546269 NIL INTDIVP (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|IntervalCategory| 2538184 2540662 2540797 "INTCAT" 2542505 NIL INTCAT (NIL T) |category| |Interval| 2543051) (|IntegerBits| 2537296 2537453 2537684 "INTBIT" 2537991 T INTBIT (NIL) |package| NIL NIL) (|AlgebraicIntegrate| 2534674 2534914 2535526 "INTALG" 2537025 NIL INTALG (NIL T T T T T) |package| NIL NIL) (|AlgebraicIntegration| 2533557 2533726 2534089 "INTAF" 2534481 NIL INTAF (NIL T T) |package| NIL NIL) (|InnerTable| 2524784 2533200 2533462 "INTABL" 2533467 NIL INTABL (NIL T T T) |domain| NIL NIL) (|IntegerNumberSystem| 2516692 2520447 2520515 "INS" 2522278 T INS (NIL) |category| NIL 2523538) (|IntegerNumberSystem&| 2512247 2513384 2515000 "INS-" 2515161 NIL INS- (NIL T) |domain| NIL NIL) (|InnerPolySign| 2510262 2510587 2511075 "INPSIGN" 2511858 NIL INPSIGN (NIL T T) |package| NIL NIL) (|InfiniteProductPrimeField| 2508507 2508696 2509100 "INPRODPF" 2510034 NIL INPRODPF (NIL T T) |package| NIL NIL) (|InfiniteProductFiniteField| 2506247 2506436 2506921 "INPRODFF" 2508279 NIL INPRODFF (NIL T T T T) |package| NIL NIL) (|InnerMultFact| 2504063 2504394 2504959 "INNMFACT" 2505877 NIL INNMFACT (NIL T T T T) |package| NIL NIL) (|InnerModularGcd| 2502629 2502759 2503097 "INMODGCD" 2503899 NIL INMODGCD (NIL T T NIL NIL) |package| NIL NIL) (|InnerNumericFloatSolvePackage| 2500113 2500462 2501014 "INFSP" 2502225 NIL INFSP (NIL T T T) |package| NIL NIL) (|InfiniteProductCharacteristicZero| 2498346 2498535 2498946 "INFPROD0" 2499885 NIL INFPROD0 (NIL T T) |package| NIL NIL) (|InputForm| 2493864 2495344 2496158 "INFORM" 2497553 T INFORM (NIL) |domain| NIL NIL) (|InputFormFunctions1| 2493171 2493262 2493450 "INFORM1" 2493744 NIL INFORM1 (NIL T) |package| NIL NIL) (|Infinity| 2492216 2492390 2492631 "INFINITY" 2492962 T INFINITY (NIL) |package| NIL NIL) (|InfinitlyClosePoint| 2488112 2489636 2490271 "INFCLSPT" 2491978 NIL INFCLSPT (NIL T NIL T T T T T T T) |domain| NIL NIL) (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| 2482981 2485785 2486656 "INFCLSPS" 2487457 NIL INFCLSPS (NIL T NIL T) |domain| NIL NIL) (|InfinitlyClosePointCategory| 2468093 2469509 2469945 "INFCLCT" 2481448 NIL INFCLCT (NIL T NIL T T T T T T T) |category| NIL 2482867) (|InnerNumericEigenPackage| 2465667 2466070 2466641 "INEP" 2467656 NIL INEP (NIL T T T) |package| NIL NIL) (|IndexedExponents| 2464581 2465396 2465563 "INDE" 2465568 NIL INDE (NIL T) |domain| NIL NIL) (|IncrementingMaps| 2463811 2463907 2464126 "INCRMAPS" 2464456 NIL INCRMAPS (NIL T) |package| NIL NIL) (|InnerNormalBasisFieldFunctions| 2455516 2456882 2458472 "INBFF" 2462326 NIL INBFF (NIL T) |package| NIL NIL) (|IndexedMatrix| 2450326 2455259 2455430 "IMATRIX" 2455435 NIL IMATRIX (NIL T NIL NIL) |domain| NIL NIL) (|InnerMatrixQuotientFieldFunctions| 2447858 2448025 2448606 "IMATQF" 2450109 NIL IMATQF (NIL T T T T T T T T) |package| NIL NIL) (|InnerMatrixLinearAlgebraFunctions| 2444498 2444829 2445438 "IMATLIN" 2447457 NIL IMATLIN (NIL T T T T) |package| NIL NIL) (|IndexedList| 2436975 2444376 2444469 "ILIST" 2444474 NIL ILIST (NIL T NIL) |domain| NIL NIL) (|InnerIndexedTwoDimensionalArray| 2434032 2436676 2436922 "IIARRAY2" 2436927 NIL IIARRAY2 (NIL T NIL NIL T T) |domain| NIL NIL) (|InnerFiniteField| 2426498 2433809 2433967 "IFF" 2433972 NIL IFF (NIL NIL NIL) |domain| NIL NIL) (|IndexedFlexibleArray| 2419181 2425143 2425534 "IFARRAY" 2426194 NIL IFARRAY (NIL T NIL) |domain| NIL NIL) (|InnerFreeAbelianMonoid| 2418066 2418968 2419135 "IFAMON" 2419140 NIL IFAMON (NIL T T NIL) |domain| NIL NIL) (|InnerEvalable| 2417454 2417524 2417615 "IEVALAB" 2417944 NIL IEVALAB (NIL T T) |category| NIL NIL) (|InnerEvalable&| 2417022 2417095 2417328 "IEVALAB-" 2417333 NIL IEVALAB- (NIL T T T) |domain| NIL NIL) (|IndexedDirectProductObject| 2416491 2416820 2416973 "IDPO" 2416978 NIL IDPO (NIL T T) |domain| NIL NIL) (|IndexedDirectProductOrderedAbelianMonoidSup| 2415427 2416169 2416405 "IDPOAMS" 2416410 NIL IDPOAMS (NIL T T) |domain| NIL NIL) (|IndexedDirectProductOrderedAbelianMonoid| 2414450 2415120 2415344 "IDPOAM" 2415349 NIL IDPOAM (NIL T T) |domain| NIL NIL) (|IndexedDirectProductCategory| 2412850 2413173 2413300 "IDPC" 2414124 NIL IDPC (NIL T T) |category| NIL 2414368) (|IndexedDirectProductAbelianMonoid| 2412073 2412578 2412774 "IDPAM" 2412779 NIL IDPAM (NIL T T) |domain| NIL NIL) (|IndexedDirectProductAbelianGroup| 2411192 2411806 2411998 "IDPAG" 2412003 NIL IDPAG (NIL T T) |domain| NIL NIL) (|IdealDecompositionPackage| 2402730 2404657 2406746 "IDECOMP" 2409222 NIL IDECOMP (NIL NIL NIL) |package| NIL NIL) (|PolynomialIdeals| 2390640 2391985 2393594 "IDEAL" 2401280 NIL IDEAL (NIL T T T T) |domain| NIL NIL) (|InfClsPt| 2387200 2389093 2389613 "ICP" 2390222 NIL ICP (NIL T NIL T) |domain| NIL NIL) (|InnerCommonDenominator| 2385592 2385750 2386134 "ICDEN" 2387008 NIL ICDEN (NIL T T T T) |package| NIL NIL) (|IndexCard| 2384348 2384788 2385021 "ICARD" 2385393 T ICARD (NIL) |domain| NIL NIL) (|IntegralBasisPolynomialTools| 2380498 2381057 2381864 "IBPTOOLS" 2383727 NIL IBPTOOLS (NIL T T T T) |package| NIL NIL) (|IndexedBits| 2374033 2379933 2380110 "IBITS" 2380376 NIL IBITS (NIL NIL) |domain| NIL NIL) (|IntegralBasisTools| 2368520 2369323 2370425 "IBATOOL" 2373157 NIL IBATOOL (NIL T T T) |package| NIL NIL) (|ChineseRemainderToolsForIntegralBases| 2364755 2365442 2366368 "IBACHIN" 2367799 NIL IBACHIN (NIL T T T) |package| NIL NIL) (|IndexedTwoDimensionalArray| 2361592 2364394 2364630 "IARRAY2" 2364635 NIL IARRAY2 (NIL T NIL NIL) |domain| NIL NIL) (|IndexedOneDimensionalArray| 2356127 2361410 2361548 "IARRAY1" 2361553 NIL IARRAY1 (NIL T NIL) |domain| NIL NIL) (|InnerAlgebraicNumber| 2346392 2352840 2353854 "IAN" 2355169 T IAN (NIL) |domain| NIL NIL) (|InnerAlgFactor| 2345501 2345580 2345906 "IALGFACT" 2346289 NIL IALGFACT (NIL T T T T) |package| NIL NIL) (|HyperbolicFunctionCategory| 2344703 2344822 2344904 "HYPCAT" 2345321 T HYPCAT (NIL) |category| NIL NIL) (|HyperbolicFunctionCategory&| 2344055 2344178 2344491 "HYPCAT-" 2344496 NIL HYPCAT- (NIL T) |domain| NIL NIL) (|HTMLFormat| 2342486 2342856 2343181 "HTMLFORM" 2343766 T HTMLFORM (NIL) |domain| NIL NIL) (|HomogeneousAggregate| 2337521 2339399 2339483 "HOAGG" 2341220 NIL HOAGG (NIL T) |category| NIL 2342122) (|HomogeneousAggregate&| 2335438 2335981 2336802 "HOAGG-" 2336807 NIL HOAGG- (NIL T T) |domain| NIL NIL) (|HexadecimalExpansion| 2325597 2334403 2334727 "HEXADEC" 2335170 T HEXADEC (NIL) |domain| NIL NIL) (|HeuGcd| 2323600 2323883 2324293 "HEUGCD" 2325265 NIL HEUGCD (NIL T) |package| NIL NIL) (|HyperellipticFiniteDivisor| 2322352 2323273 2323548 "HELLFDIV" 2323553 NIL HELLFDIV (NIL T T T T) |domain| NIL NIL) (|Heap| 2312678 2314797 2316459 "HEAP" 2320734 NIL HEAP (NIL T) |domain| NIL NIL) (|HomogeneousDirectProduct| 2303992 2312474 2312636 "HDP" 2312641 NIL HDP (NIL NIL T) |domain| NIL NIL) (|HomogeneousDistributedMultivariatePolynomial| 2293578 2303247 2303589 "HDMP" 2303793 NIL HDMP (NIL NIL T) |domain| NIL NIL) (|HallBasis| 2292393 2292630 2292936 "HB" 2293306 T HB (NIL) |package| NIL NIL) (|HashTable| 2283707 2292116 2292298 "HASHTBL" 2292303 NIL HASHTBL (NIL T T NIL) |domain| NIL NIL) (|Pi| 2280318 2282970 2283328 "HACKPI" 2283369 T HACKPI (NIL) |domain| NIL NIL) (|GuessUnivariatePolynomial| 2248122 2254904 2262183 "GUESSUP" 2273121 NIL GUESSUP (NIL NIL) |package| NIL NIL) (|GuessPolynomial| 2193404 2206523 2219289 "GUESSP" 2235402 T GUESSP (NIL) |package| NIL NIL) (|Guess| 2134108 2143184 2152765 "GUESS" 2184385 NIL GUESS (NIL T T T T NIL NIL) |package| NIL NIL) (|GuessInteger| 2084655 2096394 2107954 "GUESSINT" 2122588 T GUESSINT (NIL) |package| NIL NIL) (|GuessFinite| 2039117 2048931 2059178 "GUESSF" 2074514 NIL GUESSF (NIL T) |package| NIL NIL) (|GuessFiniteFunctions| 2038591 2038643 2038843 "GUESSF1" 2039041 NIL GUESSF1 (NIL T) |package| NIL NIL) (|GuessAlgebraicNumber| 1990490 2001564 2012961 "GUESSAN" 2027250 T GUESSAN (NIL) |package| NIL NIL) (|GeneralTriangularSet| 1984334 1990206 1990438 "GTSET" 1990443 NIL GTSET (NIL T T T T) |domain| NIL NIL) (|GeneralSparseTable| 1975719 1984131 1984299 "GSTBL" 1984304 NIL GSTBL (NIL T T T NIL) |domain| NIL NIL) (|GeneralUnivariatePowerSeries| 1964524 1974068 1974528 "GSERIES" 1975371 NIL GSERIES (NIL T NIL NIL) |domain| NIL NIL) (|Group| 1963181 1963753 1963793 "GROUP" 1964163 T GROUP (NIL) |category| NIL 1964405) (|Group&| 1961920 1962223 1962721 "GROUP-" 1962726 NIL GROUP- (NIL T) |domain| NIL NIL) (|GroebnerSolve| 1958704 1959343 1960121 "GROEBSOL" 1961247 NIL GROEBSOL (NIL NIL T T) |package| NIL NIL) (|GradedModule| 1957027 1957315 1957417 "GRMOD" 1958393 NIL GRMOD (NIL T T) |category| NIL 1958622) (|GradedModule&| 1956712 1956744 1956944 "GRMOD-" 1956949 NIL GRMOD- (NIL T T T) |domain| NIL NIL) (|GraphImage| 1949205 1950702 1952366 "GRIMAGE" 1955084 T GRIMAGE (NIL) |domain| NIL NIL) (|GraphicsDefaults| 1946422 1946824 1947454 "GRDEF" 1948623 T GRDEF (NIL) |package| NIL NIL) (|GrayCode| 1945429 1945627 1945886 "GRAY" 1946195 T GRAY (NIL) |package| NIL NIL) (|GradedAlgebra| 1944316 1944744 1944848 "GRALG" 1945137 NIL GRALG (NIL T T) |category| NIL 1945285) (|GradedAlgebra&| 1943844 1943918 1944177 "GRALG-" 1944182 NIL GRALG- (NIL T T T) |domain| NIL NIL) (|GeneralPolynomialSet| 1939087 1943037 1943389 "GPOLSET" 1943667 NIL GPOLSET (NIL T T T T) |domain| NIL NIL) (|GeneralPackageForAlgebraicFunctionField| 1904370 1906572 1909373 "GPAFF" 1936841 NIL GPAFF (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|GosperSummationMethod| 1903242 1903321 1903777 "GOSPER" 1904267 NIL GOSPER (NIL T T T T T) |package| NIL NIL) (|GuessOption| 1897179 1898426 1899700 "GOPT" 1902006 T GOPT (NIL) |domain| NIL NIL) (|GuessOptionFunctions0| 1889112 1890743 1892415 "GOPT0" 1895565 T GOPT0 (NIL) |domain| NIL NIL) (|GeneralModulePolynomial| 1881959 1882817 1883694 "GMODPOL" 1888632 NIL GMODPOL (NIL NIL T T T NIL T) |domain| NIL NIL) (|GeneralHenselPackage| 1880284 1880532 1880938 "GHENSEL" 1881677 NIL GHENSEL (NIL T T) |package| NIL NIL) (|GenerateUnivariatePowerSeries| 1868788 1870144 1871995 "GENUPS" 1878727 NIL GENUPS (NIL T T) |package| NIL NIL) (|GenUFactorize| 1868136 1868242 1868439 "GENUFACT" 1868658 NIL GENUFACT (NIL T) |package| NIL NIL) (|GeneralPolynomialGcdPackage| 1866788 1866948 1867344 "GENPGCD" 1867947 NIL GENPGCD (NIL T T T T) |package| NIL NIL) (|GeneralizedMultivariateFactorize| 1865804 1865848 1866263 "GENMFACT" 1866720 NIL GENMFACT (NIL T T T T T) |package| NIL NIL) (|GenExEuclid| 1863419 1863768 1864267 "GENEEZ" 1865411 NIL GENEEZ (NIL T T) |package| NIL NIL) (|GnuDraw| 1861005 1861450 1862000 "GDRAW" 1862899 T GDRAW (NIL) |package| NIL NIL) (|GeneralDistributedMultivariatePolynomial| 1851013 1860244 1860585 "GDMP" 1860864 NIL GDMP (NIL NIL T T) |domain| NIL NIL) (|GenericNonAssociativeAlgebra| 1832267 1839350 1841428 "GCNAALG" 1849114 NIL GCNAALG (NIL T NIL NIL NIL) |domain| NIL NIL) (|GcdDomain| 1829766 1831045 1831093 "GCDDOM" 1831494 T GCDDOM (NIL) |category| NIL 1831806) (|GcdDomain&| 1828584 1828880 1829348 "GCDDOM-" 1829353 NIL GCDDOM- (NIL T) |domain| NIL NIL) (|GroebnerPackage| 1826425 1826648 1827113 "GB" 1828280 NIL GB (NIL T T T T) |package| NIL NIL) (|GroebnerInternalPackage| 1808873 1811903 1815249 "GBINTERN" 1823256 NIL GBINTERN (NIL T T T T) |package| NIL NIL) (|GroebnerFactorizationPackage| 1804949 1805326 1806067 "GBF" 1808357 NIL GBF (NIL T T T T) |package| NIL NIL) (|EuclideanGroebnerBasisPackage| 1802679 1802897 1803393 "GBEUCLID" 1804648 NIL GBEUCLID (NIL T T T T) |package| NIL NIL) (|GaussianFactorizationPackage| 1801502 1801693 1801990 "GAUSSFAC" 1802454 T GAUSSFAC (NIL) |package| NIL NIL) (|GaloisGroupUtilities| 1798140 1798734 1799416 "GALUTIL" 1800890 NIL GALUTIL (NIL T) |package| NIL NIL) (|GaloisGroupPolynomialUtilities| 1794958 1795372 1795978 "GALPOLYU" 1797667 NIL GALPOLYU (NIL T T) |package| NIL NIL) (|GaloisGroupFactorizationUtilities| 1789393 1789810 1790617 "GALFACTU" 1794427 NIL GALFACTU (NIL T T T) |package| NIL NIL) (|GaloisGroupFactorizer| 1773643 1776191 1779250 "GALFACT" 1786442 NIL GALFACT (NIL T) |package| NIL NIL) (|FortranVectorFunctionCategory| 1769114 1770088 1770176 "FVFUN" 1772344 T FVFUN (NIL) |category| NIL 1773555) (|FortranVectorCategory| 1767868 1768132 1768204 "FVC" 1768714 T FVC (NIL) |category| NIL 1769026) (|FunctionCalled| 1767348 1767537 1767677 "FUNCTION" 1767788 NIL FUNCTION (NIL NIL) |domain| NIL NIL) (|FortranType| 1763416 1764236 1765108 "FT" 1766514 T FT (NIL) |domain| NIL NIL) (|FortranTemplate| 1761409 1762099 1762499 "FTEM" 1763062 T FTEM (NIL) |domain| NIL NIL) (|FunctionSpaceUnivariatePolynomialFactor| 1757919 1758433 1759245 "FSUPFACT" 1760840 NIL FSUPFACT (NIL T T T) |package| NIL NIL) (|FortranScalarType| 1755293 1755685 1756254 "FST" 1757400 T FST (NIL) |domain| NIL NIL) (|FunctionSpaceReduce| 1753745 1753912 1754287 "FSRED" 1755078 NIL FSRED (NIL T T) |package| NIL NIL) (|FunctionSpacePrimitiveElement| 1751323 1751745 1752406 "FSPRMELT" 1753257 NIL FSPRMELT (NIL T T) |package| NIL NIL) (|FunctionalSpecialFunction| 1743489 1744345 1745497 "FSPECF" 1750313 NIL FSPECF (NIL T T) |package| NIL NIL) (|FunctionSpace| 1715746 1727946 1728022 "FS" 1734799 NIL FS (NIL T) |category| NIL 1738507) (|FunctionSpace&| 1698908 1703083 1709176 "FS-" 1709745 NIL FS- (NIL T T) |domain| NIL NIL) (|FunctionSpaceIntegration| 1697880 1697950 1698371 "FSINT" 1698815 NIL FSINT (NIL T T) |package| NIL NIL) (|FourierSeries| 1695251 1696166 1696655 "FSERIES" 1697550 NIL FSERIES (NIL T T) |domain| NIL NIL) (|FunctionSpaceComplexIntegration| 1693040 1693237 1693780 "FSCINT" 1695020 NIL FSCINT (NIL T T) |package| NIL NIL) (|FiniteSetAggregate| 1687427 1691272 1691359 "FSAGG" 1692057 NIL FSAGG (NIL T) |category| NIL 1692453) (|FiniteSetAggregate&| 1684061 1684862 1686104 "FSAGG-" 1686293 NIL FSAGG- (NIL T T) |domain| NIL NIL) (|FiniteSetAggregateFunctions2| 1682453 1682621 1683003 "FSAGG2" 1683859 NIL FSAGG2 (NIL T T T T) |package| NIL NIL) (|FunctionSpaceToUnivariatePowerSeries| 1678233 1678582 1679586 "FS2UPS" 1682071 NIL FS2UPS (NIL T T T T T NIL) |package| NIL NIL) (|FunctionSpaceFunctions2| 1677540 1677590 1677858 "FS2" 1678159 NIL FS2 (NIL T T T T) |package| NIL NIL) (|FunctionSpaceToExponentialExpansion| 1675540 1675762 1676339 "FS2EXPXP" 1677290 NIL FS2EXPXP (NIL T T NIL NIL) |package| NIL NIL) (|FactoredFunctionUtilities| 1674528 1674698 1674987 "FRUTIL" 1675341 NIL FRUTIL (NIL T) |package| NIL NIL) (|Factored| 1661445 1667318 1669420 "FR" 1672482 NIL FR (NIL T) |domain| NIL NIL) (|FramedNonAssociativeAlgebra| 1652943 1656898 1657007 "FRNAALG" 1659935 NIL FRNAALG (NIL T) |category| NIL 1661021) (|FramedNonAssociativeAlgebra&| 1645438 1646961 1649151 "FRNAALG-" 1650892 NIL FRNAALG- (NIL T T) |domain| NIL NIL) (|FramedNonAssociativeAlgebraFunctions2| 1644699 1644749 1645047 "FRNAAF2" 1645364 NIL FRNAAF2 (NIL T T T T) |package| NIL NIL) (|FramedModule| 1642074 1642702 1643167 "FRMOD" 1644432 NIL FRMOD (NIL T T T T NIL) |domain| NIL NIL) (|FractionalIdeal| 1638223 1639057 1639587 "FRIDEAL" 1641759 NIL FRIDEAL (NIL T T T T) |domain| NIL NIL) (|FractionalIdealFunctions2| 1636745 1636865 1637413 "FRIDEAL2" 1638079 NIL FRIDEAL2 (NIL T T T T T T T T) |package| NIL NIL) (|FullyRetractableTo| 1635570 1636171 1636251 "FRETRCT" 1636256 NIL FRETRCT (NIL T) |category| NIL 1636541) (|FullyRetractableTo&| 1634200 1634510 1635088 "FRETRCT-" 1635093 NIL FRETRCT- (NIL T T) |domain| NIL NIL) (|FramedAlgebra| 1629657 1631269 1631394 "FRAMALG" 1633157 NIL FRAMALG (NIL T T) |category| NIL 1633630) (|FramedAlgebra&| 1626671 1627282 1628317 "FRAMALG-" 1628767 NIL FRAMALG- (NIL T T T) |domain| NIL NIL) (|Fraction| 1617523 1625880 1626301 "FRAC" 1626306 NIL FRAC (NIL T) |domain| NIL NIL) (|FractionFunctions2| 1616899 1616975 1617175 "FRAC2" 1617423 NIL FRAC2 (NIL T T) |package| NIL NIL) (|FactoredFunctions2| 1616275 1616351 1616551 "FR2" 1616799 NIL FR2 (NIL T T) |package| NIL NIL) (|FloatingPointSystem| 1607404 1611670 1611738 "FPS" 1613851 T FPS (NIL) |category| NIL 1614887) (|FloatingPointSystem&| 1606335 1606521 1606855 "FPS-" 1607155 NIL FPS- (NIL T) |domain| NIL NIL) (|FieldOfPrimeCharacteristic| 1602134 1604583 1604665 "FPC" 1605143 T FPC (NIL) |category| NIL 1605443) (|FieldOfPrimeCharacteristic&| 1601704 1601771 1602003 "FPC-" 1602008 NIL FPC- (NIL T) |domain| NIL NIL) (|FullyPatternMatchable| 1599895 1600843 1600929 "FPATMAB" 1600934 NIL FPATMAB (NIL T) |category| NIL 1601186) (|FullPartialFractionExpansion| 1595759 1596411 1597171 "FPARFRAC" 1599297 NIL FPARFRAC (NIL T T) |domain| NIL NIL) (|FortranProgram| 1588299 1589098 1590288 "FORTRAN" 1594744 NIL FORTRAN (NIL NIL NIL NIL NIL) |domain| NIL NIL) (|FortranPackage| 1584854 1585552 1586375 "FORT" 1587520 T FORT (NIL) |package| NIL NIL) (|FortranFunctionCategory| 1580823 1581665 1581741 "FORTFN" 1583687 T FORTFN (NIL) |category| NIL 1584766) (|FortranProgramCategory| 1580397 1580471 1580545 "FORTCAT" 1580655 T FORTCAT (NIL) |category| NIL 1580768) (|ScriptFormulaFormat| 1577356 1577990 1578639 "FORMULA" 1579802 T FORMULA (NIL) |domain| NIL NIL) (|ScriptFormulaFormat1| 1576932 1576982 1577133 "FORMULA1" 1577282 NIL FORMULA1 (NIL T) |package| NIL NIL) (|FindOrderFinite| 1576030 1576111 1576442 "FORDER" 1576827 NIL FORDER (NIL T T T T) |package| NIL NIL) (|FortranOutputStackPackage| 1574201 1574484 1574909 "FOP" 1575671 T FOP (NIL) |package| NIL NIL) (|FreeNilpotentLie| 1571817 1572747 1573128 "FNLA" 1573949 NIL FNLA (NIL NIL NIL T) |domain| NIL NIL) (|FileNameCategory| 1569741 1570242 1570304 "FNCAT" 1571272 T FNCAT (NIL) |category| |FileName| 1571735) (|FileName| 1569155 1569660 1569714 "FNAME" 1569719 T FNAME (NIL) |domain| NIL NIL) (|FortranMachineTypeCategory| 1567248 1568498 1568580 "FMTC" 1568585 T FMTC (NIL) |category| NIL 1568659) (|FreeMonoid| 1561713 1563282 1564265 "FMONOID" 1566322 NIL FMONOID (NIL T) |domain| NIL NIL) (|FreeModule| 1560642 1561290 1561534 "FM" 1561539 NIL FM (NIL T T) |domain| NIL NIL) (|FortranMatrixFunctionCategory| 1556113 1557087 1557175 "FMFUN" 1559343 T FMFUN (NIL) |category| NIL 1560554) (|FortranMatrixCategory| 1554867 1555131 1555203 "FMC" 1555713 T FMC (NIL) |category| NIL 1556025) (|FreeModuleCat| 1550546 1551619 1551710 "FMCAT" 1553750 NIL FMCAT (NIL T T) |category| NIL 1554515) (|FreeModule1| 1549065 1550177 1550335 "FM1" 1550460 NIL FM1 (NIL T T) |domain| NIL NIL) (|FloatingRealPackage| 1545378 1546013 1546835 "FLOATRP" 1548337 NIL FLOATRP (NIL T) |package| NIL NIL) (|Float| 1535307 1541197 1542420 "FLOAT" 1544181 T FLOAT (NIL) |domain| NIL NIL) (|FloatingComplexPackage| 1530908 1531697 1532703 "FLOATCP" 1534401 NIL FLOATCP (NIL T) |package| NIL NIL) (|FullyLinearlyExplicitRingOver| 1529031 1530195 1530297 "FLINEXP" 1530302 NIL FLINEXP (NIL T) |category| NIL 1530492) (|FullyLinearlyExplicitRingOver&| 1527728 1528044 1528602 "FLINEXP-" 1528607 NIL FLINEXP- (NIL T T) |domain| NIL NIL) (|FiniteLinearAggregateSort| 1526089 1526286 1526694 "FLASORT" 1527497 NIL FLASORT (NIL T T) |package| NIL NIL) (|FreeLieAlgebra| 1521487 1522603 1522706 "FLALG" 1525003 NIL FLALG (NIL T T) |category| |LiePolynomial| 1525767) (|FiniteLinearAggregate| 1512176 1517386 1517472 "FLAGG" 1519708 NIL FLAGG (NIL T) |category| NIL 1520688) (|FiniteLinearAggregate&| 1510314 1510761 1511521 "FLAGG-" 1511526 NIL FLAGG- (NIL T T) |domain| NIL NIL) (|FiniteLinearAggregateFunctions2| 1508723 1508891 1509271 "FLAGG2" 1510112 NIL FLAGG2 (NIL T T T T) |package| NIL NIL) (|FiniteRankAlgebra| 1503561 1504935 1505068 "FINRALG" 1507364 NIL FINRALG (NIL T T) |category| NIL 1508191) (|FiniteRankAlgebra&| 1502259 1502577 1503145 "FINRALG-" 1503150 NIL FINRALG- (NIL T T T) |domain| NIL NIL) (|Finite| 1501156 1501482 1501524 "FINITE" 1501936 T FINITE (NIL) |category| NIL 1502177) (|Finite&| 1500872 1500927 1501062 "FINITE-" 1501067 NIL FINITE- (NIL T) |domain| NIL NIL) (|FiniteRankNonAssociativeAlgebra| 1486600 1489907 1490024 "FINAALG" 1497873 NIL FINAALG (NIL T) |category| NIL 1500495) (|FiniteRankNonAssociativeAlgebra&| 1477428 1479157 1481325 "FINAALG-" 1484583 NIL FINAALG- (NIL T T) |domain| NIL NIL) (|File| 1476566 1477040 1477203 "FILE" 1477310 NIL FILE (NIL T) |domain| NIL NIL) (|FileCategory| 1474302 1474698 1474794 "FILECAT" 1476138 NIL FILECAT (NIL T T) |category| NIL 1476484) (|Field| 1470976 1473185 1473225 "FIELD" 1473274 T FIELD (NIL) |category| NIL 1473458) (|Field&| 1469035 1469544 1470279 "FIELD-" 1470284 NIL FIELD- (NIL T) |domain| NIL NIL) (|FreeGroup| 1465791 1466847 1467394 "FGROUP" 1468543 NIL FGROUP (NIL T) |domain| NIL NIL) (|FGLMIfCanPackage| 1464291 1464539 1464913 "FGLMICPK" 1465509 NIL FGLMICPK (NIL T NIL) |package| NIL NIL) (|FiniteFieldExtension| 1458005 1464096 1464246 "FFX" 1464251 NIL FFX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldSquareFreeDecomposition| 1457111 1457193 1457460 "FFSQFR" 1457894 NIL FFSQFR (NIL T T) |package| NIL NIL) (|FiniteFieldSolveLinearPolynomialEquation| 1456249 1456345 1456676 "FFSLPE" 1456991 NIL FFSLPE (NIL T T T) |package| NIL NIL) (|FiniteFieldPolynomialPackage| 1446643 1448443 1450461 "FFPOLY" 1454332 NIL FFPOLY (NIL T) |package| NIL NIL) (|FiniteFieldPolynomialPackage2| 1445584 1445661 1446106 "FFPOLY2" 1446542 NIL FFPOLY2 (NIL T T) |package| NIL NIL) (|FiniteFieldExtensionByPolynomial| 1439284 1445349 1445539 "FFP" 1445544 NIL FFP (NIL T NIL) |domain| NIL NIL) (|FiniteField| 1432075 1439081 1439224 "FF" 1439229 NIL FF (NIL NIL NIL) |domain| NIL NIL) (|FiniteFieldNormalBasisExtension| 1424329 1430643 1431080 "FFNBX" 1431770 NIL FFNBX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldNormalBasisExtensionByPolynomial| 1416202 1422494 1423063 "FFNBP" 1424024 NIL FFNBP (NIL T NIL) |domain| NIL NIL) (|FiniteFieldNormalBasis| 1407464 1414723 1415183 "FFNB" 1415852 NIL FFNB (NIL NIL NIL) |domain| NIL NIL) (|FunctionFieldIntegralBasis| 1405586 1405841 1406367 "FFINTBAS" 1407180 NIL FFINTBAS (NIL T T T) |package| NIL NIL) (|FiniteFieldCategory| 1399259 1402598 1402666 "FFIELDC" 1403857 T FFIELDC (NIL) |category| NIL 1404591) (|FiniteFieldCategory&| 1396824 1397461 1398400 "FFIELDC-" 1398405 NIL FFIELDC- (NIL T) |domain| NIL NIL) (|FiniteFieldHomomorphisms| 1395948 1395996 1396265 "FFHOM" 1396736 NIL FFHOM (NIL T T T) |package| NIL NIL) (|FiniteFieldFunctions| 1391520 1392396 1393406 "FFF" 1395023 NIL FFF (NIL T) |package| NIL NIL) (|FractionFreeFastGaussian| 1382761 1384235 1385995 "FFFG" 1389926 NIL FFFG (NIL T T) |package| NIL NIL) (|FractionFreeFastGaussianFractions| 1380002 1380423 1381162 "FFFGF" 1382286 NIL FFFGF (NIL T T T) |package| NIL NIL) (|FiniteFieldFactorizationWithSizeParseBySideEffect| 1377315 1377624 1378168 "FFFACTSE" 1379644 NIL FFFACTSE (NIL T T) |package| NIL NIL) (|FiniteFieldFactorization| 1374828 1375137 1375631 "FFFACTOR" 1376957 NIL FFFACTOR (NIL T T) |package| NIL NIL) (|FiniteFieldCyclicGroupExtension| 1368050 1374203 1374471 "FFCGX" 1374692 NIL FFCGX (NIL T NIL) |domain| NIL NIL) (|FiniteFieldCyclicGroupExtensionByPolynomial| 1361230 1367359 1367667 "FFCGP" 1367914 NIL FFCGP (NIL T NIL) |domain| NIL NIL) (|FiniteFieldCyclicGroup| 1353546 1360614 1360875 "FFCG" 1361079 NIL FFCG (NIL NIL NIL) |domain| NIL NIL) (|FunctionFieldCategory| 1321636 1335258 1335466 "FFCAT" 1347014 NIL FFCAT (NIL T T T) |category| NIL 1349518) (|FunctionFieldCategory&| 1313118 1314649 1316887 "FFCAT-" 1319638 NIL FFCAT- (NIL T T T T) |domain| NIL NIL) (|FunctionFieldCategoryFunctions2| 1311894 1311944 1312456 "FFCAT2" 1313044 NIL FFCAT2 (NIL T T T T T T T T) |package| NIL NIL) (|FortranExpression| 1294775 1299911 1301901 "FEXPR" 1310040 NIL FEXPR (NIL NIL NIL T) |domain| NIL NIL) (|FullyEvalableOver| 1293418 1293946 1294031 "FEVALAB" 1294173 NIL FEVALAB (NIL T) |category| NIL 1294529) (|FullyEvalableOver&| 1292319 1292558 1293038 "FEVALAB-" 1293043 NIL FEVALAB- (NIL T T) |domain| NIL NIL) (|FiniteDivisor| 1290157 1291156 1291526 "FDIV" 1292151 NIL FDIV (NIL T T T T) |domain| NIL NIL) (|FiniteDivisorCategory| 1284989 1285891 1286128 "FDIVCAT" 1289322 NIL FDIVCAT (NIL T T T T) |category| NIL 1289965) (|FiniteDivisorCategory&| 1284544 1284583 1284919 "FDIVCAT-" 1284924 NIL FDIVCAT- (NIL T T T T T) |domain| NIL NIL) (|FiniteDivisorFunctions2| 1283125 1283241 1283763 "FDIV2" 1284404 NIL FDIV2 (NIL T T T T T T T T) |package| NIL NIL) (|FortranCodePackage1| 1280596 1281072 1281661 "FCPAK1" 1282590 T FCPAK1 (NIL) |package| NIL NIL) (|FourierComponent| 1279348 1279767 1280001 "FCOMP" 1280430 NIL FCOMP (NIL T) |domain| NIL NIL) (|FortranCode| 1254866 1259577 1264940 "FC" 1274023 T FC (NIL) |domain| NIL NIL) (|FiniteAlgebraicExtensionField| 1242263 1248274 1248377 "FAXF" 1252049 NIL FAXF (NIL T) |category| NIL 1253396) (|FiniteAlgebraicExtensionField&| 1236873 1238034 1239682 "FAXF-" 1240750 NIL FAXF- (NIL T T) |domain| NIL NIL) (|FlexibleArray| 1229695 1235684 1236044 "FARRAY" 1236569 NIL FARRAY (NIL T) |domain| NIL NIL) (|FiniteAbelianMonoidRing| 1222147 1225029 1225149 "FAMR" 1227185 NIL FAMR (NIL T T) |category| NIL 1227915) (|FiniteAbelianMonoidRing&| 1220525 1220917 1221605 "FAMR-" 1221610 NIL FAMR- (NIL T T T) |domain| NIL NIL) (|FiniteAbelianMonoidRingFunctions2| 1219766 1219816 1220116 "FAMR2" 1220451 NIL FAMR2 (NIL T T T T T) |package| NIL NIL) (|FreeAbelianMonoid| 1218529 1219572 1219702 "FAMONOID" 1219707 NIL FAMONOID (NIL T) |domain| NIL NIL) (|FreeAbelianMonoidCategory| 1214771 1215660 1215796 "FAMONC" 1217737 NIL FAMONC (NIL T T) |category| NIL 1218331) (|FreeAbelianGroup| 1212957 1214319 1214577 "FAGROUP" 1214582 NIL FAGROUP (NIL T) |domain| NIL NIL) (|FactoringUtilities| 1208427 1209062 1209913 "FACUTIL" 1212268 NIL FACUTIL (NIL T T T T) |package| NIL NIL) (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| 1206919 1207144 1207580 "FACTRN" 1208173 NIL FACTRN (NIL T) |package| NIL NIL) (|FactoredFunctions| 1205450 1205722 1206097 "FACTFUNC" 1206618 NIL FACTFUNC (NIL T) |package| NIL NIL) (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| 1203886 1204111 1204571 "FACTEXT" 1205196 NIL FACTEXT (NIL T) |package| NIL NIL) (|ExponentialOfUnivariatePuiseuxSeries| 1192701 1202404 1202856 "EXPUPXS" 1203587 NIL EXPUPXS (NIL T NIL NIL) |domain| NIL NIL) (|ExpressionTubePlot| 1187861 1188898 1190070 "EXPRTUBE" 1191581 T EXPRTUBE (NIL) |package| NIL NIL) (|ExpressionSolve| 1186188 1186330 1186787 "EXPRSOL" 1187690 NIL EXPRSOL (NIL T T T T) |package| NIL NIL) (|ExpressionSpaceODESolver| 1179522 1180394 1181651 "EXPRODE" 1185103 NIL EXPRODE (NIL T T) |package| NIL NIL) (|Expression| 1157283 1176754 1177644 "EXPR" 1178688 NIL EXPR (NIL T) |domain| NIL NIL) (|ExpressionToUnivariatePowerSeries| 1146312 1147099 1148486 "EXPR2UPS" 1156193 NIL EXPR2UPS (NIL T T) |package| NIL NIL) (|ExpressionFunctions2| 1145682 1145762 1145962 "EXPR2" 1146208 NIL EXPR2 (NIL T T) |package| NIL NIL) (|ExponentialExpansion| 1128719 1143885 1144515 "EXPEXPAN" 1145349 NIL EXPEXPAN (NIL T T NIL NIL) |domain| NIL NIL) (|Export3D| 1128253 1128327 1128457 "EXP3D" 1128621 T EXP3D (NIL) |package| NIL NIL) (|Exit| 1128030 1128190 1128231 "EXIT" 1128236 T EXIT (NIL) |domain| NIL NIL) (|EvaluateCycleIndicators| 1127330 1127432 1127662 "EVALCYC" 1127904 NIL EVALCYC (NIL T) |package| NIL NIL) (|Evalable| 1126664 1126799 1126866 "EVALAB" 1127136 NIL EVALAB (NIL T) |category| NIL 1127293) (|Evalable&| 1125984 1126125 1126431 "EVALAB-" 1126436 NIL EVALAB- (NIL T T) |domain| NIL NIL) (|EuclideanDomain| 1122066 1123951 1124011 "EUCDOM" 1124914 T EUCDOM (NIL) |category| NIL 1125472) (|EuclideanDomain&| 1119861 1120432 1121283 "EUCDOM-" 1121288 NIL EUCDOM- (NIL T) |domain| NIL NIL) (|ExpertSystemToolsPackage| 1100389 1104352 1108599 "ESTOOLS" 1115678 T ESTOOLS (NIL) |package| NIL NIL) (|ExpertSystemToolsPackage2| 1099800 1099872 1100062 "ESTOOLS2" 1100293 NIL ESTOOLS2 (NIL T T) |package| NIL NIL) (|ExpertSystemToolsPackage1| 1099372 1099422 1099583 "ESTOOLS1" 1099726 NIL ESTOOLS1 (NIL T) |package| NIL NIL) (|ExpressionSpace| 1089830 1092174 1092234 "ES" 1096909 T ES (NIL) |category| NIL 1099144) (|ExpressionSpace&| 1082495 1084269 1086929 "ES-" 1087243 NIL ES- (NIL T) |domain| NIL NIL) (|ExpertSystemContinuityPackage| 1075659 1077000 1078505 "ESCONT" 1081064 T ESCONT (NIL) |package| NIL NIL) (|ExpertSystemContinuityPackage1| 1075176 1075222 1075410 "ESCONT1" 1075589 NIL ESCONT1 (NIL NIL NIL) |package| NIL NIL) (|ExpressionSpaceFunctions2| 1074606 1074667 1074868 "ES2" 1075091 NIL ES2 (NIL T T) |package| NIL NIL) (|ExpressionSpaceFunctions1| 1073995 1074067 1074268 "ES1" 1074510 NIL ES1 (NIL T T) |package| NIL NIL) (|ErrorFunctions| 1072820 1072981 1073255 "ERROR" 1073765 T ERROR (NIL) |package| NIL NIL) (|EqTable| 1064147 1072563 1072725 "EQTBL" 1072730 NIL EQTBL (NIL T T) |domain| NIL NIL) (|Equation| 1053462 1057343 1059349 "EQ" 1062187 NIL EQ (NIL T) |domain| NIL NIL) (|EquationFunctions2| 1052878 1052954 1053134 "EQ2" 1053362 NIL EQ2 (NIL T T) |package| NIL NIL) (|EigenPackage| 1044825 1046537 1048423 "EP" 1051051 NIL EP (NIL T) |package| NIL NIL) (|EntireRing| 1043611 1044356 1044406 "ENTIRER" 1044411 T ENTIRER (NIL) |category| NIL 1044497) (|EuclideanModularRing| 1038098 1040185 1040765 "EMR" 1043317 NIL EMR (NIL T T T NIL NIL NIL) |domain| NIL NIL) (|EltableAggregate| 1036815 1037047 1037144 "ELTAGG" 1037785 NIL ELTAGG (NIL T T) |category| NIL 1038067) (|EltableAggregate&| 1036417 1036485 1036708 "ELTAGG-" 1036713 NIL ELTAGG- (NIL T T T) |domain| NIL NIL) (|Eltable| 1036117 1036146 1036225 "ELTAB" 1036353 NIL ELTAB (NIL T T) |category| NIL NIL) (|EllipticFunctionsUnivariateTaylorSeries| 1034639 1034793 1035140 "ELFUTS" 1035924 NIL ELFUTS (NIL T T) |package| NIL NIL) (|ElementaryFunctionCategory| 1034193 1034249 1034331 "ELEMFUN" 1034538 T ELEMFUN (NIL) |category| NIL NIL) (|ElementaryFunctionCategory&| 1033955 1033976 1034135 "ELEMFUN-" 1034140 NIL ELEMFUN- (NIL T) |domain| NIL NIL) (|ExtensibleLinearAggregate| 1026237 1030780 1030874 "ELAGG" 1032577 NIL ELAGG (NIL T) |category| NIL 1033298) (|ExtensibleLinearAggregate&| 1023788 1024344 1025349 "ELAGG-" 1025354 NIL ELAGG- (NIL T T) |domain| NIL NIL) (|ElementaryFunctionsUnivariatePuiseuxSeries| 1010183 1012334 1013595 "EFUPXS" 1022822 NIL EFUPXS (NIL T T T T) |domain| NIL NIL) (|ElementaryFunctionsUnivariateLaurentSeries| 998242 1000395 1001610 "EFULS" 1009217 NIL EFULS (NIL T T T) |domain| NIL NIL) (|ElementaryFunctionStructurePackage| 993313 993775 994628 "EFSTRUC" 997693 NIL EFSTRUC (NIL T T) |package| NIL NIL) (|ElementaryFunction| 975229 976987 979188 "EF" 991269 NIL EF (NIL T T) |package| NIL NIL) (|ExtAlgBasis| 973855 974330 974601 "EAB" 974996 T EAB (NIL) |domain| NIL NIL) (|e04ucfAnnaType| 972590 973736 973815 "E04UCFA" 973820 T E04UCFA (NIL) |domain| NIL NIL) (|e04nafAnnaType| 971325 972471 972550 "E04NAFA" 972555 T E04NAFA (NIL) |domain| NIL NIL) (|e04mbfAnnaType| 970060 971206 971285 "E04MBFA" 971290 T E04MBFA (NIL) |domain| NIL NIL) (|e04jafAnnaType| 968795 969941 970020 "E04JAFA" 970025 T E04JAFA (NIL) |domain| NIL NIL) (|e04gcfAnnaType| 967532 968676 968755 "E04GCFA" 968760 T E04GCFA (NIL) |domain| NIL NIL) (|e04fdfAnnaType| 966269 967413 967492 "E04FDFA" 967497 T E04FDFA (NIL) |domain| NIL NIL) (|e04dgfAnnaType| 965004 966150 966229 "E04DGFA" 966234 T E04DGFA (NIL) |domain| NIL NIL) (|e04AgentsPackage| 954682 956990 959456 "E04AGNT" 962586 T E04AGNT (NIL) |package| NIL NIL) (|DifferentialVariableCategory| 952447 953074 953180 "DVARCAT" 954171 NIL DVARCAT (NIL T) |category| NIL 954550) (|DifferentialVariableCategory&| 951179 951467 952023 "DVARCAT-" 952028 NIL DVARCAT- (NIL T T) |domain| NIL NIL) (|DesingTreePackage| 937722 938439 939776 "DTP" 950353 NIL DTP (NIL T NIL T T T T T T T T T) |package| NIL NIL) (|DesingTree| 933982 936708 936990 "DSTREE" 937497 NIL DSTREE (NIL T) |domain| NIL NIL) (|DesingTreeCategory| 930302 932860 932947 "DSTRCAT" 933321 NIL DSTRCAT (NIL T) |category| |DesingTree| 933548) (|DifferentialSparseMultivariatePolynomial| 919165 929830 930150 "DSMP" 930155 NIL DSMP (NIL T T T) |domain| NIL NIL) (|DrawOption| 910739 912409 914219 "DROPT" 917391 T DROPT (NIL) |domain| NIL NIL) (|DrawOptionFunctions1| 910199 910279 910453 "DROPT1" 910635 NIL DROPT1 (NIL T) |package| NIL NIL) (|DrawOptionFunctions0| 901940 903728 905671 "DROPT0" 908312 T DROPT0 (NIL) |package| NIL NIL) (|TopLevelDrawFunctionsForPoints| 898700 899312 900094 "DRAWPT" 901234 T DRAWPT (NIL) |package| NIL NIL) (|TopLevelDrawFunctions| 887968 889781 891969 "DRAW" 896632 NIL DRAW (NIL T) |package| NIL NIL) (|DrawNumericHack| 887274 887363 887598 "DRAWHACK" 887855 NIL DRAWHACK (NIL T) |package| NIL NIL) (|DrawComplex| 884739 885269 885881 "DRAWCX" 886700 T DRAWCX (NIL) |package| NIL NIL) (|TopLevelDrawFunctionsForAlgebraicCurves| 883785 883895 884229 "DRAWCURV" 884605 NIL DRAWCURV (NIL T T) |package| NIL NIL) (|TopLevelDrawFunctionsForCompiledFunctions| 864497 868302 872580 "DRAWCFUN" 879605 T DRAWCFUN (NIL) |package| NIL NIL) (|DequeueAggregate| 859846 862418 862494 "DQAGG" 863564 NIL DQAGG (NIL T) |category| |Dequeue| 864009) (|DifferentialPolynomialCategory| 840076 850359 850560 "DPOLCAT" 854644 NIL DPOLCAT (NIL T T T T) |category| NIL 855638) (|DifferentialPolynomialCategory&| 832157 834021 837170 "DPOLCAT-" 837175 NIL DPOLCAT- (NIL T T T T T) |domain| NIL NIL) (|DirectProductModule| 822017 831899 832086 "DPMO" 832091 NIL DPMO (NIL NIL T T) |domain| NIL NIL) (|DirectProductMatrixModule| 811716 821614 821926 "DPMM" 821931 NIL DPMM (NIL NIL T T T) |domain| NIL NIL) (|DistributedMultivariatePolynomial| 801434 811026 811335 "DMP" 811528 NIL DMP (NIL NIL T) |domain| NIL NIL) (|DiscreteLogarithmPackage| 800635 800747 801043 "DLP" 801298 NIL DLP (NIL T) |package| NIL NIL) (|DataList| 791660 799247 799588 "DLIST" 800346 NIL DLIST (NIL T) |domain| NIL NIL) (|DoublyLinkedAggregate| 787032 789830 789916 "DLAGG" 790873 NIL DLAGG (NIL T) |category| NIL 791226) (|DivisionRing| 785063 785979 786033 "DIVRING" 786265 T DIVRING (NIL) |category| NIL 786436) (|DivisionRing&| 783509 783882 784502 "DIVRING-" 784507 NIL DIVRING- (NIL T) |domain| NIL NIL) (|Divisor| 781355 782855 783075 "DIV" 783350 NIL DIV (NIL T) |domain| NIL NIL) (|DivisorCategory| 777494 778880 778961 "DIVCAT" 780410 NIL DIVCAT (NIL T) |category| |Divisor| 780942) (|DisplayPackage| 774615 775083 775708 "DISPLAY" 776913 T DISPLAY (NIL) |package| NIL NIL) (|DirichletRing| 770727 772409 773065 "DIRRING" 774015 NIL DIRRING (NIL T) |domain| NIL NIL) (|DirectProduct| 762105 770564 770685 "DIRPROD" 770690 NIL DIRPROD (NIL NIL T) |domain| NIL NIL) (|DirectProductFunctions2| 760233 760516 760951 "DIRPROD2" 761788 NIL DIRPROD2 (NIL NIL T T) |package| NIL NIL) (|DirectProductCategory| 744771 753205 753319 "DIRPCAT" 754028 NIL DIRPCAT (NIL NIL T) |category| NIL 755375) (|DirectProductCategory&| 740377 741294 742775 "DIRPCAT-" 743433 NIL DIRPCAT- (NIL T NIL T) |domain| NIL NIL) (|DiophantineSolutionPackage| 739204 739446 739780 "DIOSP" 740111 T DIOSP (NIL) |package| NIL NIL) (|DictionaryOperations| 734275 737424 737515 "DIOPS" 738312 NIL DIOPS (NIL T) |category| NIL 738673) (|DictionaryOperations&| 733577 733720 734052 "DIOPS-" 734057 NIL DIOPS- (NIL T T) |domain| NIL NIL) (|DifferentialRing| 731841 732698 732760 "DIFRING" 733103 T DIFRING (NIL) |category| NIL 733296) (|DifferentialRing&| 731247 731362 731637 "DIFRING-" 731642 NIL DIFRING- (NIL T) |domain| NIL NIL) (|DifferentialExtension| 727689 729598 729684 "DIFEXT" 730327 NIL DIFEXT (NIL T) |category| NIL 730820) (|DifferentialExtension&| 725022 725648 726721 "DIFEXT-" 726726 NIL DIFEXT- (NIL T T) |domain| NIL NIL) (|Dictionary| 721189 724338 724409 "DIAGG" 724414 NIL DIAGG (NIL T) |category| NIL 724455) (|Dictionary&| 720297 720496 720882 "DIAGG-" 720887 NIL DIAGG- (NIL T T) |domain| NIL NIL) (|DenavitHartenbergMatrix| 713423 718431 718888 "DHMATRIX" 719961 NIL DHMATRIX (NIL T) |domain| NIL NIL) (|DoubleFloatVector| 705684 713078 713228 "DFVEC" 713323 T DFVEC (NIL) |domain| NIL NIL) (|DoubleFloatSpecialFunctions| 692885 695451 698430 "DFSFUN" 702775 T DFSFUN (NIL) |package| NIL NIL) (|DoubleFloatMatrix| 686677 692425 692631 "DFMAT" 692729 T DFMAT (NIL) |domain| NIL NIL) (|DoubleFloat| 678035 683879 684711 "DFLOAT" 685883 T DFLOAT (NIL) |domain| NIL NIL) (|DefiniteIntegrationTools| 674460 674952 675769 "DFINTTLS" 677487 NIL DFINTTLS (NIL T T) |package| NIL NIL) (|DeRhamComplex| 669646 671056 671787 "DERHAM" 673834 NIL DERHAM (NIL T NIL) |domain| NIL NIL) (|Dequeue| 656577 659190 661426 "DEQUEUE" 667461 NIL DEQUEUE (NIL T) |domain| NIL NIL) (|DegreeReductionPackage| 655088 655323 655709 "DEGRED" 656313 NIL DEGRED (NIL T T) |package| NIL NIL) (|RationalFunctionDefiniteIntegration| 648853 650026 651509 "DEFINTRF" 653834 NIL DEFINTRF (NIL T) |package| NIL NIL) (|ElementaryFunctionDefiniteIntegration| 644462 645146 646232 "DEFINTEF" 648121 NIL DEFINTEF (NIL T T) |package| NIL NIL) (|DecimalExpansion| 634629 643439 643759 "DECIMAL" 644190 T DECIMAL (NIL) |domain| NIL NIL) (|DistinctDegreeFactorize| 630134 630813 631690 "DDFACT" 633886 NIL DDFACT (NIL T T) |package| NIL NIL) (|DoubleResultantPackage| 629346 629408 629714 "DBLRESP" 630048 NIL DBLRESP (NIL T T T T) |package| NIL NIL) (|Database| 625835 626257 626837 "DBASE" 628965 NIL DBASE (NIL T) |domain| NIL NIL) (|d03fafAnnaType| 624534 625690 625782 "D03FAFA" 625787 T D03FAFA (NIL) |domain| NIL NIL) (|d03eefAnnaType| 623234 624389 624481 "D03EEFA" 624486 T D03EEFA (NIL) |domain| NIL NIL) (|d03AgentsPackage| 619878 620612 621433 "D03AGNT" 622461 T D03AGNT (NIL) |package| NIL NIL) (|d02ejfAnnaType| 618818 619731 619824 "D02EJFA" 619829 T D02EJFA (NIL) |domain| NIL NIL) (|d02cjfAnnaType| 617758 618671 618764 "D02CJFA" 618769 T D02CJFA (NIL) |domain| NIL NIL) (|d02bhfAnnaType| 616698 617611 617704 "D02BHFA" 617709 T D02BHFA (NIL) |domain| NIL NIL) (|d02bbfAnnaType| 615638 616551 616644 "D02BBFA" 616649 T D02BBFA (NIL) |domain| NIL NIL) (|d02AgentsPackage| 604757 607201 609794 "D02AGNT" 613093 T D02AGNT (NIL) |package| NIL NIL) (|d01WeightsPackage| 600985 601843 602785 "D01WGTS" 603865 T D01WGTS (NIL) |package| NIL NIL) (|d01TransformFunctionType| 599569 600848 600946 "D01TRNS" 600951 T D01TRNS (NIL) |domain| NIL NIL) (|d01gbfAnnaType| 598173 599452 599530 "D01GBFA" 599535 T D01GBFA (NIL) |domain| NIL NIL) (|d01fcfAnnaType| 596777 598056 598134 "D01FCFA" 598139 T D01FCFA (NIL) |domain| NIL NIL) (|d01asfAnnaType| 595381 596660 596738 "D01ASFA" 596743 T D01ASFA (NIL) |domain| NIL NIL) (|d01aqfAnnaType| 593985 595264 595342 "D01AQFA" 595347 T D01AQFA (NIL) |domain| NIL NIL) (|d01apfAnnaType| 592589 593868 593946 "D01APFA" 593951 T D01APFA (NIL) |domain| NIL NIL) (|d01anfAnnaType| 591193 592472 592550 "D01ANFA" 592555 T D01ANFA (NIL) |domain| NIL NIL) (|d01amfAnnaType| 589797 591076 591154 "D01AMFA" 591159 T D01AMFA (NIL) |domain| NIL NIL) (|d01alfAnnaType| 588401 589680 589758 "D01ALFA" 589763 T D01ALFA (NIL) |domain| NIL NIL) (|d01akfAnnaType| 587005 588284 588362 "D01AKFA" 588367 T D01AKFA (NIL) |domain| NIL NIL) (|d01ajfAnnaType| 585609 586888 586966 "D01AJFA" 586971 T D01AJFA (NIL) |domain| NIL NIL) (|d01AgentsPackage| 575732 577911 580212 "D01AGNT" 583356 T D01AGNT (NIL) |package| NIL NIL) (|CyclotomicPolynomialPackage| 574196 574478 574864 "CYCLOTOM" 575416 T CYCLOTOM (NIL) |package| NIL NIL) (|CycleIndicators| 567922 569255 570718 "CYCLES" 572779 T CYCLES (NIL) |package| NIL NIL) (|CoerceVectorMatrixPackage| 566759 566950 567261 "CVMP" 567702 NIL CVMP (NIL T) |package| NIL NIL) (|ComplexTrigonometricManipulations| 562283 562621 563340 "CTRIGMNP" 566313 NIL CTRIGMNP (NIL T T) |package| NIL NIL) (|CyclicStreamTools| 561143 561297 561583 "CSTTOOLS" 562095 NIL CSTTOOLS (NIL T T) |package| NIL NIL) (|ComplexRootFindingPackage| 553946 554806 556014 "CRFP" 560096 NIL CRFP (NIL T T) |package| NIL NIL) (|CRApackage| 552457 552694 553052 "CRAPACK" 553649 NIL CRAPACK (NIL T) |package| NIL NIL) (|ComplexPatternMatch| 551334 551503 551877 "CPMATCH" 552248 NIL CPMATCH (NIL T T T) |package| NIL NIL) (|CharacteristicPolynomialInMonogenicalAlgebra| 550671 550720 551001 "CPIMA" 551261 NIL CPIMA (NIL T T T) |package| NIL NIL) (|CoordinateSystems| 544367 545315 546487 "COORDSYS" 549628 NIL COORDSYS (NIL T) |package| NIL NIL) (|ContinuedFraction| 537760 540760 541614 "CONTFRAC" 543588 NIL CONTFRAC (NIL T) |domain| NIL NIL) (|CommutativeRing| 536533 537278 537338 "COMRING" 537343 T COMRING (NIL) |category| NIL 537432) (|SubSpaceComponentProperty| 535046 535395 535725 "COMPPROP" 536269 T COMPPROP (NIL) |domain| NIL NIL) (|ComplexPattern| 534452 534496 534728 "COMPLPAT" 534978 NIL COMPLPAT (NIL T T T) |package| NIL NIL) (|Complex| 518778 534146 534324 "COMPLEX" 534329 NIL COMPLEX (NIL T) |domain| NIL NIL) (|ComplexFunctions2| 518161 518235 518433 "COMPLEX2" 518680 NIL COMPLEX2 (NIL T T) |package| NIL NIL) (|ComplexFactorization| 517631 517675 517879 "COMPFACT" 518093 NIL COMPFACT (NIL T T) |package| NIL NIL) (|ComplexCategory| 491656 507827 507912 "COMPCAT" 509862 NIL COMPCAT (NIL T) |category| NIL 512207) (|ComplexCategory&| 475114 479345 485182 "COMPCAT-" 485922 NIL COMPCAT- (NIL T T) |domain| NIL NIL) (|Comparable| 474606 474798 474848 "COMPAR" 474945 T COMPAR (NIL) |category| NIL 475032) (|CommuteUnivariatePolynomialCategory| 474056 474085 474324 "COMMUPC" 474553 NIL COMMUPC (NIL T T T) |package| NIL NIL) (|CommonOperators| 473676 473728 473850 "COMMONOP" 473980 T COMMONOP (NIL) |package| NIL NIL) (|Commutator| 473064 473270 473418 "COMM" 473564 T COMM (NIL) |domain| NIL NIL) (|CombinatorialOpsCategory| 471730 471991 472069 "COMBOPC" 472704 T COMBOPC (NIL) |category| NIL 473021) (|IntegerCombinatoricFunctions| 469826 470083 470495 "COMBINAT" 471419 NIL COMBINAT (NIL T) |package| NIL NIL) (|CombinatorialFunction| 463425 464144 465145 "COMBF" 468959 NIL COMBF (NIL T T) |package| NIL NIL) (|Color| 461615 462033 462421 "COLOR" 463063 T COLOR (NIL) |domain| NIL NIL) (|ComplexRootPackage| 460971 461034 461275 "CMPLXRT" 461528 NIL CMPLXRT (NIL T T) |package| NIL NIL) (|TwoDimensionalPlotClipping| 454028 455549 457238 "CLIP" 459350 T CLIP (NIL) |package| NIL NIL) (|CliffordAlgebra| 451495 452514 452920 "CLIF" 453741 NIL CLIF (NIL NIL T NIL) |domain| NIL NIL) (|Collection| 445883 448633 448697 "CLAGG" 450227 NIL CLAGG (NIL T) |category| NIL 451018) (|Collection&| 443529 444169 445062 "CLAGG-" 445067 NIL CLAGG- (NIL T T) |domain| NIL NIL) (|ComplexIntegerSolveLinearPolynomialEquation| 442424 442613 442987 "CINTSLPE" 443316 NIL CINTSLPE (NIL T T) |package| NIL NIL) (|ChangeOfVariable| 438224 438868 439743 "CHVAR" 441731 NIL CHVAR (NIL T T T) |package| NIL NIL) (|CharacteristicZero| 437108 437853 437919 "CHARZ" 437924 T CHARZ (NIL) |category| NIL 437943) (|CharacteristicPolynomialPackage| 436587 436652 436844 "CHARPOL" 437019 NIL CHARPOL (NIL T) |package| NIL NIL) (|CharacteristicNonZero| 435272 436062 436134 "CHARNZ" 436217 T CHARNZ (NIL) |category| NIL 436306) (|Character| 432242 433133 433696 "CHAR" 434743 T CHAR (NIL) |domain| NIL NIL) (|CombinatorialFunctionCategory| 431708 431788 431876 "CFCAT" 432117 T CFCAT (NIL) |category| NIL NIL) (|Cell| 429002 429458 430039 "CELL" 431176 NIL CELL (NIL T) |domain| NIL NIL) (|ComplexDoubleFloatVector| 419398 428362 428600 "CDFVEC" 428828 T CDFVEC (NIL) |domain| NIL NIL) (|ComplexDoubleFloatMatrix| 412109 418865 419111 "CDFMAT" 419216 T CDFMAT (NIL) |domain| NIL NIL) (|CommonDenominator| 410713 410870 411208 "CDEN" 411917 NIL CDEN (NIL T T T) |package| NIL NIL) (|CharacterClass| 404251 409175 409695 "CCLASS" 410237 T CCLASS (NIL) |domain| NIL NIL) (|CartesianTensor| 396151 397388 398625 "CARTEN" 403130 NIL CARTEN (NIL NIL NIL T) |domain| NIL NIL) (|CartesianTensorFunctions2| 394594 394807 395210 "CARTEN2" 395909 NIL CARTEN2 (NIL NIL NIL T T) |package| NIL NIL) (|CardinalNumber| 391752 392936 393462 "CARD" 394112 T CARD (NIL) |domain| NIL NIL) (|CylindricalAlgebraicDecompositionUtilities| 390381 390543 390901 "CADU" 391556 NIL CADU (NIL T T) |package| NIL NIL) (|CylindricalAlgebraicDecompositionPackage| 385363 386259 387364 "CAD" 389397 NIL CAD (NIL T) |package| NIL NIL) (|CachableSet| 384401 384811 384863 "CACHSET" 385103 T CACHSET (NIL) |category| NIL 385260) (|CancellationAbelianMonoid| 383615 383992 384072 "CABMON" 384165 T CABMON (NIL) |category| NIL 384268) (|BinaryTree| 380150 383089 383276 "BTREE" 383485 NIL BTREE (NIL T) |domain| NIL NIL) (|BinaryTournament| 376527 379493 379732 "BTOURN" 379979 NIL BTOURN (NIL T) |domain| NIL NIL) (|BinaryTreeCategory| 372844 375694 375781 "BTCAT" 375894 NIL BTCAT (NIL T) |category| NIL 376053) (|BinaryTreeCategory&| 372326 372429 372688 "BTCAT-" 372693 NIL BTCAT- (NIL T T) |domain| NIL NIL) (|BitAggregate| 365009 370774 370828 "BTAGG" 371220 T BTAGG (NIL) |category| NIL 371494) (|BitAggregate&| 364315 364452 364760 "BTAGG-" 364765 NIL BTAGG- (NIL T) |domain| NIL NIL) (|BinarySearchTree| 359996 363062 363441 "BSTREE" 364004 NIL BSTREE (NIL T) |domain| NIL NIL) (|BasicStochasticDifferential| 357468 358134 358649 "BSD" 359551 T BSD (NIL) |domain| NIL NIL) (|BrillhartTests| 355619 355855 356275 "BRILL" 357142 NIL BRILL (NIL T) |package| NIL NIL) (|BinaryRecursiveAggregate| 350771 353594 353686 "BRAGG" 354811 NIL BRAGG (NIL T) |category| NIL 355185) (|BinaryRecursiveAggregate&| 348774 349257 350071 "BRAGG-" 350076 NIL BRAGG- (NIL T T) |domain| NIL NIL) (|BalancedPAdicRational| 336816 347496 347885 "BPADICRT" 348460 NIL BPADICRT (NIL NIL) |domain| NIL NIL) (|BalancedPAdicInteger| 334343 336676 336780 "BPADIC" 336785 NIL BPADIC (NIL NIL) |domain| NIL NIL) (|BoundIntegerRoots| 333769 333813 334041 "BOUNDZRO" 334275 NIL BOUNDZRO (NIL T T) |package| NIL NIL) (|BasicOperator| 326469 328003 329489 "BOP" 332325 T BOP (NIL) |domain| NIL NIL) (|BasicOperatorFunctions1| 322244 322960 323888 "BOP1" 325624 NIL BOP1 (NIL T) |package| NIL NIL) (|Boolean| 320040 320866 321302 "BOOLEAN" 321838 T BOOLEAN (NIL) |domain| NIL NIL) (|BiModule| 319129 319589 319663 "BMODULE" 319668 NIL BMODULE (NIL T T) |category| NIL 319795) (|BlowUpPackage| 312783 313854 315191 "BLUPPACK" 318012 NIL BLUPPACK (NIL T NIL T T T) |package| NIL NIL) (|BlowUpWithQuadTrans| 311905 312546 312689 "BLQT" 312694 T BLQT (NIL) |domain| NIL NIL) (|BlowUpMethodCategory| 309451 310082 310152 "BLMETCT" 311246 T BLMETCT (NIL) |category| NIL 311823) (|BlowUpWithHamburgerNoether| 308566 309204 309359 "BLHN" 309364 T BLHN (NIL) |domain| NIL NIL) (|BlasLevelOne| 298333 300640 303091 "BLAS1" 306155 T BLAS1 (NIL) |package| NIL NIL) (|Bits| 292070 297975 298104 "BITS" 298228 T BITS (NIL) |domain| NIL NIL) (|BinaryFile| 290593 291224 291513 "BINFILE" 291817 T BINFILE (NIL) |domain| NIL NIL) (|BinaryExpansion| 280774 289582 289898 "BINARY" 290323 T BINARY (NIL) |domain| NIL NIL) (|BagAggregate| 277681 279671 279739 "BGAGG" 280146 NIL BGAGG (NIL T) |category| NIL 280374) (|BagAggregate&| 277439 277473 277616 "BGAGG-" 277621 NIL BGAGG- (NIL T T) |domain| NIL NIL) (|BasicFunctions| 276083 276456 276796 "BFUNCT" 277143 T BFUNCT (NIL) |domain| NIL NIL) (|BezoutMatrix| 273749 274005 274487 "BEZOUT" 275809 NIL BEZOUT (NIL T T T T T) |package| NIL NIL) (|Bezier| 272242 272538 272910 "BEZIER" 273419 NIL BEZIER (NIL T) |package| NIL NIL) (|BalancedBinaryTree| 267076 270286 270847 "BBTREE" 271754 NIL BBTREE (NIL T) |domain| NIL NIL) (|BasicType| 266705 266761 266809 "BASTYPE" 266981 T BASTYPE (NIL) |category| NIL NIL) (|BasicType&| 266495 266525 266640 "BASTYPE-" 266645 NIL BASTYPE- (NIL T) |domain| NIL NIL) (|BalancedFactorisation| 265390 265498 265813 "BALFACT" 266332 NIL BALFACT (NIL T T) |package| NIL NIL) (|AxiomServer| 264347 264529 264784 "AXSERV" 265173 T AXSERV (NIL) |package| NIL NIL) (|Automorphism| 262654 263408 263705 "AUTOMOR" 264104 NIL AUTOMOR (NIL T) |domain| NIL NIL) (|UnitsKnownAttribute| 262527 262532 262600 "ATUNIKN" 262605 T ATUNIKN (NIL) |category| NIL NIL) (|AttributeRegistry| 261869 261874 261938 "ATTREG" 261943 T ATTREG (NIL) |category| NIL NIL) (|AttributeButtons| 258975 259559 260194 "ATTRBUT" 261282 T ATTRBUT (NIL) |domain| NIL NIL) (|ShallowlyMutableAttribute| 258836 258841 258921 "ATSHMUT" 258926 T ATSHMUT (NIL) |category| NIL NIL) (|ArcTrigonometricFunctionCategory| 257990 258109 258203 "ATRIG" 258656 T ATRIG (NIL) |category| NIL NIL) (|ArcTrigonometricFunctionCategory&| 257652 257695 257902 "ATRIG-" 257907 NIL ATRIG- (NIL T) |domain| NIL NIL) (|PartiallyOrderedSetAttribute| 257507 257512 257598 "ATPOSET" 257603 T ATPOSET (NIL) |category| NIL NIL) (|NoZeroDivisorsAttribute| 257372 257377 257453 "ATNZDIV" 257458 T ATNZDIV (NIL) |category| NIL NIL) (|NullSquareAttribute| 257245 257250 257318 "ATNULSQ" 257323 T ATNULSQ (NIL) |category| NIL NIL) (|NotherianAttribute| 257120 257125 257191 "ATNOTHR" 257196 T ATNOTHR (NIL) |category| NIL NIL) (|MultiplicativeValuationAttribute| 256967 256972 257066 "ATMULVA" 257071 T ATMULVA (NIL) |category| NIL NIL) (|LeftUnitaryAttribute| 256838 256843 256913 "ATLUNIT" 256918 T ATLUNIT (NIL) |category| NIL NIL) (|LazyRepresentationAttribute| 256695 256700 256784 "ATLR" 256789 T ATLR (NIL) |category| NIL NIL) (|JacobiIdentityAttribute| 256560 256565 256641 "ATJACID" 256646 T ATJACID (NIL) |category| NIL NIL) (|FiniteAggregateAttribute| 256423 256428 256506 "ATFINAG" 256511 T ATFINAG (NIL) |category| NIL NIL) (|CanonicalUnitNormalAttribute| 256278 256283 256369 "ATCUNOR" 256374 T ATCUNOR (NIL) |category| NIL NIL) (|CommutativeStarAttribute| 256141 256146 256224 "ATCS" 256229 T ATCS (NIL) |category| NIL NIL) (|CentralAttribute| 256020 256025 256087 "ATCENRL" 256092 T ATCENRL (NIL) |category| NIL NIL) (|CanonicalAttribute| 255895 255900 255966 "ATCANON" 255971 T ATCANON (NIL) |category| NIL NIL) (|CanonicalClosedAttribute| 255758 255763 255841 "ATCANCL" 255846 T ATCANCL (NIL) |category| NIL NIL) (|ArbitraryPrecisionAttribute| 255615 255620 255704 "ATARBPR" 255709 T ATARBPR (NIL) |category| NIL NIL) (|ArbitraryExponentAttribute| 255474 255479 255561 "ATARBEX" 255566 T ATARBEX (NIL) |category| NIL NIL) (|ApproximateAttribute| 255345 255350 255420 "ATAPPRO" 255425 T ATAPPRO (NIL) |category| NIL NIL) (|AdditiveValuationAttribute| 255204 255209 255291 "ATADDVA" 255296 T ATADDVA (NIL) |category| NIL NIL) (|ArrayStack| 245017 247184 248909 "ASTACK" 253536 NIL ASTACK (NIL T) |domain| NIL NIL) (|AssociatedEquations| 242420 242868 243501 "ASSOCEQ" 244519 NIL ASSOCEQ (NIL T T) |package| NIL NIL) (|Asp9| 240912 241853 242063 "ASP9" 242250 NIL ASP9 (NIL NIL) |domain| NIL NIL) (|Asp8| 240546 240813 240880 "ASP8" 240885 NIL ASP8 (NIL NIL) |domain| NIL NIL) (|Asp80| 238781 239886 240130 "ASP80" 240344 NIL ASP80 (NIL NIL) |domain| NIL NIL) (|Asp7| 237080 238169 238396 "ASP7" 238594 NIL ASP7 (NIL NIL) |domain| NIL NIL) (|Asp78| 235417 236495 236714 "ASP78" 236903 NIL ASP78 (NIL NIL) |domain| NIL NIL) (|Asp77| 233753 234832 235051 "ASP77" 235240 NIL ASP77 (NIL NIL) |domain| NIL NIL) (|Asp74| 232049 233138 233367 "ASP74" 233566 NIL ASP74 (NIL NIL) |domain| NIL NIL) (|Asp73| 230347 231434 231663 "ASP73" 231862 NIL ASP73 (NIL NIL) |domain| NIL NIL) (|Asp6| 228686 229765 229982 "ASP6" 230170 NIL ASP6 (NIL NIL) |domain| NIL NIL) (|Asp55| 227016 228101 228320 "ASP55" 228509 NIL ASP55 (NIL NIL) |domain| NIL NIL) (|Asp50| 225347 226428 226648 "ASP50" 226838 NIL ASP50 (NIL NIL) |domain| NIL NIL) (|Asp4| 223879 224810 225010 "ASP4" 225187 NIL ASP4 (NIL NIL) |domain| NIL NIL) (|Asp49| 222408 223339 223541 "ASP49" 223719 NIL ASP49 (NIL NIL) |domain| NIL NIL) (|Asp42| 220552 221663 221938 "ASP42" 222207 NIL ASP42 (NIL NIL NIL NIL) |domain| NIL NIL) (|Asp41| 218705 219813 220086 "ASP41" 220353 NIL ASP41 (NIL NIL NIL NIL) |domain| NIL NIL) (|Asp35| 217038 218120 218339 "ASP35" 218528 NIL ASP35 (NIL NIL) |domain| NIL NIL) (|Asp34| 216670 216937 217006 "ASP34" 217011 NIL ASP34 (NIL NIL) |domain| NIL NIL) (|Asp33| 216222 216314 216455 "ASP33" 216571 NIL ASP33 (NIL NIL) |domain| NIL NIL) (|Asp31| 214515 215607 215836 "ASP31" 216035 NIL ASP31 (NIL NIL) |domain| NIL NIL) (|Asp30| 214147 214414 214483 "ASP30" 214488 NIL ASP30 (NIL NIL) |domain| NIL NIL) (|Asp29| 213697 213791 213932 "ASP29" 214048 NIL ASP29 (NIL NIL) |domain| NIL NIL) (|Asp28| 213329 213596 213665 "ASP28" 213670 NIL ASP28 (NIL NIL) |domain| NIL NIL) (|Asp27| 212961 213228 213297 "ASP27" 213302 NIL ASP27 (NIL NIL) |domain| NIL NIL) (|Asp24| 211486 212418 212621 "ASP24" 212800 NIL ASP24 (NIL NIL) |domain| NIL NIL) (|Asp20| 209768 210862 211094 "ASP20" 211296 NIL ASP20 (NIL NIL) |domain| NIL NIL) (|Asp1| 208300 209231 209431 "ASP1" 209608 NIL ASP1 (NIL NIL) |domain| NIL NIL) (|Asp19| 206625 207712 207932 "ASP19" 208122 NIL ASP19 (NIL NIL) |domain| NIL NIL) (|Asp12| 206177 206269 206410 "ASP12" 206526 NIL ASP12 (NIL NIL) |domain| NIL NIL) (|Asp10| 204411 205514 205759 "ASP10" 205974 NIL ASP10 (NIL NIL) |domain| NIL NIL) (|TwoDimensionalArray| 201270 204024 204249 "ARRAY2" 204254 NIL ARRAY2 (NIL T) |domain| NIL NIL) (|OneDimensionalArray| 195159 200535 200789 "ARRAY1" 201084 NIL ARRAY1 (NIL T) |domain| NIL NIL) (|OneDimensionalArrayFunctions2| 193375 193663 194087 "ARRAY12" 194837 NIL ARRAY12 (NIL T T) |package| NIL NIL) (|TwoDimensionalArrayCategory| 183671 186279 186451 "ARR2CAT" 191766 NIL ARR2CAT (NIL T T T) |category| NIL 192975) (|TwoDimensionalArrayCategory&| 179838 180860 182368 "ARR2CAT-" 182373 NIL ARR2CAT- (NIL T T T T) |domain| NIL NIL) (|ApplyRules| 177722 177928 178437 "APPRULE" 179583 NIL APPRULE (NIL T T T) |package| NIL NIL) (|ApplyUnivariateSkewPolynomial| 177093 177150 177391 "APPLYORE" 177641 NIL APPLYORE (NIL T T T) |package| NIL NIL) (|ApplicationProgramInterface| 175651 175869 176201 "API" 176831 T API (NIL) |package| NIL NIL) (|Any| 174083 174471 174795 "ANY" 175349 T ANY (NIL) |domain| NIL NIL) (|AnyFunctions1| 172933 173099 173360 "ANY1" 173878 NIL ANY1 (NIL T) |package| NIL NIL) (|AntiSymm| 169143 170384 170948 "ANTISYM" 172440 NIL ANTISYM (NIL T NIL) |domain| NIL NIL) (|AnonymousFunction| 168892 169054 169121 "ANON" 169126 T ANON (NIL) |domain| NIL NIL) (|AlgebraicNumber| 159460 165887 166849 "AN" 167976 T AN (NIL) |domain| NIL NIL) (|AbelianMonoidRing| 153584 155485 155593 "AMR" 157017 NIL AMR (NIL T T) |category| NIL 157953) (|AbelianMonoidRing&| 152263 152558 153135 "AMR-" 153140 NIL AMR- (NIL T T T) |domain| NIL NIL) (|AssociationList| 131828 152090 152218 "ALIST" 152223 NIL ALIST (NIL T T) |domain| NIL NIL) (|AlgebraGivenByStructuralConstants| 127001 131087 131416 "ALGSC" 131678 NIL ALGSC (NIL T NIL NIL NIL) |domain| NIL NIL) (|AlgebraPackage| 120277 121187 122332 "ALGPKG" 125966 NIL ALGPKG (NIL T T) |package| NIL NIL) (|AlgebraicMultFact| 118768 118962 119357 "ALGMFACT" 120043 NIL ALGMFACT (NIL T T T) |package| NIL NIL) (|AlgebraicManipulations| 111091 112039 113114 "ALGMANIP" 118067 NIL ALGMANIP (NIL T T) |package| NIL NIL) (|AlgebraicFunctionField| 97882 110316 110634 "ALGFF" 110957 NIL ALGFF (NIL T T T NIL) |domain| NIL NIL) (|AlgFactor| 96410 96599 96930 "ALGFACT" 97643 NIL ALGFACT (NIL T) |package| NIL NIL) (|Algebra| 94976 95767 95836 "ALGEBRA" 95938 NIL ALGEBRA (NIL T) |category| NIL 96025) (|Algebra&| 94543 94618 94834 "ALGEBRA-" 94839 NIL ALGEBRA- (NIL T T) |domain| NIL NIL) (|AssociationListAggregate| 70289 91056 91176 "ALAGG" 91399 NIL ALAGG (NIL T T) |category| |AssociationList| 91625) (|ArcHyperbolicFunctionCategory| 69449 69574 69662 "AHYP" 70103 T AHYP (NIL) |category| NIL NIL) (|Aggregate| 67687 68056 68104 "AGG" 68958 T AGG (NIL) |category| NIL 69431) (|Aggregate&| 66746 66993 67365 "AGG-" 67370 NIL AGG- (NIL T) |domain| NIL NIL) (|AffineSpaceCategory| 62636 63427 63510 "AFSPCAT" 65807 NIL AFSPCAT (NIL T) |category| NIL 66632) (|AlgebraicFunction| 58425 59087 59831 "AF" 62018 NIL AF (NIL T T) |package| NIL NIL) (|AffineSpace| 57480 58279 58390 "AFFSP" 58395 NIL AFFSP (NIL NIL T) |domain| NIL NIL) (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| 56013 57190 57405 "AFFPLPS" 57410 NIL AFFPLPS (NIL T) |domain| NIL NIL) (|AffinePlane| 55078 55895 55978 "AFFPL" 55983 NIL AFFPL (NIL T) |domain| NIL NIL) (|AffineAlgebraicSetComputeWithResultant| 48512 49389 50647 "AFALGRES" 54122 NIL AFALGRES (NIL T NIL T T T) |package| NIL NIL) (|AffineAlgebraicSetComputeWithGroebnerBasis| 45978 46239 46844 "AFALGGRO" 48217 NIL AFALGGRO (NIL T NIL T T T) |package| NIL NIL) (|PlaneAlgebraicCurvePlot| 44687 45081 45400 "ACPLOT" 45721 T ACPLOT (NIL) |domain| NIL NIL) (|AlgebraicallyClosedFunctionSpace| 28628 39906 40048 "ACFS" 41463 NIL ACFS (NIL T) |category| |Expression| 41846) (|AlgebraicallyClosedFunctionSpace&| 25328 26092 27446 "ACFS-" 27451 NIL ACFS- (NIL T T) |domain| NIL NIL) (|AlgebraicallyClosedField| 18951 21835 21913 "ACF" 23646 T ACF (NIL) |category| NIL 24442) (|AlgebraicallyClosedField&| 16600 17188 18117 "ACF-" 18122 NIL ACF- (NIL T) |domain| NIL NIL) (|AbelianSemiGroup| 15981 16189 16251 "ABELSG" 16410 T ABELSG (NIL) |category| NIL 16518) (|AbelianSemiGroup&| 15728 15766 15909 "ABELSG-" 15914 NIL ABELSG- (NIL T) |domain| NIL NIL) (|AbelianMonoid| 14733 15060 15116 "ABELMON" 15417 T ABELMON (NIL) |category| NIL 15619) (|AbelianMonoid&| 14172 14295 14545 "ABELMON-" 14550 NIL ABELMON- (NIL T) |domain| NIL NIL) (|AbelianGroup| 13194 13622 13676 "ABELGRP" 13869 T ABELGRP (NIL) |category| NIL 14003) (|AbelianGroup&| 12401 12575 12914 "ABELGRP-" 12919 NIL ABELGRP- (NIL T) |domain| NIL NIL) (|OneDimensionalArrayAggregate| 6156 11366 11466 "A1AGG" 11471 NIL A1AGG (NIL T) |category| NIL 11565) (|OneDimensionalArrayAggregate&| 30 1630 3956 "A1AGG-" 3961 NIL A1AGG- (NIL T T) |domain| NIL NIL)) 
\ No newline at end of file
diff --git a/src/share/algebra/operation.daase b/src/share/algebra/operation.daase
index 9fce78f..dc40fd7 100644
--- a/src/share/algebra/operation.daase
+++ b/src/share/algebra/operation.daase
@@ -1,3297 +1,3318 @@
 
-(1566386 . 3614189654)       
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Permutation| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage1| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Permutation| (|Integer|)))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *1 (|RepresentationPackage1| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Integer|)))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|OpenMathErrorKind|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *1 (|OpenMathError|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PermutationGroup| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|AffinePlane| *3)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerPrimesPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Table| (|StochasticDifferential| *3) (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |base| *3) (|:| |exponent| (|NonNegativeInteger|)))) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(1571468 . 3618694787)       
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Character|))) (|isDomain| *1 (|CharacterClass|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|CharacterClass|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|isDomain| *2 (|Record| (|:| |sysok| (|Boolean|)) (|:| |z0| (|List| *7)) (|:| |n0| (|List| *7)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |zeros| (|List| *4)) (|:| |extDegree| (|Integer|)))) (|isDomain| *1 (|RootsFindingPackage| *4))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Algebra| *2)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GenExEuclid| *3 *5))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|String|))) (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultantReduit| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1 *4) (AND (|isDomain| *4 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *3)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
 (((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *6 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|NonNegativeInteger|))) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionFieldCategory&| *4 *3 *5 *6)) (|ofCategory| *4 (|FunctionFieldCategory| *3 *5 *6)))) ((*1 *2 *3 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|NewtonInterpolation| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |value| *4) (|:| |weight| (|Integer|))))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| *4)) (|isDomain| *1 (|RandomDistributions| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |Hermite| *3) (|:| |eqMat| *3))) (|isDomain| *1 (|SmithNormalForm| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *2 *3 *4 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *5 *6))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *2 (|Complex| *5)) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *5 *3)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *3 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *2) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4 *5) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Factored| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *5 *2)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|ExpressionSpace|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Equation| *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Equation| *1)) (|ofCategory| *1 (|ExpressionSpace|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *4 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *9 (|PlacesCategory| *5 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DesingTreeCategory| *11)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
+(((*1 *1) (|isDomain| *1 (|Void|)))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |%expansion| (|ExponentialExpansion| *5 *3 *6 *7)) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToExponentialExpansion| *5 *3 *6 *7)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofType| *6 (|Symbol|)) (|ofType| *7 *3)))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootPackage| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| (|Integer|)))) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|Product| *2 *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Mapping| *4 (|Integer|) (|Integer|))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|OutputForm|)))) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SquareMatrix| *3 *4)) (|isDomain| *1 (|QuadraticForm| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *5))) (|ofCategory| *5 (|Ring|)) (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5))))) 
+(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|BasicFunctions|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| (|List| *4)))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|RootsFindingPackage| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ApplicationProgramInterface|))))) 
+(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *5 *2)) (|ofCategory| *2 (|FunctionSpace| *5)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *5 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *5 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *5 (|Kernel| $)))))))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|PositiveInteger|)) (|has| *4 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *3 (|PositiveInteger|)) (|has| *4 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4))))) 
+(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|GenusZeroIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|Fraction| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|GenusZeroIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DirichletRing| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |gen| *3) (|:| |exp| (|Integer|)))) (|isDomain| *1 (|Divisor| *3)) (|ofCategory| *3 (|SetCategoryWithDegree|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|)))))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Vector| (|Fraction| (|Integer|)))) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Fraction| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *5) (|:| |right| *5)))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Record| (|:| |left| *5) (|:| |right| *5))))) ((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *4) (|:| |right| *4)))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *5) (|:| |right| *5)))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|isDomain| *4 (|Record| (|:| |left| *5) (|:| |right| *5)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Record| (|:| |factor| *3) (|:| |degree| *4)))) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Any|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *4 *5))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TangentExpansions| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3)))) ((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Complex| (|Expression| *4))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Complex| *3)) (|isDomain| *1 (|TrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|isDomain| *3 (|List| (|OrderedVariableList| *4))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackage| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|isDomain| *5 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *2 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *2 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|List| (|BasicOperator|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *8 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegrate| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *6 *7 *8))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
+(((*1 *1 *1) (|partial| |ofCategory| *1 (|StepThrough|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|Integer|))))) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|NonNegativeInteger|))))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |factor| *3) (|:| |exponent| (|Integer|))))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|NonNegativeInteger|))))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
 (((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|isDomain| *3 (|List| (|OrderedVariableList| *4))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *1 (|GroebnerSolve| *4 *5 *6)) (|ofCategory| *6 (|GcdDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|EuclideanModularRing| *3 *4 *2 *5 *6 *7)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofType| *5 (|Mapping| *4 *4 *2)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *7 (|Mapping| (|Union| *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ModularField| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|Mapping| *3 *3 *2)) (|ofType| *5 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3 *2)))) ((*1 *2) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ModularRing| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|Mapping| *3 *3 *2)) (|ofType| *5 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3 *2)))) ((*1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ElementaryFunction| *4 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|RadicalCategory|)))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Record| (|:| |high| (|List| (|Symbol|))) (|:| |low| (|List| (|Symbol|))))) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *4)) (|ofCategory| *4 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *4 (|Field|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|PolynomialComposition| *2 *3)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Union| "nil" "sqfr" "irred" "prime")) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AlgebraicFunctionField| *4 *5 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|ofType| *7 *6)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|IrredPolyOverFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|InputForm|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FiniteDivisor| *3 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| (|PrimeField| *3)) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) *2)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|PartialDifferentialRing| *6)) (|isDomain| *2 (|Matrix| *7)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *6 *7 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *7)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *6) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|)))) ((*1 *2 *3) (AND (|ofCategory| *5 (|Join| (|ConvertibleTo| *2) (|CommutativeRing|))) (|isDomain| *2 (|Pattern| *4)) (|isDomain| *1 (|ComplexPattern| *4 *5 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|ComplexCategory| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *2 (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GeneralPolynomialSet| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ConvertibleTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|PointCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RomanNumeral|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *2) (OR (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *4 *5 *6 *7 *8)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|SingletonAsOrderedSet|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *2 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *2 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|SquareFreeRegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *5))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|Polynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|Polynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|SquareFreeRegularTriangularSet| *4 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6)))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|RecurrenceOperator| *4 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Symbol|)) (|PartialDifferentialRing| (|Symbol|)) (|CombinatorialOpsCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *3)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|AlgebraicFunction| *4 *5))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PolynomialInterpolationAlgorithms| *4 *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|Record| (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)) (|:| |points| (|Integer|)) (|:| |connect| (|Integer|)) (|:| |spline| (|Integer|)) (|:| |axes| (|Integer|)) (|:| |axesColor| (|Palette|)) (|:| |units| (|Integer|)) (|:| |unitsColor| (|Palette|)) (|:| |showing| (|Integer|))))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|TranscendentalIntegration| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |special| *3) (|:| |integrand| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Mapping| *6 (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *5 (|List| (|NonNegativeInteger|))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *6))) (|isDomain| *1 (|FractionFreeFastGaussian| *6 *7)) (|ofCategory| *7 (|AbelianMonoidRing| *6 (|NonNegativeInteger|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|d01WeightsPackage|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|Integer|))))) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|NonNegativeInteger|))))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |factor| *3) (|:| |exponent| (|Integer|))))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| (|NonNegativeInteger|))))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|NAGLinkSupportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Matrix| (|Integer|))) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Partition|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
-(((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PrincipalIdealDomain|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FractionFreeFastGaussian| *4 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *4 *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *1 *1) (|partial| |ofCategory| *1 (|StepThrough|)))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *5)))) (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *5))))) 
-(((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| *4))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|SmithNormalForm| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *4 (|List| *6)) (|isDomain| *2 (|Record| (|:| |fs| (|Boolean|)) (|:| |sd| *4) (|:| |td| (|List| *4)))) (|isDomain| *1 (|TableauxBumpers| *6)) (|isDomain| *5 (|List| *4))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|Ring|)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2) (AND (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|isDomain| *3 (|Mapping| (|Boolean|) *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *4 *5)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|Pattern| *5)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Mapping| (|Boolean|) (|List| *6))) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAttachPredicates| *4 *2 *5)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *5 (|Type|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAttachPredicates| *4 *2 *5)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Mapping| (|Boolean|) *5)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|AttachPredicates| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|AttachPredicates| *5)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Mapping| (|Boolean|) (|List| *6))) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|RewriteRule| *4 *5 *6))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)) (|isDomain| *1 (|IntegerCombinatoricFunctions| *2))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *7) (|:| |polj| *7))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5)) (|ofType| *4 (|List| (|Symbol|)))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *10)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *5 (|List| *9)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *4 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *6 *7 *4 *8 *9 *10 *11 *12 *15)) (|ofCategory| *15 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IntersectionDivisorPackage| *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (|ofCategory| *14 (|DesingTreeCategory| *13)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|List| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Tableau| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| *4))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PatternMatchable| *5)) (|isDomain| *2 (|PatternMatchListResult| *5 *6 (|List| *6))) (|isDomain| *1 (|PatternMatch| *5 *6 *4)) (|isDomain| *3 (|List| *6)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|List| (|Equation| *3))) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|RetractableTo| (|Symbol|))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *3)))) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|Ring|)) (|not| (|ofCategory| *3 (|RetractableTo| (|Symbol|)))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|not| (|ofCategory| *3 (|RetractableTo| (|Symbol|)))) (|not| (|ofCategory| *3 (|Ring|))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|NewtonInterpolation| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *2)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Expression| (|Float|)))) (|isDomain| *4 (|List| (|Float|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
 (((*1 *2 *2) (|partial| AND (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *1) (|ofCategory| *1 (|FiniteFieldCategory|)))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *5 *6 *7 *8 *3))))) 
-(((*1 *2 *3 *4 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|ExpressionSpace|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Equation| *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Equation| *1)) (|ofCategory| *1 (|ExpressionSpace|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Mapping| *8 *8)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *7) (|:| |coeff| *7)) "failed") *7)) (|isDomain| *6 (|List| (|Fraction| *8))) (|ofCategory| *7 (|Field|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|isDomain| *3 (|Fraction| *8)) (|isDomain| *2 (|Record| (|:| |answer| (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (|isDomain| *1 (|TranscendentalIntegration| *7 *8))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *2) (|:| |polj| *2))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *4) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *4 *2 *3 *5)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|MonogenicAlgebra| *2 *3))))) 
+(((*1 *1 *2 *2 *2 *2) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatchListResult| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *5 (|ListAggregate| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatchResult| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BalancedBinaryTree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *4 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| *3))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|MonogenicAlgebra| *4 *5)) (|isDomain| *1 (|InfiniteProductFiniteField| *4 *5 *6 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *6)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| *3))) (|isDomain| *1 (|InfiniteProductPrimeField| *4 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|ofCategory| *1 (|FiniteLinearAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|CharacterClass|)))) ((*1 *2 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|ExtAlgBasis|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *2 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Automorphism| *6)) (|isDomain| *5 (|Mapping| *6 *6)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| R (|Matrix| *6)) (|:| A (|Matrix| *6)) (|:| |Ainv| (|Matrix| *6)))) (|isDomain| *1 (|PseudoLinearNormalForm| *6)) (|isDomain| *3 (|Matrix| *6))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *2 (|FunctionSpace| *3)) (|isDomain| *1 (|AlgebraicFunction| *3 *2)) (|ofCategory| *3 (|RetractableTo| *4)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *1 *1 *2 *2 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|)))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *3 *4)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|IndexedAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |mat| (|Matrix| (|Fraction| (|Polynomial| *4)))) (|:| |vec| (|List| (|Fraction| (|Polynomial| *4)))) (|:| |rank| (|NonNegativeInteger|)) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|GaussianFactorizationPackage|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *13)) (|ofCategory| *13 (|DesingTreeCategory| *12)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) *2)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|List| *7) (|List| *7))) (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (AND (|isDomain| *3 (|Record| (|:| |det| *12) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) (|isDomain| *4 (|Matrix| *12)) (|isDomain| *5 (|List| (|Fraction| (|Polynomial| *9)))) (|isDomain| *6 (|List| (|List| *12))) (|isDomain| *7 (|NonNegativeInteger|)) (|isDomain| *8 (|Integer|)) (|ofCategory| *9 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *12 (|PolynomialCategory| *9 *11 *10)) (|ofCategory| *10 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *11 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |eqzro| (|List| *12)) (|:| |neqzro| (|List| *12)) (|:| |wcond| (|List| (|Polynomial| *9))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *9)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *9))))))))) (|isDomain| *1 (|ParametricLinearEquations| *9 *10 *11 *12))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|Finite|)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|SetOfMIntegersInOneToN| *3 *4))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| C (|Matrix| *5)) (|:| |g| (|Vector| *5))))) (|isDomain| *1 (|PseudoLinearNormalForm| *5)) (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Boolean|) (|BasicOperator|) (|BasicOperator|))) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|))))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|FileCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |num| (|Pattern| *3)) (|:| |den| (|Pattern| *3)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3)))) ((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *4))) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|LinearPolynomialEquationByFractions| *4))))) 
-(((*1 *2 *3 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|CharacteristicZero|) (|AlgebraicallyClosedField|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| *5))) (|isDomain| *1 (|Kovacic| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|CharacteristicZero|) (|AlgebraicallyClosedField|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| *6))) (|isDomain| *1 (|Kovacic| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Mapping| (|SparseUnivariatePolynomial| *3) (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegration| *6 *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|AffineSpaceCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|Algebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Field|)) (|ofType| *6 (|Vector| (|Matrix| *3))) (|isDomain| *1 (|AlgebraGivenByStructuralConstants| *3 *4 *5 *6)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|AnyFunctions1| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp10| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) (|isDomain| *1 (|Asp19| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|))) (|isDomain| *1 (|Asp1| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct|) (|construct| (QUOTE X) (QUOTE HESS)) (|MachineFloat|)))) (|isDomain| *1 (|Asp20| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|))) (|isDomain| *1 (|Asp24| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp31| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp35| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE EPS)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp41| *3 *4 *5)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE EPS)) (|construct| (QUOTE YA) (QUOTE YB)) (|MachineFloat|)))) (|isDomain| *1 (|Asp42| *3 *4 *5)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) (|isDomain| *1 (|Asp49| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) (|isDomain| *1 (|Asp4| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) (|isDomain| *1 (|Asp50| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp55| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp6| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp73| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp74| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp77| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp78| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp7| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp80| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|))) (|isDomain| *1 (|Asp9| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 2)) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|CartesianTensor| *3 *4 *5))) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SquareMatrix| *4 *5)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DirectProduct| *4 *5)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Matrix| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|CoerceVectorMatrixPackage| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))) (|isDomain| *1 (|Database| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 10)) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|DirichletRing| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|DirichletRing| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|PositiveInteger|))) (|isDomain| *1 (|DirichletRing| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 (|PositiveInteger|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|DirichletRing| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|DataList| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| (|Expression| *4))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|Float|)))) (|isDomain| *2 (|SegmentBinding| (|Float|))) (|isDomain| *1 (|DrawNumericHack| *4)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|ExtAlgBasis|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|EuclideanModularRing| *3 *2 *4 *5 *6 *7)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4) (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *1 (|ExponentialExpansion| *3 *4 *5 *6)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Expression| *5)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|FiniteAlgebraicExtensionField| *4)) (|isDomain| *1 (|FiniteFieldHomomorphisms| *3 *4 *2)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|FiniteAlgebraicExtensionField| *4)) (|isDomain| *1 (|FiniteFieldHomomorphisms| *2 *4 *3)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|XRecursivePolynomial| *3 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|XDistributedPolynomial| *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|FreeLieAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|MachineFloat|))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileNameCategory|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|ScriptFormulaFormat|)) (|isDomain| *1 (|ScriptFormulaFormat1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FourierComponent| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|AbelianGroup|))) (|isDomain| *1 (|FourierSeries| *3 *4)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))))) ((*1 *1 *2) (AND (|isDomain| *1 (|FourierSeries| *2 *3)) (|ofCategory| *2 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Join| (|OrderedSet|) (|AbelianGroup|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Fraction| *3)))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Fraction| *3))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranScalarType|)) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FortranType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|MachineFloat|))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| *3)))) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *6 (|Vector| (|Matrix| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 16)) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|IndexCard|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|AssociatedJordanAlgebra| *3 *2)) (|ofCategory| *2 (|NonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|CoercibleTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|LeftAlgebra| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XPBWPolynomial| *3 *4)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|AssociatedLieAlgebra| *3 *2)) (|ofCategory| *2 (|NonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Magma| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| *3)))) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| *3)))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3)) (|isDomain| *1 (|MappingPackage1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|MachineInteger|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|MachineFloat|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|Integer|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|MachineInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|MachineInteger|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MakeCachableSet| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |index| *3) (|:| |exponent| *4))) (|isDomain| *1 (|ModuleMonomial| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|SetCategory|)) (|ofType| *5 (|Mapping| (|Boolean|) *2 *2)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |index| *3) (|:| |exponent| *4))) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|ModuleMonomial| *3 *4 *5)) (|ofType| *5 (|Mapping| (|Boolean|) *2 *2)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |coef| *3) (|:| |monom| *4)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)) (|isDomain| *1 (|MonoidRing| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|MyUnivariatePolynomial| *3 *4))) (|ofType| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|MyExpression| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MyUnivariatePolynomial| *3 *4)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|MyUnivariatePolynomial| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MyUnivariatePolynomial| *3 *2)) (|ofType| *3 (|Symbol|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|NonAssociativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| |nia| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |mdnia| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|None|)) (|isDomain| *1 (|NoneFunctions1| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalODEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalODEProblem|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PartialDifferentialRing| *3)) (|isDomain| *1 (|OrdinaryDifferentialRing| *3 *2 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 *3))) ((*1 *1 *2) (AND (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 *3) (|isDomain| *1 (|OrdinaryDifferentialRing| *3 *2 *4)) (|ofCategory| *2 (|PartialDifferentialRing| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathErrorKind|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|UnivariateSkewPolynomial| *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Automorphism| *4)) (|ofType| *6 (|Mapping| *4 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OrdSetInts|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *3 *4 *5 *6)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|List| (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Polynomial| *3)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|List| (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|AlgebraicNumber|))) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PolynomialAN2Expression|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|AlgebraicNumber|)))) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PolynomialAN2Expression|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalPDEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalPDEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Tree| *3)) (|isDomain| *1 (|PendantTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PermutationGroup| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Factored| *3))) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|PartialFraction| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| *3)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Pi|)) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|PiCoercions| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|Partition|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ResolveLatticeCompletion| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Exit|)) (|isDomain| *1 (|ResolveLatticeCompletion| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|ofType| *6 (|List| *2)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|RetractableTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|RationalFunction| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RectangularMatrix| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *4 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 (|IndexedExponents| *4) *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *2 *4)) (|ofCategory| *4 (|PolynomialCategory| *3 (|IndexedExponents| *2) *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|SquareMatrix| *3 *4)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Character|)) (|ofCategory| *1 (|StringAggregate|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Switch|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Symbol|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Table| (|Symbol|) (|FortranType|))) (|isDomain| *1 (|SymbolTable|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Tableau| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|TexFormat|)) (|isDomain| *1 (|TexFormat1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|TaylorSeries| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PrimitiveArray| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Tuple| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| (QUOTE |x|) *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Segment| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|UniversalSegment| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|UnivariatePolynomial| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Variable| *3)) (|ofType| *3 *2))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|GraphImage|)) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Void|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *4)) (|isDomain| *1 (|WeightedPolynomials| *3 *4 *5 *2 *6 *7 *8)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|WeightedPolynomials| *3 *4 *5 *2 *6 *7 *8)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *4)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|XAlgebra| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedMonoid|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *9)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *7 (|NonNegativeInteger|))) (|ofCategory| *9 (|FiniteAbelianMonoidRing| (|Fraction| *7) (|NonNegativeInteger|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|FractionFreeFastGaussianFractions| *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *9)) (|isDomain| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *7 *6)) (|ofCategory| *9 (|FiniteAbelianMonoidRing| (|Fraction| *7) *6)) (|isDomain| *2 (|Stream| (|Matrix| (|SparseUnivariatePolynomial| *7)))) (|isDomain| *1 (|FractionFreeFastGaussianFractions| *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *8)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|AbelianMonoidRing| *7 (|NonNegativeInteger|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|FractionFreeFastGaussian| *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *8)) (|isDomain| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|AbelianMonoidRing| *7 *6)) (|isDomain| *2 (|Stream| (|Matrix| (|SparseUnivariatePolynomial| *7)))) (|isDomain| *1 (|FractionFreeFastGaussian| *7 *8))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|PositiveInteger|)) (|has| *4 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *3 (|PositiveInteger|)) (|has| *4 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|Vector| (|Integer|)))) (|isDomain| *1 (|GrayCode|))))) 
-(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *5 *6 *7 *8))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Union| "prime" "polynomial" "normal" "cyclic"))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3 *3 *2) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Monoid|) (|Finite|) (CATEGORY |package| (SIGNATURE ** (*3 *3 (|Integer|)))))) (|isDomain| *1 (|DiscreteLogarithmPackage| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|FlexibleArray| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofType| *4 (|Integer|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Union| *3 (|List| *1))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|StreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|OpenMathConnection|))))) 
-(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|LinGroebnerPackage| *5 *6))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|CommonOperators|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|ExpressionSpace&| *3)) (|ofCategory| *3 (|ExpressionSpace|)))) ((*1 *2 *2) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpace&| *3 *4)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|List| (|NewSparseUnivariatePolynomial| *3))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|ExpressionTubePlot|)) (|isDomain| *3 (|DoubleFloat|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|Record| (|:| |answer| *3) (|:| |logpart| *3))) (|isDomain| *1 (|AlgebraicHermiteIntegration| *5 *6 *7 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |answer| (|Fraction| *6)) (|:| |logpart| (|Fraction| *6)) (|:| |specpart| (|Fraction| *6)) (|:| |polypart| *6))) (|isDomain| *1 (|TranscendentalHermiteIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Record| (|:| |num| (|Vector| *4)) (|:| |den| *4)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (|ofCategory| *1 (|PAdicIntegerCategory| *2))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|List| (|List| (|Union| (|:| |array| *6) (|:| |scalar| *3))))) (|isDomain| *4 (|List| (|Union| (|:| |array| (|List| *3)) (|:| |scalar| (|Symbol|))))) (|isDomain| *6 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4 *5 *6 *3) (AND (|isDomain| *5 (|List| (|List| (|Union| (|:| |array| *6) (|:| |scalar| *3))))) (|isDomain| *4 (|List| (|Union| (|:| |array| (|List| *3)) (|:| |scalar| (|Symbol|))))) (|isDomain| *6 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4 *5 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|TheSymbolTable|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *2 *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6))))) (|isDomain| *1 (|LexTriangularPackage| *5 *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Stream| (|Polynomial| *4)) (|Stream| (|Polynomial| *4)))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|List| *2) *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *2)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *2))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Record| (|:| |factor| *3) (|:| |degree| *4)))) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ODEIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Record| (|:| |max| (|Union| (|Integer|) "failed")) (|:| |ord| (|Union| (|Integer|) "failed")) (|:| |ker| (|Kernel| *5)))) (|isDomain| *1 (|RecurrenceOperator| *6 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *3 *4)) (|isDomain| *1 (|PatternMatchListResult| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *5 (|ListAggregate| *4))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Matrix| *6))) (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|RepresentationPackage2| *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *6 (|Ring|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage2| *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RepresentationPackage2| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5 *4)) (|isDomain| *1 (|MappingPackage2| *4 *5)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *2 *3 *4 *5)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *2 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *3 *4 *4 *5 *6 *7) (AND (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |mainpart| *4) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (|List| *4))) (|isDomain| *7 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4 *4)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedField|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| *3) (|LinearlyExplicitRingOver| *3))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Record| (|:| |ans| *4) (|:| |right| *4) (|:| |sol?| (|Boolean|)))) (|isDomain| *1 (|ElementaryRischDE| *8 *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *5 (|Finite|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|CliffordAlgebra| *4 *2 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|QuadraticForm| *4 *2)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Expression| *3)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *5)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicStochasticDifferential|)) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|PolynomialCategory| *4 (|IndexedExponents| *5) *5)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Polynomial| *4)) (|isDomain| *1 (|TaylorSeries| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Symbol|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatDE| *4 *2 *3 *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2))))) ((*1 *2 *3 *4) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatDE| *4 *2 *5 *3)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)))))))) 
-(((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *5)) (|Record| (|:| |index| *2) (|:| |exponent| *5)))) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *2 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 (|OrderedVariableList| *3)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|)))) (|isDomain| *1 (|PointsOfFiniteOrderTools| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerPrimesPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| *3)) (|ofType| *3 (|PseudoAlgebraicClosureOfRationalNumber|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfFiniteField| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfRationalNumber|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|String|))) (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|ErrorFunctions|))))) 
-(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *1 *2 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|PackageForPoly| *4 *5 *6 *7)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *2 (|Fraction| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))))) ((*1 *2) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *2 *5)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *2 *5)))) ((*1 *2) (|partial| AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *2 *4)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *7)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *2 *7 *4)) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Set| (|Symbol|))) (|isDomain| *1 (|ApplicationProgramInterface|)) (|isDomain| *3 (|Symbol|))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Result|))))) 
-(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|GuessFiniteFunctions| *3)) (|ofCategory| *3 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|))))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| *8))) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| *6))) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2) (AND (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|CardinalNumber|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|CardinalNumber|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PointCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|VectorSpace| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|CardinalNumber|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|))))) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *2 (|Record| (|:| |part1| *3) (|:| |part2| *4))) (|isDomain| *1 (|MakeRecord| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Tuple| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|RadicalCategory|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Mapping| *4 (|Integer|) (|Integer|))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|OutputForm|)))) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SquareMatrix| *3 *4)) (|isDomain| *1 (|QuadraticForm| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *5))) (|ofCategory| *5 (|Ring|)) (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelThreeSpace|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|AxiomServer|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Database| (|IndexCard|))) (|isDomain| *1 (|OperationsQuery|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |radval| (|Expression| (|Integer|))) (|:| |radmult| (|Integer|)) (|:| |radvect| (|List| (|Matrix| (|Expression| (|Integer|)))))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|MonogenicLinearOperator| *3)) (|isDomain| *1 (|OppositeMonogenicLinearOperator| *2 *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|Ring|) (|Module| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|XExponentialPackage| *4 *5 *2)) (|ofCategory| *2 (|XPolynomialsCat| *5 *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SplittingTree| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|List| (|Point| *3)))))))) 
-(((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Integer|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| *2) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *1 (|MappingPackage1| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|List| *5) (|List| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|MappingPackage1| *5)) (|ofCategory| *5 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|LyndonWord| *3)) (|:| |c| *4)))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (|Integer|))))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *3))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *3 *5 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|d02AgentsPackage|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *6 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *6)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FileCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Library|)))) 
-(((*1 *2 *3 *3 *3 *4 *5) (AND (|isDomain| *5 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|List| (|Point| *4))) (|isDomain| *1 (|TubePlotTools|)) (|isDomain| *3 (|Point| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
-(((*1 *1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *8 (|PlacesCategory| *4 *7)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *8)) (|isDomain| *4 (|AffinePlane| *8)) (|isDomain| *9 (|Symbol|)) (|ofCategory| *8 (|Field|)) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *12 (|DirectProductCategory| (|#| *10) *5)) (|ofCategory| *13 (|LocalPowerSeriesCategory| *8)) (|ofCategory| *14 (|PlacesCategory| *8 *13)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *8 *10 *11 *12 *2 *13 *14 *7 *6)) (|ofCategory| *11 (|PolynomialCategory| *8 *12 (|OrderedVariableList| *10))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *8)) (|ofCategory| *7 (|DivisorCategory| *14)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *1) (|isDomain| *1 (|SingletonAsOrderedSet|)))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|d03AgentsPackage|))))) 
-(((*1 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 *3)) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) *3 *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 HPSPEC) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|HeuGcd| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ApplicationProgramInterface|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *2 (|PolynomialCategory| *4 *6 *5)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *2)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|))))) 
-(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Union| "nil" "sqfr" "irred" "prime")) (|isDomain| *1 (|Factored| *4)) (|ofCategory| *4 (|IntegralDomain|))))) 
-(((*1 *1) (|isDomain| *1 (|ThreeDimensionalViewport|)))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *3 *2)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|Tuple| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|ConvertibleTo| (|Pattern| *3))) (|ofCategory| *3 (|PatternMatchable| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|ConvertibleTo| (|Pattern| *3))) (|ofCategory| *2 (|PatternMatchable| *3)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|)))) (|isDomain| *7 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|)))) (|isDomain| *7 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *2 *3 *4 *2 *2 *5) (|partial| AND (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *3 (|Kernel| *4)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|DefiniteIntegrationTools| *6 *4))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|GeneralPolynomialGcdPackage| *3 *4 *2 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2) (AND (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|NPCoef| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Kernel| *5))) (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |special| *3) (|:| |integrand| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|OrderedCompletion| *2)) (|ofCategory| *2 (|SpecialFunctionCategory|)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|PatternMatchIntegration| *5 *2))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *2 (|List| (|Expression| *6))) (|isDomain| *1 (|DegreeReductionPackage| *5 *6)) (|isDomain| *3 (|Expression| *6)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|IntegrationResultToFunction| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|List| (|Expression| *4))) (|isDomain| *1 (|IntegrationResultRFToFunction| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentExpansionCategory| *3 *2)) (|ofCategory| *3 (|OrderedRing|)) (|ofCategory| *2 (|StreamAggregate| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|SegmentExpansionCategory| *4 *2)) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *2 (|StreamAggregate| *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| (|Symbol|) *3)) (|isDomain| *1 (|XPolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *1) (|isDomain| *1 (|Void|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternFunctions1| *4 *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Tableau| (|List| *4))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|RationalLODE| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |basis| (|List| (|Fraction| *6))) (|:| |mat| (|Matrix| *5)))) (|isDomain| *1 (|RationalLODE| *5 *6)) (|isDomain| *4 (|List| (|Fraction| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|RationalLODE| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |basis| (|List| (|Fraction| *6))) (|:| |mat| (|Matrix| *5)))) (|isDomain| *1 (|RationalLODE| *5 *6)) (|isDomain| *4 (|List| (|Fraction| *6)))))) 
-(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *1 *1 *2 *2) (|partial| AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 *2) (|ofType| *4 *2)))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|isDomain| *1 (|IncrementingMaps| *3)) (|ofCategory| *3 (|Join| (|Monoid|) (|AbelianSemiGroup|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultantReduit| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SubSpaceComponentProperty|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|DifferentialVariableCategory| *3)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Vector| (|List| (|Integer|)))) (|isDomain| *1 (|HallBasis|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4))))) 
-(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Matrix| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| *5)) (|:| |coeff| (|Fraction| *5)))) (|isDomain| *1 (|RationalIntegration| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranType|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |cd| (|String|)) (|:| |name| (|String|)))) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Equation| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |varOrder| (|List| (|Symbol|))) (|:| |inhom| (|Union| (|List| (|Vector| (|NonNegativeInteger|))) "failed")) (|:| |hom| (|List| (|Vector| (|NonNegativeInteger|)))))) (|isDomain| *1 (|DiophantineSolutionPackage|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *9 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|isDomain| *2 (|Record| (|:| |mult| (|NonNegativeInteger|)) (|:| |subMult| (|NonNegativeInteger|)) (|:| |blUpRec| (|List| (|Record| (|:| |recTransStr| (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *6)) (|:| |recPoint| (|AffinePlane| *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (|isDomain| *1 (|BlowUpPackage| *6 *7 *8 *9 *5)) (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *6)) (|isDomain| *4 (|AffinePlane| *6)) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *6 *9)) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ComplexDoubleFloatMatrix|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ComplexDoubleFloatVector|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloatMatrix|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloatVector|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U16Matrix|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U32Matrix|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U8Matrix|))))) 
-(((*1 *1 *2 *1) (|partial| AND (|isDomain| *2 (|BasicStochasticDifferential|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Union| (|Boolean|) "failed")) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *6)) (|:| |tower| *7)))) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *6)) (|:| |tower| *7)))) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|NonNegativeInteger|)))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1) (|ofCategory| *1 (|StepThrough|)))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| (|List| *7) *7 (|SparseUnivariatePolynomial| *7))) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |frac| (|Fraction| *7)) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *6 *7 *3 *8)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *7)) (|ofCategory| *8 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *7))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |frac| (|Fraction| *6)) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) (|isDomain| *1 (|RationalRicDE| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|TriangularMatrixOperations| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *6)) (|ofCategory| *6 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|ModularHermitianRowReduction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Record| (|:| |particular| *1) (|:| |basis| (|List| *1)))) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)))) ((*1 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |particular| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|:| |basis| (|List| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemContinuityPackage1| *4 *5)) (|ofType| *4 *3) (|ofType| *5 *3))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ExtAlgBasis|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *8)) (|isDomain| *4 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|Ring|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|FactoringUtilities| *5 *6 *7 *8)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|GradedModule| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|AbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *5 *3 *6 *7)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *6)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *2 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategoryWithDegree|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|LexTriangularPackage| *5 *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|)) (|isDomain| *3 (|Expression| (|Integer|)))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (|isDomain| *1 (|d01AgentsPackage|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Record| (|:| |start| *3) (|:| |factors| (|Factored| *3)))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
 (((*1 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
-(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|HallBasis|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *4 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedMonoid|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|OrderedVariableList| *5))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |dpolys| (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|:| |coords| (|List| (|Integer|))))) (|isDomain| *1 (|GroebnerSolve| *5 *6 *7)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *7 (|GcdDomain|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| *8)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *8)) (|isDomain| *1 (|FactoringUtilities| *6 *7 *8 *9))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|FunctionSpaceReduce| *4 *3)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|FunctionSpace| *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceReduce| *5 *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *5 (|RetractableTo| (|AlgebraicNumber|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Complex| (|DoubleFloat|)))) (|isDomain| *1 (|ComplexDoubleFloatVector|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Vector| *3))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *1 *1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
-(((*1 *2 *2 *2 *3 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|Symbol|)) (|:| |c| (|XPolynomial| *3))))) (|isDomain| *1 (|XPolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| *3) (|:| |c| (|XRecursivePolynomial| *3 *4))))) (|isDomain| *1 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *2 *2 *2 *3 *4) (AND (|isDomain| *3 (|Automorphism| *5)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *2)) (|ofCategory| *2 (|UnivariateSkewPolynomialCategory| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|NonCommutativeOperatorDivision| *3 *4)) (|ofCategory| *3 (|MonogenicLinearOperator| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |lm| (|FreeMonoid| *3)) (|:| |mm| (|FreeMonoid| *3)) (|:| |rm| (|FreeMonoid| *3)))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |lm| (|OrderedFreeMonoid| *3)) (|:| |mm| (|OrderedFreeMonoid| *3)) (|:| |rm| (|OrderedFreeMonoid| *3)))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|RationalFunction| *4))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *4) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *12 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (|ofCategory| *3 (|DesingTreeCategory| *13))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|MatrixCategory| *7 *8 *9)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *2)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *2 *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *2 *4)) (|ofCategory| *4 (|EuclideanDomain|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|SquareMatrix| *3 *4)) (|ofType| *3 (|NonNegativeInteger|))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialExtension| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|DifferentialExtension| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DifferentialRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|DifferentialRing|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|PartialDifferentialRing| *3)) (|isDomain| *1 (|IntegrationResult| *2)) (|isDomain| *3 (|Symbol|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PartialDifferentialRing| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PartialDifferentialRing| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *4 (|String|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|RewriteRule| *3 *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3))))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Vector| (|Vector| *5))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *4 (|Vector| *5))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |center| *5) (|:| |equation| *5)))) (|isDomain| *1 (|PrimitiveRatDE| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |center| *4) (|:| |equation| *4)))) (|isDomain| *1 (|PrimitiveRatDE| *5 *4 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |center| *5) (|:| |equation| *5)))) (|isDomain| *1 (|PrimitiveRatDE| *4 *5 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |center| *4) (|:| |equation| *4)))) (|isDomain| *1 (|PrimitiveRatDE| *5 *4 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |gblist| (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|:| |gvlist| (|List| (|Integer|))))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Vector| *2)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *6 (|QuotientFieldCategory| *5)) (|ofCategory| *2 (|Join| (|FramedAlgebra| *6 *7) (|RetractableTo| *6))) (|isDomain| *1 (|FractionalIdeal| *5 *6 *7 *2)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *3 (|None|)) (|isDomain| *1 (|Any|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Void|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5 *4)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MappingPackage3| *5 *4 *6))))) 
+(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroup| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroupExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|SparseUnivariatePolynomial| *3)))) ((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroupExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DrawComplex|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Fraction| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|PrimitiveRatDE| *5 *2 *3 *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|PrimitiveRatDE| *5 *2 *3 *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Database| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| (*2 $)) (SIGNATURE |fullDisplay| (*2 $))))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Database| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| (*2 $)) (SIGNATURE |fullDisplay| (*2 $))))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IndexCard|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |prime| (|Integer|)) (|:| |factors| (|List| *3)))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|OrderedVariableList| *5))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|List| (|DistributedMultivariatePolynomial| *5 *6)))) (|isDomain| *1 (|GroebnerSolve| *5 *6 *7)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *7 (|GcdDomain|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3 *1) (|partial| AND (|ofCategory| *1 (|KeyedDictionary| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|Multiset| *4)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *3 (|None|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|)))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *4)))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *4))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *8) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *8))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)) (|isDomain| *4 (|NonNegativeInteger|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|)))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|UnivariatePolynomial| *5 *4))) (|isDomain| *1 (|SturmHabichtPackage| *4 *5)) (|isDomain| *3 (|UnivariatePolynomial| *5 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |value| *4) (|:| |weight| (|Integer|))))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| *4)) (|isDomain| *1 (|RandomDistributions| *4))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *3 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|ProjectivePlane| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *8 (|PlacesCategory| *4 *7)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)))) ((*1 *1 *2 *3 *4 *5 *6 *5 *7 *8 *9) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *8)) (|isDomain| *4 (|AffinePlane| *8)) (|isDomain| *9 (|Symbol|)) (|ofCategory| *8 (|Field|)) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *12 (|DirectProductCategory| (|#| *10) *5)) (|ofCategory| *13 (|LocalPowerSeriesCategory| *8)) (|ofCategory| *14 (|PlacesCategory| *8 *13)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *8 *10 *11 *12 *2 *13 *14 *7 *6)) (|ofCategory| *11 (|PolynomialCategory| *8 *12 (|OrderedVariableList| *10))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *8)) (|ofCategory| *7 (|DivisorCategory| *14)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *1) (|isDomain| *1 (|SingletonAsOrderedSet|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SortPackage| *4 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|SortPackage| *3 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *3) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|))))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *7))) (|isDomain| *4 (|Mapping| (|List| *6) *7)) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|List| (|Fraction| *7))) (|isDomain| *1 (|RationalRicDE| *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *7 (|Fraction| *7))) (|isDomain| *4 (|Mapping| (|List| *6) *7)) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|List| (|Fraction| *7))) (|isDomain| *1 (|RationalRicDE| *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|RationalRicDE| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|AlgebraicallyClosedField|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *5 (|Fraction| *5))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|RationalRicDE| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|AlgebraicallyClosedField|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| (|List| *7) *7 (|SparseUnivariatePolynomial| *7))) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |frac| (|Fraction| *7)) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *6 *7 *3 *8)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *7)) (|ofCategory| *8 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *7))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |frac| (|Fraction| *6)) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) (|isDomain| *1 (|RationalRicDE| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| (|List| *6))) (|isDomain| *1 (|GenExEuclid| *4 *6)) (|isDomain| *5 (|List| *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |cont| *5) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|DistinctDegreeFactorize| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Expression| (|Fraction| (|Integer|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *2 *5)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *2 *5)))) ((*1 *2) (|partial| AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *2 *4)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Complex| (|Expression| *4))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Complex| *3)) (|isDomain| *1 (|TrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |a| *6) (|:| |b| (|Fraction| *6)) (|:| |c| (|Fraction| *6)) (|:| |t| *6))) (|isDomain| *1 (|TranscendentalRischDE| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|BasicOperatorFunctions1| *2))))) 
-(((*1 *1 *1) (AND (|ofCategory| *2 (|CharacteristicZero|)) (|ofCategory| *2 (|EuclideanDomain|)) (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|AlgebraicNumber|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|SimplifyAlgebraicNumberConvertPackage|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *4 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *4 *5 *6 *3))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Vector| *1)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|CharacteristicNonZero|)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Vector| *1))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *2 *2 *3 *4) (AND (|isDomain| *3 (|Automorphism| *5)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *2)) (|ofCategory| *2 (|UnivariateSkewPolynomialCategory| *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|ofCategory| *2 (|Ring|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |func| *3) (|:| |kers| (|List| (|Kernel| *3))) (|:| |vals| (|List| *3)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp12| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp29| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp33| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FortranProgramCategory|)) (|isDomain| *2 (|Void|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FileName|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
-(((*1 *1) (|isDomain| *1 (|Color|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *2 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *1 *2 *2 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileNameCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RetractableTo| (|Integer|))) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *2 (|EuclideanDomain|)) (|ofCategory| *3 (|QuotientFieldCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|FractionalIdeal| *2 *3 *4 *5)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *3 *4) (|RetractableTo| *3)))))) 
-(((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Union| "left" "center" "right" "vertical" "horizontal"))))) 
-(((*1 *2 *3 *3 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1) (AND (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)))) ((*1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (|isDomain| *1 (|TheSymbolTable|))) ((*1 *1) (|isDomain| *1 (|SymbolTable|)))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|RationalFunction| *4))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|PlacesCategory| *5 *8)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *5 *6 *4 *7 *3 *8 *2)) (|ofCategory| *4 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinesOpPack| *4))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| (|Symbol|))) (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|Vector| (|Matrix| *4))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| *2)) (|ofType| *7 (|Vector| (|Matrix| *4))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Symbol|))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| *2)) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1) (AND (|isDomain| *1 (|GenericNonAssociativeAlgebra| *2 *3 *4 *5)) (|ofCategory| *2 (|CommutativeRing|)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|Vector| (|Matrix| *2)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|CRApackage| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|List| *4))) (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|Record| (|:| |basis| (|Matrix| *7)) (|:| |basisDen| *7) (|:| |basisInv| (|Matrix| *7))))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *7)) (|:| |basisDen| *7) (|:| |basisInv| (|Matrix| *7)))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|d03AgentsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *5 *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *6) (|:| |coeff| *6)) "failed") *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Union| (|Record| (|:| |answer| (|Fraction| *7)) (|:| |a0| *6)) (|Record| (|:| |ratpart| (|Fraction| *7)) (|:| |coeff| (|Fraction| *7))) "failed")) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |unit| *1) (|:| |canonical| *1) (|:| |associate| *1))) (|ofCategory| *1 (|IntegralDomain|))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|SubSpaceComponentProperty|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 (|Integer|))))) 
+(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Integer|)) (|ofCategory| *6 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3)))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *1 *1 *2 *1) (AND (|isDomain| *1 (|BinaryTree| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|BinaryTree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|TubePlot| *3)) (|isDomain| *1 (|NumericTubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|TubePlot| *2)) (|ofCategory| *2 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *4))))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *4))))) (|isDomain| *1 (|RadicalSolvePackage| *4))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *2 *3 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *3) (|:| |xpnt| (|Integer|))))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *3))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *3 *5 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *1 (|FileCategory| *2 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|FileCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|))))) 
+(((*1 *1 *1 *2 *1) (AND (|ofCategory| *1 (|BinaryTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *4)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *3 (|DivisorCategory| *11)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *3 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *5 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) *4)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|isDomain| *1 (|InterpolateFormsPackage| *6 *7 *5 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *3 (|DivisorCategory| *11)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Kernel| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *14)) (|ofCategory| *14 (|DesingTreeCategory| *13)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *12 *15)) (|ofCategory| *15 (|BlowUpMethodCategory|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *1 (|PartitionsAndPermutations|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *4 *2 *5 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *2 *6 *7 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|InnerModularGcd| *4 *2 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofType| *5 *4) (|ofType| *6 (|Mapping| *4 *4 (|NonNegativeInteger|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4))))) 
+(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *4) (|:| |ineq| (|List| *9)))) (|isDomain| *1 (|QuasiComponentPackage| *6 *7 *8 *9 *4)) (|isDomain| *3 (|List| *9)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *4) (|:| |ineq| (|List| *9)))) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *6 *7 *8 *9 *4)) (|isDomain| *3 (|List| *9)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *9))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *1 (|NormalizationPackage| *4 *5 *6 *2 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FGLMIfCanPackage| *4 *5)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *5)))) (|ofCategory| *4 (|GcdDomain|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LexTriangularPackage| *4 *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| *7 *5 *6)) (|isDomain| *1 (|MakeBinaryCompiledFunction| *3 *5 *6 *7)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MakeUnaryCompiledFunction| *3 *5 *6)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| AND (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |mainpart| *4) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (|List| *4))) (|isDomain| *7 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4 *4)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedField|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| *3) (|LinearlyExplicitRingOver| *3))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|ElementaryRischDESystem| *8 *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GenExEuclid| *5 *3))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Equation| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |varOrder| (|List| (|Symbol|))) (|:| |inhom| (|Union| (|List| (|Vector| (|NonNegativeInteger|))) "failed")) (|:| |hom| (|List| (|Vector| (|NonNegativeInteger|)))))) (|isDomain| *1 (|DiophantineSolutionPackage|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| (|Integer|)))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *4)))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *4)))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *2 (|Record| (|:| |particular| *4) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|ElementaryFunctionLODESolver| *6 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ElementaryFunctionLODESolver| *6 *2 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5)))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|List| (|Vector| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5)))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|List| (|Vector| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *7 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| *7 "failed")) (|:| |basis| (|List| *7))))) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *7 *3)) (|isDomain| *4 (|List| *7)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|NonLinearSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|NonLinearSolvePackage| *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|NonLinearFirstOrderODESolver| *5 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *5) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Matrix| *7)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)) (|isDomain| *4 (|Vector| *7)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedFunctionSpace| *5) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Vector| *6))) (|isDomain| *1 (|ElementaryFunctionODESolver| *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| (|Equation| *7))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Union| (|Record| (|:| |particular| *7) (|:| |basis| (|List| *7))) *7 "failed")) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Union| (|Record| (|:| |particular| *3) (|:| |basis| (|List| *3))) *3 "failed")) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *3 (|Equation| *2)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *2)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))))) ((*1 *2 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Equation| *2)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |particular| *6) (|:| |basis| (|List| *6))) "failed") *7 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *6)) (|:| |basis| (|Matrix| *6)))) (|isDomain| *1 (|SystemODESolver| *6 *7)) (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Vector| *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *6 (|List| (|List| (|Expression| *3)))) (|isDomain| *7 (|String|)) (|isDomain| *8 (|DoubleFloat|)) (|isDomain| *5 (|List| (|Expression| (|Float|)))) (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *6 (|List| (|List| (|Expression| *3)))) (|isDomain| *7 (|String|)) (|isDomain| *5 (|List| (|Expression| (|Float|)))) (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *4 (|Float|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *4 (|Float|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|TransSolvePackage| *4)) (|isDomain| *3 (|Expression| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|TransSolvePackage| *4)) (|isDomain| *3 (|Equation| (|Expression| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|Equation| (|Expression| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|Expression| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|List| (|Equation| (|Expression| *5)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|SystemSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|SystemSolvePackage| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|Fraction| (|Polynomial| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *4))))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Union| (|Fraction| (|Polynomial| *5)) (|SuchThat| (|Symbol|) (|Polynomial| *5)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|EigenPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5))))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Point| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|Record| (|:| |%term| (|Record| (|:| |%coef| (|UnivariatePuiseuxSeries| *4 *5 *6)) (|:| |%expon| (|ExponentialOfUnivariatePuiseuxSeries| *4 *5 *6)) (|:| |%expTerms| (|List| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| *4)))))) (|:| |%type| (|String|)))) (|isDomain| *1 (|UnivariatePuiseuxSeriesWithExponentialSingularity| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4)))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
+(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Kernel| *2))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *5)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *5 *6 *2)) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1) (|isDomain| *1 (|Character|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *2 *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|CommonDenominator| *3 *4 *2)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|InnerCommonDenominator| *4 *5 *2 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|MatrixCommonDenominator| *4 *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *3 *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *1 *2 *2 *3 *1 *4) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|PseudoAlgebraicClosureOfRationalNumber|))) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Symbol|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfRationalNumber|))))) 
+(((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|)))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *2 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|PatternMatchResult| *4 *5)) (|isDomain| *3 (|PatternMatchResult| *4 *6)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|ListAggregate| *5)) (|isDomain| *1 (|PatternMatchListResult| *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PatternFunctions1| *4 *5)) (|ofCategory| *5 (|Type|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|Integer|))) (|isDomain| *1 (|Infinity|)))) ((*1 *1) (AND (|isDomain| *1 (|OnePointCompletion| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 (|NonNegativeInteger|) *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks1| *2)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Mapping| *3 (|NonNegativeInteger|) *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|MappingPackage1| *3))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Mapping| (|SparseUnivariatePolynomial| *3) (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegration| *6 *3))))) 
+(((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *1 (|XFreeAlgebra| *4 *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Database| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| (*2 $)) (SIGNATURE |fullDisplay| (*2 $))))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Database| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| (*2 $)) (SIGNATURE |fullDisplay| (*2 $))))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IndexCard|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricPlaneCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricSpaceCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricSurface| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|HallBasis|))))) 
+(((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|XRecursivePolynomial| *4 *2)) (|ofCategory| *1 (|FreeLieAlgebra| *4 *2)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *1 (|XFreeAlgebra| *4 *2)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *3 (|OrderedMonoid|))))) 
+(((*1 *2 *3 *4 *5) (AND (|ofCategory| *6 (|UnivariatePolynomialCategory| *9)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|EuclideanDomain|)) (|ofCategory| *10 (|PolynomialCategory| *9 *7 *8)) (|isDomain| *2 (|Record| (|:| |deter| (|List| (|SparseUnivariatePolynomial| *10))) (|:| |dterm| (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| *10))))) (|:| |nfacts| (|List| *6)) (|:| |nlead| (|List| *10)))) (|isDomain| *1 (|NPCoef| *6 *7 *8 *9 *10)) (|isDomain| *3 (|SparseUnivariatePolynomial| *10)) (|isDomain| *4 (|List| *6)) (|isDomain| *5 (|List| *10))))) 
+(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|InputForm|))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Kernel| *7)) (|ofCategory| *7 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| *2) (|RetractableTo| *5) (|PartialDifferentialRing| *5) (|CombinatorialOpsCategory|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RecurrenceOperator| *6 *7))))) 
+(((*1 *2 *1 *3 *3 *4 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *4 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ExtAlgBasis|))))) 
+(((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|List| (|PrimitiveArray| (|DoubleFloat|)))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|)))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|PermutationCategory| *3))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| (|Complex| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *5)))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| (|Complex| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|ExpressionTubePlot|)) (|isDomain| *3 (|DoubleFloat|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| (|Mapping| *4 (|List| *4)))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|List| (|Mapping| *4 (|List| *4)))) (|isDomain| *1 (|BasicOperatorFunctions1| *4)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForAlgebraicCurves| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricPlaneCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricPlaneCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|has| *6 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *3) (AND (|has| *9 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *10)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *10 (|MatrixCategory| *7 *8 *9)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| *7))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Void|))))) 
 (((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *3 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *5)) *4 *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|isDomain| *1 (|PushVariables| *4 *5 *3 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PushVariables| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *1 *1) (|ofCategory| *1 (|OrderedAbelianMonoidSup|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|d01WeightsPackage|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|Kernel| *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|SmithNormalForm| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatDE| *4 *2 *3 *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2))))) ((*1 *2 *3 *4) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatDE| *4 *2 *5 *3)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
 (((*1 *1 *2 *2) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|CliffordAlgebra| *2 *3 *4)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|QuadraticForm| *2 *3)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|Monoid|))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *3))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *2 *1) (|partial| AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|RationalFunctionIntegration| *4))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *2 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|MakeFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|)))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|QuotientFieldCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|FractionalIdeal| *2 *3 *4 *5)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *3 *4) (|RetractableTo| *3))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)) (|isDomain| *1 (|LocalAlgebra| *3 *4 *2)) (|ofCategory| *3 (|Algebra| *4)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)) (|isDomain| *1 (|Localize| *3 *4 *2)) (|ofCategory| *3 (|Module| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *4 (|Union| "left" "center" "right" "vertical" "horizontal")) (|ofCategory| *1 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|RightOpenIntervalRootCharacterization| (|RealClosure| *3) (|SparseUnivariatePolynomial| (|RealClosure| *3)))) (|isDomain| *1 (|RealClosure| *3)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)))))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |det| *8) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3 *4 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|Algebra| *3)) (|isDomain| *1 (|LocalAlgebra| *2 *3 *4)) (|ofCategory| *4 (|SubsetCategory| (|Monoid|) *3)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|Module| *3)) (|isDomain| *1 (|Localize| *2 *3 *4)) (|ofCategory| *4 (|SubsetCategory| (|Monoid|) *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Record| (|:| |num| (|Vector| *4)) (|:| |den| *4)))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BalancedBinaryTree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|GraphImage|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *1 *1) (|isDomain| *1 (|TwoDimensionalViewport|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
 (((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|InnerModularGcd| *4 *2 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofType| *5 *4) (|ofType| *6 (|Mapping| *4 *4 (|NonNegativeInteger|)))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *1 *1) (|isDomain| *1 (|Boolean|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |integrand| *3) (|:| |intvar| *3)))) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
-(((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|List| (|Kernel| *2))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *5 *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Mapping| (|InputForm|) (|List| (|InputForm|)))) (|isDomain| *1 (|BasicOperator|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|InputForm|) (|List| (|InputForm|)))) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|List| (|Integer|)))) (|isDomain| *1 (|Partition|)) (|isDomain| *3 (|List| (|Integer|)))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|OrderedRing|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *5 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *4))))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *3))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Polynomial| *5)))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Polynomial| *5))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|StructuralConstantsPackage| *4))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathDevice|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OrderedVariableList| *3)) (|ofType| *3 (|List| *2)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|QueryEquation|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|SegmentBinding| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Symbol|)))) ((*1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Variable| *3)) (|ofType| *3 *2)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *2 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *2 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Expression| *3)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofType| *4 (|List| (|Symbol|)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| (|Fraction| (|Integer|))))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7))))) (|ofCategory| *7 (|OrderedRing|)) (|ofCategory| *8 (|Join| (|UnivariatePowerSeriesCategory| *3 *7) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *2 (|Union| (|:| |%series| *8) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *6 *3 *7 *8 *9 *10)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PartialTranscendentalFunctions| *8)) (|ofType| *10 (|Symbol|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|OrderedRing|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *1 *1 *2 *1) (AND (|ofCategory| *1 (|BinaryTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Record| (|:| |lcmfij| *6) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *4) (|:| |polj| *4))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *4))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
-(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|PermutationCategory| *3))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *2)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|))))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|XDistributedPolynomial| (|Symbol|) *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|XPolynomial| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|XRecursivePolynomial| *3 *4))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Mapping| (|InputForm|) (|List| (|InputForm|)))) (|isDomain| *1 (|BasicOperator|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|InputForm|) (|List| (|InputForm|)))) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerPrimesPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *4 (|Integer|))) (|isDomain| *5 (|Mapping| (|Stream| *4))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|isDomain| *2 (|Matrix| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|ElementaryFunctionCategory|))) ((*1 *2 *3) (AND (|isDomain| *3 (|Factored| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Record| (|:| |coef| (|NonNegativeInteger|)) (|:| |logand| *4)))) (|isDomain| *1 (|FactoredFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|Ring|) (|Module| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|XExponentialPackage| *4 *5 *2)) (|ofCategory| *2 (|XPolynomialsCat| *5 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *4 (|Module| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| (|List| *6))) (|isDomain| *1 (|GenExEuclid| *4 *6)) (|isDomain| *5 (|List| *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Factored| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *5) (|:| |radicand| (|List| *5)))) (|isDomain| *1 (|FactoredFunctions| *5)) (|isDomain| *4 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RadicalCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinesOpPack| *4))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PermutationGroup| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|AssociatedEquations| *4 *5)) (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
-(((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3)))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *10)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *5 (|List| *9)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *4 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *6 *7 *4 *8 *9 *10 *11 *12 *15)) (|ofCategory| *15 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IntersectionDivisorPackage| *6 *7 *4 *8 *9 *10 *11 *12 *13 *14 *15)) (|ofCategory| *14 (|DesingTreeCategory| *13)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|List| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|U32Vector|))) (|isDomain| *1 (|U32VectorPolynomialOperations|)) (|isDomain| *3 (|U32Vector|))))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| (|List| *8))) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|isDomain| *2 (|Record| (|:| |unitPart| *9) (|:| |suPart| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *9)) (|:| |exponent| (|Integer|))))))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *3 (|SparseUnivariatePolynomial| *9))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *1 (|FortranType|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5 *4)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| *4)))) (|:| |xValues| (|Segment| *4)) (|:| |yValues| (|Segment| *4)))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|List| (|Point| *4))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|Record| (|:| |id| (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |poly| *6) (|:| |normal| (|Fraction| *6)) (|:| |special| (|Fraction| *6)))) (|isDomain| *1 (|MonomialExtensionTools| *5 *6)) (|isDomain| *3 (|Fraction| *6)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialDecomposition| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *4) (|partial| AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |left| *3) (|:| |right| *3))) (|isDomain| *1 (|PolynomialDecomposition| *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *2 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Vector| (|Expression| (|Float|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Record| (|:| |zeros| (|Stream| (|DoubleFloat|))) (|:| |ones| (|Stream| (|DoubleFloat|))) (|:| |singularities| (|Stream| (|DoubleFloat|))))) (|isDomain| *1 (|BasicFunctions|))))) 
 (((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|Kernel| *4))) (|ofCategory| *4 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *3 *4)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|PatternMatchResult| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 *2)) (|ofType| *6 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *4 *2)) (|ofCategory| *2 (|LeftModule| *4)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *1 *1 *1) (|partial| |ofCategory| *1 (|CancellationAbelianMonoid|)))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
+(((*1 *2 *2 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|ApplyRules| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4))))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|String|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *1 *1) (|isDomain| *1 (|ThreeDimensionalViewport|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Stream| *3))) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PermutationGroup| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Record| (|:| |num| (|Matrix| *5)) (|:| |den| *5)))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Quaternion| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|Octonion| *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|CommutativeRing|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|BasicStochasticDifferential|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|TwoFactorize| *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *5)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *4 *5 *6 *7)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| *3)) (|ofType| *7 *3))) ((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofType| *8 (|List| *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|WeightedPolynomials| *4 *5 *6 *7 *8 *9 *10)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofType| *9 (|List| *3)) (|ofType| *10 *3)))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *3)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|LinGroebnerPackage| *5 *6))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |special| *3) (|:| |integrand| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *6)))) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|GraphImage|))))) 
 (((*1 *2 *1 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *2 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *2 *1) (AND (|isDomain| *2 "right") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2 *1) (AND (|isDomain| *2 "left") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *2 (|Any|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|Library|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *3 (|UniversalSegment| (|Integer|))) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|LinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *3 "value") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *2) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|ofCategory| *1 (|TableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *3 "last") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2 *1) (AND (|isDomain| *2 "rest") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *3 "first") (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *3 *4 *2 *5 *6) (AND (|isDomain| *5 (|Record| (|:| |done| (|List| *11)) (|:| |todo| (|List| (|Record| (|:| |val| *3) (|:| |tower| *11)))))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *10)) (|:| |tower| *11)))) (|isDomain| *3 (|List| *10)) (|isDomain| *4 (|List| *11)) (|ofCategory| *10 (|RecursivePolynomialCategory| *7 *8 *9)) (|ofCategory| *11 (|RegularTriangularSetCategory| *7 *8 *9 *10)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (AND (|isDomain| *5 (|Record| (|:| |done| (|List| *11)) (|:| |todo| (|List| (|Record| (|:| |val| *3) (|:| |tower| *11)))))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *10)) (|:| |tower| *11)))) (|isDomain| *3 (|List| *10)) (|isDomain| *4 (|List| *11)) (|ofCategory| *10 (|RecursivePolynomialCategory| *7 *8 *9)) (|ofCategory| *11 (|SquareFreeRegularTriangularSetCategory| *7 *8 *9 *10)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *7 *8 *9 *10 *11))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|List| (|List| *3))))) ((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|List| (|List| *3))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|List| (|List| *5))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|Tableau| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *2 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "right") (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "left") (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 (|Integer|)) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *2)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|DataList| (|String|))) (|isDomain| *1 (|Database| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ *3)) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|QueryEquation|)) (|isDomain| *1 (|Database| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "count") (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DataList| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "sort") (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "unique") (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Eltable| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *3 *2 *4 *5 *6 *7)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *2 *1 *1 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *2 *1 *2 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *2 *3 *4)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|IndexCard|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|Library|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| (|Pattern| *4))) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|PermutationCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Permutation| *4)) (|isDomain| *1 (|PermutationGroup| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|PlacesCategory| *2 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|DirectProduct| *4 *2)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|QuadraticForm| *4 *2)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "value") (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|RewriteRule| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))))) ((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|Ruleset| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|StringAggregate|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "last") (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "rest") (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "first") (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FunctionSpaceReduce| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|SemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|List| *6) "failed") (|Integer|) *6 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|BasicOperatorFunctions1| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Vector| *4))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|List| (|Integer|)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| (|Boolean|) *5)) (|isDomain| *1 (|PatternFunctions1| *4 *5)) (|ofCategory| *5 (|Type|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5 *5)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
-(((*1 *2 *2 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *2 (|List| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
-(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |points| (|NonNegativeInteger|)) (|:| |curves| (|NonNegativeInteger|)) (|:| |polygons| (|NonNegativeInteger|)) (|:| |constructs| (|NonNegativeInteger|))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursiveAggregate| *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| *4) (|:| |num| *4)))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| AND (|isDomain| *4 (|List| *11)) (|isDomain| *5 (|List| (|SparseUnivariatePolynomial| *9))) (|isDomain| *6 (|List| *9)) (|isDomain| *7 (|List| *12)) (|isDomain| *8 (|List| (|NonNegativeInteger|))) (|ofCategory| *11 (|OrderedSet|)) (|ofCategory| *9 (|EuclideanDomain|)) (|ofCategory| *12 (|PolynomialCategory| *9 *10 *11)) (|ofCategory| *10 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *12))) (|isDomain| *1 (|MultivariateLifting| *10 *11 *9 *12)) (|isDomain| *3 (|SparseUnivariatePolynomial| *12))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PermutationGroup| *4))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ElementaryFunction| *4 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *2 (|Record| (|:| |cycle?| (|Boolean|)) (|:| |prefix| (|NonNegativeInteger|)) (|:| |period| (|NonNegativeInteger|)))) (|isDomain| *1 (|Stream| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *3 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|ListToMap| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| *5)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Mapping| *5 *6)) (|isDomain| *1 (|ListToMap| *6 *5)))) ((*1 *2 *3 *4 *5 *2) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|isDomain| *6 (|Mapping| *2 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *1 *1 *3) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *3 (|Character|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *2 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "right") (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "left") (|ofCategory| *1 (|BinaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 (|Integer|)) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *4 *5 *2)) (|ofType| *4 *3) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *2)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|DataList| (|String|))) (|isDomain| *1 (|Database| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ *3)) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|QueryEquation|)) (|isDomain| *1 (|Database| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "count") (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DataList| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "sort") (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "unique") (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Eltable| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *2) (AND (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *3 *2 *4 *5 *6 *7)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *2 *1 *1 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *2 *1 *2 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *2 *3 *4)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|IndexCard|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|Library|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| (|Pattern| *4))) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|PermutationCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Permutation| *4)) (|isDomain| *1 (|PermutationGroup| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|PlacesCategory| *2 *4)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|DirectProduct| *4 *2)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|QuadraticForm| *4 *2)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "value") (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|RewriteRule| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))))) ((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|Ruleset| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|StringAggregate|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "last") (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 "rest") (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 "first") (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FunctionSpaceReduce| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *12 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *7 *8 *9 *10 *11 *12 *13 *3 *14)) (|ofCategory| *3 (|DesingTreeCategory| *13))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *1) (|isDomain| *1 (|GraphImage|)))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldSquareFreeDecomposition| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |outval| *4) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| *4)))))) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|List| (|Equation| *4))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|))))) 
 (((*1 *1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|Multiset| *4)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *7)) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Boolean|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|Record| (|:| |solns| (|List| *5)) (|:| |maps| (|List| (|Record| (|:| |arg| *5) (|:| |res| *5)))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Table| (|StochasticDifferential| *3) (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MakeFloatCompiledFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MakeFloatCompiledFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Stream| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *2))))) 
+(((*1 *2 *3 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|TranscendentalRischDESystem| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UTSodetools| *4 *3 *5 *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *3))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 (|Integer|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|SquareMatrix| *3 *4)) (|ofType| *3 (|NonNegativeInteger|))))) 
+(((*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|PlaneAlgebraicCurvePlot|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Factored| *4) *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *4)) (|isDomain| *1 (|FactoredFunctionUtilities| *4)))) ((*1 *1 *1) (|isDomain| *1 (|Plot3D|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1) (|isDomain| *1 (|Plot|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *2 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Commutator|))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Commutator|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|SingleInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *4 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *1 *2 *3 *3 *4 *5) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2 *3 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *1) (|isDomain| *1 (|GraphImage|)))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|RepeatedDoubling| *2)) (|ofCategory| *2 (|Join| (|SetCategory|) (CATEGORY |domain| (SIGNATURE + ($ $ $)))))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |prime| (|Integer|)) (|:| |factors| (|List| *3)))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|String|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G)))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *9 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|SubSpaceComponentProperty|)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|InternalPrintPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *3))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|Divisor| *2)) (|ofCategory| *2 (|SetCategoryWithDegree|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofType| *2 (|List| (|Symbol|))) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *2) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *4) (|:| |exponent| *5)) (|Record| (|:| |index| *4) (|:| |exponent| *5)))) (|isDomain| *1 (|GeneralModulePolynomial| *2 *3 *4 *5 *6 *7)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *2))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
 (((*1 *2 *3 *4 *4 *5 *4 *3 *6 *3 *4 *7 *8 *9 *10) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|String|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G)))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *9 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp31| PEDERV)))) (|isDomain| *10 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|DoubleResultantPackage| *5 *2 *6 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *5 *2 *6))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Record| (|:| |close| (|List| *6)) (|:| |open| (|List| *6))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |base| *3) (|:| |exponent| (|NonNegativeInteger|)))) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerBits|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|ofCategory| *1 (|ExpressionSpace|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Fraction| (|Integer|))))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *5 *4 *4 *4 *3 *4 *4 *6) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|DoubleFloat|))) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinarySearchTree| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|List| (|Fraction| *7))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *3 (|Fraction| *7)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|Symbol|)) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|PureAlgebraicIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *1 *2 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Expression| *3)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *4) (|:| |exponent| *5)) (|Record| (|:| |index| *4) (|:| |exponent| *5)))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *2 *4 *5 *6 *7)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *5 (|OrderedVariableList| *3))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
 (((*1 *2 *3 *3 *4 *3 *4 *4 *4 *5 *5 *5 *5 *4 *4 *6 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp77| FCNF)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp78| FCNG)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|)))) ((*1 *2 *3 *4 *5 *5 *6 *3 *3 *3 *3) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *9) (|:| |radicand| *9))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *8 *9)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *9 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*8 $)) (SIGNATURE |denom| (*8 $)) (SIGNATURE |coerce| ($ *8)))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|AffinePlane| *3))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|isDomain| *2 (|ModuleMonomial| *5 *6 *7)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *6 *7 *8)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *3))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Monoid|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|MonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
 (((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp10| COEFFN)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp80| BDYVAL)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|)))) ((*1 *2 *3 *4 *4 *5 *4 *4 *5 *5 *3 *4 *4 *6 *7 *8 *8) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp10| COEFFN)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp80| BDYVAL)))) (|isDomain| *8 (|FileName|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|DistributedMultivariatePolynomial| *3 *4)) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|isDomain| *1 (|GeneralDistributedMultivariatePolynomial| *3 *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|HomogeneousDistributedMultivariatePolynomial| *3 *4)) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |f1| (|List| *4)) (|:| |f2| (|List| (|List| (|List| *4)))) (|:| |f3| (|List| (|List| *4))) (|:| |f4| (|List| (|List| (|List| *4)))))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| (|List| (|List| *4))))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *5 *3)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *4))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp41| FCN JACOBF JACEPS)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp42| G JACOBG JACGEP)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *2) (AND (|ofType| *4 *2) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionSpace&| *3 *4)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerNumberSystem&| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|NonAssociativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OctonionCategory&| *3 *4)) (|ofCategory| *3 (|OctonionCategory| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|QuotientFieldCategory&| *3 *4)) (|ofCategory| *3 (|QuotientFieldCategory| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|QuaternionCategory&| *3 *4)) (|ofCategory| *3 (|QuaternionCategory| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealClosedField&| *3)) (|ofCategory| *3 (|RealClosedField|)))) ((*1 *2) (AND (|ofCategory| *1 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealNumberSystem&| *3)) (|ofCategory| *3 (|RealNumberSystem|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| (|Complex| *4)))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| (|Complex| *4)))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| (|Complex| *4))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| (|Complex| *4))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
 (((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|CharacterClass|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Character|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *3) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Equation| (|OnePointCompletion| *3))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|OnePointCompletion| *3)) (|isDomain| *1 (|PowerSeriesLimitPackage| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|OnePointCompletion| (|Polynomial| *5)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|OnePointCompletion| (|Fraction| (|Polynomial| *5)))) (|isDomain| *1 (|RationalFunctionLimitPackage| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|OnePointCompletion| *3)) (|isDomain| *1 (|RationalFunctionLimitPackage| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *4 (|List| *13)) (|isDomain| *5 (|List| *9)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *13 (|DesingTreeCategory| *12)) (|ofCategory| *6 (|Field|)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *6 *7 *3 *8 *9 *10 *11 *2 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|ofCategory| *2 (|DivisorCategory| *11)) (|isDomain| *1 (|IntersectionDivisorPackage| *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *4)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Divisor| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *1 (|MappingPackageInternalHacks2| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *2 *5 *6 *7 *8 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *4))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| *5)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *5) (|:| |degree| (|Integer|))))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *5))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *3 *3 *3 *3 *3 *5 *5 *4 *3 *6 *7) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp41| FCN JACOBF JACEPS)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp42| G JACOBG JACGEP)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MyExpression| *3 *4)) (|ofType| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks1| *2))))) 
+(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|String|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *4 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NormalizationPackage| *6 *7 *8 *4 *5)) (|ofCategory| *5 (|RegularTriangularSetCategory| *6 *7 *8 *4))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *1 (|ExponentialExpansion| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *1 (|UnivariatePuiseuxSeriesWithExponentialSingularity| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|DivisionRing|))) ((*1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (OR (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Type|))) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Group|)) (|ofCategory| *2 (|Type|))))) ((*1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
 (((*1 *2 *3 *3 *4 *3 *4 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5 *4)) (|isDomain| *1 (|MappingPackage2| *4 *5))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *1 (|MappingPackageInternalHacks2| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|U32Vector|)) (|isDomain| *5 (|Integer|)) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *6)) (|ofCategory| *3 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Void|))))) 
 (((*1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Finite|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|List| (|Fraction| *7))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *3 (|Fraction| *7)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *1 *2) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|OrderedFreeMonoid| *3)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|OrderedMonoid|)) (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp4| FUNCTN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6))))) 
+(((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|EuclideanDomain|))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|CliffordAlgebra| *3 *4 *5)) (|ofType| *3 *2) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|QuadraticForm| *3 *4))))) 
-(((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Union| "nil" "sqfr" "irred" "prime")) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|RepeatedDoubling| *2)) (|ofCategory| *2 (|Join| (|SetCategory|) (CATEGORY |domain| (SIGNATURE + ($ $ $)))))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *4 *4 *3 *5 *3 *3 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp4| FUNCTN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Expression| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Character|))) (|isDomain| *1 (|CharacterClass|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|CharacterClass|))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *2)))) (|isDomain| *4 (|Kernel| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *5 *2 *6)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *2)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *5))))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Fraction| (|Polynomial| *5))) (|isDomain| *1 (|RationalFunction| *5)) (|ofCategory| *5 (|IntegralDomain|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
 (((*1 *2 *3 *3 *4 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| (|Complex| *4)))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|))))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| (|Complex| *4)))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| (|Complex| *4))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| (|Complex| *4))))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|isDomain| *1 (|PackageForPoly| *4 *3 *2 *5)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *2)) (|ofType| *5 (|NonNegativeInteger|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|PolynomialDecomposition| *2 *4)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SubSpace| 3 (|DoubleFloat|))) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Export3D|))))) 
+(((*1 *1 *2 *3) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|isDomain| *1 (|CliffordAlgebra| *4 *2 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Field|)) (|ofType| *5 (|QuadraticForm| *4 *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|ModuleMonomial| *5 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|GeneralModulePolynomial| *4 *2 *5 *6 *7 *8)) (|ofCategory| *8 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *4))))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *5)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| *5)) (|ofCategory| *1 (|PowerSeriesCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|ofCategory| *1 (|PowerSeriesCategory| *4 *3 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|OrderedSet|))))) 
 (((*1 *2 *3 *4 *4 *3 *5 *3 *3 *4 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp4| FUNCTN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|List| (|PrimitiveArray| (|DoubleFloat|)))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *6)) (|:| |exponent| (|Integer|))))) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|ParadoxicalCombinatorsForStreams| *4)) (|ofCategory| *4 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|List| (|Stream| *5)) (|List| (|Stream| *5)))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Stream| *5))) (|isDomain| *1 (|ParadoxicalCombinatorsForStreams| *5)) (|ofCategory| *5 (|Type|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|OrderedFreeMonoid| *3)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|OrderedMonoid|)) (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1) (|isDomain| *1 (|GraphImage|)))) 
-(((*1 *2 *3 *2) (|partial| AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *4)))) ((*1 *2 *3 *2) (|partial| AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *1 (|LinearSystemMatrixPackage| *4 *5 *2 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| AND (|isDomain| *4 (|List| *2)) (|isDomain| *5 (|Mapping| *2 *2)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|ODETools| *2 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|LinearDependence| *4 *5))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|ofCategory| *2 (|Ring|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| *4)))) (|isDomain| *1 (|PatternMatchResult| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *6 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|SuchThat| (|List| (|Polynomial| *4)) (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| (|PrimeField| *3)) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) *2)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *8))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|Type|)) (|ofCategory| *1 (|DirectProductCategory| *3 *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|PrincipalIdealDomain|)) (|isDomain| *2 (|Record| (|:| |coef| (|List| *1)) (|:| |generator| *1))) (|isDomain| *3 (|List| *1))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| *3))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| *3))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|FortranTemplate|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|FortranTemplate|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgebraicMultFact| *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|AlgebraicNumber|) *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| (|AlgebraicNumber|) *6 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|AlgebraicMultFact| *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|Complex| (|Integer|)))) (|isDomain| *1 (|GaussianFactorizationPackage|)) (|isDomain| *3 (|Complex| (|Integer|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GeneralizedMultivariateFactorize| *4 *5 *6 *7 *3)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *3 (|PolynomialCategory| *7 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|GenUFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| *5 *6))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|InnerAlgFactor| *5 *6 *7 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *7)) (|SparseUnivariatePolynomial| *7))) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|InnerMultFact| *5 *6 *7 *3)) (|ofCategory| *3 (|PolynomialCategory| *7 *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *7)) (|SparseUnivariatePolynomial| *7))) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|PolynomialCategory| *7 *6 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *8))) (|isDomain| *1 (|InnerMultFact| *5 *6 *7 *8)) (|isDomain| *3 (|SparseUnivariatePolynomial| *8)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *4 *5)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5))))) ((*1 *2 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|LyndonWord| *4))) (|isDomain| *1 (|LyndonWord| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultFiniteFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultFiniteFactorize| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MPolyCatPolyFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Polynomial| *6) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MRationalFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| *6) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultivariateFactorize| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFunctionFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Polynomial| (|Integer|))))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| (|Fraction| (|Integer|)) *4))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|SimpleAlgebraicExtensionAlgFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| (|Fraction| (|Polynomial| (|Integer|))) *4))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|SAERationalFunctionAlgFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| *7)))) (|isDomain| *1 (|SupFractionFactorizer| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| *7))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|UniqueFactorizationDomain|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *9)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *7 (|NonNegativeInteger|))) (|ofCategory| *9 (|FiniteAbelianMonoidRing| (|Fraction| *7) (|NonNegativeInteger|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|FractionFreeFastGaussianFractions| *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *9)) (|isDomain| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *7 *6)) (|ofCategory| *9 (|FiniteAbelianMonoidRing| (|Fraction| *7) *6)) (|isDomain| *2 (|Stream| (|Matrix| (|SparseUnivariatePolynomial| *7)))) (|isDomain| *1 (|FractionFreeFastGaussianFractions| *7 *8 *9)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *8)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|AbelianMonoidRing| *7 (|NonNegativeInteger|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|FractionFreeFastGaussian| *7 *8)))) ((*1 *2 *3 *4 *5 *6 *6) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|Mapping| *7 (|NonNegativeInteger|) (|NonNegativeInteger|) *8)) (|isDomain| *5 (|Vector| *8)) (|isDomain| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|ofCategory| *8 (|AbelianMonoidRing| *7 *6)) (|isDomain| *2 (|Stream| (|Matrix| (|SparseUnivariatePolynomial| *7)))) (|isDomain| *1 (|FractionFreeFastGaussian| *7 *8))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Kernel| *1)) (|ofCategory| *1 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *1))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Variable| *5)) (|ofType| *5 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|UnivariatePolynomial| *5 (|Polynomial| *6))) (|isDomain| *1 (|PolynomialToUnivariatePolynomial| *5 *6)) (|isDomain| *3 (|Polynomial| *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|RationalFunction| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *7) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *7))))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Union| (|BasicStochasticDifferential|) (|Integer|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|ofCategory| *1 (|ExpressionSpace|))))) 
 (((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianGroup|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianSemiGroup|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|Color|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|DenavitHartenbergMatrix| *3)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|SemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|SemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|FreeModule1| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *6 *7 *2)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *3))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|InnerTaylorSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|InnerTaylorSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|LeftModule| *2)) (|ofCategory| *2 (|Rng|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *6)) (|isDomain| *4 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Mapping| *7 *5)) (|isDomain| *1 (|MappingPackage3| *5 *6 *7)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *2 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Monad|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *4 *5)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RightModule| *2)) (|ofCategory| *2 (|Rng|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SemiGroup|))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *2 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|DirectProductCategory| *3 *4)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *2 (|DirectProductCategory| *3 *4)))) ((*1 *1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *4 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 (|IndexedExponents| *4) *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|VectorCategory| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|AbelianGroup|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|GenusZeroIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4 *5 *5 *5 *4 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|Fraction| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|GenusZeroIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Kernel| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|RegularChain| *4 *5))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
-(((*1 *2 *3 *4 *4 *3) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *3 *6)) (|ofCategory| *6 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) ((*1 *2) (AND (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|CardinalNumber|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|CardinalNumber|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PointCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|VectorSpace| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|CardinalNumber|))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| *2)) (|:| |logand| (|SparseUnivariatePolynomial| *2))))) (|isDomain| *4 (|List| (|Record| (|:| |integrand| *2) (|:| |intvar| *2)))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|IntegrationResult| *2))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|OrderedCompletion| *3))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|OrderedCompletion| *3) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| *3) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| *3) "failed"))) "failed")) (|isDomain| *1 (|PowerSeriesLimitPackage| *5 *3)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Equation| *3)) (|isDomain| *5 (|String|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|OrderedCompletion| *3)) (|isDomain| *1 (|PowerSeriesLimitPackage| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|OrderedCompletion| (|Polynomial| *5)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| *5))) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| *5))) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| (|Fraction| (|Polynomial| *5))) "failed"))) "failed")) (|isDomain| *1 (|RationalFunctionLimitPackage| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Union| (|OrderedCompletion| *3) (|Record| (|:| |leftHandLimit| (|Union| (|OrderedCompletion| *3) "failed")) (|:| |rightHandLimit| (|Union| (|OrderedCompletion| *3) "failed"))) "failed")) (|isDomain| *1 (|RationalFunctionLimitPackage| *5)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Equation| (|Fraction| (|Polynomial| *6)))) (|isDomain| *5 (|String|)) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|OrderedCompletion| *3)) (|isDomain| *1 (|RationalFunctionLimitPackage| *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Union| (|BasicStochasticDifferential|) (|Integer|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *2 (|Result|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|Result|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericEigenPackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|AssociationList| (|String|) (|None|))) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CardinalNumber|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *6 (|PositiveInteger|)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |plist| (|List| *3)) (|:| |modulo| *5))) (|isDomain| *1 (|GeneralHenselPackage| *5 *3)) (|isDomain| *4 (|List| *3))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *13))) (|isDomain| *3 (|SparseUnivariatePolynomial| *13)) (|isDomain| *4 (|List| *12)) (|isDomain| *5 (|List| *10)) (|isDomain| *6 (|List| *13)) (|isDomain| *7 (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| *13))))) (|isDomain| *8 (|List| (|NonNegativeInteger|))) (|isDomain| *9 (|Vector| (|List| (|SparseUnivariatePolynomial| *10)))) (|ofCategory| *12 (|OrderedSet|)) (|ofCategory| *10 (|EuclideanDomain|)) (|ofCategory| *13 (|PolynomialCategory| *10 *11 *12)) (|ofCategory| *11 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|MultivariateLifting| *11 *12 *10 *13))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| (|Float|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| (|Float|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Complex| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Complex| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Complex| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *5)))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Complex| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|TheSymbolTable|)) (|isDomain| *3 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinarySearchTree| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
 (((*1 *2) (AND (|isDomain| *2 (|OrderedCompletion| (|Integer|))) (|isDomain| *1 (|Infinity|)))) ((*1 *1) (AND (|isDomain| *1 (|OrderedCompletion| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|List| (|NewSparseUnivariatePolynomial| *3))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *6))) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)))))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
 (((*1 *1) (|isDomain| *1 (|FortranCode|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *6 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|SuchThat| (|List| (|Polynomial| *4)) (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|EuclideanDomain|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (|partial| |ofCategory| *1 (|CharacteristicNonZero|))) ((*1 *1 *1) (|ofCategory| *1 (|FiniteFieldCategory|))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|CharacteristicNonZero|)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
 (((*1 *2) (AND (|isDomain| *2 (|OrderedCompletion| (|Integer|))) (|isDomain| *1 (|Infinity|)))) ((*1 *1) (AND (|isDomain| *1 (|OrderedCompletion| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
 (((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
 (((*1 *2 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1 *3 *4 *4 *5) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1 *3 *4 *4 *5) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RoutinesTable|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpressionToOpenMath| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpressionToOpenMath| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Expression| *5)) (|ofCategory| *5 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ExpressionToOpenMath| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Expression| *6)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ExpressionToOpenMath| *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *2 (|String|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|String|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *2 (|Void|)))) ((*1 *2 *3 *1 *4) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ComplexDoubleFloatMatrix|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ComplexDoubleFloatVector|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloatMatrix|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloatVector|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U16Matrix|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U32Matrix|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U8Matrix|))))) 
 (((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *3 *2 *5)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *3)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *5 *2 *6)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *3))))) 
 (((*1 *2 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *2 *3 *4) (|partial| AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *3 *4) (|partial| AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *6 (|PolynomialCategory| *2 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *9)) (|ofCategory| *10 (|DivisorCategory| *4)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *2 *5 *6 *7 *8 *9 *4 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Multiset| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *2 *3 *4))))) 
 (((*1 *2 *3 *4 *5 *5 *5 *6 *4 *4 *4 *5 *4 *5 *7) (AND (|isDomain| *3 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Matrix| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|isDomain| *3 (|Integer|)) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *2 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *2 (|DirectProductCategory| *3 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|ofType| *9 (|Mapping| *6 *4)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Float|))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *4 *5)) (|ofType| *4 *3) (|ofType| *5 *3))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *5 *3 *3 *3 *6 *4 *3) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UTSodetools| *4 *3 *5 *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *3))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|LinearDependence| *4 *5))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *1 (|ExponentialExpansion| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *1 (|UnivariatePuiseuxSeriesWithExponentialSingularity| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4)))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *6 *4 *7)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|PseudoAlgebraicClosureOfRationalNumber|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| *3)) (|ofType| *3 *2)))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5))))) 
 (((*1 *2 *3 *4 *5 *4 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *7 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Matrix| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|Switch|))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5)) (|ofType| *4 (|List| (|Symbol|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *2 (|List| (|Fraction| (|Integer|)))) (|isDomain| *1 (|RealZeroPackage| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GenExEuclid| *3 *5))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *3 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| (|List| *3)))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *3 *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*3 $)) (SIGNATURE |denom| (*3 $)) (SIGNATURE |coerce| ($ *3)))))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *2 *3 *4 *5 *5 *5 *5 *6 *4 *4 *4 *4 *4 *5 *4 *5 *5 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|HallBasis|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *3 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|FortranTemplate|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|FortranTemplate|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|CharacteristicZero|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Expression| *5)) (|isDomain| *1 (|IntegrationResultRFToFunction| *5))))) 
+(((*1 *2 *3) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|)))))) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5)) (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|)))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *2 *5)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *6 *2 *7)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *4 *6)) (|ofCategory| *2 (|DirectProductCategory| *5 *6))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| (|List| *8))) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |upol| (|SparseUnivariatePolynomial| *8)) (|:| |Lval| (|List| *8)) (|:| |Lfact| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *8)) (|:| |exponent| (|Integer|))))) (|:| |ctpol| *8))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *1 (|Product| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *1 *2 *3 *4) (AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *4 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *3) (|:| |exponent| *4)) (|Record| (|:| |index| *3) (|:| |exponent| *4)))) (|isDomain| *1 (|GeneralModulePolynomial| *5 *2 *3 *4 *6 *7)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *4 (|OrderedVariableList| *5)))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *4 *4 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|RootsFindingPackage| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IrrRepSymNatPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|CommonDenominator| *2 *4 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|InnerCommonDenominator| *2 *4 *5 *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|MatrixCommonDenominator| *2 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *2 *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|Join| (|FieldOfPrimeCharacteristic|) (CATEGORY |package| (SIGNATURE |coerce| (*2 *4)) (SIGNATURE |lookup| ((|PositiveInteger|) *2)) (SIGNATURE |basis| ((|Vector| *2) (|PositiveInteger|))) (SIGNATURE |Frobenius| (*2 *2))))) (|isDomain| *1 (|FiniteFieldPolynomialPackage2| *2 *4))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| *6)) (|:| |coeff| (|Fraction| *6)))) (|isDomain| *1 (|TranscendentalIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *1) (AND (|ofCategory| *1 (|GradedAlgebra| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1) (|ofCategory| *1 (|MonadWithUnit|))) ((*1 *1) (|ofCategory| *1 (|Monoid|))) ((*1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|))))) 
 (((*1 *2 *3 *3 *4 *4 *3 *4 *4 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|))))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
+(((*1 *2 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *3 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
 (((*1 *2 *3 *4 *4 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *1 *2 *3 *1) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *3)) (|Record| (|:| |index| *5) (|:| |exponent| *3)))) (|isDomain| *1 (|GeneralModulePolynomial| *4 *2 *5 *3 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *3 (|OrderedVariableList| *4)))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Kernel| *5))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Kernel| *5)) (|isDomain| *1 (|IntegrationTools| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
 (((*1 *2 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LeadingCoefDetermination| *6 *7 *3 *8)) (|ofCategory| *8 (|PolynomialCategory| *3 *7 *6))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|OrderedRing|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|RealNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|IntegrationResult| (|Fraction| (|Polynomial| *5)))) (|isDomain| *1 (|RationalFunctionIntegration| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Record| (|:| |lcmfij| *6) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *4) (|:| |polj| *4))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|BinaryTournament| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|TangentExpansions| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|isDomain| *1 (|PackageForPoly| *4 *3 *2 *5)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *2)) (|ofType| *5 (|NonNegativeInteger|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *4 (|List| *6)) (|isDomain| *2 (|Record| (|:| |fs| (|Boolean|)) (|:| |sd| *4) (|:| |td| (|List| *4)))) (|isDomain| *1 (|TableauxBumpers| *6)) (|isDomain| *5 (|List| *4))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Stream| *3))) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)))) ((*1 *1) (|ofCategory| *1 (|Finite|))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1 *1) (|isDomain| *1 (|Integer|))) ((*1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *2 *1) (AND (|isDomain| *2 (|Permutation| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Permutation| *4)) (|isDomain| *1 (|PermutationGroup| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|isDomain| *1 (|IntegralBasisTools| *2 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *2 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
 (((*1 *2 *3 *4 *4 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|BezoutMatrix| *4 *3 *2 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *3)) (|ofCategory| *3 (|LocalPowerSeriesCategory| *5))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|))) ((*1 *1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Vector| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|RationalLODE| *4 *2)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *2 (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|RationalLODE| *4 *2)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|)))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
-(((*1 *1 *1 *1) (|partial| AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|not| (|has| *1 (ATTRIBUTE |arbitraryPrecision|))) (|not| (|has| *1 (ATTRIBUTE |arbitraryExponent|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|OrderedSet|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *4 *2)) (|ofCategory| *2 (|LeftModule| *4)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|NonNegativeInteger|))) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|ofCategory| *2 (|FunctionSpace| *5)) (|isDomain| *1 (|ExpressionSolve| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *7 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *2)))))) 
 (((*1 *2 *3 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Stream| (|Polynomial| *4)) (|Stream| (|Polynomial| *4)))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|RightOpenIntervalRootCharacterization| (|RealClosure| *4) (|SparseUnivariatePolynomial| (|RealClosure| *4)))) (|isDomain| *3 (|OutputForm|)) (|isDomain| *1 (|RealClosure| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *4 (|Mapping| (|Boolean|) *2 *2)) (|isDomain| *1 (|UserDefinedPartialOrdering| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *2))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|GradedAlgebra| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1) (|ofCategory| *1 (|MonadWithUnit|))) ((*1 *1) (|ofCategory| *1 (|Monoid|))) ((*1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *1 (|FourierSeries| *3 *2)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *2 (|Join| (|OrderedSet|) (|AbelianGroup|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|BinarySearchTree| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
+(((*1 *1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *3 *4 *4 *4 *3 *3 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Record| (|:| |k| *4) (|:| |c| *3)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ExtAlgBasis|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|KeyedDictionary| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| (QUOTE |x|) *4)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|UnivariateTaylorSeries| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| *3))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *8 *3)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*8 $)) (SIGNATURE |denom| (*8 $)) (SIGNATURE |coerce| ($ *8)))))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Stream| *4))) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *4 *5)) (|isDomain| *3 (|Stream| *4)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4))))) 
 (((*1 *2 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| (|InputForm|))) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
 (((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ApplicationProgramInterface|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|NormRetractPackage| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|ofType| *6 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ExtensionField| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Finite|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Factored| *2)) (|ofCategory| *2 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *1 (|MultivariateSquareFree| *5 *6 *7 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
+(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|RadixUtilities|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DoubleFloat|))))) 
+(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|Record| (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)) (|:| |points| (|Integer|)) (|:| |connect| (|Integer|)) (|:| |spline| (|Integer|)) (|:| |axes| (|Integer|)) (|:| |axesColor| (|Palette|)) (|:| |units| (|Integer|)) (|:| |unitsColor| (|Palette|)) (|:| |showing| (|Integer|))))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Tableau| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| *4))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6))))) 
 (((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp35| FCN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagRootFindingPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 *2)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *1 (|HeuGcd| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|has| $ (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *2 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *2 *5))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *5 (|List| (|Symbol|))) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *6)) (|ofCategory| *6 (|Type|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearDependence| *4 *5))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |lm| (|FreeMonoid| *3)) (|:| |mm| (|FreeMonoid| *3)) (|:| |rm| (|FreeMonoid| *3)))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |lm| (|OrderedFreeMonoid| *3)) (|:| |mm| (|OrderedFreeMonoid| *3)) (|:| |rm| (|OrderedFreeMonoid| *3)))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|Float|)))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *5 (|Float|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 *2) (|ofType| *4 *2)))) 
+(((*1 *2 *3 *3 *3 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
 (((*1 *2 *3 *4 *5 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPolynomialRootsPackage|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *4 *2))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *3 (|DivisorCategory| *10)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *3 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|isDomain| *1 (|InterpolateFormsPackage| *4 *5 *6 *7 *8 *9 *10 *3)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *3 (|DivisorCategory| *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 (|PseudoAlgebraicClosureOfFiniteField| *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerAlgebraicNumber|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *3)) (|isDomain| *1 (|GosperSummationMethod| *5 *3 *6 *7 *2)) (|ofCategory| *2 (|Join| (|RetractableTo| (|Fraction| (|Integer|))) (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
 (((*1 *2 *3 *4 *5 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPolynomialRootsPackage|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef| *4) (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef| *3) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Vector| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|RepresentationPackage2| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| A (|Matrix| *5)) (|:| |eqs| (|List| (|Record| (|:| C (|Matrix| *5)) (|:| |g| (|Vector| *5)) (|:| |eq| *6) (|:| |rh| *5)))))) (|isDomain| *1 (|SystemODESolver| *5 *6)) (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *6)) (|:| |vec| (|Vector| *5)))) (|isDomain| *1 (|SystemODESolver| *5 *6)) (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Vector| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5 *4)) (|isDomain| *1 (|MappingPackage2| *4 *5)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *2 *3 *4 *5)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *2 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *3 (|OrderedMonoid|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|NAGLinkSupportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Matrix| (|Integer|))) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionFieldCategory&| *4 *3 *5 *6)) (|ofCategory| *4 (|FunctionFieldCategory| *3 *5 *6)))) ((*1 *2 *3 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|))))) 
+(((*1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *1 (|TheSymbolTable|))))) 
 (((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootPackage| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| (|Integer|)))) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *5 *6 *3 *7 *8 *2 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|NeitherSparseOrDensePowerSeries| (|PseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|Places| *5)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|NeitherSparseOrDensePowerSeries| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *9)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *9 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *6)) (|isDomain| *1 (|ParametrizationPackage| *6 *7 *3 *8 *9 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *4 (|PlacesCategory| *6 *2))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|RationalIntegration| *3 *4))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))) (|isDomain| *1 (|d01AgentsPackage|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| *3)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5)))))) 
+(((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|KeyedDictionary| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
 (((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *8))) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Any|)) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FiniteDivisor| *3 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5))))) 
+(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
 (((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ApplicationProgramInterface|))))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *2 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)))) ((*1 *2 *1 *3 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| *7 *5 *6)) (|isDomain| *1 (|MakeBinaryCompiledFunction| *3 *5 *6 *7)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MakeUnaryCompiledFunction| *3 *5 *6)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|ElementaryIntegration| *6 *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (|isDomain| *1 (|SmithNormalForm| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| *3)))) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Multiset| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|RealNumberSystem|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|isDomain| *2 (|Record| (|:| |r| *3) (|:| |phi| *3)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BalancedPAdicRational| *3)) (|ofType| *3 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|BalancedPAdicRational| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PAdicRational| *3)) (|ofType| *3 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|PAdicRational| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofType| *3 *2) (|isDomain| *1 (|PAdicRationalConstructor| *3 *4)) (|ofCategory| *4 (|PAdicIntegerCategory| *3)))) ((*1 *1 *1) (AND (|ofType| *2 (|Integer|)) (|isDomain| *1 (|PAdicRationalConstructor| *2 *3)) (|ofCategory| *3 (|PAdicIntegerCategory| *2)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|UnivariateTaylorSeriesCategory| *2))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4))))) 
-(((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| *2)) (|:| |logand| (|SparseUnivariatePolynomial| *2))))) (|isDomain| *4 (|List| (|Record| (|:| |integrand| *2) (|:| |intvar| *2)))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|IntegrationResult| *2))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroup| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroupExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|SparseUnivariatePolynomial| *3)))) ((*1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldCyclicGroupExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *7) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *7))))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|RadicalCategory|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Fraction| *6)) (|isDomain| *1 (|PadeApproximants| *5 *4 *6)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *5)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|UnivariateTaylorSeries| *5 *6 *7)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|Symbol|)) (|ofType| *7 *5) (|isDomain| *2 (|Fraction| (|UnivariatePolynomial| *6 *5))) (|isDomain| *1 (|PadeApproximantPackage| *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|UnivariateTaylorSeries| *5 *6 *7)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|Symbol|)) (|ofType| *7 *5) (|isDomain| *2 (|Fraction| (|UnivariatePolynomial| *6 *5))) (|isDomain| *1 (|PadeApproximantPackage| *5 *6 *7))))) 
-(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|d01AgentsPackage|))))) 
-(((*1 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Record| (|:| |particular| *1) (|:| |basis| (|List| *1)))) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)))) ((*1 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |particular| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|:| |basis| (|List| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|PseudoAlgebraicClosureOfRationalNumber|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| *3)) (|ofType| *3 *2)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *5 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| *6))) (|isDomain| *1 (|ChangeOfVariable| *5 *6 *7)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|ComplexCategory| *6)) (|ofCategory| (|Polynomial| *6) (|PatternMatchable| *5)) (|ofCategory| *6 (|Join| (|PatternMatchable| *5) (|CommutativeRing|))) (|isDomain| *1 (|ComplexPatternMatch| *5 *6 *3)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *2 (|PatternMatchResult| *4 *1)) (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *1 (|PatternMatchable| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *6)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|SetCategory|) (|RetractableTo| *3))) (|ofCategory| *3 (|PatternMatchable| *5)) (|isDomain| *1 (|PatternMatchPushDown| *5 *3 *6)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|ConvertibleTo| *4) (|PatternMatchable| *5) (|RetractableTo| (|Kernel| $)))) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|PatternMatchable| *5))) (|isDomain| *1 (|PatternMatchFunctionSpace| *5 *6 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| (|Integer|) *3)) (|isDomain| *4 (|Pattern| (|Integer|))) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *1 (|PatternMatchIntegerNumberSystem| *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *6)) (|isDomain| *3 (|Kernel| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|RetractableTo| (|Kernel| $)) (|ConvertibleTo| *4) (|PatternMatchable| *5))) (|isDomain| *4 (|Pattern| *5)) (|isDomain| *1 (|PatternMatchKernel| *5 *6)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchListResult| *5 *6 *3)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PatternMatchable| *5)) (|ofCategory| *3 (|ListAggregate| *6)) (|isDomain| *1 (|PatternMatchListAggregate| *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (AND (|isDomain| *5 (|Mapping| (|PatternMatchResult| *6 *3) *8 (|Pattern| *6) (|PatternMatchResult| *6 *3))) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|PatternMatchResult| *6 *3)) (|isDomain| *4 (|Pattern| *6)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *3 (|Join| (|PolynomialCategory| *9 *7 *8) (|ConvertibleTo| *4))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|Join| (|Ring|) (|OrderedSet|) (|PatternMatchable| *6))) (|isDomain| *1 (|PatternMatchPolynomialCategory| *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|Join| (|PolynomialCategory| *8 *6 *7) (|ConvertibleTo| *4))) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *7 (|PatternMatchable| *5)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|Join| (|Ring|) (|OrderedSet|) (|PatternMatchable| *5))) (|isDomain| *1 (|PatternMatchPolynomialCategory| *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|QuotientFieldCategory| *6)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|PatternMatchable| *5) (|ConvertibleTo| *4))) (|isDomain| *4 (|Pattern| *5)) (|isDomain| *1 (|PatternMatchQuotientFieldCategory| *5 *6 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *1 (|PatternMatchSymbol| *5)))) ((*1 *2 *3 *4 *5 *2 *6) (AND (|isDomain| *4 (|List| (|Pattern| *7))) (|isDomain| *5 (|Mapping| *9 (|List| *9))) (|isDomain| *6 (|Mapping| (|PatternMatchResult| *7 *9) *9 (|Pattern| *7) (|PatternMatchResult| *7 *9))) (|ofCategory| *7 (|SetCategory|)) (|ofCategory| *9 (|Join| (|Ring|) (|ConvertibleTo| (|Pattern| *7)) (|RetractableTo| *8))) (|isDomain| *2 (|PatternMatchResult| *7 *9)) (|isDomain| *3 (|List| *9)) (|ofCategory| *8 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|PatternMatchTools| *7 *8 *9))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|PositiveInteger|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|KernelFunctions2| *2 *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Stack| (|String|))) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1 *4) (AND (|isDomain| *4 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *3)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FramedAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Matrix| *5))) (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|StructuralConstantsPackage| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|))))) 
-(((*1 *2 *3 *4 *4 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Record| (|:| |lcmfij| *6) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *4) (|:| |polj| *4))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *4))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|IntegerPrimesPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedRing|)) (|isDomain| *1 (|ExpertSystemToolsPackage1| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| (|Boolean|) *5)) (|isDomain| *1 (|PatternFunctions1| *4 *5)) (|ofCategory| *5 (|Type|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3 *4 *3 *3) (AND (|isDomain| *3 (|Equation| *6)) (|isDomain| *4 (|BasicOperator|)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *5 *6)))) ((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|List| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *3 (|List| (|Equation| *7))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| (|Equation| *8))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *8)) (|isDomain| *6 (|List| *8)) (|ofCategory| *8 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *8)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *6 (|List| (|Equation| *8))) (|ofCategory| *8 (|FunctionSpace| *7)) (|isDomain| *5 (|Equation| *8)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *8)))) ((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|Equation| *5)) (|isDomain| *4 (|BasicOperator|)) (|ofCategory| *5 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *5)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *3)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|List| *3)) (|ofCategory| *3 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|List| *3)) (|ofCategory| *3 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ExpressionSolve| *7 *3 *2 *8)) (|ofCategory| *8 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *3))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *6)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *5))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *1 (|TaylorSolve| *5 *2 *6))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| A (|Matrix| *5)) (|:| |eqs| (|List| (|Record| (|:| C (|Matrix| *5)) (|:| |g| (|Vector| *5)) (|:| |eq| *6) (|:| |rh| *5)))))) (|isDomain| *1 (|SystemODESolver| *5 *6)) (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *6)) (|:| |vec| (|Vector| *5)))) (|isDomain| *1 (|SystemODESolver| *5 *6)) (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Vector| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SplittingTree| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *4 (|String|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
+(((*1 *2 *3 *4 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *4 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
 (((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *6 (|PositiveInteger|)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |plist| (|List| *3)) (|:| |modulo| *5))) (|isDomain| *1 (|GeneralHenselPackage| *5 *3)) (|isDomain| *4 (|List| *3))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |op| (|BasicOperator|)) (|:| |w| (|DoubleFloat|)))) (|isDomain| *1 (|d01WeightsPackage|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|List| *8))) (|isDomain| *3 (|List| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|PolynomialDecomposition| *2 *4)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|ODETools| *4 *5)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|ODETools| *5 *6)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |radval| (|Expression| (|Integer|))) (|:| |radmult| (|Integer|)) (|:| |radvect| (|List| (|Matrix| (|Expression| (|Integer|)))))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|FlexibleArray| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofType| *4 (|Integer|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|CycleIndicators|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SortedCache| *3)) (|ofCategory| *3 (|CachableSet|))))) 
 (((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Factored| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *5 *6))))) 
-(((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|EuclideanDomain|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| (|List| *8))) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|isDomain| *2 (|Record| (|:| |unitPart| *9) (|:| |suPart| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *9)) (|:| |exponent| (|Integer|))))))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *3 (|SparseUnivariatePolynomial| *9))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 (|NonNegativeInteger|) *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks1| *2)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Mapping| *3 (|NonNegativeInteger|) *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|MappingPackage1| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Kernel| *5))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Kernel| *5)) (|isDomain| *1 (|IntegrationTools| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $))))))))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $))))))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $))))))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *4 *2)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Kernel| *2))) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $))))))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *4 *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *2 (|Record| (|:| |particular| *4) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|ConstantLODE| *6 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RepresentationPackage2| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedAlgebra&| *3 *4 *5)) (|ofCategory| *3 (|FramedAlgebra| *4 *5)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Matrix| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FramedAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Matrix| *5))) (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|StructuralConstantsPackage| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PatternMatchListResult| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|ListAggregate| *3)))) ((*1 *1) (AND (|isDomain| *1 (|PatternMatchResult| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *2 *3 *4)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|GcdDomain|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *2 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|SubResultantPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| (|Vector| (|Integer|)))) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|GrayCode|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GnuDraw|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Vector| *1)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Vector| *1)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |radicand| (|Fraction| *5)) (|:| |deg| (|NonNegativeInteger|)))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TangentExpansions| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |mval| (|Matrix| *3)) (|:| |invmval| (|Matrix| *3)) (|:| |genIdeal| (|PolynomialIdeals| *3 *4 *5 *6)))) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|PatternMatchResult| *4 *5)) (|isDomain| *3 (|PatternMatchResult| *4 *6)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|ListAggregate| *5)) (|isDomain| *1 (|PatternMatchListResult| *4 *5 *6))))) 
-(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| *6)) (|:| |coeff| (|Fraction| *6)))) (|isDomain| *1 (|TranscendentalIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|PAdicIntegerCategory| *2)))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *5 *2))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|List| *8))) (|isDomain| *3 (|List| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Fraction| (|Factored| (|Polynomial| *4)))) (|isDomain| *1 (|RationalFunctionFactorizer| *4))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|OrderedRing|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|Stream| *7))) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *5 (|IndexedExponents| *6) *6)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Mapping| (|Stream| *7) *7)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *5 *6 *7))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef1| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|CyclicStreamTools| *3 *2)) (|ofCategory| *2 (|LazyStreamAggregate| *3))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GenExEuclid| *5 *3))))) 
-(((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|OpenMathPackage|)) (|isDomain| *3 (|String|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Matrix| (|PrimeField| *3))) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|))))))))) ((*1 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|SingleInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|BasicFunctions|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Integer|)) (|ofCategory| *6 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *6))))) 
-(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *6 (|List| (|Kernel| *3))) (|isDomain| *5 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|ElementaryIntegration| *7 *3))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *3 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *5)) *4 *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|isDomain| *1 (|PushVariables| *4 *5 *3 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PushVariables| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *6))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *1) (|isDomain| *1 (|Color|)))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|NonLinearSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|NonLinearSolvePackage| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |particular| (|Union| *6 "failed")) (|:| |basis| (|List| *6))) *7 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *6) "failed")) (|:| |basis| (|List| (|Vector| *6))))) (|isDomain| *1 (|SystemODESolver| *6 *7)) (|isDomain| *4 (|Vector| *6))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|SplittingNode| *4 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingTree| *4 *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |%expansion| (|ExponentialExpansion| *5 *3 *6 *7)) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToExponentialExpansion| *5 *3 *6 *7)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofType| *6 (|Symbol|)) (|ofType| *7 *3)))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|PrincipalIdealDomain|)) (|isDomain| *2 (|Record| (|:| |coef| (|List| *1)) (|:| |generator| *1))) (|isDomain| *3 (|List| *1))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|ApplyRules| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4))))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
 (((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|OppositeMonogenicLinearOperator| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)))) ((*1 *1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *1 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|PartitionsAndPermutations|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1) (|isDomain| *1 (|Partition|))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *6))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|)))) ((*1 *1 *2 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Matrix| *11)) (|isDomain| *4 (|List| (|Fraction| (|Polynomial| *8)))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *8 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *11 (|PolynomialCategory| *8 *10 *9)) (|ofCategory| *9 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *10 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |rgl| (|List| (|Record| (|:| |eqzro| (|List| *11)) (|:| |neqzro| (|List| *11)) (|:| |wcond| (|List| (|Polynomial| *8))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *8)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *8)))))))))) (|:| |rgsz| (|Integer|)))) (|isDomain| *1 (|ParametricLinearEquations| *8 *9 *10 *11)) (|isDomain| *7 (|Integer|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |nullBranch| "null") (|:| |assignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |arrayIndex| (|List| (|Polynomial| (|Integer|)))) (|:| |rand| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |arrayAssignmentBranch| (|Record| (|:| |var| (|Symbol|)) (|:| |rand| (|OutputForm|)) (|:| |ints2Floats?| (|Boolean|)))) (|:| |conditionalBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |thenClause| (|FortranCode|)) (|:| |elseClause| (|FortranCode|)))) (|:| |returnBranch| (|Record| (|:| |empty?| (|Boolean|)) (|:| |value| (|Record| (|:| |ints2Floats?| (|Boolean|)) (|:| |expr| (|OutputForm|)))))) (|:| |blockBranch| (|List| (|FortranCode|))) (|:| |commentBranch| (|List| (|String|))) (|:| |callBranch| (|String|)) (|:| |forBranch| (|Record| (|:| |range| (|SegmentBinding| (|Polynomial| (|Integer|)))) (|:| |span| (|Polynomial| (|Integer|))) (|:| |body| (|FortranCode|)))) (|:| |labelBranch| (|SingleInteger|)) (|:| |loopBranch| (|Record| (|:| |switch| (|Switch|)) (|:| |body| (|FortranCode|)))) (|:| |commonBranch| (|Record| (|:| |name| (|Symbol|)) (|:| |contents| (|List| (|Symbol|))))) (|:| |printBranch| (|List| (|OutputForm|))))) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *4)) (|ofCategory| *4 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *4 (|Field|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UTSodetools| *4 *5 *6 *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *6))) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *3 *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5)) (|ofType| *4 (|List| (|Symbol|)))))) 
 (((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Record| (|:| |num| (|Matrix| *5)) (|:| |den| *5)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Fraction| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *5) (|:| |right| *5)))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *4 (|Record| (|:| |left| *5) (|:| |right| *5))))) ((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *4) (|:| |right| *4)))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Fraction| (|Integer|))) (|isDomain| *2 (|List| (|Record| (|:| |left| *5) (|:| |right| *5)))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|isDomain| *4 (|Record| (|:| |left| *5) (|:| |right| *5)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3)) (|isDomain| *1 (|MappingPackage1| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *4))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|)))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
 (((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *1) (|partial| |ofCategory| *1 (|IntegralDomain|))) ((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *1) (|partial| |isDomain| *1 (|NonNegativeInteger|))) ((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *4)))) ((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *2 *5 *6)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *4 *2)) (|ofCategory| *6 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *2 *2) (|partial| AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *2 *6)) (|isDomain| *4 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks3| *5 *6 *2))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |sup| (|Polynomial| *6)) (|:| |inf| (|Polynomial| *6)))) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |cont| *5) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|DistinctDegreeFactorize| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FourierComponent| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
 (((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Float|))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |llcmres| *1) (|:| |coeff1| *1) (|:| |coeff2| *1))) (|ofCategory| *1 (|LeftOreRing|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Vector| *6)) (|isDomain| *4 (|Vector| (|Integer|))) (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6)) (|isDomain| *1 (|RandomDistributions| *6))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|))) ((*1 *1 *1 *2 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|isDomain| *2 (|Record| (|:| |pol| (|SparseUnivariatePolynomial| *9)) (|:| |polval| (|SparseUnivariatePolynomial| *8)))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|SparseUnivariatePolynomial| *8))))) 
-(((*1 *2 *3 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |a| *6) (|:| |b| (|Fraction| *6)) (|:| |h| *6) (|:| |c1| (|Fraction| *6)) (|:| |c2| (|Fraction| *6)) (|:| |t| *6))) (|isDomain| *1 (|TranscendentalRischDESystem| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|None|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SimpleCell| *5 *6))) (|isDomain| *1 (|SimpleCell| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SimpleCell| *5 *3))) (|isDomain| *1 (|SimpleCell| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *3 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
 (((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|None|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Factored| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|PartialFraction| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|PartialFractionPackage| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Factored| (|Polynomial| *6))) (|isDomain| *5 (|Symbol|)) (|isDomain| *3 (|Polynomial| *6)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|PartialFractionPackage| *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|OneDimensionalArray| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|OneDimensionalArray| *5)) (|isDomain| *1 (|OneDimensionalArrayFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *7 *5)) (|isDomain| *4 (|DirectProduct| *6 *7)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|DirectProduct| *6 *5)) (|isDomain| *1 (|DirectProductFunctions2| *6 *7 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|FiniteLinearAggregate| *5)) (|isDomain| *1 (|FiniteLinearAggregateFunctions2| *6 *4 *5 *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|FiniteSetAggregate| *5)) (|isDomain| *1 (|FiniteSetAggregateFunctions2| *6 *4 *5 *2)) (|ofCategory| *4 (|FiniteSetAggregate| *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|ListFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|PrimitiveArray| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|PrimitiveArray| *5)) (|isDomain| *1 (|PrimitiveArrayFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *3 *6 *3)) (|isDomain| *5 (|Stream| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamFunctions2| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|Vector| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|VectorFunctions2| *6 *5))))) 
-(((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *3 (|PlacesCategory| *4 *8)) (|ofCategory| *9 (|DivisorCategory| *3)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *2 *8 *3 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *4 *5 *6 *7 *2 *8 *3)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *3 (|PlacesCategory| *4 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Places| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|ProjectivePlane| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *4))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Boolean|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|RightOpenIntervalRootCharacterization| (|RealClosure| *3) (|SparseUnivariatePolynomial| (|RealClosure| *3)))) (|isDomain| *1 (|RealClosure| *3)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *3 (|DivisorCategory| *10)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *3 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|isDomain| *1 (|InterpolateFormsPackage| *4 *5 *6 *7 *8 *9 *10 *3)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *3 (|DivisorCategory| *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 (|PseudoAlgebraicClosureOfFiniteField| *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|ElementaryIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Fraction| (|Integer|))))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|CharacteristicZero|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Expression| *5)) (|isDomain| *1 (|IntegrationResultRFToFunction| *5))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|CancellationAbelianMonoid|)) (|ofCategory| *3 (|OrderedAbelianMonoid|))))) 
-(((*1 *2 *3 *3 *3 *4 *5) (AND (|isDomain| *5 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| *4))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Union| (|:| |ans| (|Record| (|:| |ans| *3) (|:| |nosol| (|Boolean|)))) (|:| |eq| (|Record| (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (|isDomain| *1 (|TranscendentalRischDE| *6 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| "left" "center" "right" "vertical" "horizontal")) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *8 (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|NewtonPolygon| *6 *3 *7 *8)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *6 *7))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2))))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2)))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|GraphImage|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)) (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |coef| *3) (|:| |monom| *4)))) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Stream| (|Record| (|:| |k| *4) (|:| |c| *3))))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Set| (|Symbol|))) (|isDomain| *1 (|ApplicationProgramInterface|)) (|isDomain| *3 (|Symbol|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
-(((*1 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|Integer|))) (|isDomain| *1 (|Infinity|)))) ((*1 *1) (AND (|isDomain| *1 (|OnePointCompletion| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| *4)) (|ofCategory| *4 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|PureAlgebraicLODE| *5 *6 *7 *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *1 (|XFreeAlgebra| *4 *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PrimitiveArray| (|ModMonic| *3 *4))) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *5 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|SymmetricFunctions| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|SymmetricFunctions| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *4 *2 *3 *5)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|MonogenicAlgebra| *2 *3))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|XRecursivePolynomial| *4 *2)) (|ofCategory| *1 (|FreeLieAlgebra| *4 *2)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *1 (|XFreeAlgebra| *4 *2)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *7)) (|:| |neqzro| (|List| *7)) (|:| |wcond| (|List| (|Polynomial| *4))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|UTSodetools| *5 *2 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *3 (|UnivariateTaylorSeriesCategory| *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctions| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *4 *5 *6 *7)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| *3)) (|ofType| *7 *3))) ((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofType| *8 (|List| *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|WeightedPolynomials| *4 *5 *6 *7 *8 *9 *10)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofType| *9 (|List| *3)) (|ofType| *10 *3)))) 
-(((*1 *2 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *2 *2) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
+(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Record| (|:| |factors| (|List| *3)) (|:| |error| *5)))) (|isDomain| *1 (|ComplexRootFindingPackage| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *5))))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Record| (|:| |factors| (|List| *3)) (|:| |error| *4)))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
 (((*1 *2 *2 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|GenExEuclid| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|GeneralHenselPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofType| *4 *3) (|ofType| *5 (|Mapping| *3 *3 (|NonNegativeInteger|))) (|isDomain| *1 (|InnerModularGcd| *3 *2 *4 *5)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *3 *1 *4) (AND (|isDomain| *3 (|SplittingNode| *5 *6)) (|isDomain| *4 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *6 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingTree| *5 *6))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricPlaneCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForAlgebraicCurves| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricPlaneCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricPlaneCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|ParametricSpaceCurve| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|ParametricSpaceCurve| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *3)) (|ofCategory| *3 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|ParametricSurface| *6)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|isDomain| *5 (|List| (|DrawOption|))) (|ofCategory| *6 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *6)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|ParametricSurface| *5)) (|isDomain| *4 (|SegmentBinding| (|Float|))) (|ofCategory| *5 (|Join| (|ConvertibleTo| (|InputForm|)) (|SetCategory|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctions| *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|)))) ((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|TopLevelDrawFunctionsForPoints|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Integer|) *2 *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|HeuGcd| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|)))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|Kernel| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 (|Integer|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Record| (|:| |under| *1) (|:| |floor| *1) (|:| |upper| *1))) (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *3 *6))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|LinearDependence| *5 *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| *5)) (|not| (|ofCategory| *5 (|Field|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Vector| (|Fraction| *5))) (|isDomain| *1 (|LinearDependence| *5 *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|QuotientFieldCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|FractionalIdeal| *2 *3 *4 *5)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *3 *4) (|RetractableTo| *3))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)) (|isDomain| *1 (|LocalAlgebra| *3 *4 *2)) (|ofCategory| *3 (|Algebra| *4)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)) (|isDomain| *1 (|Localize| *3 *4 *2)) (|ofCategory| *3 (|Module| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *5 *2)) (|ofCategory| *2 (|FunctionSpace| *5)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *5 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *5 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *5 (|Kernel| $)))))))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Boolean|) (|BasicOperator|) (|BasicOperator|))) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|Join| (|FieldOfPrimeCharacteristic|) (CATEGORY |package| (SIGNATURE |coerce| (*2 *4)) (SIGNATURE |lookup| ((|PositiveInteger|) *2)) (SIGNATURE |basis| ((|Vector| *2) (|PositiveInteger|))) (SIGNATURE |Frobenius| (*2 *2))))) (|isDomain| *1 (|FiniteFieldPolynomialPackage2| *2 *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|Algebra| *3)) (|isDomain| *1 (|LocalAlgebra| *2 *3 *4)) (|ofCategory| *4 (|SubsetCategory| (|Monoid|) *3)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|Module| *3)) (|isDomain| *1 (|Localize| *2 *3 *4)) (|ofCategory| *4 (|SubsetCategory| (|Monoid|) *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| *4)))) (|:| |xValues| (|Segment| *4)) (|:| |yValues| (|Segment| *4)))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|List| (|Point| *4))))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|None|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *3 *2 *4 *5) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *1 (|GeneralHenselPackage| *4 *3))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|List| (|Integer|)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
 (((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| *7 *5 *6)) (|isDomain| *1 (|MakeBinaryCompiledFunction| *4 *5 *6 *7)) (|ofCategory| *4 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (AND (|ofCategory| *6 (|UnivariatePolynomialCategory| *9)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|EuclideanDomain|)) (|ofCategory| *10 (|PolynomialCategory| *9 *7 *8)) (|isDomain| *2 (|Record| (|:| |deter| (|List| (|SparseUnivariatePolynomial| *10))) (|:| |dterm| (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| *10))))) (|:| |nfacts| (|List| *6)) (|:| |nlead| (|List| *10)))) (|isDomain| *1 (|NPCoef| *6 *7 *8 *9 *10)) (|isDomain| *3 (|SparseUnivariatePolynomial| *10)) (|isDomain| *4 (|List| *6)) (|isDomain| *5 (|List| *10))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *4))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *2 *6)) (|isDomain| *4 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks3| *5 *6 *2))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|isDomain| *4 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|SplittingNode| *4 *5))) (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *4 *5)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|SplittingNode| *3 *4))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3 *2) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) ((*1 *2 *3 *2) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Expression| *5))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|CommonDenominator| *3 *4 *2)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|InnerCommonDenominator| *4 *5 *2 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|MatrixCommonDenominator| *4 *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *3 *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|)))))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
-(((*1 *2 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *3)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *7 *8 *4)) (|ofCategory| *7 (|FiniteAbelianMonoidRing| *5 *8)) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|AbelianSemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| (|Integer|)) (|:| |var| (|Kernel| *1)))) (|ofCategory| *1 (|FunctionSpace| *3))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Vector| *6)) (|isDomain| *4 (|Vector| (|Integer|))) (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6)) (|isDomain| *1 (|RandomDistributions| *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Union| "left" "center" "right" "vertical" "horizontal"))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
 (((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *1) (|isDomain| *1 (|Boolean|)))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|StreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|List| (|Integer|)))) (|isDomain| *1 (|Partition|)) (|isDomain| *3 (|List| (|Integer|)))))) 
-(((*1 *1 *2 *3 *3 *4 *5) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2 *3 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *1) (|isDomain| *1 (|GraphImage|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *4 (|Integer|))) (|isDomain| *5 (|Mapping| (|Stream| *4))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|NewtonPolygon| *4 *3 *5 *6))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *2 *2 *1) (AND (|isDomain| *1 (|ListMultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|)))))))))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2 *2 *3 *4) (AND (|isDomain| *2 (|Matrix| *5)) (|isDomain| *3 (|Automorphism| *5)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|PseudoLinearNormalForm| *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *5)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|DistributedMultivariatePolynomial| *6 (|PseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *2 *6 *7 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *4 *2 *5 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *2) (AND (|ofType| *4 *2) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|ofCategory| *1 (|Finite|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteSetAggregate&| *3 *4)) (|ofCategory| *3 (|FiniteSetAggregate| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MonogenicAlgebra&| *3 *4 *5)) (|ofCategory| *3 (|MonogenicAlgebra| *4 *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *1 (|FileCategory| *2 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|FileCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|SubSpaceComponentProperty|))))))) 
+(((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *3 *3 *4 *5 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *5 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *6 *7 *4)) (|ofCategory| *9 (|RegularTriangularSetCategory| *6 *7 *4 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|Record| (|:| |val| *8) (|:| |tower| *9)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *6 *7 *4 *8 *9))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Fraction| *3))) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|IntegralDomain|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|EuclideanModularRing| *3 *4 *2 *5 *6 *7)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofType| *5 (|Mapping| *4 *4 *2)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *7 (|Mapping| (|Union| *4 "failed") *4 *4 *2)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ModularField| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|Mapping| *3 *3 *2)) (|ofType| *5 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3 *2)))) ((*1 *2) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ModularRing| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|Mapping| *3 *3 *2)) (|ofType| *5 (|Mapping| (|Union| *2 "failed") *2 *2)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3 *2)))) ((*1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
 (((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|RewriteRule| *3 *4 *2)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|SuchThat| *2 *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Union| "nil" "sqfr" "irred" "prime")) (|isDomain| *1 (|Factored| *4)) (|ofCategory| *4 (|IntegralDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|Vector| (|MachineFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (|Integer|)))) (|ofCategory| *4 (|Join| (|UnivariatePolynomialCategory| *3) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $))))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *3 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|EuclideanDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |poly| *3) (|:| |mult| *5))) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Result|))))) 
+(((*1 *2 *1 *2 *3) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|RoutinesTable|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|d03AgentsPackage|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *1 (|ParametricPlaneCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|ParametricSpaceCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|Complex| *5)))) (|isDomain| *1 (|FloatingComplexPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *4)))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *4)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|SemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |val| (|Pattern| *3)) (|:| |exponent| (|NonNegativeInteger|)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| *5) (|:| |exponent| (|NonNegativeInteger|)))))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Record| (|:| |var| *5) (|:| |exponent| (|Integer|)))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Union| *3 (|List| *1))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *3 *4 *4 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Record| (|:| |lcmfij| *6) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *4) (|:| |polj| *4))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *4))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|Point| *4))) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Cell| *4)) (|ofCategory| *4 (|RealClosedField|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|SquareMatrix| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|QuadraticForm| *3 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *3 (|CommutativeRing|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Table| (|StochasticDifferential| *3) (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8))))) 
+(((*1 *1 *2 *2 *1) (AND (|isDomain| *1 (|ListMultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Record| (|:| |under| *1) (|:| |floor| *1) (|:| |upper| *1))) (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *3 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ExtAlgBasis|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *8)) (|isDomain| *4 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|Ring|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|FactoringUtilities| *5 *6 *7 *8)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|GradedModule| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|AbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *5 *3 *6 *7)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *6)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *2 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategoryWithDegree|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *2) (AND (|ofType| *4 *2) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|ofCategory| *1 (|Finite|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteSetAggregate&| *3 *4)) (|ofCategory| *3 (|FiniteSetAggregate| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MonogenicAlgebra&| *3 *4 *5)) (|ofCategory| *3 (|MonogenicAlgebra| *4 *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Set| (|Symbol|))) (|isDomain| *1 (|ApplicationProgramInterface|)) (|isDomain| *3 (|Symbol|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|NonLinearSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|NonLinearSolvePackage| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |particular| (|Union| *6 "failed")) (|:| |basis| (|List| *6))) *7 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *6) "failed")) (|:| |basis| (|List| (|Vector| *6))))) (|isDomain| *1 (|SystemODESolver| *6 *7)) (|isDomain| *4 (|Vector| *6))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| "skip" "MonteCarlo" "deterministic")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| "skip" "MonteCarlo" "deterministic")) (|isDomain| *1 (|GuessOption|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *6)) (|:| |exponent| (|Integer|))))) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
 (((*1 *1 *1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|ofType| *9 (|Mapping| *6 *4)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |outval| *4) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| *4)))))) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *3 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 *2) (|ofType| *4 *2)))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Mapping| (|Void|) (|SExpression|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AxiomServer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *3 *1 *4) (AND (|isDomain| *3 (|SplittingNode| *5 *6)) (|isDomain| *4 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *6 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingTree| *5 *6))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Void|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
 (((*1 *1 *1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *5 "failed") *8)) (|isDomain| *4 (|Matrix| (|SparseUnivariatePolynomial| *8))) (|ofCategory| *5 (|Ring|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *6 *7 *8)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SubSpace| 3 (|DoubleFloat|))) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Export3D|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *5 (|List| (|Symbol|))) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *6)) (|ofCategory| *6 (|Type|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|LeftModule| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Operator| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *6)) (|ofCategory| *6 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|ModularHermitianRowReduction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
 (((*1 *1 *1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|List| *8))) (|isDomain| *3 (|List| *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4 *4 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|PureAlgebraicIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|isDomain| *1 (|ChangeOfVariable| *2 *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|Product| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (AND (|isDomain| *5 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| *4))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Union| (|:| |ans| (|Record| (|:| |ans| *3) (|:| |nosol| (|Boolean|)))) (|:| |eq| (|Record| (|:| |b| *3) (|:| |c| *3) (|:| |m| *4) (|:| |alpha| *3) (|:| |beta| *3))))) (|isDomain| *1 (|TranscendentalRischDE| *6 *3))))) 
 (((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Boolean|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *3 *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *3 *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *3 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *3 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|ProjectivePlane| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef1| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|CommuteUnivariatePolynomialCategory| *3 *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *2 *3 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNumericEigenPackage| *4 *5 *6)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|List| *4)))) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1) (AND (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)))) ((*1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (|isDomain| *1 (|TheSymbolTable|))) ((*1 *1) (|isDomain| *1 (|SymbolTable|)))) 
+(((*1 *1) (|isDomain| *1 (|Boolean|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|RecurrenceOperator| *4 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Symbol|)) (|PartialDifferentialRing| (|Symbol|)) (|CombinatorialOpsCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *7)) (|:| |neqzro| (|List| *7)) (|:| |wcond| (|List| (|Polynomial| *4))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
+(((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|BezoutMatrix| *4 *3 *2 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5)) (|ofType| *4 (|List| (|Symbol|)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|NonNegativeInteger|)))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Boolean|) (|BasicOperator|) (|BasicOperator|))) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *2 (|Record| (|:| |k| (|Integer|)) (|:| |c| *4))) (|isDomain| *1 (|NeitherSparseOrDensePowerSeries| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|TriangularMatrixOperations| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianGroup|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|AbelianSemiGroup|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|Color|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|DenavitHartenbergMatrix| *3)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|SemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|SemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|FreeModule1| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *6 *7 *2)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *3))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|InnerTaylorSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|InnerTaylorSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|LeftModule| *2)) (|ofCategory| *2 (|Rng|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *6)) (|isDomain| *4 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Mapping| *7 *5)) (|isDomain| *1 (|MappingPackage3| *5 *6 *7)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *2 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Monad|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *4 *5)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RightModule| *2)) (|ofCategory| *2 (|Rng|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SemiGroup|))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *2 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|DirectProductCategory| *3 *4)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *2 (|DirectProductCategory| *3 *4)))) ((*1 *1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *4 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 (|IndexedExponents| *4) *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Monoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|VectorCategory| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|AbelianGroup|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *2)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
+(((*1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *6)) (|ofCategory| *6 (|Join| (|SetCategory|) (|RetractableTo| *5))) (|ofCategory| *5 (|PatternMatchable| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| (|Boolean|) *5)) (|isDomain| *1 (|PatternMatchPushDown| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemContinuityPackage1| *4 *5)) (|ofType| *4 *3) (|ofType| *5 *3))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|NormRetractPackage| *4 *5 *6 *3 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofType| *7 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *1)) (|isDomain| *4 (|Vector| *1)) (|ofCategory| *1 (|LinearlyExplicitRingOver| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *5)) (|:| |vec| (|Vector| *5)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Matrix| *4))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *2 *2 *3 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|Finite|)))) ((*1 *2) (AND (|isDomain| *2 (|Vector| (|SetOfMIntegersInOneToN| *3 *4))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
+(((*1 *2 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|HallBasis|))))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |left| *3) (|:| |right| *3))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|ListAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|GcdDomain|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|HeuGcd| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *5 *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| *7))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)))) ((*1 *1 *1 *1) (|isDomain| *1 (|PositiveInteger|))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|PrimitiveArray| (|U32Vector|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|ElementaryIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
+(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Union| "prime" "polynomial" "normal" "cyclic"))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|FunctionSpaceReduce| *4 *3)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|FunctionSpace| *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceReduce| *5 *3))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RootsFindingPackage| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *5 *6 *3 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *2 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Boolean|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *3 *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *3 *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
+(((*1 *2 *3 *3 *3 *4 *5) (AND (|isDomain| *5 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|List| (|Point| *4))) (|isDomain| *1 (|TubePlotTools|)) (|isDomain| *3 (|Point| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|Partition|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |coef| (|Fraction| *5)) (|:| |poly| *3))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
 (((*1 *2 *3 *4 *3 *4 *4 *4 *4 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *6 *7 *5)) (|ofCategory| *7 (|Field|)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Vector| (|List| *3))) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|GenExEuclid| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PointCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| *5)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *5) (|:| |degree| (|Integer|))))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *5))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|BasicOperatorFunctions1| *2))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
 (((*1 *2 *3 *3 *4 *4 *3 *3 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
 (((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *2 *1 *1 *1 *1) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *1 *1 *1) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|PlaneAlgebraicCurvePlot|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Factored| *4) *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *4)) (|isDomain| *1 (|FactoredFunctionUtilities| *4)))) ((*1 *1 *1) (|isDomain| *1 (|Plot3D|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1) (|isDomain| *1 (|Plot|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *1 (|RealZeroPackage| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *2 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *1 (|RealZeroPackageQ| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *4 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *4)) (|isDomain| *1 (|MappingPackage2| *4 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|BasicOperator|))) ((*1 *1 *1) (|isDomain| *1 (|SubSpaceComponentProperty|))) ((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
 (((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|GraphImage|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|List| *8))) (|isDomain| *3 (|List| *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *3 *6 *6 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|not| (|has| *1 (ATTRIBUTE |arbitraryPrecision|))) (|not| (|has| *1 (ATTRIBUTE |arbitraryExponent|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|OrderedSet|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Mapping| (|SparseMultivariateTaylorSeries| *4 *3 *5))) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *4 *3 *5)) (|ofCategory| *5 (|PolynomialCategory| *4 (|IndexedExponents| *3) *3)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Mapping| (|TaylorSeries| *4))) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicStochasticDifferential|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| *4))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *4 (|PolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (|isDomain| *1 (|GroebnerInternalPackage| *6 *7 *8 *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Stream| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3))))) 
 (((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp27| DOT)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| IMAGE)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|)))) ((*1 *2 *3 *3 *4 *3 *3 *3 *3 *3 *3 *3 *5 *3 *6 *7 *8) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp27| DOT)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| IMAGE)))) (|isDomain| *8 (|FileName|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3 *3 *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *3)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|isDomain| *1 (|BalancedBinaryTree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *1 *1 *1) (OR (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Type|))) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Group|)) (|ofCategory| *2 (|Type|))))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Field|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LocalAlgebra| *2 *4 *3)) (|ofCategory| *2 (|Algebra| *4)) (|ofCategory| *3 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LocalAlgebra| *3 *4 *2)) (|ofCategory| *3 (|Algebra| *4)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|LieAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|Localize| *2 *4 *3)) (|ofCategory| *2 (|Module| *4)) (|ofCategory| *3 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|Localize| *3 *4 *2)) (|ofCategory| *3 (|Module| *4)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| (|Expression| (|Integer|)) *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|MappingPackage4| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrdinaryWeightedPolynomials| *2 *3 *4 *5)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *2 *5 *6)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *4 *2)) (|ofCategory| *6 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Expression| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|StochasticDifferential| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|VectorSpace| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *3)) (|isDomain| *1 (|WeightedPolynomials| *2 *3 *4 *5 *6 *7 *8)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BalancedPAdicRational| *4)) (|ofType| *4 *3) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|PAdicRational| *4)) (|ofType| *4 *3) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1 *3) (AND (|ofType| *4 *3) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|PAdicRationalConstructor| *4 *5)) (|isDomain| *3 (|Integer|)) (|ofCategory| *5 (|PAdicIntegerCategory| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *2 *3)) (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|has| *2 (SIGNATURE ** (*2 *2 *3))) (|has| *2 (SIGNATURE |coerce| (*2 (|Symbol|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)) (|isDomain| *3 (|DoubleFloat|))))) 
+(((*1 *2 *2 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *3)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Monoid|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|SetAggregate| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |normal| (|Factored| *3)) (|:| |special| (|Factored| *3)))) (|isDomain| *1 (|MonomialExtensionTools| *5 *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| *2)) (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|MonomialExtensionTools| *5 *2)) (|ofCategory| *5 (|Field|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|AbelianGroup|))) ((*1 *1 *1) (|ofCategory| *1 (|AbelianGroup|))) ((*1 *1 *1 *1) (|partial| |isDomain| *1 (|CardinalNumber|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Database| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *2 *1) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianGroup|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianGroup|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |basis| (|Matrix| *6)) (|:| |basisDen| *6) (|:| |basisInv| (|Matrix| *6))))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *5 *6 *7)) (|isDomain| *3 (|Record| (|:| |basis| (|Matrix| *6)) (|:| |basisDen| *6) (|:| |basisInv| (|Matrix| *6)))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FileCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Library|)))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|Switch|))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|Record| (|:| |height| (|Integer|)) (|:| |base| (|Integer|)) (|:| |quotient| (|Integer|)) (|:| |reste| (|Integer|)) (|:| |type| (|Union| "left" "center" "right" "vertical" "horizontal")))) (|isDomain| *1 (|NewtonPolygon| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |height| (|Integer|)) (|:| |base| (|Integer|)) (|:| |quotient| (|Integer|)) (|:| |reste| (|Integer|)) (|:| |type| (|Union| "left" "center" "right" "vertical" "horizontal")))) (|isDomain| *1 (|NewtonPolygon| *4 *5 *6 *7))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *4 *3 *4 *3 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Matrix| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|Integer|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|Integer|)) (|isDomain| *7 (|String|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Integer|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Integer|)) (|isDomain| *8 (|String|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|AbelianSemiGroup|))) ((*1 *1 *1 *1) (|isDomain| *1 (|Color|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Database| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianSemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianSemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|CancellationAbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *2 *1) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianSemiGroup|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RepresentationPackage2| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Automorphism| *6)) (|isDomain| *5 (|Mapping| *6 *6)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| R (|Matrix| *6)) (|:| A (|Matrix| *6)) (|:| |Ainv| (|Matrix| *6)))) (|isDomain| *1 (|PseudoLinearNormalForm| *6)) (|isDomain| *3 (|Matrix| *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|TranscendentalFunctionCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|FourierComponent| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *1 (|MappingPackageInternalHacks2| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|PolynomialIdeals| *3 *4 *5 *6))) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|BasicStochasticDifferential|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *2 (|LeftModule| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|ApplyUnivariateSkewPolynomial| *5 *2 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *1 *2 *2) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3 *2 *2 *4 *5) (AND (|isDomain| *4 (|Automorphism| *2)) (|isDomain| *5 (|Mapping| *2 *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *2 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *2))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|Segment| (|DoubleFloat|)))) (|isDomain| *1 (|PlotTools|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *7))) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5))))) 
 (((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *5 *4 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|ListAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *1 (|MappingPackageInternalHacks2| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedAlgebra| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicStochasticDifferential|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|))))) 
 (((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|isDomain| *4 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *2 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|Matrix| *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2)) (|isDomain| *1 (|IntegralBasisTools| *2 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *2 *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
 (((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|Vector| *5)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|SingleInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *5))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *1 (|File| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|BasicStochasticDifferential|))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Table| (|PositiveInteger|) (|NonNegativeInteger|)))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *1 (|PartitionsAndPermutations|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|ListToMap| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| *5)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Mapping| *5 *6)) (|isDomain| *1 (|ListToMap| *6 *5)))) ((*1 *2 *3 *4 *5 *2) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| *2)) (|isDomain| *6 (|Mapping| *2 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListToMap| *5 *2)))) ((*1 *2 *1 *1 *3) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *3 (|Character|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
 (((*1 *2 *3 *4 *5 *3 *6 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Complex| (|DoubleFloat|))) (|isDomain| *6 (|String|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|Partition|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|isDomain| *1 (|TwoFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Mapping| *4 (|Integer|))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *5 *7)) (|isDomain| *4 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *4 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|Divisor| *2)) (|ofCategory| *2 (|SetCategoryWithDegree|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofType| *2 (|List| (|Symbol|))) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *2) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *4) (|:| |exponent| *5)) (|Record| (|:| |index| *4) (|:| |exponent| *5)))) (|isDomain| *1 (|GeneralModulePolynomial| *2 *3 *4 *5 *6 *7)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *2))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 *2)) (|ofType| *6 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|BasicOperatorFunctions1| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *3 (|DoubleFloat|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|)))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Vector| (|List| *3))) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|GenExEuclid| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *7)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *2 *7 *4)) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|CliffordAlgebra| *2 *3 *4)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|QuadraticForm| *2 *3)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|Monoid|))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *3))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *2 *1) (|partial| AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|List| (|Record| (|:| |func| *2) (|:| |pole| (|Boolean|))))) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *4 *2))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumber| *3)) (|ofType| *3 (|PseudoAlgebraicClosureOfRationalNumber|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfFiniteField| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfRationalNumber|))))) 
+(((*1 *1) (|isDomain| *1 (|Color|)))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Factored| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|PartialFraction| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|PartialFractionPackage| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Factored| (|Polynomial| *6))) (|isDomain| *5 (|Symbol|)) (|isDomain| *3 (|Polynomial| *6)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|PartialFractionPackage| *6))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *1)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Stream| *3))) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|Type|))))) 
 (((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLapack|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|RetractableTo| (|Fraction| *2)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BoundIntegerRoots| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Kernel| *1)) (|ofCategory| *1 (|ExpressionSpace|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealClosure| *3)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|))))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *2 *3)) (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PrimitiveArray| (|SingleInteger|))) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *6) (|:| |right| *6) (|:| |sol?| (|Boolean|))) (|Integer|) *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *1 *1 *2 *2) (|partial| AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 *2) (|ofType| *4 *2)))) 
 (((*1 *2 *3 *4 *4 *5 *4 *6 *4 *5) (AND (|isDomain| *3 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Matrix| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLapack|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|DirectProductCategory| *3 *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|Type|)))) ((*1 *1 *2) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *5)) (|Record| (|:| |index| *2) (|:| |exponent| *5)))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *2 *5 *6 *7)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 (|OrderedVariableList| *3))))) ((*1 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *2 *5 *6 *7 *8 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *4))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *3 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
 (((*1 *1 *1 *1) (AND (|isDomain| *1 (|IndexedBits| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PermutationCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|BasicOperator|))) ((*1 *1 *1) (|isDomain| *1 (|SubSpaceComponentProperty|))) ((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Expression| *3)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *4) (|:| |exponent| *5)) (|Record| (|:| |index| *4) (|:| |exponent| *5)))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *2 *4 *5 *6 *7)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *5 (|OrderedVariableList| *3))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Integer|))))) 
 (((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLapack|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|CommonDenominator| *2 *4 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|InnerCommonDenominator| *2 *4 *5 *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|MatrixCommonDenominator| *2 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *2 *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| (|Integer|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaussianFactorizationPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerPrimesPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UniqueFactorizationDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *1 (|List| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Stream| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|isDomain| *2 (|ModuleMonomial| *5 *6 *7)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *6 *7 *8)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *3))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Monoid|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|MonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *3 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|PermutationCategory| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|DesingTreeCategory| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|DesingTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|DesingTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Tree| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Tree| *2))) (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |cd| (|String|)) (|:| |name| (|String|)))) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4 *2 *5 *6 *7 *8 *9 *10) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *13))) (|isDomain| *3 (|SparseUnivariatePolynomial| *13)) (|isDomain| *4 (|List| *12)) (|isDomain| *5 (|List| *10)) (|isDomain| *6 (|List| *13)) (|isDomain| *7 (|List| (|List| (|Record| (|:| |expt| (|NonNegativeInteger|)) (|:| |pcoef| *13))))) (|isDomain| *8 (|List| (|NonNegativeInteger|))) (|isDomain| *9 (|Vector| (|List| (|SparseUnivariatePolynomial| *10)))) (|ofCategory| *12 (|OrderedSet|)) (|ofCategory| *10 (|EuclideanDomain|)) (|ofCategory| *13 (|PolynomialCategory| *10 *11 *12)) (|ofCategory| *11 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|MultivariateLifting| *11 *12 *10 *13))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *3 *4 *4 *5 *4 *4 *5) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLapack|))))) 
-(((*1 *2 *3) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |glbase| (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|:| |glval| (|List| (|Integer|))))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *4 *5)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|InnerModularGcd| *4 *2 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofType| *5 *4) (|ofType| *6 (|Mapping| *4 *4 (|NonNegativeInteger|)))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|BasicType|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Reference| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *2 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|UniversalSegment| (|Integer|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|SetAggregate| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|isDomain| *2 (|List| (|Vector| *5))) (|isDomain| *1 (|InterpolateFormsPackage| *5 *6 *7 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *3 (|DivisorCategory| *11))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *3 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
+(((*1 *2 *3 *3 *2 *4) (AND (|isDomain| *3 (|Matrix| *2)) (|isDomain| *4 (|Integer|)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2)) (|isDomain| *1 (|IntegralBasisTools| *2 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *2 *5))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|InputForm|))))) 
 (((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1) (|isDomain| *1 (|SubSpaceComponentProperty|))) ((*1 *1 *2 *2 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileNameCategory|)))) ((*1 *1) (|isDomain| *1 (|ScriptFormulaFormat|))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PatternMatchListResult| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|ListAggregate| *3)))) ((*1 *1) (AND (|isDomain| *1 (|PatternMatchResult| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1) (|isDomain| *1 (|Symbol|))) ((*1 *1) (|isDomain| *1 (|Symbol|))) ((*1 *1) (|isDomain| *1 (|TexFormat|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *2 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Any|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AnyFunctions1| *4)) (|ofCategory| *4 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MyExpression| *3 *4)) (|ofType| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricPlaneCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricSpaceCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricSurface| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *6) (|:| |right| *6) (|:| |sol?| (|Boolean|))) (|Integer|) *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Union| (|Fraction| (|Polynomial| *6)) (|SuchThat| (|Symbol|) (|Polynomial| *6)))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *6))))) (|isDomain| *1 (|EigenPackage| *6)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *6)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *5)) (|SuchThat| (|Symbol|) (|Polynomial| *5)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| *4)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|EigenPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5))))))) 
+(((*1 *2 *3 *2 *2) (AND (|isDomain| *2 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|isDomain| *3 (|OrderedVariableList| *4)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealZeroPackage| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
 (((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *1 (|DrawOptionFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GuessOption|))))) 
 (((*1 *1 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|DifferentialVariableCategory| *3)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|))))) 
-(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedAlgebra| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *2 (|LeftModule| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|ApplyUnivariateSkewPolynomial| *5 *2 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *1 *2 *2) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3 *2 *2 *4 *5) (AND (|isDomain| *4 (|Automorphism| *2)) (|isDomain| *5 (|Mapping| *2 *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *2 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *2))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|DivisionRing|))) ((*1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1) (OR (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Type|))) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Group|)) (|ofCategory| *2 (|Type|))))) ((*1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|RectangularMatrix| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|PseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|ProjectivePlane| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|OrdinaryDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Result|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|)))))) 
-(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Kernel| *7)) (|ofCategory| *7 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| *2) (|RetractableTo| *5) (|PartialDifferentialRing| *5) (|CombinatorialOpsCategory|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RecurrenceOperator| *6 *7))))) 
+(((*1 *1 *1) (|partial| |ofCategory| *1 (|CharacteristicNonZero|))) ((*1 *1 *1) (|ofCategory| *1 (|FiniteFieldCategory|))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|CharacteristicNonZero|)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ListMonoidOps| *4 *2 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofType| *5 *2))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *7))) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *6 *4)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *5 *6 *4 *7))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InternalRationalUnivariateRepresentationPackage| *5 *6 *7 *8 *3))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *7) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *7) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *1 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|EuclideanDomain|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|EuclideanDomain|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|ComplexCategory| *4)) (|ofCategory| *4 (|IntegerNumberSystem|)) (|isDomain| *1 (|ComplexIntegerSolveLinearPolynomialEquation| *4 *5)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldSolveLinearPolynomialEquation| *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|IntegerSolveLinearPolynomialEquation|)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |sin| (|Stream| *4)) (|:| |cos| (|Stream| *4)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *4)) (|isDomain| *3 (|Stream| *4))))) 
-(((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|)))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *2)))) (|isDomain| *4 (|Kernel| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *5 *2 *6)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *2)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *5))))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Fraction| (|Polynomial| *5))) (|isDomain| *1 (|RationalFunction| *5)) (|ofCategory| *5 (|IntegralDomain|))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PrimitiveArray| (|ModMonic| *3 *4))) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *2 *3) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|isDomain| *1 (|CliffordAlgebra| *4 *2 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Field|)) (|ofType| *5 (|QuadraticForm| *4 *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|ModuleMonomial| *5 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofType| *7 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *6)) (|Record| (|:| |index| *5) (|:| |exponent| *6)))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|GeneralModulePolynomial| *4 *2 *5 *6 *7 *8)) (|ofCategory| *8 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *4))))) ((*1 *1 *2 *3) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *5)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| *5)) (|ofCategory| *1 (|PowerSeriesCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|ofCategory| *1 (|PowerSeriesCategory| *4 *3 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *2 *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AlgebraicFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CombinatorialFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ElementaryFunction| *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpressionSpace&| *4)) (|ofCategory| *4 (|ExpressionSpace|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionSpace&| *4 *5)) (|ofCategory| *4 (|FunctionSpace| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LiouvillianFunction| *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|QuasiAlgebraicSet| (|Fraction| (|Integer|)) (|OrderedVariableList| *3) (|DirectProduct| *4 (|NonNegativeInteger|)) (|DistributedMultivariatePolynomial| *3 (|Fraction| (|Integer|))))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|NonNegativeInteger|)) (|isDomain| *1 (|QuasiAlgebraicSet2| *3 *4))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
 (((*1 *2 *3 *4 *3 *3 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|)))) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| *4)))) (|isDomain| *1 (|PatternMatchResult| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|d01WeightsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|Type|)) (|ofCategory| *1 (|DirectProductCategory| *3 *4))))) 
+(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Kernel| *6))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Kernel| *6)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *5 *6))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|Float|))) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|List| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Integer|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| *2) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Multiset| *3)))) ((*1 *1 *2) (AND (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *4 (|OrderedVariableList| *5)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6)) (|ofCategory| *6 (|GcdDomain|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *4 (|OrderedVariableList| *5)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6)) (|ofCategory| *6 (|GcdDomain|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4))))) (|isDomain| *1 (|EigenPackage| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *3 *7 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *7)) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|RewriteRule| *3 *4 *2)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|SuchThat| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|))))) 
 (((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2 *2) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|UniversalSegment| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|isDomain| *1 (|ChangeOfVariable| *2 *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|DesingTreeCategory| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|DesingTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|DesingTreeCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Tree| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Tree| *2))) (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4))) (|isDomain| *1 (|CommonDenominator| *4 *5 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *6) (|:| |den| *4))) (|isDomain| *1 (|InnerCommonDenominator| *4 *5 *6 *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| (|Matrix| *4)) (|:| |den| *4))) (|isDomain| *1 (|MatrixCommonDenominator| *4 *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |eq| *7) (|:| |rh| (|List| (|Fraction| *6))))) (|isDomain| *1 (|PrimitiveRatDE| *5 *6 *7 *3)) (|isDomain| *4 (|List| (|Fraction| *6))) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4))) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
-(((*1 *2 *1 *3 *3 *4 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *4 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3)))))) 
+(((*1 *2 *3 *2 *3) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *4 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *3 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|SymbolTable|)))) ((*1 *2 *3 *2 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|InputForm|))) (|isDomain| *1 (|InputForm|))))) 
+(((*1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (|ofCategory| *3 (|DesingTreeCategory| *11))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *4 *2 *2 *2 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *2))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *2) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|FunctionFieldIntegralBasis| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| (|Integer|))) (|:| |basisDen| (|Integer|)) (|:| |basisInv| (|Matrix| (|Integer|))))) (|isDomain| *1 (|NumberFieldIntegralBasis| *3 *4)) (|ofCategory| *4 (|FramedAlgebra| (|Integer|) *3)))) ((*1 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *4)) (|:| |basisDen| *4) (|:| |basisInv| (|Matrix| *4)))) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *3 *4 *5 *6)) (|ofCategory| *6 (|MonogenicAlgebra| *4 *5)))) ((*1 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *4)) (|:| |basisDen| *4) (|:| |basisInv| (|Matrix| *4)))) (|isDomain| *1 (|WildFunctionFieldIntegralBasis| *3 *4 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *4 *5))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|AbelianSemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgebraicMultFact| *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|AlgebraicNumber|) *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|AlgebraicNumber|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| (|AlgebraicNumber|) *6 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|AlgebraicMultFact| *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|Complex| (|Integer|)))) (|isDomain| *1 (|GaussianFactorizationPackage|)) (|isDomain| *3 (|Complex| (|Integer|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GeneralizedMultivariateFactorize| *4 *5 *6 *7 *3)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *3 (|PolynomialCategory| *7 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|GenUFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| *5 *6))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|InnerAlgFactor| *5 *6 *7 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *7)) (|SparseUnivariatePolynomial| *7))) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|InnerMultFact| *5 *6 *7 *3)) (|ofCategory| *3 (|PolynomialCategory| *7 *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *7)) (|SparseUnivariatePolynomial| *7))) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|PolynomialCategory| *7 *6 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *8))) (|isDomain| *1 (|InnerMultFact| *5 *6 *7 *8)) (|isDomain| *3 (|SparseUnivariatePolynomial| *8)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *4 *5)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5))))) ((*1 *2 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|LyndonWord| *4))) (|isDomain| *1 (|LyndonWord| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultFiniteFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultFiniteFactorize| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MPolyCatPolyFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Polynomial| *6) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MRationalFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| *6) *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateFactorize| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultivariateFactorize| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFunctionFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Polynomial| (|Integer|))))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| (|Fraction| (|Integer|)) *4))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|SimpleAlgebraicExtensionAlgFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|MonogenicAlgebra| (|Fraction| (|Polynomial| (|Integer|))) *4))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|SAERationalFunctionAlgFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| *7)))) (|isDomain| *1 (|SupFractionFactorizer| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| *7))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|UniqueFactorizationDomain|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|Mapping| *6 (|List| *6)))) (|ofCategory| *5 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *5 *6))))) 
 (((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *3 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|OrderedFreeMonoid| *3)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|OrderedMonoid|)) (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| (|Fraction| (|Integer|))))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|EuclideanDomain|)))) ((*1 *2 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |lm| (|FreeMonoid| *3)) (|:| |rm| (|FreeMonoid| *3)))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |quotient| (|NonNegativeInteger|)) (|:| |remainder| (|NonNegativeInteger|)))) (|isDomain| *1 (|NonNegativeInteger|)))) ((*1 *2 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |lm| (|Union| (|OrderedFreeMonoid| *3) "failed")) (|:| |rm| (|Union| (|OrderedFreeMonoid| *3) "failed")))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|Logic|))) ((*1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Kernel| *1)) (|ofCategory| *1 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *1))))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Variable| *5)) (|ofType| *5 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|UnivariatePolynomial| *5 (|Polynomial| *6))) (|isDomain| *1 (|PolynomialToUnivariatePolynomial| *5 *6)) (|isDomain| *3 (|Polynomial| *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $))))) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *4)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *5 *4 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|RationalFunction| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
+(((*1 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
 (((*1 *2 *3 *4 *3 *4 *4 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *3 *6 *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PackageForPoly| *3 *4 *5 *6)) (|ofCategory| *4 (|FiniteAbelianMonoidRing| *3 *5))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PermutationCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Set| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Set| (|List| *4))) (|isDomain| *1 (|PermutationGroup| *4)) (|isDomain| *3 (|List| *4)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Set| (|Set| *4))) (|isDomain| *1 (|PermutationGroup| *4)) (|isDomain| *3 (|Set| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3))))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Tableau| *3))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
 (((*1 *2 *3 *4 *3 *5 *5 *3 *5 *4) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *2 *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|ofCategory| *1 (|ExpressionSpace|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| (|Float|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| (|Float|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Complex| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Complex| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Complex| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *5)))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Complex| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *10 (|PlacesCategory| *5 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *5 *6 *3 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (|ofCategory| *4 (|DesingTreeCategory| *11))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)) (|isDomain| *4 (|DoubleFloat|))))) 
+(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *5 (|Finite|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *6 *4 *7)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *6))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|List| (|Record| (|:| |func| *2) (|:| |pole| (|Boolean|))))) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *4 *2))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|))))) 
-(((*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| *4)))))))) (|isDomain| *1 (|EigenPackage| *4)) (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4))))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|Point| *4))) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *6) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|List| *2) *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *2)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *2))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|TopLevelThreeSpace|))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *9 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|isDomain| *2 (|Record| (|:| |mult| (|NonNegativeInteger|)) (|:| |subMult| (|NonNegativeInteger|)) (|:| |blUpRec| (|List| (|Record| (|:| |recTransStr| (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *6)) (|:| |recPoint| (|AffinePlane| *6)) (|:| |recChart| *5) (|:| |definingExtension| *6)))))) (|isDomain| *1 (|BlowUpPackage| *6 *7 *8 *9 *5)) (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *6)) (|isDomain| *4 (|AffinePlane| *6)) (|ofCategory| *8 (|FiniteAbelianMonoidRing| *6 *9)) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *4 *5)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldFunctions| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|))))))))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *3 *3 *3 *4 *3 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SExpression|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AxiomServer|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|PoincareBirkhoffWittLyndonBasis| *3)) (|:| |c| *4)))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|LyndonWord| *3))) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|IrredPolyOverFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|List| (|Places| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|)))) ((*1 *1 *2 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *3 *3 *4 *3 *5 *3 *5 *4 *5 *5 *4 *4 *5 *3) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|RetractableTo| *5))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *6)))))) (|isDomain| *1 (|RetractSolvePackage| *5 *6))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| (|Complex| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| *5)))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| (|Complex| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| (|Complex| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|Float|))) (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|Numeric| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5 *5)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LieExponentials| *2 *3 *4)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|DifferentialRing|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Mapping| *1 (|NonNegativeInteger|))) (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Mapping| *1 (|NonNegativeInteger|))) (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
 (((*1 *2 *3 *4 *5 *6 *3 *3 *3 *3 *6 *3 *7 *8) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp28| APROD)))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp34| MSOLVE)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Multiset| *3)))) ((*1 *1 *2) (AND (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|)))))) 
-(((*1 *2 *3 *3 *2 *4) (AND (|isDomain| *3 (|Matrix| *2)) (|isDomain| *4 (|Integer|)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2)) (|isDomain| *1 (|IntegralBasisTools| *2 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *2 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|LinearDependence| *5 *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| *5)) (|not| (|ofCategory| *5 (|Field|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Vector| (|Fraction| *5))) (|isDomain| *1 (|LinearDependence| *5 *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Tree| *3))) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *2 (|Record| (|:| |cycle?| (|Boolean|)) (|:| |prefix| (|NonNegativeInteger|)) (|:| |period| (|NonNegativeInteger|)))) (|isDomain| *1 (|Stream| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *3 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3 *1) (AND (|isDomain| *2 (|Record| (|:| |less| (|BinarySearchTree| *3)) (|:| |greater| (|BinarySearchTree| *3)))) (|isDomain| *1 (|BinarySearchTree| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|DivisorCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|IntegrationResult| *4)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *3) (|TranscendentalFunctionCategory|))) (|ofCategory| *3 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|IntegrationResultToFunction| *3 *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|IntegrationResult| (|Fraction| (|Polynomial| *3)))) (|ofCategory| *3 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|IntegrationResultRFToFunction| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |normal| *3) (|:| |special| *3))) (|isDomain| *1 (|MonomialExtensionTools| *5 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Vector| (|Vector| *5))) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|CharacterClass|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|StringAggregate|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Character|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|StringAggregate|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LyndonWord| *3))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|OpenMathPackage|))))) 
 (((*1 *2 *3 *4 *3 *4 *5 *3 *4 *3 *3 *3 *3) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| (|Fraction| (|Polynomial| *6)))) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|RationalFunctionIntegration| *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|SubSpaceComponentProperty|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *3 *6)) (|ofCategory| *6 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4)))) (|:| |geneigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| *4)))))))) (|isDomain| *1 (|EigenPackage| *4)) (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4))))))) 
+(((*1 *2 *1 *3 *4 *4 *5) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1 *3 *4 *4 *5) (AND (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *7) (|:| |polj| *7))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *3 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4 *3 *3 *3 *3 *5 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp30| APROD)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagLinearEquationSolvingPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|Record| (|:| |height| (|Integer|)) (|:| |base| (|Integer|)) (|:| |quotient| (|Integer|)) (|:| |reste| (|Integer|)) (|:| |type| (|Union| "left" "center" "right" "vertical" "horizontal")))) (|isDomain| *1 (|NewtonPolygon| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |height| (|Integer|)) (|:| |base| (|Integer|)) (|:| |quotient| (|Integer|)) (|:| |reste| (|Integer|)) (|:| |type| (|Union| "left" "center" "right" "vertical" "horizontal")))) (|isDomain| *1 (|NewtonPolygon| *4 *5 *6 *7))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *4))))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|Vector| (|Matrix| *4)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *7)) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6))))) (|isDomain| *1 (|LexTriangularPackage| *5 *6))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|CartesianTensor| *5 *6 *7)) (|ofType| *5 (|Integer|)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|CommutativeRing|)) (|ofCategory| *8 (|CommutativeRing|)) (|isDomain| *2 (|CartesianTensor| *5 *6 *8)) (|isDomain| *1 (|CartesianTensorFunctions2| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *9)) (|ofCategory| *9 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *2 (|PolynomialCategory| *9 *7 *5)) (|isDomain| *1 (|MPolyCatFunctions2| *5 *6 *7 *8 *9 *4 *2)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *8 *6 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *2 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *2 (|DirectProductCategory| *3 *4))))) 
-(((*1 *1) (|isDomain| *1 (|Color|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4))))) 
-(((*1 *2 *3 *4 *3 *3) (AND (|isDomain| *3 (|Equation| *6)) (|isDomain| *4 (|BasicOperator|)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *5 *6)))) ((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|List| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *3 (|List| (|Equation| *7))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| (|Equation| *8))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *8)) (|isDomain| *6 (|List| *8)) (|ofCategory| *8 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *8)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Equation| *7)) (|ofCategory| *7 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *6 (|List| (|Equation| *8))) (|ofCategory| *8 (|FunctionSpace| *7)) (|isDomain| *5 (|Equation| *8)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *8)))) ((*1 *2 *3 *4 *3 *5) (AND (|isDomain| *3 (|Equation| *5)) (|isDomain| *4 (|BasicOperator|)) (|ofCategory| *5 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *5)))) ((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *3)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|FunctionSpace| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *6 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|List| *3)) (|ofCategory| *3 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionSpaceODESolver| *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|List| *3)) (|ofCategory| *3 (|FunctionSpace| *7)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ExpressionSolve| *7 *3 *2 *8)) (|ofCategory| *8 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *3))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *6)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *5))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *1 (|TaylorSolve| *5 *2 *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |poly| *3) (|:| |mult| *5))) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|ExtAlgBasis|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|FunctionFieldIntegralBasis| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|NumberFieldIntegralBasis| *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *4 *3 *5 *6)) (|ofCategory| *6 (|MonogenicAlgebra| *3 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|WildFunctionFieldIntegralBasis| *4 *3 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *3 *5))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Kernel| *1)) (|ofCategory| *1 (|ExpressionSpace|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| *4)))))))) (|isDomain| *1 (|EigenPackage| *4)) (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4))))))) 
+(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *2 (|Fraction| (|Integer|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| (|Integer|)))))) (|isDomain| *2 (|List| (|List| (|Equation| (|Polynomial| *4))))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *4)))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *4)))) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *2 (|Record| (|:| |particular| *4) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|ElementaryFunctionLODESolver| *6 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *2 *4 *2 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ElementaryFunctionLODESolver| *6 *2 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5)))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|List| (|Vector| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| (|Vector| *5) "failed")) (|:| |basis| (|List| (|Vector| *5)))))) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)) (|isDomain| *4 (|List| (|Vector| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *7 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|List| (|Record| (|:| |particular| (|Union| *7 "failed")) (|:| |basis| (|List| *7))))) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *7 *3)) (|isDomain| *4 (|List| *7)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|NonLinearSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|NonLinearSolvePackage| *4)))) ((*1 *2 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|NonLinearFirstOrderODESolver| *5 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *5) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Matrix| *7)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)) (|isDomain| *4 (|Vector| *7)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedFunctionSpace| *5) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Vector| *6))) (|isDomain| *1 (|ElementaryFunctionODESolver| *5 *6)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| (|Equation| *7))) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| *7)) (|isDomain| *4 (|List| (|BasicOperator|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *7)) (|:| |basis| (|List| (|Vector| *7))))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Equation| *7)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Union| (|Record| (|:| |particular| *7) (|:| |basis| (|List| *7))) *7 "failed")) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Union| (|Record| (|:| |particular| *3) (|:| |basis| (|List| *3))) *3 "failed")) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *3 (|Equation| *2)) (|isDomain| *4 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *2)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))))) ((*1 *2 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Equation| *2)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ElementaryFunctionODESolver| *6 *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|Float|)))) (|isDomain| *4 (|Float|)) (|isDomain| *5 (|List| *4)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *4 *5 *6 *5 *4 *4) (AND (|isDomain| *3 (|Vector| (|Expression| *4))) (|isDomain| *5 (|List| (|Float|))) (|isDomain| *6 (|Expression| (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |particular| *6) (|:| |basis| (|List| *6))) "failed") *7 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|isDomain| *2 (|Record| (|:| |particular| (|Vector| *6)) (|:| |basis| (|Matrix| *6)))) (|isDomain| *1 (|SystemODESolver| *6 *7)) (|isDomain| *3 (|Matrix| *6)) (|isDomain| *4 (|Vector| *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7 *8) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *6 (|List| (|List| (|Expression| *3)))) (|isDomain| *7 (|String|)) (|isDomain| *8 (|DoubleFloat|)) (|isDomain| *5 (|List| (|Expression| (|Float|)))) (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *3 *3 *3 *4 *4 *5 *6 *7) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *6 (|List| (|List| (|Expression| *3)))) (|isDomain| *7 (|String|)) (|isDomain| *5 (|List| (|Expression| (|Float|)))) (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *4 (|Float|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *4 (|Float|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|TransSolvePackage| *4)) (|isDomain| *3 (|Expression| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|TransSolvePackage| *4)) (|isDomain| *3 (|Equation| (|Expression| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|Equation| (|Expression| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|Expression| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|TransSolvePackage| *5)) (|isDomain| *3 (|List| (|Equation| (|Expression| *5)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|SystemSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *5)))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|SystemSolvePackage| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *4)))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|SystemSolvePackage| *5)) (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|Fraction| (|Polynomial| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|SystemSolvePackage| *4)) (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *4))))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Tableau| *3))))) 
-(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *7 *8 *9)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *7 *8 *9 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *7 *8 *9)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *7 *8 *9 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *1 (|BlowUpPackage| *4 *5 *2 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *3 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined")) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|)))) ((*1 *2 *2 *3 *4 *4 *5) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerBits|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *4 *4 *3) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *3 *6)) (|ofCategory| *6 (|SetCategory|))))) 
 (((*1 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|CombinatorialOpsCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1) (|ofCategory| *1 (|CombinatorialOpsCategory|)))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *3 (|DivisorCategory| *10)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *3 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Record| (|:| |num| (|List| *6)) (|:| |den| *6))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Fraction| (|DistributedMultivariatePolynomial| *6 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|:| |den| (|DistributedMultivariatePolynomial| *5 *4)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Fraction| (|DistributedMultivariatePolynomial| *6 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|:| |den| (|DistributedMultivariatePolynomial| *5 *4)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
+(((*1 *2 *1 *3 *3) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Void|))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *5 "failed") *7)) (|isDomain| *4 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|RadicalCategory|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PointsOfFiniteOrderTools| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Fraction| *3)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|List| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (AND (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|String|)) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DoubleFloat|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3 (|Integer|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PermutationGroup| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|MonogenicLinearOperator| *3)) (|isDomain| *1 (|OppositeMonogenicLinearOperator| *2 *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *5 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Stream| (|Stream| (|Polynomial| *5)))) (|isDomain| *1 (|WeierstrassPreparation| *5)) (|isDomain| *4 (|Stream| (|Polynomial| *5)))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (AND (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|String|)) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceToExponentialExpansion| *3 *2 *4 *5)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *2))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3) (CATEGORY |domain| (SIGNATURE |coerce| ($ *4))))) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *5 (|Join| (|UnivariatePowerSeriesCategory| *2 *4) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *3 *2 *4 *5 *6 *7)) (|ofCategory| *6 (|PartialTranscendentalFunctions| *5)) (|ofType| *7 (|Symbol|))))) 
-(((*1 *1) (|ofCategory| *1 (|FiniteFieldCategory|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |primelt| *5) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *5))) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|FunctionSpacePrimitiveElement| *4 *5)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |primelt| *3) (|:| |pol1| (|SparseUnivariatePolynomial| *3)) (|:| |pol2| (|SparseUnivariatePolynomial| *3)) (|:| |prim| (|SparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|FunctionSpacePrimitiveElement| *4 *3)) (|ofCategory| *3 (|AlgebraicallyClosedField|)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *3 *4 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef1| (|Integer|)) (|:| |coef2| (|Integer|)) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|PrimitiveElement| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *5))) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|PrimitiveElement| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *6))) (|:| |prim| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *1 (|PrimitiveElement| *6))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *7))) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *4 *5 *6 *7)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| *1)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *2 *3 *4 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *5 *6))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldSquareFreeDecomposition| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|FiniteAbelianMonoidRing| *5 *7)) (|ofCategory| *7 (|DirectProductCategory| *8 (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *6 *7 *8 *4)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *5))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *3 (|DoubleFloat|))))) 
-(((*1 *1) (|isDomain| *1 (|Color|)))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *2 (|BlowUpMethodCategory|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|FractionFreeFastGaussian| *5 *6)) (|ofCategory| *6 (|AbelianMonoidRing| *5 *4)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|FractionFreeFastGaussian| *5 *6)) (|ofCategory| *6 (|AbelianMonoidRing| *5 *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *5)) (|isDomain| *3 (|List| *5)) (|ofType| *4 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|PolynomialInterpolation| *4 *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *5)) (|isDomain| *1 (|PolynomialInterpolation| *4 *5)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3 *3 *4 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Fraction| (|Polynomial| *6))) (|isDomain| *1 (|RationalInterpolation| *5 *6)) (|ofType| *5 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *6) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *7) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| *8) (|:| |order| (|NonNegativeInteger|)))) (|List| *6) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Field|)) (|ofType| *11 (|Mapping| *8 *6)) (|ofCategory| *9 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *10 (|Mapping| *6 *9)) (|isDomain| *2 (|List| (|Record| (|:| |function| *8) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *6 *7 *8 *9 *10 *11)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *9) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| *9) (|:| |order| (|NonNegativeInteger|)))) (|List| *7) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|Field|)) (|ofType| *12 (|Mapping| *9 *7)) (|ofCategory| *10 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *11 (|Mapping| *7 *10)) (|isDomain| *2 (|List| (|Record| (|:| |function| *9) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *7 *8 *9 *10 *11 *12)) (|ofCategory| *8 (|GcdDomain|)) (|ofCategory| *9 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *10) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *6 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *6 (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *6 (|Integer|))))) (|ofType| *6 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *6 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *7 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *7 (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *7 (|Integer|))))) (|ofType| *7 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *7 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *7))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixManipulation| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Matrix| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *6)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *3 *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Equation| *3))) (|isDomain| *1 (|Equation| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *2)) (|ofCategory| *2 (|ElementaryFunctionCategory|)) (|ofCategory| *2 (|FunctionSpace| *4))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |unit| *1) (|:| |canonical| *1) (|:| |associate| *1))) (|ofCategory| *1 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|List| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Vector| *4))) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DisplayPackage|))))) 
+(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *3 (|List| (|Palette|))) (|isDomain| *1 (|GraphImage|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *4 *5 *6 *3))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
 (((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|LinearAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |adjMat| *3) (|:| |detMat| *4))) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Result|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|RetractableTo| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofType| *7 (|Vector| *6)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *6)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)) (|ofType| *7 *2)))) 
+(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 *3)) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) *3 *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 HPSPEC) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|OpenMathError|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|GcdDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| *8))) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|Record| (|:| |order| (|NonNegativeInteger|)) (|:| |function| *6))) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|SubSpace| 3 *3)))) ((*1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| *4) (|:| |num| *4)))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
 (((*1 *2 *3 *3 *4 *5 *3 *3 *4 *4 *4 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatchResult| *4 *5)) (|ofCategory| *5 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternFunctions1| *5 *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternFunctions1| *5 *6))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|SquareMatrix| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|QuadraticForm| *3 *4))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *4)))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *4)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|SemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| (|Kernel| *1)) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |val| (|Pattern| *3)) (|:| |exponent| (|NonNegativeInteger|)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |var| *5) (|:| |exponent| (|NonNegativeInteger|)))))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Record| (|:| |var| *5) (|:| |exponent| (|Integer|)))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
-(((*1 *2 *3 *4 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *3 (|DivisorCategory| *11)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *3 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (|isDomain| *4 (|Integer|)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |den| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|isDomain| *4 (|Integer|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |den| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|isDomain| *4 (|Integer|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *1 *3 *3 *2) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *2 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)))) ((*1 *2 *1 *3 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|TaylorSeries| *5))) (|isDomain| *1 (|WeierstrassPreparation| *5)) (|isDomain| *4 (|TaylorSeries| *5))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *2 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *2 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TemplateUtilities|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|RationalFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
 (((*1 *2 *3 *4 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Kernel| (|AlgebraicNumber|))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|isDomain| *3 (|List| (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|isDomain| *3 (|Kernel| (|AlgebraicNumber|))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|FractionalIdeal| *3 *2 *4 *5)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *2 *4) (|RetractableTo| *2))))) ((*1 *2 *1) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|FramedModule| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *5 (|FramedAlgebra| *2 *4)) (|ofType| *6 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Kernel| (|InnerAlgebraicNumber|))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|InnerAlgebraicNumber|))) (|isDomain| *3 (|List| (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|InnerAlgebraicNumber|))) (|isDomain| *3 (|Kernel| (|InnerAlgebraicNumber|))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|MonogenicAlgebra| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|NormInMonogenicAlgebra| *4 *2 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
-(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| (|Polynomial| *5))) (|:| |coeff| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|RationalFunctionIntegration| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|List| (|Polynomial| *5))) (|isDomain| *1 (|FunctionFieldCategory&| *4 *5 *6 *7)) (|ofCategory| *4 (|FunctionFieldCategory| *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Polynomial| *4)))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|PackageForPoly| *4 *5 *6 *7)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6))))) 
+(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Mapping| *2 (|NonNegativeInteger|) (|NonNegativeInteger|) *7)) (|isDomain| *4 (|Vector| *7)) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Vector| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *7 (|AbelianMonoidRing| *2 *5)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *7))))) 
 (((*1 *2 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|List| (|Equation| *4))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined")) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *1 (|IntegerFactorizationPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PatternMatchable| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatch| *5 *6 *4)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *13)) (|ofCategory| *13 (|DesingTreeCategory| *12)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) *2)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4))) (|isDomain| *1 (|CommonDenominator| *4 *5 *3)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *6) (|:| |den| *4))) (|isDomain| *1 (|InnerCommonDenominator| *4 *5 *6 *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *5)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| (|Matrix| *4)) (|:| |den| *4))) (|isDomain| *1 (|MatrixCommonDenominator| *4 *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |eq| *7) (|:| |rh| (|List| (|Fraction| *6))))) (|isDomain| *1 (|PrimitiveRatDE| *5 *6 *7 *3)) (|isDomain| *4 (|List| (|Fraction| *6))) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|QuotientFieldCategory| *4)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4))) (|isDomain| *1 (|UnivariatePolynomialCommonDenominator| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *4) (|partial| AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *3 *4) (|partial| AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *6 (|PolynomialCategory| *2 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *9)) (|ofCategory| *10 (|DivisorCategory| *4)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *2 *5 *6 *7 *8 *9 *4 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stream| *4))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DefiniteIntegrationTools| *4 *5)) (|ofCategory| *5 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DrawComplex|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
-(((*1 *1 *1 *2 *3 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|PolynomialSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| *7)))) (|isDomain| *1 (|SupFractionFactorizer| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| *7))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|UniqueFactorizationDomain|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *4 *3)) (|ofCategory| *3 (|Join| (|UnivariatePolynomialCategory| *4) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *4 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
+(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|DisplayPackage|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *2 *6)) (|ofCategory| *6 (|SetCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *1 (|SplittingNode| *3 *2)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Permutation| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage1| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Permutation| (|Integer|)))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *1 (|RepresentationPackage1| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Integer|)))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *2 (|FiniteFieldCategory|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModMonic| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *2 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *6)) (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *6 *3 *7 *4)) (|ofCategory| *7 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *6) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *4)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|NonCommutativeOperatorDivision| *3 *4)) (|ofCategory| *3 (|MonogenicLinearOperator| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PolynomialInterpolationAlgorithms| *4 *2))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *4 *4 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| G)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagIntegrationPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|List| (|BasicOperator|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerBits|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Tree| *3))) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *7 *8 *9)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *7 *8 *9 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *7 *8 *9)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *7 *8 *9 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *7 *8 *9 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *2 (|FunctionSpace| *3)) (|isDomain| *1 (|AlgebraicFunction| *3 *2)) (|ofCategory| *3 (|RetractableTo| *4)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|)))))))))) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *5)))) (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *5))))) 
 (((*1 *2 *1 *1 *3) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *3 (|Character|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|AbelianSemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|RetractableTo| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofType| *7 (|Vector| *6)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *6)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)) (|ofType| *7 *2)))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|U32Vector|))) (|isDomain| *1 (|U32VectorPolynomialOperations|)) (|isDomain| *3 (|U32Vector|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|OpenMathConnection|)) (|isDomain| *4 (|Any|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
+(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *2 *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|SquareMatrix| *2 *3)) (|ofType| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|FreeGroup| (|BasicOperator|))) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *4)) (|ofCategory| *4 (|LeftModule| *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|FreeGroup| (|BasicOperator|))) (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|EltableAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *2 *6 *7)) (|ofCategory| *6 (|DirectProductCategory| *5 *2)) (|ofCategory| *7 (|DirectProductCategory| *4 *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Partition|))))) 
+(((*1 *1) (|isDomain| *1 (|ODEIntensityFunctionsTable|)))) 
 (((*1 *2 *3 *3 *3 *4 *4 *5 *5 *5 *3 *5 *5 *3 *6 *3 *3 *3) (AND (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|Matrix| *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *2)) (|isDomain| *1 (|IntegralBasisTools| *2 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *2 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |const| *3) (|:| |nconst| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *2 *4 *5) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *1 (|GeneralHenselPackage| *4 *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *1 (|Plot3D|))))) 
 (((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|SubSpace| 3 *3)))) ((*1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3 *4 *2 *2 *2 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *2))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *2 *2 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *2 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *2 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Mapping| (|DoubleFloat|) (|DoubleFloat|)))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|NormRetractPackage| *4 *5 *6 *3 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofType| *7 (|PositiveInteger|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated")))))))) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UTSodetools| *4 *5 *6 *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Any|)) (|isDomain| *1 (|AnyFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| *2)) (|ofType| *4 (|List| *2)) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| *5)) (|ofCategory| *5 (|FortranMachineTypeCategory|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|NormRetractPackage| *4 *5 *6 *3 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofType| *7 (|PositiveInteger|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|RetractableTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (|partial| OR (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|not| (|ofCategory| *3 (|Algebra| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|IntegerNumberSystem|))) (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|QuotientFieldCategory| (|Integer|)))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (|partial| OR (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
 (((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
-(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *10 (|RegularTriangularSetCategory| *6 *7 *8 *9)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *10) (|:| |ineq| (|List| *9))))) (|isDomain| *1 (|QuasiComponentPackage| *6 *7 *8 *9 *10)) (|isDomain| *3 (|List| *9)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *10 (|RegularTriangularSetCategory| *6 *7 *8 *9)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *10) (|:| |ineq| (|List| *9))))) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *6 *7 *8 *9 *10)) (|isDomain| *3 (|List| *9))))) 
-(((*1 *2 *1 *3 *3 *4) (AND (|isDomain| *3 (|Mapping| (|OutputForm|) (|OutputForm|) (|OutputForm|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ListMonoidOps| *5 *6 *7)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|AbelianMonoid|)) (|ofType| *7 *6))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|SparseUnivariateSkewPolynomial| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Automorphism| *3)) (|ofType| *5 (|Mapping| *3 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *6)))) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RealNumberSystem|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|BasicStochasticDifferential|))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| *3)) (|:| |logand| (|SparseUnivariatePolynomial| *3))))) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|FunctionSpace| *5)) (|isDomain| *1 (|AlgebraicFunction| *5 *2)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|OutputForm|)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *2 *3) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |points| (|NonNegativeInteger|)) (|:| |curves| (|NonNegativeInteger|)) (|:| |polygons| (|NonNegativeInteger|)) (|:| |constructs| (|NonNegativeInteger|))))))) 
 (((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|List| (|Fraction| *6))) (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|RationalIntegration| *5 *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Record| (|:| |zeros| (|Stream| (|DoubleFloat|))) (|:| |ones| (|Stream| (|DoubleFloat|))) (|:| |singularities| (|Stream| (|DoubleFloat|))))) (|isDomain| *1 (|BasicFunctions|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|AxiomServer|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Database| (|IndexCard|))) (|isDomain| *1 (|OperationsQuery|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *1 (|HeuGcd| *3))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3 *1) (|partial| AND (|ofCategory| *1 (|KeyedDictionary| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|Multiset| *4)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Multiset| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|Void|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
 (((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerAlgebraicNumber|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|U32Vector|)) (|isDomain| *5 (|Integer|)) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *6)) (|ofCategory| *3 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |bas| (|GeneralTriangularSet| *4 *5 *6 *7)) (|:| |top| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|DictionaryOperations| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|PartialDifferentialRing| *6)) (|isDomain| *2 (|Matrix| *7)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *6 *7 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *7)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *6) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|XDistributedPolynomial| (|Symbol|) *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|XPolynomial| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|XRecursivePolynomial| *3 *4))))) 
+(((*1 *1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
 (((*1 *2 *3 *3 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *2 (|BlowUpMethodCategory|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Union| (|Integer|) "failed") *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Integer|) "failed") *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Integer|) "failed") *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|PartialDifferentialRing| *4)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *4 *2 *5 *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *3 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *2 *6)) (|ofCategory| *6 (|PolynomialCategory| *2 *4 *5))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *3 (|PlacesCategory| *4 *8)) (|ofCategory| *9 (|DivisorCategory| *3)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *2 *8 *3 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *2 *8 *3 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *4)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *4 *5 *6 *7 *2 *8 *3)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *3 (|PlacesCategory| *4 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Places| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|ProjectivePlane| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 *3)) (|ofType| *7 *3) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PackageForPoly| *4 *5 *6 *7)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6))))) 
+(((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|NPCoef| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|Complex| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|Polynomial| *4))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *1) (|ofCategory| *1 (|AbelianMonoid|))) ((*1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *3 *6 *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SortPackage| *4 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|SortPackage| *3 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *3) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|))))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|List| *4)))) (|isDomain| *2 (|List| (|List| *4))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *4))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 (|Integer|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|PolynomialIdeals| *3 *4 *5 *6))) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|HeuGcd| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|GcdDomain|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Record| (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6))))) 
+(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *6 *7 *5)) (|ofCategory| *7 (|Field|)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RoutinesTable|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |gblist| (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|:| |gvlist| (|List| (|Integer|))))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|MatrixCategory| *7 *8 *9)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *2)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *2 *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *2 *4)) (|ofCategory| *4 (|EuclideanDomain|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (|Integer|))))) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|Factored| *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *4) (|:| |pow| (|Integer|))))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Factored| *4)) (|isDomain| *1 (|GaloisGroupFactorizer| *4))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *5 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|IndexedAggregate| *4 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |polyPart| (|LaurentPolynomial| *4 *5)) (|:| |fracPart| (|Fraction| *5)))) (|isDomain| *1 (|LaurentPolynomial| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |primePart| *1) (|:| |commonPart| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *6)) (|isDomain| *5 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *6)) (|SparseUnivariatePolynomial| *6))) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |outval| *7) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| *7)))))) (|isDomain| *1 (|InnerNumericEigenPackage| *6 *7 *4)) (|ofCategory| *7 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|NewtonPolygon| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *3 *6 *7 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|DirectProductCategory| *8 *2)) (|ofType| *8 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *6 *3 *7 *8 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *6 *7)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *6))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |poly| *6) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *5 *6 *3 *7)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |poly| *6) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) (|isDomain| *1 (|RationalRicDE| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|BalancedPAdicRational| *3)) (|ofType| *3 (|Integer|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *3 (|Stream| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *2)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *3)))) ((*1 *2 *3) (AND (|isDomain| *2 (|ContinuedFraction| (|Integer|))) (|isDomain| *1 (|NumericContinuedFraction| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PAdicRational| *3)) (|ofType| *3 (|Integer|)))) ((*1 *2 *1) (AND (|ofType| *3 (|Integer|)) (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PAdicRationalConstructor| *3 *4)) (|ofCategory| *4 (|PAdicIntegerCategory| *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *4 *2)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|))))) 
-(((*1 *1 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Expression| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Color|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|Finite|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|String|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathErrorKind|)) (|isDomain| *1 (|OpenMathError|))))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| C (|Matrix| *5)) (|:| |g| (|Vector| *5))))) (|isDomain| *1 (|PseudoLinearNormalForm| *5)) (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|LiePolynomial| *4 *5))) (|isDomain| *1 (|LieExponentials| *4 *5 *6)) (|ofCategory| *5 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *6 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |sup| (|Polynomial| *6)) (|:| |inf| (|Polynomial| *6)))) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *4 *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |polnum| (|NewSparseUnivariatePolynomial| *3)) (|:| |polden| *3) (|:| |power| (|NonNegativeInteger|)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |polnum| *1) (|:| |polden| *1) (|:| |power| (|NonNegativeInteger|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Tableau| (|List| *4))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4))))) 
+(((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Mapping| (|SparseMultivariateTaylorSeries| *4 *3 *5))) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *4 *3 *5)) (|ofCategory| *5 (|PolynomialCategory| *4 (|IndexedExponents| *3) *3)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Mapping| (|TaylorSeries| *4))) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *4 (|Mapping| (|Boolean|) *2 *2)) (|isDomain| *1 (|UserDefinedPartialOrdering| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *2))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *2 (|DivisorCategory| *9)) (|ofCategory| *10 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *1 (|FortranType|))))) 
 (((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|OutputForm|) (|OutputForm|))) (|isDomain| *1 (|BasicOperator|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|OutputForm|) (|List| (|OutputForm|)))) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Mapping| (|OutputForm|) (|List| (|OutputForm|)))) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Database| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| (*2 $)) (SIGNATURE |fullDisplay| (*2 $))))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|IndexCard|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|MathMLFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TexFormat|))))) 
-(((*1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Expression| *3)))) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|TransSolvePackageService| *3))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Any|)) (|isDomain| *1 (|AnyFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| *2)) (|ofType| *4 (|List| *2)) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| *5)) (|ofCategory| *5 (|FortranMachineTypeCategory|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Matrix| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Expression| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Vector| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *5 (|FiniteAlgebraicExtensionField| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|NormRetractPackage| *4 *5 *6 *3 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *6)) (|ofType| *7 (|PositiveInteger|)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|RetractableTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (|partial| OR (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|not| (|ofCategory| *3 (|Algebra| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|IntegerNumberSystem|))) (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|QuotientFieldCategory| (|Integer|)))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (|partial| OR (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *2) (|:| |polj| *2))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|))))) 
-(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *3 *4 *3 *4 *3 *5 *5) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|List| (|PrimitiveArray| *5))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *4 (|PrimitiveArray| *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DrawComplex|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |coef| *3) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| (|NewSparseUnivariatePolynomial| *3)) (|:| |remainder| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Void|))))) 
+(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|PartialDifferentialRing| *5)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *8) (|:| |radicand| *8))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *3 *7 *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)) (SIGNATURE |coerce| ($ *7)))))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Plot|)) (|isDomain| *1 (|PlotFunctions1| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *3 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|KeyedDictionary| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1) (|ofCategory| *1 (|AbelianMonoid|))) ((*1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *2)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Expression| *5)))) (|isDomain| *3 (|Vector| (|Expression| *5))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|TransSolvePackageService| *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|SubSpace| 3 *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *1 *2 *2 *3 *1 *4) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|PseudoAlgebraicClosureOfRationalNumber|))) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Symbol|)) (|isDomain| *1 (|PseudoAlgebraicClosureOfRationalNumber|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DrawComplex|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *6)) (|:| |exponent| (|Integer|))))) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *2 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)) (|isDomain| *3 (|Float|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|))))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GraphicsDefaults|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OneDimensionalArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|OneDimensionalArray| *3))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Point| *4)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|SparseUnivariatePolynomial| (|Polynomial| *4)) (|Polynomial| *4))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TemplateUtilities|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *3 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|LyndonWord| *3)) (|:| |c| *4)))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |close| *1) (|:| |open| (|List| *7))))) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|TheSymbolTable|)) (|isDomain| *3 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *2)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Expression| *5)))) (|isDomain| *3 (|Vector| (|Expression| *5))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|TransSolvePackageService| *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Factored| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *5 *6))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| (|List| *8))) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |upol| (|SparseUnivariatePolynomial| *8)) (|:| |Lval| (|List| *8)) (|:| |Lfact| (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *8)) (|:| |exponent| (|Integer|))))) (|:| |ctpol| *8))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4 *5 *6 *5) (AND (|isDomain| *4 (|List| (|Float|))) (|isDomain| *5 (|List| (|OrderedCompletion| (|Float|)))) (|isDomain| *6 (|List| (|Expression| (|Float|)))) (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Float|))) (|isDomain| *5 (|List| (|OrderedCompletion| (|Float|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Float|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Expression| (|Float|)))) (|isDomain| *4 (|List| (|Float|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|))))) 
 (((*1 *2 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|StochasticDifferential| *4)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|StochasticDifferential| *4))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|List| (|NonNegativeInteger|)))))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MakeFloatCompiledFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|MakeFloatCompiledFunction| *3)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Union| (|:| |overq| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|:| |overan| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|:| |failed| (|Boolean|)))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Fraction| *3))) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |sin| (|Stream| *4)) (|:| |cos| (|Stream| *4)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *4)) (|isDomain| *3 (|Stream| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ir| (|IntegrationResult| (|Fraction| *6))) (|:| |specpart| (|Fraction| *6)) (|:| |polypart| *6))) (|isDomain| *1 (|TranscendentalIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|RetractableTo| *5))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Equation| (|Fraction| (|Polynomial| *6)))))) (|isDomain| *1 (|RetractSolvePackage| *5 *6))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *8) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *8))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)) (|isDomain| *4 (|NonNegativeInteger|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *2) (AND (|ofType| *4 *2) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DirectProductCategory&| *3 *4 *5)) (|ofCategory| *3 (|DirectProductCategory| *4 *5)))) ((*1 *2) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionSpace&| *3 *4)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerNumberSystem&| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|NonAssociativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OctonionCategory&| *3 *4)) (|ofCategory| *3 (|OctonionCategory| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|QuotientFieldCategory&| *3 *4)) (|ofCategory| *3 (|QuotientFieldCategory| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|QuaternionCategory&| *3 *4)) (|ofCategory| *3 (|QuaternionCategory| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealClosedField&| *3)) (|ofCategory| *3 (|RealClosedField|)))) ((*1 *2) (AND (|ofCategory| *1 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealNumberSystem&| *3)) (|ofCategory| *3 (|RealNumberSystem|))))) 
-(((*1 *2 *1 *1 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|isDomain| *4 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *6 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *5 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|Product| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 (|List| *2))) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *5 *2))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4))))) 
+(((*1 *2 *3 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|AlgebraicNumber|))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|OneDimensionalArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|OneDimensionalArrayFunctions2| *5 *2)))) ((*1 *2 *3 *1 *2 *2) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3 *1 *2) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |pol| (|SparseUnivariatePolynomial| *4)) (|:| |deg| (|PositiveInteger|)))) (|isDomain| *1 (|DegreeReductionPackage| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *6 *2)) (|isDomain| *4 (|DirectProduct| *5 *6)) (|ofType| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|DirectProductFunctions2| *5 *6 *2)))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *4 *2 *3 *5 *6 *7)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *3)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Expression| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *5 (|FunctionFieldCategory| *2 *3 *4)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateFunctions2| *5 *4 *2 *6)) (|ofCategory| *4 (|FiniteLinearAggregate| *5)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|FiniteSetAggregateFunctions2| *5 *4 *2 *6)) (|ofCategory| *4 (|FiniteSetAggregate| *5)) (|ofCategory| *6 (|FiniteSetAggregate| *2)))) ((*1 *1 *1) (|isDomain| *1 (|InnerAlgebraicNumber|))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListFunctions2| *5 *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|ofCategory| *8 (|FiniteLinearAggregate| *2)) (|ofCategory| *9 (|FiniteLinearAggregate| *2)) (|isDomain| *1 (|MatrixCategoryFunctions2| *5 *6 *7 *4 *2 *8 *9 *10)) (|ofCategory| *4 (|MatrixCategory| *5 *6 *7)) (|ofCategory| *10 (|MatrixCategory| *2 *8 *9)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Divisor| *1)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|PrimitiveArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|PrimitiveArrayFunctions2| *5 *2)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|ofType| *6 (|List| *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *7 *2)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|Ring|)) (|ofType| *5 (|NonNegativeInteger|)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *8 (|DirectProductCategory| *6 *7)) (|ofCategory| *9 (|DirectProductCategory| *5 *7)) (|ofCategory| *10 (|DirectProductCategory| *6 *2)) (|ofCategory| *11 (|DirectProductCategory| *5 *2)) (|isDomain| *1 (|RectangularMatrixCategoryFunctions2| *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (|ofCategory| *4 (|RectangularMatrixCategory| *5 *6 *7 *8 *9)) (|ofCategory| *12 (|RectangularMatrixCategory| *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|Stream| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|StreamFunctions2| *5 *2)))) ((*1 *2 *2 *1 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|isDomain| *4 (|Mapping| (|Boolean|) *2 *2)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *2)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *5 *6 *7)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|VectorFunctions2| *5 *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|SmithNormalForm| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *4 *4 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |theta| (|DoubleFloat|)) (|:| |phi| (|DoubleFloat|)) (|:| |scale| (|DoubleFloat|)) (|:| |scaleX| (|DoubleFloat|)) (|:| |scaleY| (|DoubleFloat|)) (|:| |scaleZ| (|DoubleFloat|)) (|:| |deltaX| (|DoubleFloat|)) (|:| |deltaY| (|DoubleFloat|)))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PatternMatchable| *5)) (|isDomain| *2 (|PatternMatchListResult| *5 *6 (|List| *6))) (|isDomain| *1 (|PatternMatch| *5 *6 *4)) (|isDomain| *3 (|List| *6)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|List| (|Equation| *3))) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|RetractableTo| (|Symbol|))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|List| (|Equation| (|Polynomial| *3)))) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|Ring|)) (|not| (|ofCategory| *3 (|RetractableTo| (|Symbol|)))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|not| (|ofCategory| *3 (|RetractableTo| (|Symbol|)))) (|not| (|ofCategory| *3 (|Ring|))) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5)))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Kernel| *6)) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *1 (|GenusZeroIntegration| *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| AND (|isDomain| *4 (|SparseUnivariatePolynomial| *11)) (|isDomain| *6 (|List| *10)) (|isDomain| *7 (|List| (|NonNegativeInteger|))) (|isDomain| *8 (|List| *11)) (|ofCategory| *10 (|OrderedSet|)) (|ofCategory| *11 (|EuclideanDomain|)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|PolynomialCategory| *11 *9 *10)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|MultivariateSquareFree| *9 *10 *11 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofType| *6 (|List| *2))))) 
+(((*1 *2 *3 *2) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) ((*1 *2 *3 *2) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |gen| *3) (|:| |exp| (|Integer|)))) (|isDomain| *1 (|Divisor| *3)) (|ofCategory| *3 (|SetCategoryWithDegree|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Record| (|:| |high| (|List| (|Symbol|))) (|:| |low| (|List| (|Symbol|))))) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *4 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6)) (|ofCategory| *5 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *3 *4 *5 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *5 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *6 *7 *4)) (|ofCategory| *9 (|RegularTriangularSetCategory| *6 *7 *4 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|Record| (|:| |val| *8) (|:| |tower| *9)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *6 *7 *4 *8 *9))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *7 *8) (AND (|isDomain| *3 (|Record| (|:| |det| *12) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) (|isDomain| *4 (|Matrix| *12)) (|isDomain| *5 (|List| (|Fraction| (|Polynomial| *9)))) (|isDomain| *6 (|List| (|List| *12))) (|isDomain| *7 (|NonNegativeInteger|)) (|isDomain| *8 (|Integer|)) (|ofCategory| *9 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *12 (|PolynomialCategory| *9 *11 *10)) (|ofCategory| *10 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *11 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |eqzro| (|List| *12)) (|:| |neqzro| (|List| *12)) (|:| |wcond| (|List| (|Polynomial| *9))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *9)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *9))))))))) (|isDomain| *1 (|ParametricLinearEquations| *9 *10 *11 *12))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingNode| *3 *2)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|SubSpaceComponentProperty|))))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|TranscendentalIntegration| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|Mapping| (|IntegrationResult| *3) *3 (|Symbol|))) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (|Symbol|))) (|ofCategory| *3 (|ElementaryFunctionCategory|)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|RetractableTo| *4)) (|ofCategory| *3 (|FunctionSpace| *7)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *7 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *7 (|PatternMatchable| (|Integer|))) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|IntegrationTools| *7 *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
+(((*1 *2 *2 *2 *3 *3 *4 *2 *5) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|isDomain| *5 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *2 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *2 *2 *3 *3 *4 *3 *2 *5) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|GenusZeroIntegration| *6 *2 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4)))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|Float|))) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stream| *4))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Set| (|NonNegativeInteger|))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|GraphImage|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *6 (|List| (|Kernel| *3))) (|isDomain| *5 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|ElementaryIntegration| *7 *3))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|AffinePlane| *3)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|KeyedAccessFile| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Library|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |var| (|List| (|Symbol|))) (|:| |pred| (|Any|)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *3 *4) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *3 *4) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *4 (|Union| "left" "center" "right" "vertical" "horizontal")) (|ofCategory| *1 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *2 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedRing|)) (|isDomain| *1 (|ExpertSystemToolsPackage1| *3))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|SplittingNode| *4 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingTree| *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |discriminant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SquareMatrix| *4 *2)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Join| (|Ring|) (CATEGORY |package| (ATTRIBUTE (|commutative| "*"))))) (|isDomain| *1 (|Permanent| *4 *2))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (AND (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|String|)) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *6)))) (|isDomain| *4 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *5 (|Symbol|)) (|isDomain| *7 (|Fraction| (|Integer|))) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *6))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldSquareFreeDecomposition| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LiePolynomial| *3 *4)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|AntiSymm| *2 *3)) (|ofType| *3 (|List| (|Symbol|))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|CliffordAlgebra| *4 *2 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|QuadraticForm| *4 *2)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Expression| *3)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FreeModuleCat| *2 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MonogenicLinearOperator| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|MonoidRing| *2 *3)) (|ofCategory| *3 (|Monoid|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *5)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *6)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicStochasticDifferential|)) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|PolynomialCategory| *4 (|IndexedExponents| *5) *5)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *4 *5 *2)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Polynomial| *4)) (|isDomain| *1 (|TaylorSeries| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranType|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Record| (|:| |num| (|Vector| *4)) (|:| |den| *4)))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|GeneralPolynomialGcdPackage| *3 *4 *2 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2) (AND (|ofCategory| *2 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IndexedString| *3)) (|ofType| *3 *2))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategory|)) (|isDomain| *2 (|SingleInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinarySearchTree| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinaryTournament| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Matrix| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CharacteristicPolynomialPackage| *2)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|CharacteristicPolynomialInMonogenicalAlgebra| *4 *2 *3)) (|ofCategory| *3 (|MonogenicAlgebra| *4 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|EigenPackage| *5)) (|ofCategory| *5 (|GcdDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|isDomain| *2 (|Polynomial| *4)) (|isDomain| *1 (|EigenPackage| *4)) (|ofCategory| *4 (|GcdDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Polynomial| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *1 (|NumericComplexEigenPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|NumericRealEigenPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PrincipalIdealDomain|))))) 
 (((*1 *2 *3 *4 *5 *6 *5) (AND (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|String|)) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSpecialFunctionsPackage|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|TubePlot| *3)) (|isDomain| *1 (|NumericTubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|TubePlot| *2)) (|ofCategory| *2 (|PlottableSpaceCurveCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraPackage| *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)))) ((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofType| *7 *2))) ((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|Vector| *4))) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Stream| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GuessOptionFunctions0|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *1) (|ofCategory| *1 (|FiniteFieldCategory|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |primelt| *5) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *5))) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|FunctionSpacePrimitiveElement| *4 *5)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |primelt| *3) (|:| |pol1| (|SparseUnivariatePolynomial| *3)) (|:| |pol2| (|SparseUnivariatePolynomial| *3)) (|:| |prim| (|SparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|FunctionSpacePrimitiveElement| *4 *3)) (|ofCategory| *3 (|AlgebraicallyClosedField|)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *3 *4 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef1| (|Integer|)) (|:| |coef2| (|Integer|)) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|PrimitiveElement| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *5))) (|:| |prim| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|PrimitiveElement| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| *6))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |coef| (|List| (|Integer|))) (|:| |poly| (|List| (|SparseUnivariatePolynomial| *6))) (|:| |prim| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *1 (|PrimitiveElement| *6))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|ComplexCategory| *6)) (|ofCategory| (|Polynomial| *6) (|PatternMatchable| *5)) (|ofCategory| *6 (|Join| (|PatternMatchable| *5) (|CommutativeRing|))) (|isDomain| *1 (|ComplexPatternMatch| *5 *6 *3)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *2 (|PatternMatchResult| *4 *1)) (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *1 (|PatternMatchable| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *6)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|SetCategory|) (|RetractableTo| *3))) (|ofCategory| *3 (|PatternMatchable| *5)) (|isDomain| *1 (|PatternMatchPushDown| *5 *3 *6)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|ConvertibleTo| *4) (|PatternMatchable| *5) (|RetractableTo| (|Kernel| $)))) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|PatternMatchable| *5))) (|isDomain| *1 (|PatternMatchFunctionSpace| *5 *6 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| (|Integer|) *3)) (|isDomain| *4 (|Pattern| (|Integer|))) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *1 (|PatternMatchIntegerNumberSystem| *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *6)) (|isDomain| *3 (|Kernel| *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|RetractableTo| (|Kernel| $)) (|ConvertibleTo| *4) (|PatternMatchable| *5))) (|isDomain| *4 (|Pattern| *5)) (|isDomain| *1 (|PatternMatchKernel| *5 *6)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchListResult| *5 *6 *3)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PatternMatchable| *5)) (|ofCategory| *3 (|ListAggregate| *6)) (|isDomain| *1 (|PatternMatchListAggregate| *5 *6 *3)))) ((*1 *2 *3 *4 *2 *5) (AND (|isDomain| *5 (|Mapping| (|PatternMatchResult| *6 *3) *8 (|Pattern| *6) (|PatternMatchResult| *6 *3))) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|PatternMatchResult| *6 *3)) (|isDomain| *4 (|Pattern| *6)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *3 (|Join| (|PolynomialCategory| *9 *7 *8) (|ConvertibleTo| *4))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|Join| (|Ring|) (|OrderedSet|) (|PatternMatchable| *6))) (|isDomain| *1 (|PatternMatchPolynomialCategory| *6 *7 *8 *9 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|Join| (|PolynomialCategory| *8 *6 *7) (|ConvertibleTo| *4))) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *7 (|PatternMatchable| *5)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|Join| (|Ring|) (|OrderedSet|) (|PatternMatchable| *5))) (|isDomain| *1 (|PatternMatchPolynomialCategory| *5 *6 *7 *8 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 *3)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|QuotientFieldCategory| *6)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|PatternMatchable| *5) (|ConvertibleTo| *4))) (|isDomain| *4 (|Pattern| *5)) (|isDomain| *1 (|PatternMatchQuotientFieldCategory| *5 *6 *3)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|PatternMatchResult| *5 (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *1 (|PatternMatchSymbol| *5)))) ((*1 *2 *3 *4 *5 *2 *6) (AND (|isDomain| *4 (|List| (|Pattern| *7))) (|isDomain| *5 (|Mapping| *9 (|List| *9))) (|isDomain| *6 (|Mapping| (|PatternMatchResult| *7 *9) *9 (|Pattern| *7) (|PatternMatchResult| *7 *9))) (|ofCategory| *7 (|SetCategory|)) (|ofCategory| *9 (|Join| (|Ring|) (|ConvertibleTo| (|Pattern| *7)) (|RetractableTo| *8))) (|isDomain| *2 (|PatternMatchResult| *7 *9)) (|isDomain| *3 (|List| *9)) (|ofCategory| *8 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|PatternMatchTools| *7 *8 *9))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Kernel| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|RetractableTo| (|Integer|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|SparseUnivariatePolynomial| *5)) (|isDomain| *1 (|AlgebraicFunction| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Kernel| *1)) (|ofCategory| *1 (|Ring|)) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Integer|)) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *6 *2)) (|ofCategory| *6 (|Type|)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|RadixUtilities|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *6))) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)))))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
+(((*1 *2 *3 *4 *2 *2 *2 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *2))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PointCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|List| (|Places| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|ofCategory| *2 (|FunctionSpace| *5)) (|isDomain| *1 (|ExpressionSolve| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *7 (|UnivariateTaylorSeriesCategory| (|SparseUnivariatePolynomialExpressions| *2)))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *2 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *8))) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|ODETools| *4 *5)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|ODETools| *5 *6)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7))))) (|ofCategory| *7 (|OrderedRing|)) (|ofCategory| *8 (|Join| (|UnivariatePowerSeriesCategory| *3 *7) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *2 (|Union| (|:| |%series| *8) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *6 *3 *7 *8 *9 *10)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PartialTranscendentalFunctions| *8)) (|ofType| *10 (|Symbol|))))) 
 (((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *1 (|SplittingNode| *3 *2)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *1 *2 *2 *2 *2) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|WuWenTsunTriangularSet| *4 *5 *6 *7))) (|isDomain| *1 (|WuWenTsunTriangularSet| *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *9)) (|isDomain| *4 (|Mapping| (|Boolean|) *9 *9)) (|isDomain| *5 (|Mapping| *9 *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|List| (|WuWenTsunTriangularSet| *6 *7 *8 *9))) (|isDomain| *1 (|WuWenTsunTriangularSet| *6 *7 *8 *9))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|InternalRationalUnivariateRepresentationPackage| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *4 *5)) (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *3 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|DirectProductCategory| *3 *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|Type|)))) ((*1 *1 *2) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *5)) (|Record| (|:| |index| *2) (|:| |exponent| *5)))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *2 *5 *6 *7)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 (|OrderedVariableList| *3))))) ((*1 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
 (((*1 *2 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|FGLMIfCanPackage| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *7)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|InterfaceGroebnerPackage| *3 *4 *5 *6 *7)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *3 (|OrderedVariableList| *4)))) (|ofCategory| *3 (|GcdDomain|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|LexTriangularPackage| *3 *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|))))) 
 (((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Fraction| *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|CycleIndicators|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|d02AgentsPackage|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Equation| *3))) (|ofCategory| *3 (|Evalable| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Equation| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Evalable| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|Equation| *2)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *1 *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *1 (|List| *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|BasicOperator|))) (|isDomain| *3 (|List| (|Mapping| *1 (|List| *1)))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|BasicOperator|))) (|isDomain| *3 (|List| (|Mapping| *1 *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Mapping| *1 *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Mapping| *1 (|List| *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Mapping| *1 (|List| *1)))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Mapping| *1 *1))) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Equation| *3))) (|ofCategory| *1 (|Evalable| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Equation| *3)) (|ofCategory| *1 (|Evalable| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 (|Integer|))) (|isDomain| *4 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|EvaluateCycleIndicators| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|FreeLieAlgebra| *4 *5)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Mapping| *1 *1)) (|ofCategory| *1 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Mapping| *1 (|List| *1))) (|ofCategory| *1 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|isDomain| *4 (|List| (|Mapping| *1 (|List| *1)))) (|ofCategory| *1 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|isDomain| *4 (|List| (|Mapping| *1 *1))) (|ofCategory| *1 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|BasicOperator|))) (|isDomain| *3 (|List| *1)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1 *2 *1 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *2 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|ConvertibleTo| (|InputForm|))))) ((*1 *2 *3 *4) (AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *3 *4) (AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *2 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *8)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *2 *5 *3 *6 *7 *8 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *3 *6 *7 *8 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *6 (|PolynomialCategory| *2 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *4 (|PlacesCategory| *2 *9)) (|ofCategory| *10 (|DivisorCategory| *4)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *2 *5 *6 *7 *8 *9 *4 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *2 *5 *6 *7 *8 *9 *4 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *1 *1 *2 *3) (AND (|ofCategory| *1 (|InnerEvalable| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| *5)) (|ofCategory| *1 (|InnerEvalable| *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Type|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|OnePointCompletion| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|MoebiusTransform| *3)))) ((*1 *2 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *2)) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|DistributedMultivariatePolynomial| *5 *2))) (|isDomain| *4 (|Places| *2)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *2 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|PermutationCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|PolynomialPackageForCurve| *2 *3 *5 *6 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *2 *5)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *2)))) ((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|RationalFunction| *4)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *2 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|RationalFunction| *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *4)))) (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|RationalFunction| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|RationalFunction| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|has| *3 (SIGNATURE ** (*3 *3 *4))) (|isDomain| *2 (|Stream| *3))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|SmithNormalForm| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpaceComponentProperty|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)) (|isDomain| *3 (|DoubleFloat|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Equation| (|Expression| *4)))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *4))))) (|isDomain| *1 (|RadicalSolvePackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *5))))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Equation| (|Fraction| (|Polynomial| *4))))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Equation| (|Expression| *4))))) (|isDomain| *1 (|RadicalSolvePackage| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
 (((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|PolyGroebner| *4))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|Float|)))) (|isDomain| *1 (|RealSolvePackage|)) (|isDomain| *5 (|Float|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|InputForm|))) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FiniteDivisor| *3 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|NonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|RealNumberSystem|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|isDomain| *2 (|Record| (|:| |r| *3) (|:| |phi| *3)))))) 
+(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Mapping| *8 *8)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *7) (|:| |right| *7) (|:| |sol?| (|Boolean|))) (|Integer|) *7)) (|isDomain| *6 (|List| (|Fraction| *8))) (|ofCategory| *7 (|Field|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|isDomain| *3 (|Fraction| *8)) (|isDomain| *2 (|Record| (|:| |answer| (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (|isDomain| *1 (|TranscendentalIntegration| *7 *8))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SquareMatrix| *4 *2)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *2 (|Join| (|Ring|) (CATEGORY |package| (ATTRIBUTE (|commutative| "*"))))) (|isDomain| *1 (|Permanent| *4 *2))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef1| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|GcdDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|PermutationCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|DrawComplex|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|Comparable|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4 *5 *5 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|Polynomial| *6)) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| *7)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *7 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|isDomain| *1 (|DefiniteIntegrationTools| *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|isDomain| *4 (|OrderedCompletion| *6)) (|ofCategory| *6 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|DefiniteIntegrationTools| *5 *6))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|LiePolynomial| *4 *5))) (|isDomain| *1 (|LieExponentials| *4 *5 *6)) (|ofCategory| *5 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *6 (|PositiveInteger|))))) 
 (((*1 *2 *3 *3 *4 *5 *5 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|String|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|MergeThing| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
-(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *1) (|isDomain| *1 (|Character|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Record| (|:| |particular| *1) (|:| |basis| (|List| *1)))) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)))) ((*1 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |particular| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|:| |basis| (|List| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
 (((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *2 (|Complex| *5)) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *5 *3)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *3 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
-(((*1 *2 *3) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|)))))) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5)) (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|)))))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|AbelianSemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| (|Integer|)) (|:| |var| (|Kernel| *1)))) (|ofCategory| *1 (|FunctionSpace| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
 (((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|PlacesCategory| *5 *8)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *5 *6 *4 *7 *3 *8 *2)) (|ofCategory| *4 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *5))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Matrix| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|CharacteristicPolynomialPackage| *2)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|CharacteristicPolynomialInMonogenicalAlgebra| *4 *2 *3)) (|ofCategory| *3 (|MonogenicAlgebra| *4 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|EigenPackage| *5)) (|ofCategory| *5 (|GcdDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|isDomain| *2 (|Polynomial| *4)) (|isDomain| *1 (|EigenPackage| *4)) (|ofCategory| *4 (|GcdDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Polynomial| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *1 (|NumericComplexEigenPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|NumericRealEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Integer|)))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|NumericRealEigenPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|List| *4)))) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|TableauxBumpers| *4)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
-(((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *2)) (|Record| (|:| |index| *5) (|:| |exponent| *2)))) (|ofCategory| *2 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *2 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *2 (|OrderedVariableList| *3)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Mapping| (|List| *4) *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|StreamTensor| *4))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *1 (|Expression| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
 (((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
-(((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *6) (|:| |right| *6) (|:| |sol?| (|Boolean|))) (|Integer|) *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Union| (|Record| (|:| |answer| (|Fraction| *7)) (|:| |a0| *6)) (|Record| (|:| |ratpart| (|Fraction| *7)) (|:| |coeff| (|Fraction| *7))) "failed")) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
-(((*1 *1 *1 *2 *1) (AND (|isDomain| *1 (|BinaryTree| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|BinaryTree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *3 *6 *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|RationalFunctionIntegration| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|)))) 
+(((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2 *2 *3 *4) (AND (|isDomain| *2 (|Matrix| *5)) (|isDomain| *3 (|Automorphism| *5)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|PseudoLinearNormalForm| *5))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagSeriesSummationPackage|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PointCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerBits|))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
+(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|List| *7) (|List| *7))) (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *1) (|isDomain| *1 (|ThreeDimensionalViewport|)))) 
 (((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|AbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2 *1 *1 *3) (AND (|isDomain| *2 (|Mapping| *3 *3 *3)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| *3 *3 *3)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|OneDimensionalArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|OneDimensionalArray| *6)) (|isDomain| *1 (|OneDimensionalArrayFunctions2| *5 *6)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *8 *7)) (|isDomain| *4 (|CartesianTensor| *5 *6 *7)) (|ofType| *5 (|Integer|)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|CommutativeRing|)) (|ofCategory| *8 (|CommutativeRing|)) (|isDomain| *2 (|CartesianTensor| *5 *6 *8)) (|isDomain| *1 (|CartesianTensorFunctions2| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Complex| *5)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|CommutativeRing|)) (|isDomain| *2 (|Complex| *6)) (|isDomain| *1 (|ComplexFunctions2| *5 *6)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Expression| *3) (|Expression| *3))) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *6)) (|isDomain| *4 (|DirectProduct| *5 *6)) (|ofType| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|isDomain| *2 (|DirectProduct| *5 *7)) (|isDomain| *1 (|DirectProductFunctions2| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Equation| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Equation| *6)) (|isDomain| *1 (|EquationFunctions2| *5 *6)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Equation| *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *2 *6)) (|isDomain| *4 (|String|)) (|isDomain| *5 (|Kernel| *6)) (|ofCategory| *6 (|ExpressionSpace|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ExpressionSpaceFunctions1| *6 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *5)) (|isDomain| *4 (|Kernel| *5)) (|ofCategory| *5 (|ExpressionSpace|)) (|ofCategory| *2 (|ExpressionSpace|)) (|isDomain| *1 (|ExpressionSpaceFunctions2| *5 *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *1 *1)) (|isDomain| *3 (|Kernel| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Matrix| *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|ExpertSystemToolsPackage2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Expression| *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Expression| *6)) (|isDomain| *1 (|ExpressionFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *6)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *7 *5)) (|isDomain| *1 (|FiniteAbelianMonoidRingFunctions2| *5 *6 *4 *7 *2)) (|ofCategory| *4 (|FiniteAbelianMonoidRing| *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *9 *5)) (|isDomain| *4 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *9 (|Field|)) (|ofCategory| *10 (|UnivariatePolynomialCategory| *9)) (|ofCategory| *11 (|UnivariatePolynomialCategory| (|Fraction| *10))) (|isDomain| *2 (|FiniteDivisor| *9 *10 *11 *12)) (|isDomain| *1 (|FiniteDivisorFunctions2| *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *12 (|FunctionFieldCategory| *9 *10 *11)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|FullyEvalableOver| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *8 *5)) (|ofCategory| *5 (|UniqueFactorizationDomain|)) (|ofCategory| *8 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *9 (|UnivariatePolynomialCategory| *8)) (|ofCategory| *2 (|FunctionFieldCategory| *8 *9 *10)) (|isDomain| *1 (|FunctionFieldCategoryFunctions2| *5 *6 *7 *4 *8 *9 *10 *2)) (|ofCategory| *4 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *10 (|UnivariatePolynomialCategory| (|Fraction| *9))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *2 (|FiniteLinearAggregate| *6)) (|isDomain| *1 (|FiniteLinearAggregateFunctions2| *5 *4 *6 *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Factored| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *6)) (|isDomain| *1 (|FactoredFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Fraction| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| *6)) (|isDomain| *1 (|FractionFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *9 *5)) (|isDomain| *4 (|FractionalIdeal| *5 *6 *7 *8)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *6 (|QuotientFieldCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *8 (|Join| (|FramedAlgebra| *6 *7) (|RetractableTo| *6))) (|ofCategory| *9 (|EuclideanDomain|)) (|ofCategory| *10 (|QuotientFieldCategory| *9)) (|ofCategory| *11 (|UnivariatePolynomialCategory| *10)) (|isDomain| *2 (|FractionalIdeal| *9 *10 *11 *12)) (|isDomain| *1 (|FractionalIdealFunctions2| *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *12 (|Join| (|FramedAlgebra| *10 *11) (|RetractableTo| *10))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|CommutativeRing|)) (|ofCategory| *2 (|FramedNonAssociativeAlgebra| *6)) (|isDomain| *1 (|FramedNonAssociativeAlgebraFunctions2| *4 *5 *2 *6)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|Factored| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|Join| (|Ring|) (|OrderedSet|))) (|ofCategory| *6 (|Join| (|Ring|) (|OrderedSet|))) (|ofCategory| *2 (|FunctionSpace| *6)) (|isDomain| *1 (|FunctionSpaceFunctions2| *5 *4 *6 *2)) (|ofCategory| *4 (|FunctionSpace| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|FiniteSetAggregate| *6)) (|isDomain| *1 (|FiniteSetAggregateFunctions2| *5 *4 *6 *2)) (|ofCategory| *4 (|FiniteSetAggregate| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|IndexedDirectProductCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|IntegrationResult| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|IntegrationResult| *6)) (|isDomain| *1 (|IntegrationResultFunctions2| *5 *6)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Union| (|Record| (|:| |ratpart| *5) (|:| |coeff| *5)) "failed")) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| |ratpart| *6) (|:| |coeff| *6))) (|isDomain| *1 (|IntegrationResultFunctions2| *5 *6)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| *2 *5)) (|isDomain| *4 (|Union| *5 "failed")) (|ofCategory| *5 (|Field|)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|IntegrationResultFunctions2| *5 *2)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Union| (|Record| (|:| |mainpart| *5) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *5) (|:| |logand| *5))))) "failed")) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Record| (|:| |mainpart| *6) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *6) (|:| |logand| *6)))))) (|isDomain| *1 (|IntegrationResultFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|InfiniteTuple| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|InfiniteTuple| *6)) (|isDomain| *1 (|InfiniteTupleFunctions2| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *8 *6 *7)) (|isDomain| *4 (|InfiniteTuple| *6)) (|isDomain| *5 (|InfiniteTuple| *7)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *8 (|Type|)) (|isDomain| *2 (|InfiniteTuple| *8)) (|isDomain| *1 (|InfiniteTupleFunctions3| *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *8 *6 *7)) (|isDomain| *4 (|Stream| *6)) (|isDomain| *5 (|InfiniteTuple| *7)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *8 (|Type|)) (|isDomain| *2 (|Stream| *8)) (|isDomain| *1 (|InfiniteTupleFunctions3| *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *8 *6 *7)) (|isDomain| *4 (|InfiniteTuple| *6)) (|isDomain| *5 (|Stream| *7)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *8 (|Type|)) (|isDomain| *2 (|Stream| *8)) (|isDomain| *1 (|InfiniteTupleFunctions3| *6 *7 *8)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|ListFunctions2| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *8 *6 *7)) (|isDomain| *4 (|List| *6)) (|isDomain| *5 (|List| *7)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *8 (|Type|)) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ListFunctions3| *6 *7 *8)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| *3 *3 *3)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *8 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|ofCategory| *2 (|MatrixCategory| *8 *9 *10)) (|isDomain| *1 (|MatrixCategoryFunctions2| *5 *6 *7 *4 *8 *9 *10 *2)) (|ofCategory| *4 (|MatrixCategory| *5 *6 *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *8)) (|ofCategory| *10 (|FiniteLinearAggregate| *8)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *8 "failed") *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|ofCategory| *2 (|MatrixCategory| *8 *9 *10)) (|isDomain| *1 (|MatrixCategoryFunctions2| *5 *6 *7 *4 *8 *9 *10 *2)) (|ofCategory| *4 (|MatrixCategory| *5 *6 *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *8)) (|ofCategory| *10 (|FiniteLinearAggregate| *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Fraction| *8))) (|isDomain| *1 (|MultipleMap| *5 *6 *4 *7 *8 *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *9 *8)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *9 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|PolynomialCategory| *9 *7 *5)) (|isDomain| *1 (|MPolyCatFunctions2| *5 *6 *7 *8 *9 *4 *2)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *8 *6 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|Ring|)) (|ofCategory| *2 (|PolynomialCategory| *9 *8 *6)) (|isDomain| *1 (|MPolyCatFunctions3| *5 *6 *7 *8 *9 *4 *2)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|PolynomialCategory| *9 *7 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|MonoidRing| *5 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|Monoid|)) (|isDomain| *2 (|MonoidRing| *6 *7)) (|isDomain| *1 (|MonoidRingFunctions2| *5 *6 *7)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|NewSparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|NewSparseUnivariatePolynomial| *6)) (|isDomain| *1 (|NewSparseUnivariatePolynomialFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|CommutativeRing|)) (|ofCategory| *2 (|OctonionCategory| *6)) (|isDomain| *1 (|OctonionCategoryFunctions2| *4 *5 *2 *6)) (|ofCategory| *4 (|OctonionCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|OnePointCompletion| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|OnePointCompletion| *6)) (|isDomain| *1 (|OnePointCompletionFunctions2| *5 *6)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|OnePointCompletion| *6)) (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|OnePointCompletion| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *1 (|OnePointCompletionFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|OrderedCompletion| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|OrderedCompletion| *6)) (|isDomain| *1 (|OrderedCompletionFunctions2| *5 *6)))) ((*1 *2 *3 *4 *2 *2) (AND (|isDomain| *2 (|OrderedCompletion| *6)) (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|OrderedCompletion| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *1 (|OrderedCompletionFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|ParametricPlaneCurve| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|ParametricPlaneCurve| *6)) (|isDomain| *1 (|ParametricPlaneCurveFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|ParametricSpaceCurve| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|ParametricSpaceCurve| *6)) (|isDomain| *1 (|ParametricSpaceCurveFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|ParametricSurface| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|ParametricSurface| *6)) (|isDomain| *1 (|ParametricSurfaceFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *6)) (|isDomain| *4 (|PatternMatchResult| *5 *6)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *5 *7)) (|isDomain| *1 (|PatternMatchResultFunctions2| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Pattern| *6)) (|isDomain| *1 (|PatternFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Polynomial| *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|Polynomial| *6)) (|isDomain| *1 (|PolynomialFunctions2| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *2 *7)) (|isDomain| *4 (|Mapping| *2 *8)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|Join| (|SetCategory|) (CATEGORY |domain| (SIGNATURE + ($ $ $)) (SIGNATURE * ($ $ $)) (SIGNATURE ** ($ $ (|NonNegativeInteger|)))))) (|isDomain| *1 (|PolynomialCategoryLifting| *6 *7 *8 *5 *2)) (|ofCategory| *5 (|PolynomialCategory| *8 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|PrimitiveArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|PrimitiveArray| *6)) (|isDomain| *1 (|PrimitiveArrayFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|Point| *6)) (|isDomain| *1 (|PointFunctions2| *5 *6)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| *2 (|Polynomial| *4))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *6)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|isDomain| *1 (|PushVariables| *4 *5 *6 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *2 (|QuotientFieldCategory| *6)) (|isDomain| *1 (|QuotientFieldCategoryFunctions2| *5 *6 *4 *2)) (|ofCategory| *4 (|QuotientFieldCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|CommutativeRing|)) (|ofCategory| *2 (|QuaternionCategory| *6)) (|isDomain| *1 (|QuaternionCategoryFunctions2| *4 *5 *2 *6)) (|ofCategory| *4 (|QuaternionCategory| *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| *5 *5 *5)) (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *5 *5)) (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *10 *7)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *10 (|Ring|)) (|ofType| *5 (|NonNegativeInteger|)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *8 (|DirectProductCategory| *6 *7)) (|ofCategory| *9 (|DirectProductCategory| *5 *7)) (|ofCategory| *2 (|RectangularMatrixCategory| *5 *6 *10 *11 *12)) (|isDomain| *1 (|RectangularMatrixCategoryFunctions2| *5 *6 *7 *8 *9 *4 *10 *11 *12 *2)) (|ofCategory| *4 (|RectangularMatrixCategory| *5 *6 *7 *8 *9)) (|ofCategory| *11 (|DirectProductCategory| *6 *10)) (|ofCategory| *12 (|DirectProductCategory| *5 *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Segment| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Segment| *6)) (|isDomain| *1 (|SegmentFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Segment| *5)) (|ofCategory| *5 (|OrderedRing|)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|SegmentFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|SegmentBinding| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|SegmentBinding| *6)) (|isDomain| *1 (|SegmentBindingFunctions2| *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *1 (|SegmentExpansionCategory| *4 *2)) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *2 (|StreamAggregate| *4)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Stream| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Stream| *6)) (|isDomain| *1 (|StreamFunctions2| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *8 *6 *7)) (|isDomain| *4 (|Stream| *6)) (|isDomain| *5 (|Stream| *7)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *8 (|Type|)) (|isDomain| *2 (|Stream| *8)) (|isDomain| *1 (|StreamFunctions3| *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|isDomain| *1 (|SparseUnivariatePolynomialFunctions2| *5 *6)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| *4 *4 *4)) (|ofCategory| *1 (|TableAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|UnivariateLaurentSeries| *5 *7 *9)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|ofType| *7 (|Symbol|)) (|ofType| *9 *5) (|ofType| *10 *6) (|isDomain| *2 (|UnivariateLaurentSeries| *6 *8 *10)) (|isDomain| *1 (|UnivariateLaurentSeriesFunctions2| *5 *6 *7 *8 *9 *10)) (|ofType| *8 (|Symbol|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|UniversalSegment| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|UniversalSegment| *6)) (|isDomain| *1 (|UniversalSegmentFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|UniversalSegment| *5)) (|ofCategory| *5 (|OrderedRing|)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Stream| *6)) (|isDomain| *1 (|UniversalSegmentFunctions2| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *8 *6)) (|isDomain| *4 (|UnivariatePolynomial| *5 *6)) (|ofType| *5 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *8 (|Ring|)) (|isDomain| *2 (|UnivariatePolynomial| *7 *8)) (|isDomain| *1 (|UnivariatePolynomialFunctions2| *5 *6 *7 *8)) (|ofType| *7 (|Symbol|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *6)) (|isDomain| *1 (|UnivariatePolynomialCategoryFunctions2| *5 *4 *6 *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|UnivariatePuiseuxSeries| *5 *7 *9)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|ofType| *7 (|Symbol|)) (|ofType| *9 *5) (|ofType| *10 *6) (|isDomain| *2 (|UnivariatePuiseuxSeries| *6 *8 *10)) (|isDomain| *1 (|UnivariatePuiseuxSeriesFunctions2| *5 *6 *7 *8 *9 *10)) (|ofType| *8 (|Symbol|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *6)) (|isDomain| *1 (|UnivariateTaylorSeriesFunctions2| *5 *6 *4 *2)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|VectorFunctions2| *5 *6)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *6 "failed") *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|VectorFunctions2| *5 *6)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *4 (|OrderedMonoid|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|MatrixCategory| *7 *8 *9)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *2)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Matrix| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|SquareMatrixCategory| *2 *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *2 *3)) (|ofCategory| *5 (|DirectProductCategory| *2 *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *3))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp1| F)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagRootFindingPackage|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|Mapping| (|IntegrationResult| *3) *3 (|Symbol|))) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |special| *3) (|:| |integrand| *3)) "failed") *3 (|Symbol|))) (|ofCategory| *3 (|ElementaryFunctionCategory|)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|RetractableTo| *4)) (|ofCategory| *3 (|FunctionSpace| *7)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *7 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *7 (|PatternMatchable| (|Integer|))) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|IntegrationTools| *7 *3))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| *10)) (|isDomain| *1 (|LazardSetSolvingPackage| *5 *6 *7 *8 *9 *10)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *10 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|LexTriangularPackage| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6))))) (|isDomain| *1 (|LexTriangularPackage| *5 *6)))) ((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|RegularChain| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|QueryEquation|)))) ((*1 *2 *3 *1) (|partial| AND (|isDomain| *2 (|Equation| (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *2 (|Equation| (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Segment| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SegmentBinding| *4))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|ReductionOfOrder| *3 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |eq| *3) (|:| |op| (|List| *5)))) (|isDomain| *1 (|ReductionOfOrder| *5 *3)) (|isDomain| *4 (|List| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *2 *3 *3 *4 *5 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp6| FCN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagRootFindingPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedAlgebra&| *3 *4 *5)) (|ofCategory| *3 (|FramedAlgebra| *4 *5)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *2 *2 *2 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|Kernel| *2)) (|isDomain| *4 (|Mapping| (|Union| *2 "failed") *2 *2 (|Symbol|))) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *2 *6)) (|ofCategory| *6 (|SetCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|BasicStochasticDifferential|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DisplayPackage|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Point| *3)))))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|List| *5)))) (|isDomain| *3 (|List| (|SubSpaceComponentProperty|))) (|isDomain| *4 (|SubSpaceComponentProperty|)) (|ofCategory| *1 (|ThreeSpaceCategory| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|Point| *5)))) (|isDomain| *3 (|List| (|SubSpaceComponentProperty|))) (|isDomain| *4 (|SubSpaceComponentProperty|)) (|ofCategory| *1 (|ThreeSpaceCategory| *5)) (|ofCategory| *5 (|Ring|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixManipulation| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Matrix| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *6)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *3 *4))))) 
-(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *3 *2 *5)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *3)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *5 *2 *6)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|BinarySearchTree| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|TubePlot| *2)) (|ofCategory| *2 (|PlottableSpaceCurveCategory|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SymbolTable|)) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Stream| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|OneDimensionalArray| (|List| (|LyndonWord| *5)))) (|isDomain| *1 (|LyndonWord| *5))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *1 (|TheSymbolTable|))))) 
-(((*1 *2 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Point| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|))))) 
-(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *7))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *7 *3)) (|isDomain| *5 (|OrderedCompletion| *3))))) 
-(((*1 *1 *2 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *6)) (|isDomain| *5 (|Mapping| (|Factored| (|SparseUnivariatePolynomial| *6)) (|SparseUnivariatePolynomial| *6))) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|List| (|Record| (|:| |outval| *7) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| *7)))))) (|isDomain| *1 (|InnerNumericEigenPackage| *6 *7 *4)) (|ofCategory| *7 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|Complex| (|Float|)))) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *4)))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *4 *5)) (|ofType| *4 *3) (|ofType| *5 *3))) ((*1 *2 *3 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1) (|isDomain| *1 (|Boolean|)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Vector| (|Expression| (|Float|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |constant| *5) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *5 *6 *3 *7)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *8))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Point| (|DoubleFloat|)))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|PrimitiveArray| *3)) (|isDomain| *1 (|SubResultantPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|Bits|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
-(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|TangentExpansions| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *3 *7 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *7)) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)))) ((*1 *1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3) (AND (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|BezoutMatrix| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|MatrixCategory| *2 *5 *6))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RoutinesTable|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *2 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FunctionCalled| *3)) (|ofType| *3 *2))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RuleCalled| *3)) (|ofType| *3 *2))) ((*1 *1 *1) (|isDomain| *1 (|Symbol|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Fraction| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|PrimitiveRatDE| *5 *2 *3 *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|PrimitiveRatDE| *5 *2 *3 *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerRoots| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|List| *2)) (|isDomain| *1 (|BasicOperatorFunctions1| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 (|List| *4))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Mapping| *4 (|List| *4))) (|isDomain| *1 (|BasicOperatorFunctions1| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|LeftModule| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Operator| *3))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Mapping| *8 *8)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *7) (|:| |coeff| *7)) "failed") *7)) (|isDomain| *6 (|List| (|Fraction| *8))) (|ofCategory| *7 (|Field|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|isDomain| *3 (|Fraction| *8)) (|isDomain| *2 (|Record| (|:| |answer| (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (|isDomain| *1 (|TranscendentalIntegration| *7 *8))))) 
-(((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *3 *2)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *5 *6 *7 *8))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *4 *2 *5) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|Pattern| *6))) (|isDomain| *5 (|Mapping| (|PatternMatchResult| *6 *8) *8 (|Pattern| *6) (|PatternMatchResult| *6 *8))) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *8 (|Join| (|Ring|) (|ConvertibleTo| (|Pattern| *6)) (|RetractableTo| *7))) (|isDomain| *2 (|PatternMatchResult| *6 *8)) (|ofCategory| *7 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|PatternMatchTools| *6 *7 *8))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|KeyedDictionary| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
-(((*1 *2 *3 *4 *2 *2 *2 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *5 (|List| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *6 *2))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
-(((*1 *1 *2 *3 *4) (AND (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *4 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *3) (|:| |exponent| *4)) (|Record| (|:| |index| *3) (|:| |exponent| *4)))) (|isDomain| *1 (|GeneralModulePolynomial| *5 *2 *3 *4 *6 *7)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *4 (|OrderedVariableList| *5)))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4))))) 
-(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *2 *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|SquareMatrix| *2 *3)) (|ofType| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|String|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp73| PDEF)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp74| BNDY)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *1 (|BlowUpPackage| *4 *5 *2 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *3 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Matrix| *4))) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Record| (|:| |num| (|Vector| *4)) (|:| |den| *4)))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4))))) 
-(((*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|ThreeDimensionalMatrix| (|DoubleFloat|))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
 (((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|RetractableTo| (|Integer|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *1 *1 *1) (|isDomain| *1 (|CardinalNumber|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DivisionRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *4 *5 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *5 (|UnivariateLaurentSeriesCategory| *4)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *4 *5 *2 *6)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *4 *5)) (|ofCategory| *6 (|PartialTranscendentalFunctions| *5)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|ElementaryFunctionCategory|))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SemiGroup|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Group|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InputForm|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|MappingPackage1| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)) (|ofCategory| *4 (|LeftModule| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *4 *5)) (|ofCategory| *5 (|LeftModule| *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Operator| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Operator| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RadicalCategory|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SemiGroup|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *3 *4)) (|ofCategory| *4 (|Field|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|InputForm|)) (|isDomain| *1 (|InputFormFunctions1| *4)) (|ofCategory| *4 (|Type|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Character|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DirichletRing| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *5 "failed") *7)) (|isDomain| *4 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *1 (|FiniteLinearAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |var| (|List| (|Symbol|))) (|:| |pred| (|Any|)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Integer|)) (|ofCategory| *6 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5))))) 
-(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
-(((*1 *2 *3 *4 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *3 *4 *5 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *5 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *6 *7 *4)) (|ofCategory| *9 (|RegularTriangularSetCategory| *6 *7 *4 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|Record| (|:| |val| *8) (|:| |tower| *9)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *6 *7 *4 *8 *9))))) 
-(((*1 *1 *2 *2 *1) (|partial| AND (|isDomain| *2 (|BasicStochasticDifferential|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *1 *1 *3) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |det| *8) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3 *4 *5 *5 *4 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Kernel| *2))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *5)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *5 *6 *2)) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|has| *6 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *3) (AND (|has| *9 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *10)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *10 (|MatrixCategory| *7 *8 *9)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| *7))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *3) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3))))) 
-(((*1 *2 *3 *4 *4 *4 *3 *5 *3 *4 *6 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5 *3 *4 *6 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *2 *3 *4 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *2 (|Record| (|:| |k| (|Integer|)) (|:| |c| *4))) (|isDomain| *1 (|NeitherSparseOrDensePowerSeries| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ListMultiDictionary| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1) (|ofCategory| *1 (|AbelianMonoid|))) ((*1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|ofCategory| *1 (|Monoid|))) ((*1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (|isDomain| *1 (|Symbol|)))) 
-(((*1 *2 *3 *4 *4 *3 *5 *3 *6 *4 *7 *8 *9) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|String|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp9| G)))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp7| FCN)))) (|isDomain| *9 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp8| OUTPUT)))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOrdinaryDifferentialEquationsPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|))))) 
-(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|FunctionSpace| *5)) (|isDomain| *1 (|AlgebraicFunction| *5 *2)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|OutputForm|)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *2 *3) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|d03AgentsPackage|))))) 
-(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *1 (|FourierSeries| *3 *2)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *2 (|Join| (|OrderedSet|) (|AbelianGroup|)))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AffineSpaceCategory| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PermutationCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Set| *3)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Set| (|List| *4))) (|isDomain| *1 (|PermutationGroup| *4)) (|isDomain| *3 (|List| *4)))) ((*1 *2 *1 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Set| (|Set| *4))) (|isDomain| *1 (|PermutationGroup| *4)) (|isDomain| *3 (|Set| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *1 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *4 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|QueryEquation|)))) ((*1 *2 *3 *1) (|partial| AND (|isDomain| *2 (|Equation| (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *2 (|Equation| (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Segment| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SegmentBinding| *4))))) 
+(((*1 *2 *3 *3 *4 *5 *3 *6) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp6| FCN)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagRootFindingPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *5 *2))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Set| (|Set| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|OrderedRing|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
 (((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *4) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *6)) (|ofCategory| *6 (|Join| (|SetCategory|) (|RetractableTo| *5))) (|ofCategory| *5 (|PatternMatchable| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| (|Boolean|) *5)) (|isDomain| *1 (|PatternMatchPushDown| *4 *5 *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *2)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RetractableTo| (|Integer|))) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *1 (|FourierSeries| *3 *2)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *2 (|Join| (|OrderedSet|) (|AbelianGroup|)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|TopLevelDrawFunctionsForCompiledFunctions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|TranscendentalFunctionCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|FourierComponent| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *4 (|OrderedVariableList| *5)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6)) (|ofCategory| *6 (|GcdDomain|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *5 *6))) (|isDomain| *4 (|OrderedVariableList| *5)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *5 *6)) (|isDomain| *1 (|LinGroebnerPackage| *5 *6)) (|ofCategory| *6 (|GcdDomain|))))) 
-(((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|ContinuedFraction| *6)) (|isDomain| *1 (|PadeApproximants| *5 *4 *6)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *5)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|CyclicStreamTools| *3 *2)) (|ofCategory| *2 (|LazyStreamAggregate| *3))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |llcmres| *1) (|:| |coeff1| *1) (|:| |coeff2| *1))) (|ofCategory| *1 (|LeftOreRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *3 *3) (AND (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|BezoutMatrix| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|MatrixCategory| *2 *5 *6))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Mapping| (|List| *4) *4)) (|isDomain| *1 (|Bezier| *4)) (|isDomain| *3 (|List| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *4))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericEigenPackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|MachineFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3 (|Integer|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Automorphism| *3))))) 
+(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OneDimensionalArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|OneDimensionalArray| *3))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|UserDefinedVariableOrdering|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|OpenMathConnection|)) (|isDomain| *4 (|Any|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|)))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *4 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *9 (|PlacesCategory| *5 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DesingTreeCategory| *11)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *4 *7 *3 *8 *9 *10 *11 *2 *12)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *5 *6 *4 *7 *3 *8 *9 *10 *12))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|isDomain| *2 (|Matrix| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $))))))))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $))))))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $))))))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *4 *2)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Kernel| *2))) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $))))))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *4 *2))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *4 *2))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *6)) (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *6 *3 *7 *4)) (|ofCategory| *7 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *6) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PrimitiveArray| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *7) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *7) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ODEIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|)))))) 
+(((*1 *2 *3 *3 *2) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Monoid|) (|Finite|) (CATEGORY |package| (SIGNATURE ** (*3 *3 (|Integer|)))))) (|isDomain| *1 (|DiscreteLogarithmPackage| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Symbol|)) (|PartialDifferentialRing| (|Symbol|)) (|CombinatorialOpsCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|isDomain| *3 (|Integer|)) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Complex| *4)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)) (|ofCategory| *9 (|DivisorCategory| *4)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *5 *6 *3 *7 *8 *2 *4 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *3 *7 *8 *2 *4 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|NeitherSparseOrDensePowerSeries| (|PseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|Places| *5)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|NeitherSparseOrDensePowerSeries| *5)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *2)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *9)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *9 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *5)) (|isDomain| *1 (|ParametrizationPackage| *5 *6 *3 *7 *8 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *4 (|PlacesCategory| *5 *2)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *2 (|LocalPowerSeriesCategory| *6)) (|isDomain| *1 (|ParametrizationPackage| *6 *7 *3 *8 *9 *2 *4)) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *4 (|PlacesCategory| *6 *2))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Stack| (|String|))) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
+(((*1 *1) (|isDomain| *1 (|Boolean|)))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|PolyGroebner| *4))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|OneDimensionalArray| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|OneDimensionalArray| *5)) (|isDomain| *1 (|OneDimensionalArrayFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *7 *5)) (|isDomain| *4 (|DirectProduct| *6 *7)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *7 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|DirectProduct| *6 *5)) (|isDomain| *1 (|DirectProductFunctions2| *6 *7 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|FiniteLinearAggregate| *5)) (|isDomain| *1 (|FiniteLinearAggregateFunctions2| *6 *4 *5 *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|FiniteSetAggregate| *5)) (|isDomain| *1 (|FiniteSetAggregateFunctions2| *6 *4 *5 *2)) (|ofCategory| *4 (|FiniteSetAggregate| *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|List| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|ListFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|PrimitiveArray| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|PrimitiveArray| *5)) (|isDomain| *1 (|PrimitiveArrayFunctions2| *6 *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *3 *6 *3)) (|isDomain| *5 (|Stream| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamFunctions2| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *5 *6 *5)) (|isDomain| *4 (|Vector| *6)) (|ofCategory| *6 (|Type|)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|VectorFunctions2| *6 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *2 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
 (((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *1 *2) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *1 *1 *2 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|UniversalSegment| (|Integer|)))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|XPolynomialsCat| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|OrderedFreeMonoid| *3)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|OrderedMonoid|)) (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 *2)) (|ofType| *6 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |factor| (|Integer|)) (|:| |exponent| (|Integer|)))))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|AbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *1 *1 *1) (OR (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Type|))) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Group|)) (|ofCategory| *2 (|Type|))))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Field|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LocalAlgebra| *2 *4 *3)) (|ofCategory| *2 (|Algebra| *4)) (|ofCategory| *3 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LocalAlgebra| *3 *4 *2)) (|ofCategory| *3 (|Algebra| *4)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|LieAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|Localize| *2 *4 *3)) (|ofCategory| *2 (|Module| *4)) (|ofCategory| *3 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|Localize| *3 *4 *2)) (|ofCategory| *3 (|Module| *4)) (|ofCategory| *2 (|SubsetCategory| (|Monoid|) *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| (|Expression| (|Integer|)) *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|MappingPackage4| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrdinaryWeightedPolynomials| *2 *3 *4 *5)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *2 *5 *6)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *4 *2)) (|ofCategory| *6 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Expression| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|StochasticDifferential| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|VectorSpace| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *3)) (|isDomain| *1 (|WeightedPolynomials| *2 *3 *4 *5 *6 *7 *8)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Character|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *3 *4 *4 *3 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraPackage| *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)))) ((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))))) ((*1 *2 *1) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FramedModule| *3 *4 *5 *6 *7)) (|ofCategory| *6 (|FramedAlgebra| *4 *5)) (|ofType| *7 *2))) ((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|Vector| *4))) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Any|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputPackage|))))) 
+(((*1 *2 *3 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2))))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2)))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|AbelianGroup|))) ((*1 *1 *1) (|ofCategory| *1 (|AbelianGroup|))) ((*1 *1 *1 *1) (|partial| |isDomain| *1 (|CardinalNumber|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Database| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *2 *1) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianGroup|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianGroup|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| *4))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerBits|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|AbelianSemiGroup|))) ((*1 *1 *1 *1) (|isDomain| *1 (|Color|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Database| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianSemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianSemiGroup|)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|CancellationAbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|GradedModule| *2 *3)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *1 *1 *1) (|isDomain| *1 (|InputForm|))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Mapping| *4 *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MappingPackage4| *3 *4)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *2 *1) (AND (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|Divisor| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|AbelianSemiGroup|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfAlgExtOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|PseudoAlgebraicClosureOfRationalNumberCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FactorisationOverPseudoAlgebraicClosureOfRationalNumber| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Matrix| (|PrimeField| *3))) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|))))))))) ((*1 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|)))) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *3 *5 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|LaplaceTransform| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|Polynomial| *4))) (|isDomain| *1 (|RepresentationPackage1| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *4 *5 *4 *6 *7) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|String|)) (|isDomain| *6 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp73| PDEF)))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp74| BNDY)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
+(((*1 *1 *1 *1) (|partial| AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *2 *3 *4 *5 *6 *7)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *3 *3 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *3 "failed") *3 *3 *4)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|OrderedRing|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *5 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Complex| *4)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *6)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *6 *7 *4 *8 *3 *9 *10)) (|ofCategory| *4 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *10 (|PlacesCategory| *6 *9))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|LexTriangularPackage| *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|DesingTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfClsPt| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InfinitlyClosePoint| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *3 *4 *4 *5 *5 *3 *4 *4 *4 *6 *4) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|ThreeDimensionalMatrix| (|DoubleFloat|))) (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagPartialDifferentialEquationsPackage|))))) 
+(((*1 *2 *3 *4 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *3 (|DivisorCategory| *11)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *3 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| *7) (|:| |den| *7) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (|isDomain| *4 (|Integer|)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |den| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|isDomain| *4 (|Integer|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ord| (|Integer|)) (|:| |num| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |den| (|DistributedMultivariatePolynomial| *6 *5)) (|:| |upTo| (|Integer|)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|isDomain| *4 (|Integer|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathDevice|)) (|isDomain| *1 (|OpenMathConnection|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|OneDimensionalArray| (|List| (|LyndonWord| *5)))) (|isDomain| *1 (|LyndonWord| *5))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| (|Fraction| (|Polynomial| *6)))) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|RationalFunctionIntegration| *6))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PermutationCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Stream| *3))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PermutationGroup| *4))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|Bits|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|SubSpace| 3 *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|FileCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|List| *2)) (|isDomain| *1 (|BasicOperatorFunctions1| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 (|List| *4))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Mapping| *4 (|List| *4))) (|isDomain| *1 (|BasicOperatorFunctions1| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|LeftModule| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Operator| *3))))) 
+(((*1 *2 *1 *1 *3) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *2) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4 *5) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2 *4 *5 *6) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|List| (|NonNegativeInteger|))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Factored| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *5 *2)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|BasicType|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *2) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Reference| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *5)) (|Record| (|:| |index| *2) (|:| |exponent| *5)))) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *2 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 (|OrderedVariableList| *3)))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|IntegerPrimesPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CyclicStreamTools| *4 *3)) (|ofCategory| *3 (|LazyStreamAggregate| *4))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *4 *4 *5 *6 *7) (AND (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |mainpart| *4) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (|List| *4))) (|isDomain| *7 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4 *4)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedField|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| *3) (|LinearlyExplicitRingOver| *3))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Record| (|:| |ans| *4) (|:| |right| *4) (|:| |sol?| (|Boolean|)))) (|isDomain| *1 (|ElementaryRischDE| *8 *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *5 (|RetractableTo| (|AlgebraicNumber|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|OpenMathErrorKind|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *1 (|OpenMathError|))))) 
 (((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *3 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| (|List| *3)))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *3 *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*3 $)) (SIGNATURE |denom| (*3 $)) (SIGNATURE |coerce| ($ *3)))))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *4) (|:| |degree| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Multiset| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupFactorizer| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Factored| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Multiset| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *5))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *5)) (|:| |vec| (|Vector| (|List| (|PositiveInteger|)))))) (|isDomain| *1 (|AssociatedEquations| *5 *3)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Vector| (|Fraction| (|Integer|)))) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Stack| (|String|))) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|InputForm|)) (|isDomain| *1 (|InputFormFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|TriangularMatrixOperations| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Permutation| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|PermutationGroup| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Vector| *4))) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
+(((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| *3) (|:| |entry| *4)))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *1 (|TableAggregate| *3 *4)))) ((*1 *1) (AND (|ofCategory| *1 (|TableAggregate| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *5 *2 *6 *7)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1 *3 *4 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Fraction| *3))) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |adjMat| *3) (|:| |detMat| *4))) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)))) ((*1 *1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|FortranPackage|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|ReductionOfOrder| *3 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |eq| *3) (|:| |op| (|List| *5)))) (|isDomain| *1 (|ReductionOfOrder| *5 *3)) (|isDomain| *4 (|List| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
 (((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *5 *4)) (|ofCategory| *5 (|Type|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 |SortedExponentVector|)))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UniversalSegment| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|EuclideanDomain|)))) ((*1 *2 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |lm| (|FreeMonoid| *3)) (|:| |rm| (|FreeMonoid| *3)))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |quotient| (|NonNegativeInteger|)) (|:| |remainder| (|NonNegativeInteger|)))) (|isDomain| *1 (|NonNegativeInteger|)))) ((*1 *2 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |lm| (|Union| (|OrderedFreeMonoid| *3) "failed")) (|:| |rm| (|Union| (|OrderedFreeMonoid| *3) "failed")))) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|FGLMIfCanPackage| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerPackage| *4 *5 *6 *7)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|InterfaceGroebnerPackage| *3 *4 *5 *6 *7)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *3 (|OrderedVariableList| *4)))) (|ofCategory| *3 (|GcdDomain|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|LexTriangularPackage| *3 *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RootsFindingPackage| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
-(((*1 *2 *3 *4 *5 *5 *5 *5 *4 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|UniversalSegment| (|Integer|))) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|Record| (|:| |num| *1) (|:| |den| *5) (|:| |derivden| *5) (|:| |gd| *5))) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|List| (|Mapping| *4 (|List| *4)))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|BasicOperatorFunctions1| *4)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|List| (|Mapping| *4 (|List| *4)))) (|isDomain| *1 (|BasicOperatorFunctions1| *4)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|UTSodetools| *5 *2 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *3 (|UnivariateTaylorSeriesCategory| *5))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Expression| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|Vector| *1)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|CharacteristicNonZero|)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Vector| *1))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Vector| *2)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *6 (|QuotientFieldCategory| *5)) (|ofCategory| *2 (|Join| (|FramedAlgebra| *6 *7) (|RetractableTo| *6))) (|isDomain| *1 (|FractionalIdeal| *5 *6 *7 *2)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|isDomain| *2 (|List| (|Vector| *5))) (|isDomain| *1 (|InterpolateFormsPackage| *5 *6 *7 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *3 (|DivisorCategory| *11))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Mapping| (|Boolean|) *9)) (|isDomain| *5 (|Mapping| (|Boolean|) *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |bas| *1) (|:| |top| (|List| *9)))) (|isDomain| *3 (|List| *9)) (|ofCategory| *1 (|TriangularSetCategory| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Boolean|) *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |bas| *1) (|:| |top| (|List| *8)))) (|isDomain| *3 (|List| *8)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *8))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CyclicStreamTools| *4 *3)) (|ofCategory| *3 (|LazyStreamAggregate| *4))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultantReduit| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|AffineAlgebraicSetComputeWithGroebnerBasis| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *2)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *2)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *2 *1 *3 *4) (AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| *8 *8 *8)) (|isDomain| *4 (|Mapping| (|Boolean|) *8 *8)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|NAGLinkSupportPackage|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|CyclicStreamTools| *3 *2)) (|ofCategory| *2 (|LazyStreamAggregate| *3))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |polyPart| (|LaurentPolynomial| *4 *5)) (|:| |fracPart| (|Fraction| *5)))) (|isDomain| *1 (|LaurentPolynomial| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |primePart| *1) (|:| |commonPart| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|Places| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| AND (|isDomain| *5 (|Record| (|:| |contp| *3) (|:| |factors| (|List| (|Record| (|:| |irr| *10) (|:| |pow| (|Integer|))))))) (|isDomain| *6 (|List| *3)) (|isDomain| *7 (|List| *8)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *10 (|PolynomialCategory| *3 *9 *8)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |polfac| (|List| *10)) (|:| |correct| *3) (|:| |corrfact| (|List| (|SparseUnivariatePolynomial| *3))))) (|isDomain| *1 (|LeadingCoefDetermination| *8 *9 *3 *10)) (|isDomain| *4 (|List| (|SparseUnivariatePolynomial| *3)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ComplexCategory&| *3 *2)) (|ofCategory| *3 (|ComplexCategory| *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedAlgebra&| *3 *2 *4)) (|ofCategory| *3 (|FramedAlgebra| *2 *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|NumberFieldIntegralBasis| *3 *4)) (|ofCategory| *4 (|FramedAlgebra| *2 *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1) (|isDomain| *1 (|Color|)))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|SimpleCell| *3 (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|Cell| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|SimpleCell| *3 (|SparseUnivariatePolynomial| *3)))) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|Cell| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *4 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| *3))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|MonogenicAlgebra| *4 *5)) (|isDomain| *1 (|InfiniteProductFiniteField| *4 *5 *6 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *6)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| *3))) (|isDomain| *1 (|InfiniteProductPrimeField| *4 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *4))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *8))) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *5 *6 *7 *8)) (|isDomain| *4 (|SparseUnivariatePolynomial| *8)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| *3))) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| *3))) (|isDomain| *5 (|String|)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Expression| *5)))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *5))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Expression| *6)))) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *6))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| *5))))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *5))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| *6))))) (|isDomain| *5 (|String|)) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *6))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| *3 (|List| *3))) (|isDomain| *1 (|FunctionSpaceIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *6 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalIntegrationProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *6 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Symbol|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|IntegrationResult| (|Fraction| *5))) (|isDomain| *1 (|RationalIntegration| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|CharacteristicZero|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|Expression| *5) (|List| (|Expression| *5)))) (|isDomain| *1 (|IntegrationResultRFToFunction| *5)))) ((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Polynomial| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *2 *4)) (|ofCategory| *4 (|PolynomialCategory| *3 (|IndexedExponents| *2) *2)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *7 (|List| *7))) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
 (((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *3))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *3))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
-(((*1 *1 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RomanNumeral|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RomanNumeral|))))) 
+(((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|DisplayPackage|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *5 *3)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *4))))) 
+(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Cell| *2)) (|ofCategory| *2 (|RealClosedField|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|InputForm|)) (|isDomain| *1 (|InputFormFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|InputForm|))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PermutationGroup| *3))))) 
+(((*1 *2 *2 *3) (|partial| AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *3)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
 (((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *3 *4 *5 *6 *7 *8 *9) (|partial| AND (|isDomain| *4 (|List| *11)) (|isDomain| *5 (|List| (|SparseUnivariatePolynomial| *9))) (|isDomain| *6 (|List| *9)) (|isDomain| *7 (|List| *12)) (|isDomain| *8 (|List| (|NonNegativeInteger|))) (|ofCategory| *11 (|OrderedSet|)) (|ofCategory| *9 (|EuclideanDomain|)) (|ofCategory| *12 (|PolynomialCategory| *9 *10 *11)) (|ofCategory| *10 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *12))) (|isDomain| *1 (|MultivariateLifting| *10 *11 *9 *12)) (|isDomain| *3 (|SparseUnivariatePolynomial| *12))))) 
 (((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FractionFreeFastGaussian| *3 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *3 *4))))) 
-(((*1 *2 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Union| (|SparseUnivariatePolynomial| *4) (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|))))))) (|isDomain| *1 (|FiniteFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Color|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|FreeGroup| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|FreeMonoid| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| (|Kernel| *6))) (|isDomain| *1 (|IntegrationTools| *5 *6))))) 
+(((*1 *2 *3 *2) (|partial| AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *4)))) ((*1 *2 *3 *2) (|partial| AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *1 (|LinearSystemMatrixPackage| *4 *5 *2 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *2)))) ((*1 *2 *3 *2 *4 *5) (|partial| AND (|isDomain| *4 (|List| *2)) (|isDomain| *5 (|Mapping| *2 *2)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|ODETools| *2 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *1) (|isDomain| *1 (|IntegrationFunctionsTable|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|Cell| *3)) (|ofCategory| *3 (|RealClosedField|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *1) (|isDomain| *1 (|TwoDimensionalViewport|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Point| *4)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |coef| *3) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| (|NewSparseUnivariatePolynomial| *3)) (|:| |remainder| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |coef| *1) (|:| |gap| (|NonNegativeInteger|)) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedMonoid|))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|FGLMIfCanPackage| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *3 (|OrderedVariableList| *4)))) (|ofCategory| *3 (|GcdDomain|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|LexTriangularPackage| *3 *4))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Float|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Float|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *1) (|isDomain| *1 (|Color|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RetractableTo| (|Integer|))) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultantReduit| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|DistributedMultivariatePolynomial| *3 *4)) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|isDomain| *1 (|GeneralDistributedMultivariatePolynomial| *3 *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|HomogeneousDistributedMultivariatePolynomial| *3 *4)) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| *10)) (|isDomain| *1 (|LazardSetSolvingPackage| *5 *6 *7 *8 *9 *10)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *10 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|LexTriangularPackage| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6))))) (|isDomain| *1 (|LexTriangularPackage| *5 *6)))) ((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *5 (|OrderedVariableList| *6)))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|RegularChain| *5 *6))) (|isDomain| *1 (|RegularChain| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|SuchThat| (|List| (|Expression| *5)) (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|SuchThat| (|List| (|Expression| *5)) (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |outval| (|Complex| *4)) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| (|Complex| *4))))))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|ParadoxicalCombinatorsForStreams| *4)) (|ofCategory| *4 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|List| (|Stream| *5)) (|List| (|Stream| *5)))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| (|Stream| *5))) (|isDomain| *1 (|ParadoxicalCombinatorsForStreams| *5)) (|ofCategory| *5 (|Type|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| (|LyndonWord| *5))) (|isDomain| *1 (|LyndonWord| *5))))) 
+(((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *6)))) (|isDomain| *4 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *5 (|Symbol|)) (|isDomain| *7 (|Fraction| (|Integer|))) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|DoubleResultantPackage| *5 *2 *6 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *5 *2 *6))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|)))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|BinaryTournament| *3))))) 
-(((*1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4))))) 
-(((*1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4))))) 
-(((*1 *1 *1) (AND (|ofCategory| *2 (|FiniteFieldCategory|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModMonic| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearDependence| *4 *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *7 (|PolynomialCategory| *3 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *8) (|:| |radicand| *8))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *3 *7 *8)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *8 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)) (SIGNATURE |coerce| ($ *7)))))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAssertions| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PatternMatchAssertions|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *4 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|OpenMathEncoding|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RomanNumeral|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RomanNumeral|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|FreeGroup| (|BasicOperator|))) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *4)) (|ofCategory| *4 (|LeftModule| *2)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|FreeGroup| (|BasicOperator|))) (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |factor| (|Integer|)) (|:| |exponent| (|Integer|)))))))) 
-(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|Finite|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |additions| (|Integer|)) (|:| |multiplications| (|Integer|)) (|:| |exponentiations| (|Integer|)) (|:| |functionCalls| (|Integer|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|DifferentialRing|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Mapping| *1 (|NonNegativeInteger|))) (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Mapping| *1 (|NonNegativeInteger|))) (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Fraction| (|Integer|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Equation| *3)) (|isDomain| *5 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 (|Integer|))) (|isDomain| *4 (|Equation| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *7 (|Integer|))) (|isDomain| *4 (|Equation| *7)) (|isDomain| *5 (|UniversalSegment| (|Integer|))) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Mapping| *8 (|Fraction| (|Integer|)))) (|isDomain| *4 (|Equation| *8)) (|isDomain| *5 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *6 (|Fraction| (|Integer|))) (|ofCategory| *8 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *7 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *8 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerTaylorSeries| *3)))) ((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| *4)))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *1 (|TubePlotTools|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|String|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *4 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NormalizationPackage| *6 *7 *8 *4 *5)) (|ofCategory| *5 (|RegularTriangularSetCategory| *6 *7 *8 *4))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |val| *1) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |val| (|Pattern| *3)) (|:| |exponent| (|Pattern| *3)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Record| (|:| |val| *3) (|:| |exponent| (|Integer|)))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *4) (|:| |degree| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *4))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *2 *3) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *4 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *3 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *2 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|SymbolTable|)))) ((*1 *2 *3 *2 *1) (AND (|isDomain| *2 (|FortranType|)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *3 *5)) (|ofCategory| *4 (|Type|)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DivisorCategory| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *1 *1 *2 *3 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|))))) 
+(((*1 *1) (|isDomain| *1 (|FortranCode|)))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|FractionFreeFastGaussian| *5 *6)) (|ofCategory| *6 (|AbelianMonoidRing| *5 *4)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|FractionFreeFastGaussian| *5 *6)) (|ofCategory| *6 (|AbelianMonoidRing| *5 *4)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *5)) (|isDomain| *3 (|List| *5)) (|ofType| *4 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *1 (|PolynomialInterpolation| *4 *5)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *5)) (|isDomain| *1 (|PolynomialInterpolation| *4 *5)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3 *3 *4 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|isDomain| *2 (|Fraction| (|Polynomial| *6))) (|isDomain| *1 (|RationalInterpolation| *5 *6)) (|ofType| *5 (|Symbol|))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|RationalIntegration| *3 *4))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Boolean|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *4 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *4 *2 *2 *5) (|partial| AND (|isDomain| *2 (|OrderedCompletion| *4)) (|isDomain| *3 (|Kernel| *4)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|DefiniteIntegrationTools| *6 *4))))) 
 (((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|FortranScalarType|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|SimpleFortranProgram| *5 *4)) (|ofCategory| *4 (|FunctionSpace| *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|ElementaryIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
-(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |minor| (|List| (|PositiveInteger|))) (|:| |eq| *3) (|:| |minors| (|List| (|List| (|PositiveInteger|)))) (|:| |ops| (|List| *3)))) (|isDomain| *1 (|AssociatedEquations| *5 *3)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputPackage|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Stream| *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *4 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
-(((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *6) (|:| |coeff| *6)) "failed") *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Union| (|Record| (|:| |answer| (|Fraction| *7)) (|:| |a0| *6)) (|Record| (|:| |ratpart| (|Fraction| *7)) (|:| |coeff| (|Fraction| *7))) "failed")) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|KernelFunctions2| *2 *4))))) 
+(((*1 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DisplayPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *2 (|PolynomialCategory| *4 *6 *5)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *2)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
 (((*1 *2 *3) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|DisplayPackage|)) (|isDomain| *3 (|String|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|QuasiAlgebraicSet| (|Fraction| (|Integer|)) (|OrderedVariableList| *3) (|DirectProduct| *4 (|NonNegativeInteger|)) (|DistributedMultivariatePolynomial| *3 (|Fraction| (|Integer|))))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|NonNegativeInteger|)) (|isDomain| *1 (|QuasiAlgebraicSet2| *3 *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *4 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|List| (|InputForm|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|String|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *5 *3 *4)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|OrdinaryDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Result|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|RationalLODE| *4 *2)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *2 (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|RationalLODE| *4 *2)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|)))))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|))))) (|isDomain| *1 (|Symbol|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|OutputForm|)))) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3)) (|ofCategory| *3 (|FiniteFieldCategory|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Kernel| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|RetractableTo| (|Integer|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|SparseUnivariatePolynomial| *5)) (|isDomain| *1 (|AlgebraicFunction| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Kernel| *1)) (|ofCategory| *1 (|Ring|)) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *1))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
-(((*1 *1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2 *1 *3 *3) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|IndexedAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *4)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *3 (|DivisorCategory| *11)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *3 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *5 *6 *7 *8 *9 *10 *11 *3 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *4 *5 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) *4)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|isDomain| *1 (|InterpolateFormsPackage| *6 *7 *5 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *3 (|DivisorCategory| *11)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *6 *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2)))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1) (|ofCategory| *1 (|UniqueFactorizationDomain|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *3 *2)) (|ofCategory| *2 (|Join| (|UnivariatePolynomialCategory| *3) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $)))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *2 (|Record| (|:| |max| (|Union| (|Integer|) "failed")) (|:| |ord| (|Union| (|Integer|) "failed")) (|:| |ker| (|Kernel| *5)))) (|isDomain| *1 (|RecurrenceOperator| *6 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *6) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| *4) (|PartialDifferentialRing| *4) (|CombinatorialOpsCategory|)))))) 
 (((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Monoid|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AlgebraicFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CombinatorialFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ElementaryFunction| *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ExpressionSpace&| *4)) (|ofCategory| *4 (|ExpressionSpace|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionSpace&| *4 *5)) (|ofCategory| *4 (|FunctionSpace| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *5)) (|ofCategory| *5 (|FunctionSpace| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LiouvillianFunction| *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *8))) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DirichletRing| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *1 (|ComplexTrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| (|Complex| *3)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|TrigonometricManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|Complex| (|Float|)))) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |radicand| (|Fraction| *5)) (|:| |deg| (|NonNegativeInteger|)))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|))))) (|isDomain| *1 (|Symbol|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|OutputForm|)))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *4 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MakeUnaryCompiledFunction| *4 *5 *6)) (|ofCategory| *4 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|))))) 
+(((*1 *2 *3 *4 *2 *5) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|Pattern| *6))) (|isDomain| *5 (|Mapping| (|PatternMatchResult| *6 *8) *8 (|Pattern| *6) (|PatternMatchResult| *6 *8))) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *8 (|Join| (|Ring|) (|ConvertibleTo| (|Pattern| *6)) (|RetractableTo| *7))) (|isDomain| *2 (|PatternMatchResult| *6 *8)) (|ofCategory| *7 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|PatternMatchTools| *6 *7 *8))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *3 (|Boolean|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Color|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *3 *6 *7 *8 *9 *2 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *4 (|List| *13)) (|isDomain| *5 (|List| *9)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *13 (|DesingTreeCategory| *12)) (|ofCategory| *6 (|Field|)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *6 *7 *3 *8 *9 *10 *11 *2 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *6)) (|ofCategory| *11 (|PlacesCategory| *6 *10)) (|ofCategory| *2 (|DivisorCategory| *11)) (|isDomain| *1 (|IntersectionDivisorPackage| *6 *7 *3 *8 *9 *10 *11 *2 *12 *13 *14)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *5 *4)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Divisor| (|Places| *4))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FloatingPointSystem&| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FloatingPointSystem&| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Stream| (|Integer|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Matrix| *6))) (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|RepresentationPackage2| *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *6 (|Ring|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|RepresentationPackage2| *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RepresentationPackage2| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PrintPackage|))))) 
-(((*1 *2 *3 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SegmentCategory| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *2))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|AssociationList| (|String|) (|None|))) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|UnivariatePolynomial| *5 *4))) (|isDomain| *1 (|SturmHabichtPackage| *4 *5)) (|isDomain| *3 (|UnivariatePolynomial| *5 *4))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |op| (|BasicOperator|)) (|:| |w| (|DoubleFloat|)))) (|isDomain| *1 (|d01WeightsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|FiniteLinearAggregate| *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *6)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *6 *7 *8 *3)) (|ofCategory| *3 (|MatrixCategory| *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|List| (|PositiveInteger|))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|FiniteLinearAggregate| *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *6)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *6 *7 *8 *3)) (|ofCategory| *3 (|MatrixCategory| *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|d03AgentsPackage|))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|LaurentPolynomial| *4 *5)) (|isDomain| *3 (|Mapping| (|Record| (|:| |ans| *4) (|:| |right| *4) (|:| |sol?| (|Boolean|))) (|Integer|) *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|TranscendentalIntegration| *4 *5))))) 
+(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1 *3 *4 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *4 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6)) (|ofCategory| *5 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|RewriteRule| *3 *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3))))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|Any|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PrimitiveArray| (|ModMonic| *3 *4))) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *5 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| *2)) (|isDomain| *4 (|Mapping| *2 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|MonomialExtensionTools| *5 *2)) (|ofCategory| *5 (|Field|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OrdSetInts|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|QueryEquation|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Partition|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|FiniteAbelianMonoidRing| *5 *7)) (|ofCategory| *7 (|DirectProductCategory| *8 (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *6 *7 *8 *4)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *5))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LyndonWord| *3))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *1 *2 *3 *1 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathErrorKind|)) (|isDomain| *1 (|OpenMathError|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerBits|))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *3 (|Mapping| (|Union| *5 "failed") *8)) (|isDomain| *4 (|Matrix| (|SparseUnivariatePolynomial| *8))) (|ofCategory| *5 (|Ring|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *6 *7 *8)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|LaurentPolynomial| *4 *5)) (|isDomain| *3 (|Mapping| (|Record| (|:| |ans| *4) (|:| |right| *4) (|:| |sol?| (|Boolean|))) (|Integer|) *4)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|TranscendentalIntegration| *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|AffineSpaceCategory| *3))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *5 *4 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4))))) 
 (((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|CharacterClass|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Character|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathDevice|)) (|isDomain| *1 (|OpenMathConnection|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|DrawComplex|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *2 *3 *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SortPackage| *4 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|SortPackage| *3 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *3) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|CycleIndicators|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |polnum| (|NewSparseUnivariatePolynomial| *3)) (|:| |polden| *3) (|:| |power| (|NonNegativeInteger|)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |polnum| *1) (|:| |polden| *1) (|:| |power| (|NonNegativeInteger|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *2 *3 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|InverseLaplaceTransform| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|SpecialFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *6) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *7) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| *8) (|:| |order| (|NonNegativeInteger|)))) (|List| *6) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Field|)) (|ofType| *11 (|Mapping| *8 *6)) (|ofCategory| *9 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *10 (|Mapping| *6 *9)) (|isDomain| *2 (|List| (|Record| (|:| |function| *8) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *6 *7 *8 *9 *10 *11)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *9) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| *9) (|:| |order| (|NonNegativeInteger|)))) (|List| *7) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|Field|)) (|ofType| *12 (|Mapping| *9 *7)) (|ofCategory| *10 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *11 (|Mapping| *7 *10)) (|isDomain| *2 (|List| (|Record| (|:| |function| *9) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *7 *8 *9 *10 *11 *12)) (|ofCategory| *8 (|GcdDomain|)) (|ofCategory| *9 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *10) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *6 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *6 (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *6 (|Integer|))))) (|ofType| *6 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *6 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *6)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|List| (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *7 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *7 (|Integer|)))) (|List| (|GuessOption|))))) (|isDomain| *5 (|List| (|Symbol|))) (|isDomain| *6 (|List| (|GuessOption|))) (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *7 (|Integer|))))) (|ofType| *7 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *7 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Set| (|Set| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|NonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|FGLMIfCanPackage| *3 *4)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (|partial| AND (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *3 (|OrderedVariableList| *4)))) (|ofCategory| *3 (|GcdDomain|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|LexTriangularPackage| *3 *4))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *3 *3 *4 *5 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| (|List| *8)) (|:| |tower| *9)))) (|isDomain| *5 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *6 *7 *4)) (|ofCategory| *9 (|RegularTriangularSetCategory| *6 *7 *4 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|Record| (|:| |val| *8) (|:| |tower| *9)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *6 *7 *4 *8 *9))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |preimage| (|List| *3)) (|:| |image| (|List| *3)))) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OpenMathDevice|)) (|isDomain| *1 (|OpenMathConnection|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|StochasticDifferential| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3))))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *1 *1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
-(((*1 *2) (AND (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|DoubleFloat|))) (|isDomain| *1 (|GraphImage|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Equation| *3))) (|isDomain| *1 (|Equation| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|TaylorSeries| *5))) (|isDomain| *1 (|WeierstrassPreparation| *5)) (|isDomain| *4 (|TaylorSeries| *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LyndonWord| *3))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Polynomial| (|Integer|))) (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranCodePackage1|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|isDomain| *1 (|IncrementingMaps| *3)) (|ofCategory| *3 (|Join| (|Monoid|) (|AbelianSemiGroup|)))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|DrawComplex|))))) 
-(((*1 *1 *2 *2 *2 *2 *2 *2 *2 *2) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Quaternion| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|Octonion| *3))))) 
-(((*1 *1) (|isDomain| *1 (|TheSymbolTable|)))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|BasicType|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|GraphImage|)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *1 (|FiniteLinearAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *6)) (|ofCategory| *6 (|Join| (|FramedAlgebra| *4 *5) (|RetractableTo| *4))) (|ofCategory| *4 (|QuotientFieldCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|FractionalIdeal| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|Union| (|List| *8) "failed" "Infinite" (|Integer|))) (|isDomain| *1 (|AffineAlgebraicSetComputeWithResultant| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Expression| *5))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|List| (|Expression| *5)))) (|isDomain| *1 (|RadicalSolvePackage| *5))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|RoutinesTable|)) (|isDomain| *3 (|String|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Result|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|Logic|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *3))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|Logic|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Polynomial| *5)))) (|isDomain| *1 (|SystemSolvePackage| *5))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *4 (|MonogenicAlgebra| *5 *7)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *6)) (|:| |vec| (|Vector| *5)))) (|isDomain| *1 (|ReduceLODE| *5 *6 *7 *4 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Set| *3)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|EuclideanDomain|))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *6 (|Boolean|)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *7))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *7 *3)) (|isDomain| *5 (|OrderedCompletion| *3))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Union| "left" "center" "right" "vertical" "horizontal")) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *8 (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|NewtonPolygon| *6 *3 *7 *8)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *6 *7))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5 *5 *6 *7 *8 *8 *3) (AND (|isDomain| *6 (|List| (|Boolean|))) (|isDomain| *7 (|Matrix| (|DoubleFloat|))) (|isDomain| *8 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|DisplayPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Fraction| *3))) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|PolynomialDecomposition| *2 *3)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |sinh| (|Stream| *4)) (|:| |cosh| (|Stream| *4)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *4)) (|isDomain| *3 (|Stream| *4))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|EuclideanDomain|))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|Matrix| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|d02AgentsPackage|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Matrix| *6)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *6 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *6)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *4 *4 *5 *6 *5 *4 *7 *3) (AND (|isDomain| *4 (|Matrix| (|Integer|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *7 (|Matrix| (|DoubleFloat|))) (|isDomain| *3 (|Integer|)) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *2 *2 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *4))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *6) (|:| |coeff| *6)) "failed") *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LyndonWord| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *5 *6 *6 *7 *7 *3) (AND (|isDomain| *4 (|List| (|Boolean|))) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Matrix| (|Integer|))) (|isDomain| *7 (|DoubleFloat|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *3 *3 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined")) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|)))) ((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|)))) ((*1 *2 *2 *3 *4 *4 *5) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|List| (|DrawOption|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|BasicType|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
 (((*1 *2 *3 *1) (|partial| AND (|ofCategory| *1 (|KeyedDictionary| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *3) (|:| |polj| *3)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3))))) 
-(((*1 *2 *3 *1) (|partial| AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
 (((*1 *2 *3 *4 *3 *5 *3) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|BagAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Boolean|) (|BasicOperator|) (|BasicOperator|))) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RandomNumberSource|))))) 
 (((*1 *2 *3 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3))) ((*1 *1 *2 *3 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *7 (|List| *7))) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|)))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfClsPt| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|Logic|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfClsPt| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Float|))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|DataList| *3))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|ofCategory| *7 (|QuotientFieldCategory| *4)) (|ofCategory| *2 (|MatrixCategory| *7 *8 *9)) (|isDomain| *1 (|InnerMatrixQuotientFieldFunctions| *4 *5 *6 *3 *7 *8 *9 *2)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *7)) (|ofCategory| *9 (|FiniteLinearAggregate| *7)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5)))) ((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Matrix| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|SquareMatrixCategory| *2 *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *2 *3)) (|ofCategory| *5 (|DirectProductCategory| *2 *3)) (|ofCategory| *3 (|Field|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *3))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |ans| (|Fraction| *5)) (|:| |nosol| (|Boolean|)))) (|isDomain| *1 (|TranscendentalRischDE| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
 (((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|Logic|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|MachineFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| (|Kernel| *6))) (|isDomain| *1 (|IntegrationTools| *5 *6))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|LocalPowerSeriesCategory| *3)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *3 *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
 (((*1 *2 *3 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |left| (|Fraction| (|Integer|))) (|:| |right| (|Fraction| (|Integer|)))))) (|isDomain| *2 (|List| (|Fraction| (|Integer|)))) (|isDomain| *1 (|RealZeroPackage| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Mapping| *6 (|List| *6))) (|isDomain| *1 (|UTSodetools| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *4))))) 
-(((*1 *2 *2 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *3)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4))))) ((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Symbol|)) (|ofCategory| *6 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *6) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))) (|isDomain| *2 (|Record| (|:| |particular| *4) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|ConstantLODE| *6 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
 (((*1 *2 *3 *3 *4 *4 *5 *4 *5 *4 *4 *5 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *2 *6)) (|ofCategory| *6 (|PolynomialCategory| *2 *4 *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *2)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GuessOptionFunctions0|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|CharacterClass|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Character|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|Record| (|:| |solns| (|List| *5)) (|:| |maps| (|List| (|Record| (|:| |arg| *5) (|:| |res| *5)))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|GuessFiniteFunctions| *3)) (|ofCategory| *3 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|))))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
 (((*1 *2 *3 *4 *4 *4 *4 *5 *5 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|Integer|)) (|isDomain| *5 (|Matrix| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagMatrixOperationsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *3))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp49| OBJFUN)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
+(((*1 *1 *2 *3 *3 *3 *4) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *1 (|FiniteDivisorCategory| *4 *3 *5 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *4 *3 *5)))) ((*1 *1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *1 (|FiniteDivisorCategory| *2 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *2 *4 *5)))) ((*1 *1 *2 *2) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *1 (|FiniteDivisorCategory| *2 *3 *4 *5)) (|ofCategory| *5 (|FunctionFieldCategory| *2 *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *5 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| *6))) (|isDomain| *1 (|ChangeOfVariable| *5 *6 *7)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *3))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|MoreSystemCommands|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|LeftModule| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|Operator| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Polynomial| *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|RectangularMatrix| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|RewriteRule| *3 *4 *2)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|SuchThat| *3 *2)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
+(((*1 *2 *3 *4 *4 *3 *4 *5 *4 *4 *3 *3 *3 *3 *6 *3 *7) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Boolean|)) (|isDomain| *6 (|Matrix| (|DoubleFloat|))) (|isDomain| *7 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp49| OBJFUN)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Algebra| *2)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|SymmetricFunctions| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|SymmetricFunctions| *3)) (|ofCategory| *3 (|Ring|))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *5) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp50| LSFUN1)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|HomogeneousDistributedMultivariatePolynomial| *3 *4))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *3 *4))))) 
-(((*1 *2 *3 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|TranscendentalRischDESystem| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |k| (|OrderedFreeMonoid| *3)) (|:| |c| *4)))))) 
+(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *3 (|IntegralDomain|))))) 
+(((*1 *2 *3 *4 *5 *6 *5 *3 *7) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|)))) (|isDomain| *7 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|)))) ((*1 *2 *3 *4 *5 *6 *5 *3 *7 *3 *3 *3 *3 *3 *3 *3) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Record| (|:| |try| (|Float|)) (|:| |did| (|Float|)) (|:| |next| (|Float|)))) (|isDomain| *7 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *3 *5) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp19| LSFUN2)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|AffineSpaceCategory| *3))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *5)))) (|isDomain| *1 (|TwoFactorize| *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *5)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicLinearOperator| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *1 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|PolynomialCategory| *4 *5 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
 (((*1 *2 *3 *3 *3 *3 *4 *4 *4 *3 *5) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp24| FUNCT1)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranCode|))))) 
 (((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|String|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |left| *3) (|:| |right| *3))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|PseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|ProjectivePlane| *4)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *3 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *5)) *4 *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|isDomain| *1 (|PushVariables| *4 *5 *3 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PushVariables| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *6))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *4 *5 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|DataList| *3))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|Comparable|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FloatingPointSystem&| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FloatingPointSystem&| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Stream| (|Integer|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Float|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |val| *1) (|:| |exponent| (|Integer|)))) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |val| (|Pattern| *3)) (|:| |exponent| (|Pattern| *3)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Record| (|:| |val| *3) (|:| |exponent| (|Integer|)))) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *3 *3 *4 *5 *5 *5 *5 *5 *5 *6 *6 *6 *3 *3 *5 *7 *3 *8) (AND (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *6 (|Boolean|)) (|isDomain| *7 (|Matrix| (|Integer|))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp20| QPHESS)))) (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|AbelianMonoid|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|EuclideanDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *5 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
 (((*1 *2 *3 *3 *3 *3 *3 *3 *4 *4 *4 *3 *3 *5 *6 *3 *6 *6 *5 *6 *6 *6 *6 *5 *3 *3 *3 *3 *3 *6 *6 *6 *3 *3 *3 *3 *3 *7 *4 *4 *4 *4 *3 *8 *9) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Matrix| (|Integer|))) (|isDomain| *8 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp55| CONFUN)))) (|isDomain| *9 (|Union| (|:| |fn| (|FileName|)) (|:| |fp| (|Asp49| OBJFUN)))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))))) ((*1 *2) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *2 *5)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *2 *5)))) ((*1 *2) (|partial| AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *2 *4)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|GcdDomain|))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|PrimitiveArray| (|U32Vector|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *2 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *2 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *2 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *5 *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *2 *3 *4)) (|ofCategory| *2 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|GcdDomain|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *2 *3) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|SubResultantPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
 (((*1 *2) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|SortedCache| *3)) (|ofCategory| *3 (|CachableSet|))))) 
 (((*1 *2 *3 *3 *3 *4 *5 *3 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagOptimisationPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursiveAggregate| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Kernel| *4)) (|isDomain| *1 (|KernelFunctions2| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *1 *2 *3 *3 *3 *4) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *1 (|FiniteDivisorCategory| *4 *3 *5 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *4 *3 *5)))) ((*1 *1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *1 (|FiniteDivisorCategory| *2 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *2 *4 *5)))) ((*1 *1 *2 *2) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *1 (|FiniteDivisorCategory| *2 *3 *4 *5)) (|ofCategory| *5 (|FunctionFieldCategory| *2 *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *2 (|EuclideanDomain|)) (|ofCategory| *3 (|QuotientFieldCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|FractionalIdeal| *2 *3 *4 *5)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *3 *4) (|RetractableTo| *3)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d01AgentsPackage|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| *2))) (|isDomain| *2 (|Pattern| *3)) (|isDomain| *1 (|RewriteRule| *3 *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| *2)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|Vector| (|MachineFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Point| *5)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |f1| (|List| *4)) (|:| |f2| (|List| (|List| (|List| *4)))) (|:| |f3| (|List| (|List| *4))) (|:| |f4| (|List| (|List| (|List| *4)))))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| (|List| (|List| *4))))))) 
 (((*1 *2 *3 *4 *4 *5 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *5 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SExpression|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AxiomServer|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|Union| (|GraphImage|) "undefined"))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| (|Vector| (|Integer|)))) (|isDomain| *1 (|GrayCode|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Complex| *3)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |discriminant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
 (((*1 *2 *3 *3 *4 *4 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorFactorizer| *4 *5)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)) (|isDomain| *3 (|Float|))))) 
-(((*1 *2 *1 *3 *4 *4 *4 *4 *5 *5 *5 *5 *6 *5 *6 *5) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *5 (|Integer|)) (|isDomain| *6 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *3 *4 *4 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DirichletRing| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| *5))) (|isDomain| *1 (|FloatingRealPackage| *5)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|)))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|SortPackage| *4 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|)))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|SortPackage| *3 *2)) (|ofCategory| *2 (|Join| (|IndexedAggregate| (|Integer|) *3) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|) (ATTRIBUTE |shallowlyMutable|))))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *4 *2 *5 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *2 *6 *7 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|PartialDifferentialRing| *5)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *1 *1) (|isDomain| *1 (|AlgebraicNumber|))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|OneDimensionalArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|OneDimensionalArrayFunctions2| *5 *2)))) ((*1 *2 *3 *1 *2 *2) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|SetCategory|)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3 *1 *2) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |pol| (|SparseUnivariatePolynomial| *4)) (|:| |deg| (|PositiveInteger|)))) (|isDomain| *1 (|DegreeReductionPackage| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|))))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *6 *2)) (|isDomain| *4 (|DirectProduct| *5 *6)) (|ofType| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|DirectProductFunctions2| *5 *6 *2)))) ((*1 *1 *2 *3) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|EuclideanModularRing| *4 *2 *3 *5 *6 *7)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *3)) (|ofType| *6 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Expression| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|ofCategory| *5 (|FunctionFieldCategory| *2 *3 *4)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateFunctions2| *5 *4 *2 *6)) (|ofCategory| *4 (|FiniteLinearAggregate| *5)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|FiniteSetAggregateFunctions2| *5 *4 *2 *6)) (|ofCategory| *4 (|FiniteSetAggregate| *5)) (|ofCategory| *6 (|FiniteSetAggregate| *2)))) ((*1 *1 *1) (|isDomain| *1 (|InnerAlgebraicNumber|))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|ListFunctions2| *5 *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|ofCategory| *8 (|FiniteLinearAggregate| *2)) (|ofCategory| *9 (|FiniteLinearAggregate| *2)) (|isDomain| *1 (|MatrixCategoryFunctions2| *5 *6 *7 *4 *2 *8 *9 *10)) (|ofCategory| *4 (|MatrixCategory| *5 *6 *7)) (|ofCategory| *10 (|MatrixCategory| *2 *8 *9)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (|partial| AND (|isDomain| *2 (|Fraction| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Divisor| *1)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|PrimitiveArray| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|PrimitiveArrayFunctions2| *5 *2)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|ofType| *6 (|List| *2)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *7 *2)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|Ring|)) (|ofType| *5 (|NonNegativeInteger|)) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *8 (|DirectProductCategory| *6 *7)) (|ofCategory| *9 (|DirectProductCategory| *5 *7)) (|ofCategory| *10 (|DirectProductCategory| *6 *2)) (|ofCategory| *11 (|DirectProductCategory| *5 *2)) (|isDomain| *1 (|RectangularMatrixCategoryFunctions2| *5 *6 *7 *8 *9 *4 *2 *10 *11 *12)) (|ofCategory| *4 (|RectangularMatrixCategory| *5 *6 *7 *8 *9)) (|ofCategory| *12 (|RectangularMatrixCategory| *5 *6 *2 *10 *11)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|Stream| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|StreamFunctions2| *5 *2)))) ((*1 *2 *2 *1 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|isDomain| *4 (|Mapping| (|Boolean|) *2 *2)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *2)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *5 *6 *7)))) ((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *5 *2)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *2 (|Type|)) (|isDomain| *1 (|VectorFunctions2| *5 *2))))) 
-(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *6 (|Finite|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *6)))) (|isDomain| *1 (|RepresentationPackage2| *6)) (|isDomain| *3 (|List| (|Matrix| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *4)))) (|isDomain| *1 (|RepresentationPackage2| *4)) (|isDomain| *3 (|List| (|Matrix| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|GcdDomain|))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|PrimitiveArray| (|U32Vector|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *1) (|isDomain| *1 (|TwoDimensionalViewport|)))) 
-(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *5 (|Kernel| *4)) (|isDomain| *6 (|Symbol|)) (|ofCategory| *4 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|PureAlgebraicIntegration| *7 *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Kernel| *6)) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *1 (|GenusZeroIntegration| *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *3 *4 *4 *5 *6 *7 *8) (|partial| AND (|isDomain| *4 (|SparseUnivariatePolynomial| *11)) (|isDomain| *6 (|List| *10)) (|isDomain| *7 (|List| (|NonNegativeInteger|))) (|isDomain| *8 (|List| *11)) (|ofCategory| *10 (|OrderedSet|)) (|ofCategory| *11 (|EuclideanDomain|)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|PolynomialCategory| *11 *9 *10)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|MultivariateSquareFree| *9 *10 *11 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofType| *6 (|List| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|)))) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *7) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *7))))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|CardinalNumber|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| (|LyndonWord| *5))) (|isDomain| *1 (|LyndonWord| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RepresentationPackage2| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *2)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *2)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|ParametricSurface| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *1) (|isDomain| *1 (|IntegrationFunctionsTable|)))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfClsPt| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Union| (|Boolean|) (|List| *1))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinarySearchTree| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|BinaryTournament| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |key| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))))) (|isDomain| *1 (|IntegrationFunctionsTable|)))) ((*1 *1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |key| (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |entry| (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))))) (|isDomain| *1 (|ODEIntensityFunctionsTable|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
 (((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|PrecomputedAssociatedEquations| *5 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
-(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|ofCategory| *3 (|CommutativeRing|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (|ofCategory| *3 (|DesingTreeCategory| *11))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|DictionaryOperations| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|DictionaryOperations| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariatePolynomialDivisionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Record| (|:| |low| (|List| *3)) (|:| |high| (|List| *3)))) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (|ofCategory| *3 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2) (AND (|isDomain| *2 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Divisor| (|Places| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|FactoredFunctionUtilities| *3))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *3 (|String|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *1 *1) (|isDomain| *1 (|ThreeDimensionalViewport|)))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Point| *4)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3 *4 *4 *5 *3 *6) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|isDomain| *6 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|GenusZeroIntegration| *7 *3 *8)) (|ofCategory| *8 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|isDomain| *6 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|GenusZeroIntegration| *7 *3 *8)) (|ofCategory| *8 (|SetCategory|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *3))))) 
-(((*1 *1) (|isDomain| *1 (|Character|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) (|Boolean|))) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Expression| (|Float|)))) (|isDomain| *4 (|List| (|Float|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|))))) 
+(((*1 *2 *3 *4 *4 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|EuclideanDomain|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|isDomain| *1 (|d01AgentsPackage|))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagFittingPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3)) (|isDomain| *1 (|MappingPackage1| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *4 *2)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|CancellationAbelianMonoid|))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *1 *1 *1) (|partial| AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *2 (|List| (|RewriteRule| *3 *4 *5))) (|isDomain| *1 (|Ruleset| *3 *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3))))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |val| (|List| *8)) (|:| |towers| (|List| (|RegularTriangularSet| *5 *6 *7 *8))))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |val| (|List| *8)) (|:| |towers| (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|InputForm|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|AlgFactor| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|AlgebraicNumber|))))) ((*1 *2 *3 *1) (AND (|isDomain| *2 (|Record| (|:| |less| (|BinarySearchTree| *3)) (|:| |greater| (|BinarySearchTree| *3)))) (|isDomain| *1 (|BinarySearchTree| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|DivisorCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|IntegrationResult| *4)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedFunctionSpace| *3) (|TranscendentalFunctionCategory|))) (|ofCategory| *3 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|IntegrationResultToFunction| *3 *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|IntegrationResult| (|Fraction| (|Polynomial| *3)))) (|ofCategory| *3 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|IntegrationResultRFToFunction| *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |normal| *3) (|:| |special| *3))) (|isDomain| *1 (|MonomialExtensionTools| *5 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Vector| (|Vector| *5))) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|CharacterClass|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|StringAggregate|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Character|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|StringAggregate|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |zeros| (|List| *4)) (|:| |extDegree| (|Integer|)))) (|isDomain| *1 (|RootsFindingPackage| *4))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| *8)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InternalRationalUnivariateRepresentationPackage| *5 *6 *7 *8 *3))))) 
-(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *11))) (|isDomain| *3 (|SparseUnivariatePolynomial| *11)) (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|List| *8)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|isDomain| *7 (|Vector| (|List| (|SparseUnivariatePolynomial| *8)))) (|ofCategory| *10 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *11 (|PolynomialCategory| *8 *9 *10)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|MultivariateLifting| *9 *10 *8 *11))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Matrix| (|Expression| (|Integer|))))) (|isDomain| *1 (|RadicalEigenPackage|)) (|isDomain| *3 (|Expression| (|Integer|)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|SuchThat| (|List| (|Expression| *5)) (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|))) (|isDomain| *2 (|SuchThat| (|List| (|Expression| *5)) (|List| (|Equation| (|Expression| *5))))) (|isDomain| *1 (|RadicalSolvePackage| *5))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *4)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| (|List| (|NonNegativeInteger|)))) (|isDomain| *1 (|BlowUpPackage| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|FiniteAbelianMonoidRing| *4 *7)) (|ofCategory| *8 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|SingleInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathConnection|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *1)) (|isDomain| *4 (|Vector| *1)) (|ofCategory| *1 (|LinearlyExplicitRingOver| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *5)) (|:| |vec| (|Vector| *5)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *1)) (|ofCategory| *1 (|LinearlyExplicitRingOver| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Matrix| *4))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *4 (|MonogenicAlgebra| *5 *7)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *6)) (|:| |vec| (|Vector| *5)))) (|isDomain| *1 (|ReduceLODE| *5 *6 *7 *4 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *3 (|PartialDifferentialRing| *5)) (|isDomain| *2 (|Vector| *3)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *5 *3 *6 *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)) (|isDomain| *4 (|DoubleFloat|))))) 
-(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4))))))) (|isDomain| *3 (|List| *7)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|DictionaryOperations| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|DictionaryOperations| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OrderedCompletion| (|Float|))) (|isDomain| *2 (|OrderedCompletion| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *2 (|CharacteristicZero|)) (|ofCategory| *2 (|EuclideanDomain|)) (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|AlgebraicNumber|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|SimplifyAlgebraicNumberConvertPackage|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *4))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|None|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *2)) (|Record| (|:| |index| *5) (|:| |exponent| *2)))) (|ofCategory| *2 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|isDomain| *1 (|GeneralModulePolynomial| *3 *4 *5 *2 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *2 (|OrderedVariableList| *3)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)) (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |coef| *3) (|:| |monom| *4)))) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Stream| (|Record| (|:| |k| *4) (|:| |c| *3))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FractionFreeFastGaussian| *4 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *4 *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|isDomain| *4 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *4)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariateFormalPowerSeriesFunctions| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |normal| (|Factored| *3)) (|:| |special| (|Factored| *3)))) (|isDomain| *1 (|MonomialExtensionTools| *5 *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|Record| (|:| |answer| *3) (|:| |logpart| *3))) (|isDomain| *1 (|AlgebraicHermiteIntegration| *5 *6 *7 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |answer| (|Fraction| *6)) (|:| |logpart| (|Fraction| *6)) (|:| |specpart| (|Fraction| *6)) (|:| |polypart| *6))) (|isDomain| *1 (|TranscendentalHermiteIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|SplittingNode| *4 *5))) (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *4 *5)))) ((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|SplittingNode| *3 *4))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *3 (|Integer|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *2 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *3)) (|isDomain| *1 (|BlowUpPackage| *5 *6 *7 *8 *4)) (|ofCategory| *7 (|FiniteAbelianMonoidRing| *5 *8)) (|ofCategory| *4 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|GeneralPolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *2 *3 *4)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)))) ((*1 *1 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|IndexedAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |preimage| (|List| *3)) (|:| |image| (|List| *3)))) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|RetractableTo| (|Integer|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *1 *1 *1) (|isDomain| *1 (|CardinalNumber|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DivisionRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *4 *5 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Algebra| *3)) (|ofCategory| *5 (|UnivariateLaurentSeriesCategory| *4)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *4 *5 *2 *6)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *4 *5)) (|ofCategory| *6 (|PartialTranscendentalFunctions| *5)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|ElementaryFunctionCategory|))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SemiGroup|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Group|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InputForm|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|MappingPackage1| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *3 *4)) (|ofCategory| *4 (|LeftModule| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *4 *5)) (|ofCategory| *5 (|LeftModule| *4)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Operator| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Operator| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Pattern| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RadicalCategory|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SemiGroup|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SquareMatrixCategory| *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *3 *4)) (|ofCategory| *6 (|DirectProductCategory| *3 *4)) (|ofCategory| *4 (|Field|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|ModuleOperator| *2 *3)) (|ofCategory| *3 (|LeftModule| *2)))) ((*1 *2 *2) (AND (|isDomain| *1 (|Operator| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ODEIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Set| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| *4)) (|isDomain| *1 (|RandomDistributions| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)) (|isDomain| *3 (|Float|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|Integer|))) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
 (((*1 *2 *3 *4 *4 *4 *5 *4 *6 *6 *3) (AND (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|Matrix| (|Integer|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| *8)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|isDomain| *1 (|FiniteFieldFunctions| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |k| (|OrderedFreeMonoid| *3)) (|:| |c| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|DequeueAggregate| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Kernel| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *5) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|PureAlgebraicIntegration| *5 *3 *6)) (|ofCategory| *6 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Mapping| (|Void|) (|SExpression|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AxiomServer|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *1) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1) (AND (|isDomain| *1 (|DirichletRing| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Polynomial| *4))))) 
-(((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Matrix| *11)) (|isDomain| *4 (|List| (|Fraction| (|Polynomial| *8)))) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *8 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *11 (|PolynomialCategory| *8 *10 *9)) (|ofCategory| *9 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *10 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |rgl| (|List| (|Record| (|:| |eqzro| (|List| *11)) (|:| |neqzro| (|List| *11)) (|:| |wcond| (|List| (|Polynomial| *8))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *8)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *8)))))))))) (|:| |rgsz| (|Integer|)))) (|isDomain| *1 (|ParametricLinearEquations| *8 *9 *10 *11)) (|isDomain| *7 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4))))) (|isDomain| *1 (|EigenPackage| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|List| *4)))) (|isDomain| *2 (|List| (|List| *4))) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|TableauxBumpers| *4))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |special| *3) (|:| |integrand| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|LiouvillianFunctionCategory|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *2 *3 *4 *4) (|partial| AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|OrderedCompletion| *2)) (|ofCategory| *2 (|SpecialFunctionCategory|)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|ConvertibleTo| (|Pattern| (|Integer|)))) (|ofCategory| *5 (|PatternMatchable| (|Integer|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|PatternMatchIntegration| *5 *2))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceToExponentialExpansion| *3 *2 *4 *5)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *2))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3) (CATEGORY |domain| (SIGNATURE |coerce| ($ *4))))) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *5 (|Join| (|UnivariatePowerSeriesCategory| *2 *4) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *3 *2 *4 *5 *6 *7)) (|ofCategory| *6 (|PartialTranscendentalFunctions| *5)) (|ofType| *7 (|Symbol|))))) 
+(((*1 *2) (AND (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|ConvertibleTo| (|Pattern| *3))) (|ofCategory| *3 (|PatternMatchable| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|ConvertibleTo| (|Pattern| *3))) (|ofCategory| *2 (|PatternMatchable| *3)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|SmithNormalForm| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *4))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *1 (|AlgebraicIntegrate| *4 *5 *6 *7 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *5 *6 *7))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|GraphImage|)) (|isDomain| *1 (|ViewportPackage|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|TubePlot| *2)) (|ofCategory| *2 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|AbelianGroup|)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|InputForm|))))) 
+(((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *5 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5)) (|isDomain| *1 (|MappingPackage2| *4 *5))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|OpenMathPackage|)) (|isDomain| *3 (|String|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|BalancedPAdicRational| *3)) (|ofType| *3 (|Integer|)))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *3 (|Stream| *2)) (|ofCategory| *2 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *2)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ContinuedFraction| *3)))) ((*1 *2 *3) (AND (|isDomain| *2 (|ContinuedFraction| (|Integer|))) (|isDomain| *1 (|NumericContinuedFraction| *3)) (|ofCategory| *3 (|FloatingPointSystem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PAdicRational| *3)) (|ofType| *3 (|Integer|)))) ((*1 *2 *1) (AND (|ofType| *3 (|Integer|)) (|isDomain| *2 (|ContinuedFraction| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PAdicRationalConstructor| *3 *4)) (|ofCategory| *4 (|PAdicIntegerCategory| *3))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2 *3 *4 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *5 *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |stiffnessFactor| (|Float|)) (|:| |stabilityFactor| (|Float|)))) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *2 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *4 *3))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedDirectProductCategory| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|))))) 
+(((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *2) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|FunctionFieldIntegralBasis| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| (|Integer|))) (|:| |basisDen| (|Integer|)) (|:| |basisInv| (|Matrix| (|Integer|))))) (|isDomain| *1 (|NumberFieldIntegralBasis| *3 *4)) (|ofCategory| *4 (|FramedAlgebra| (|Integer|) *3)))) ((*1 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *4)) (|:| |basisDen| *4) (|:| |basisInv| (|Matrix| *4)))) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *3 *4 *5 *6)) (|ofCategory| *6 (|MonogenicAlgebra| *4 *5)))) ((*1 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *4)) (|:| |basisDen| *4) (|:| |basisInv| (|Matrix| *4)))) (|isDomain| *1 (|WildFunctionFieldIntegralBasis| *3 *4 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *4 *5))))) 
+(((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AlgebraPackage| *4 *3)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *2)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|isDomain| *1 (|IntegralBasisTools| *2 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *2 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|List| (|Point| *3)))))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|LazardSetSolvingPackage| *3 *4 *5 *6 *7 *2)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *2 (|SquareFreeRegularTriangularSetCategory| *3 *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|StochasticDifferential| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *1 (|HeuGcd| *3))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Polynomial| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Polynomial| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Vector| (|Union| (|GraphImage|) "undefined"))) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
+(((*1 *1) (AND (|isDomain| *1 (|DirichletRing| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *8))) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|isDomain| *1 (|FactoringUtilities| *4 *5 *6 *7))))) 
+(((*1 *2 *1) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *3 *4)) (|isDomain| *1 (|PatternMatchListResult| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *5 (|ListAggregate| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|StreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
 (((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SetOfMIntegersInOneToN| *4 *5)) (|ofType| *4 *3) (|ofType| *5 *3)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *4))))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| *3))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| (|Polynomial| *5)))) (|isDomain| *1 (|StructuralConstantsPackage| *5)) (|isDomain| *4 (|Matrix| (|Polynomial| *5))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|StructuralConstantsPackage| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Stream| (|Stream| (|Polynomial| *5)))) (|isDomain| *1 (|WeierstrassPreparation| *5)) (|isDomain| *4 (|Stream| (|Polynomial| *5)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Fraction| (|Integer|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Equation| *3)) (|isDomain| *5 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Mapping| *8 (|Fraction| (|Integer|)))) (|isDomain| *4 (|Equation| *8)) (|isDomain| *5 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *6 (|Fraction| (|Integer|))) (|ofCategory| *8 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *7 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *8 *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *4 *3)) (|ofCategory| *3 (|UnivariateLaurentSeriesCategory| *4))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Complex| *3)))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Integer|)) (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *6 *2)) (|ofCategory| *6 (|Type|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *6 *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5 *4)) (|isDomain| *1 (|MappingPackage3| *4 *5 *6))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1) (|isDomain| *1 (|TheSymbolTable|)))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1) (|ofCategory| *1 (|AbelianMonoid|))) ((*1 *1) (|ofCategory| *1 (|Aggregate|))) ((*1 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1) (|ofCategory| *1 (|Monoid|))) ((*1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1) (|isDomain| *1 (|Symbol|)))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| *4) (|LinearlyExplicitRingOver| *4))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| *5) (|LinearlyExplicitRingOver| *5))) (|isDomain| *5 (|Integer|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *7 (|Integer|))) (|isDomain| *4 (|Equation| *7)) (|isDomain| *5 (|UniversalSegment| (|Integer|))) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *4 *3)) (|ofCategory| *3 (|UnivariateTaylorSeriesCategory| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|FlexibleArray| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IndexedFlexibleArray| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofType| *4 *2)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Cell| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|Cell| *5))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *5))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|NumericalIntegrationProblem|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|)))) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalIntegrationProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))) (|:| |extra| (|Result|)))) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)) (|:| |extra| (|Result|)))))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|NumericalIntegrationCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)) (|:| |extra| (|Result|)))))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|OrdinaryDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalODEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaOrdinaryDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)))))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalOptimizationProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaNumericalOptimizationPackage|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *1 (|PartialDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|RoutinesTable|)) (|isDomain| *4 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |explanations| (|String|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|NumericalPDEProblem|)) (|isDomain| *4 (|RoutinesTable|)) (|isDomain| *2 (|Record| (|:| |measure| (|Float|)) (|:| |name| (|String|)) (|:| |explanations| (|List| (|String|))))) (|isDomain| *1 (|AnnaPartialDifferentialEquationPackage|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|Places| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Equation| *3)) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 (|Integer|))) (|isDomain| *4 (|Equation| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *7 (|Integer|))) (|isDomain| *4 (|Equation| *7)) (|isDomain| *5 (|UniversalSegment| (|NonNegativeInteger|))) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|NonNegativeInteger|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Complex| (|Integer|))))) (|isDomain| *2 (|List| (|Complex| *4))) (|isDomain| *1 (|FloatingComplexPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Complex| (|Integer|)))))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|Complex| *5)))) (|isDomain| *1 (|FloatingComplexPackage| *5)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |mval| (|Matrix| *4)) (|:| |invmval| (|Matrix| *4)) (|:| |genIdeal| (|PolynomialIdeals| *4 *5 *6 *7)))) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
 (((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|PrimitiveArray| (|SparseUnivariatePolynomial| *4))) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OrderedCompletion| (|Float|))) (|isDomain| *2 (|OrderedCompletion| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Union| (|Fraction| (|Polynomial| *6)) (|SuchThat| (|Symbol|) (|Polynomial| *6)))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *6))))) (|isDomain| *1 (|EigenPackage| *6)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *6)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *5)) (|SuchThat| (|Symbol|) (|Polynomial| *5)))) (|:| |eigmult| (|NonNegativeInteger|)) (|:| |eigvec| (|List| *4)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|EigenPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5))))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| *4 *5 *6 *7)) (|ofCategory| *4 (|Join| (|Finite|) (|Field|))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|ofCategory| *7 (|FunctionFieldCategory| *4 *5 *6)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FindOrderFinite| *4 *5 *6 *7)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|FiniteDivisor| *6 *7 *4 *8)) (|isDomain| *5 (|Mapping| *9 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|ofCategory| *8 (|FunctionFieldCategory| *6 *7 *4)) (|ofCategory| *9 (|Join| (|Finite|) (|Field|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ReducedDivisor| *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
-(((*1 *1) (|isDomain| *1 (|Character|)))) 
-(((*1 *1 *2 *3 *3 *4 *4) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Segment| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PlaneAlgebraicCurvePlot|))))) 
-(((*1 *2 *3 *4 *4 *3 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *4 *3 *5) (AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|AffinePlane| *3))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|PolynomialComposition| *2 *3)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|CRApackage| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|List| *4))) (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *4)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| (|Record| (|:| |basis| (|Matrix| *7)) (|:| |basisDen| *7) (|:| |basisInv| (|Matrix| *7))))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *7)) (|:| |basisDen| *7) (|:| |basisInv| (|Matrix| *7)))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *6 *7 *8)))) ((*1 *2 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Vector| *4))) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Vector| *3)))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|Any|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LyndonWord| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|DoubleFloat|))) (|isDomain| *1 (|e04AgentsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|Record| (|:| |start| *3) (|:| |factors| (|Factored| *3)))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LyndonWord| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1 *1 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *4 *5)) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RandomNumberSource|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *3 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |answer| *3) (|:| |polypart| *3))) (|isDomain| *1 (|TranscendentalIntegration| *5 *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |ir| (|IntegrationResult| (|Fraction| *6))) (|:| |specpart| (|Fraction| *6)) (|:| |polypart| *6))) (|isDomain| *1 (|TranscendentalIntegration| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *3 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *9) (|:| |radicand| *9))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *8 *9)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *9 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*8 $)) (SIGNATURE |denom| (*8 $)) (SIGNATURE |coerce| ($ *8)))))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |k| *4) (|:| |c| *3)))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|PoincareBirkhoffWittLyndonBasis| *3)) (|:| |c| *4)))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|LyndonWord| *3))) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *3 *3 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|UniqueFactorizationDomain|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|List| (|Polynomial| *5))) (|isDomain| *1 (|FunctionFieldCategory&| *4 *5 *6 *7)) (|ofCategory| *4 (|FunctionFieldCategory| *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *5 *6)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Polynomial| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|SparseUnivariatePolynomial| (|Polynomial| *4)) (|Polynomial| *4))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Polynomial| *4))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
+(((*1 *2 *3 *4 *4 *4 *4) (AND (|isDomain| *3 (|Matrix| (|DoubleFloat|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *4) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|ModularHermitianRowReduction| *3))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|isDomain| *2 (|Record| (|:| |pol| (|SparseUnivariatePolynomial| *9)) (|:| |polval| (|SparseUnivariatePolynomial| *8)))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|SparseUnivariatePolynomial| *8))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Complex| *3)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
 (((*1 *2 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Set| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Mapping| *4)) (|isDomain| *1 (|RandomDistributions| *4)))) ((*1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)) (|isDomain| *3 (|Float|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Segment| (|Integer|))) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|Group|))) ((*1 *1 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|PartitionsAndPermutations|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1) (|isDomain| *1 (|Partition|))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *6 (|Finite|)) (|ofCategory| *6 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *6)))) (|isDomain| *1 (|RepresentationPackage2| *6)) (|isDomain| *3 (|List| (|Matrix| *6))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *4)))) (|isDomain| *1 (|RepresentationPackage2| *4)) (|isDomain| *3 (|List| (|Matrix| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Matrix| *5)))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *3 (|List| (|Matrix| *5)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| (|Polynomial| *4)))) (|ofCategory| *4 (|RealClosedField|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Point| *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |rnum| *4) (|:| |polnum| *3) (|:| |den| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpressionToOpenMath| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|String|)) (|isDomain| *1 (|ExpressionToOpenMath| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Expression| *5)) (|ofCategory| *5 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ExpressionToOpenMath| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Expression| *6)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|Join| (|OpenMath|) (|OrderedSet|) (|Ring|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ExpressionToOpenMath| *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *2 (|String|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|String|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *2 (|Void|)))) ((*1 *2 *3 *1 *4) (AND (|ofCategory| *1 (|OpenMath|)) (|isDomain| *3 (|OpenMathDevice|)) (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Void|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LyndonWord| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3 *3 *3 *3 *4 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *3 *3 *3 *4 *5 *4 *6) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|Integer|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *4 *6 *7) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|Integer|)) (|isDomain| *7 (|String|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Integer|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|)))) ((*1 *2 *3 *3 *3 *4 *5 *6 *7 *8) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *4 (|Mapping| (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|DoubleFloat|)) (|isDomain| *7 (|Integer|)) (|isDomain| *8 (|String|)) (|isDomain| *2 (|TubePlot| (|Plot3D|))) (|isDomain| *1 (|ExpressionTubePlot|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Cell| *5)) (|ofCategory| *5 (|RealClosedField|)) (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|CylindricalAlgebraicDecompositionPackage| *5))))) 
+(((*1 *2 *3 *3 *4 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagEigenPackage|))))) 
+(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *1 (|Product| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Record| (|:| |close| (|List| *6)) (|:| |open| (|List| *6))))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LyndonWord| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|HeuGcd| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |constant| *5) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *5 *6 *3 *7)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|RightOpenIntervalRootCharacterization| (|RealClosure| *4) (|SparseUnivariatePolynomial| (|RealClosure| *4)))) (|isDomain| *3 (|OutputForm|)) (|isDomain| *1 (|RealClosure| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|)))))) 
+(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|ElementaryIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|DeRhamComplex| *2 *3)) (|ofCategory| *2 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *3 (|List| (|Symbol|)))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|PrimitiveArray| (|ModMonic| *3 *4))) (|isDomain| *1 (|ModMonic| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RealClosure| *3)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|) (|RealConstant|))))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|isDomain| *1 (|RightOpenIntervalRootCharacterization| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *2 *3)) (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *6 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *7)) (|:| |neqzro| (|List| *7)) (|:| |wcond| (|List| (|Polynomial| *4))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *9)) (|:| |neqzro| (|List| *9)) (|:| |wcond| (|List| (|Polynomial| *6))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *6)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *6)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)) (|isDomain| *4 (|List| *9)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *9)) (|:| |neqzro| (|List| *9)) (|:| |wcond| (|List| (|Polynomial| *6))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *6)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *6)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| *9)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|String|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Matrix| *10)) (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *10 (|PolynomialCategory| *7 *9 *8)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Matrix| *10)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *10 (|PolynomialCategory| *7 *9 *8)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|StochasticDifferential| *4)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|StochasticDifferential| *4))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|FiniteLinearAggregate| *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *6)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *6 *7 *8 *3)) (|ofCategory| *3 (|MatrixCategory| *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|List| (|PositiveInteger|))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|FiniteLinearAggregate| *6)) (|ofCategory| *8 (|FiniteLinearAggregate| *6)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *6 *7 *8 *3)) (|ofCategory| *3 (|MatrixCategory| *6 *7 *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|List| (|PositiveInteger|))) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *7 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|MatrixManipulation| *5 *6 *7 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *7))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *4 *3 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *5)) *4 *3)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|isDomain| *1 (|PushVariables| *4 *5 *3 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $)) (SIGNATURE |variable| ((|Union| $ "failed") (|Symbol|)))))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|PushVariables| *4 *5 *6 *2)) (|ofCategory| *2 (|PolynomialCategory| (|Polynomial| *4) *5 *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|FractionFreeFastGaussian| *3 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *3 *4))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *2) (|:| |xpnt| (|Integer|))))) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|Factored| *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *4) (|:| |pow| (|Integer|))))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Factored| *4)) (|isDomain| *1 (|GaloisGroupFactorizer| *4))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *2))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |Smith| *3) (|:| |leftEqMat| *3) (|:| |rightEqMat| *3))) (|isDomain| *1 (|SmithNormalForm| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
 (((*1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Float|))) (|isDomain| *1 (|RandomFloatDistributions|)) (|isDomain| *3 (|Float|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *2)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *2)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *3 *4 *5 *4 *4 *4) (AND (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *3 (|List| *6)) (|isDomain| *5 (|List| *3)) (|isDomain| *2 (|Record| (|:| |f1| *3) (|:| |f2| (|List| *5)) (|:| |f3| *5) (|:| |f4| (|List| *5)))) (|isDomain| *1 (|TableauxBumpers| *6)) (|isDomain| *4 (|List| *5))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|IndexedAggregate| *3 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|LyndonWord| *3)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *2)) (|ofCategory| *2 (|FunctionSpace| *4))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|ofCategory| *8 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *3) (|:| |radicand| *3))) (|isDomain| *1 (|PolynomialRoots| *5 *6 *7 *8 *3)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |numer| (*8 $)) (SIGNATURE |denom| (*8 $)) (SIGNATURE |coerce| ($ *8)))))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|PartialDifferentialRing| *4)) (|isDomain| *1 (|MultiVariableCalculusFunctions| *4 *2 *5 *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *3 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |finiteAggregate|))))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1) (|isDomain| *1 (|FortranCode|)))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |discriminant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|Commutator|))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Commutator|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Vector| *5)) (|ofCategory| *5 (|OrderedAbelianMonoid|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderingFunctions| *4 *5)) (|ofType| *4 (|NonNegativeInteger|))))) 
+(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|LiePolynomial| *3 *4)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FiniteAbelianMonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoid|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursiveAggregate| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|IrrRepSymNatPackage|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
+(((*1 *2 *2 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|UnivariatePolynomialMultiplicationPackage| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *2 *3 *1 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|RewriteRule| *3 *4 *2)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|SuchThat| *2 *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *6 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *4)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| (|Fraction| (|Polynomial| *6)))) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *6)))) ((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|List| (|NonNegativeInteger|)))))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|isDomain| *1 (|TwoFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|)))))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldFunctions| *4)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasis| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasisExtensionByPolynomial| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|Union| (|SparseUnivariatePolynomial| *3) (|Vector| (|List| (|Record| (|:| |value| *3) (|:| |index| (|SingleInteger|))))))))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FiniteFieldNormalBasisExtension| *3 *4)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|ODETools| *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *2 (|Record| (|:| |%term| (|Record| (|:| |%coef| (|UnivariatePuiseuxSeries| *4 *5 *6)) (|:| |%expon| (|ExponentialOfUnivariatePuiseuxSeries| *4 *5 *6)) (|:| |%expTerms| (|List| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| *4)))))) (|:| |%type| (|String|)))) (|isDomain| *1 (|UnivariatePuiseuxSeriesWithExponentialSingularity| *3 *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *7)) (|:| |neqzro| (|List| *7)) (|:| |wcond| (|List| (|Polynomial| *4))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *9)) (|:| |neqzro| (|List| *9)) (|:| |wcond| (|List| (|Polynomial| *6))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *6)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *6)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)) (|isDomain| *4 (|List| *9)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|PositiveInteger|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *9)) (|:| |neqzro| (|List| *9)) (|:| |wcond| (|List| (|Polynomial| *6))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *6)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *6)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Record| (|:| |eqzro| (|List| *8)) (|:| |neqzro| (|List| *8)) (|:| |wcond| (|List| (|Polynomial| *5))) (|:| |bsoln| (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *5)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *5)))))))))) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| *9)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *8)) (|isDomain| *4 (|String|)) (|ofCategory| *8 (|PolynomialCategory| *5 *7 *6)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Matrix| *10)) (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *10 (|PolynomialCategory| *7 *9 *8)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Matrix| *10)) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|String|)) (|ofCategory| *10 (|PolynomialCategory| *7 *9 *8)) (|ofCategory| *7 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *8 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *7 *8 *9 *10)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Matrix| *9)) (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PolynomialCategory| *6 *8 *7)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ParametricLinearEquations| *6 *7 *8 *9))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| *3) (|:| |entry| *4)))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *1 (|TableAggregate| *3 *4)))) ((*1 *1) (AND (|ofCategory| *1 (|TableAggregate| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|NonNegativeInteger|)))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|ModuleMonomial| *3 *2 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofType| *4 (|Mapping| (|Boolean|) (|Record| (|:| |index| *3) (|:| |exponent| *2)) (|Record| (|:| |index| *3) (|:| |exponent| *2))))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|EuclideanDomain|))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)) (|isDomain| *1 (|IntegerCombinatoricFunctions| *2))))) 
+(((*1 *1 *1 *2) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategory|)) (|isDomain| *2 (|String|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DrawComplex|))))) 
 (((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|GcdDomain|))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|HeuGcd| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *5 *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *2)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|EuclideanDomain|)) (|isDomain| *1 (|PolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| *7))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|PolynomialGcdPackage| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)))) ((*1 *1 *1 *1) (|isDomain| *1 (|PositiveInteger|))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|PrimitiveArray| (|U32Vector|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *4 *5 *3 *6 *7)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *5 *2)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *6 *7 *2)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *5 *6)) (|ofCategory| *2 (|DirectProductCategory| *4 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
 (((*1 *1 *1 *2) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
-(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *5 *2 *6 *7)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1 *3 *4 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|isDomain| *4 (|TaylorSeries| *6)) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|WeierstrassPreparation| *6)) (|isDomain| *5 (|Stream| *4))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNumericEigenPackage| *4 *5 *6)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|Field|) (|OrderedRing|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UniversalSegment| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monad|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MonadWithUnit|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef| *4) (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef| *3) (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BrillhartTests| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1 *1 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5 *5)) (|isDomain| *4 (|Mapping| (|Boolean|) *6 *6)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *6 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *5 *6))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|RealClosedField|)) (|isDomain| *1 (|SimpleCell| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| *2))) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
 (((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *8))) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *5 *6 *7 *8)) (|isDomain| *4 (|SparseUnivariatePolynomial| *8)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|EuclideanDomain|))) ((*1 *1 *1 *1) (|isDomain| *1 (|NonNegativeInteger|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *2) (AND (|isDomain| *1 (|IntegerPrimesPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *1 *3 *3 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Union| (|Boolean|) (|List| *1))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *7)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|isDomain| *2 (|List| (|Vector| *5))) (|isDomain| *1 (|InterpolateFormsPackage| *5 *6 *7 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *3 (|DivisorCategory| *11))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|isDomain| *1 (|TwoFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *1 *4 *4 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *3))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|RegularTriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5)))) ((*1 *2 *3 *1 *4 *4 *4 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *3))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *3 *4 *5 *6 *7)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FunctionSpace| *2)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|MyExpression| *2 *3)) (|ofType| *2 (|Symbol|)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|BalancedFactorisation| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|BalancedFactorisation| *5 *3))))) 
+(((*1 *2 *3 *4 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3 *1) (|partial| AND (|ofCategory| *1 (|AssociationListAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Record| (|:| |key| *3) (|:| |entry| *4)))))) 
+(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|List| (|Stream| *7))) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *5 (|IndexedExponents| *6) *6)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Mapping| (|Stream| *7) *7)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *5 *6 *7))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *1 *1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Kernel| *4)) (|isDomain| *1 (|KernelFunctions2| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|ModuleMonomial| *3 *2 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofType| *4 (|Mapping| (|Boolean|) (|Record| (|:| |index| *3) (|:| |exponent| *2)) (|Record| (|:| |index| *3) (|:| |exponent| *2))))))) 
 (((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|LaurentPolynomial| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *5 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5)) (|isDomain| *1 (|MappingPackage2| *4 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |scalar| (|Fraction| (|Integer|))) (|:| |coeff| (|SparseUnivariatePolynomial| *3)) (|:| |logand| (|SparseUnivariatePolynomial| *3))))) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|isDomain| *3 (|List| (|OrderedVariableList| *4))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DrawComplex|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|RationalLODE| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |basis| (|List| (|Fraction| *6))) (|:| |mat| (|Matrix| *5)))) (|isDomain| *1 (|RationalLODE| *5 *6)) (|isDomain| *4 (|List| (|Fraction| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|RationalLODE| *5 *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|Record| (|:| |basis| (|List| (|Fraction| *6))) (|:| |mat| (|Matrix| *5)))) (|isDomain| *1 (|RationalLODE| *5 *6)) (|isDomain| *4 (|List| (|Fraction| *6)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Integer|)) (|ofCategory| *6 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SubSpaceComponentProperty|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|FloatingPointSystem|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|PrimitiveArray| *3)) (|isDomain| *1 (|SubResultantPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *2 *3 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| (|DoubleFloat|)) (|DoubleFloat|))) (|isDomain| *3 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
 (((*1 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|not| (|has| *1 (ATTRIBUTE |arbitraryPrecision|))) (|not| (|has| *1 (ATTRIBUTE |arbitraryExponent|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedMultisetAggregate| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|OrderedSet|))) ((*1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|BinaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7))))) (|ofCategory| *7 (|OrderedRing|)) (|ofCategory| *8 (|Join| (|UnivariatePowerSeriesCategory| *3 *7) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *2 (|Union| (|:| |%series| *8) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *6 *3 *7 *8 *9 *10)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PartialTranscendentalFunctions| *8)) (|ofType| *10 (|Symbol|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *3 *5)) (|ofCategory| *4 (|Type|)) (|ofCategory| *3 (|FiniteLinearAggregate| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedMonoid|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3)))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BalancedPAdicRational| *3)) (|ofType| *3 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|BalancedPAdicRational| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PAdicRational| *3)) (|ofType| *3 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|PAdicRational| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofType| *3 *2) (|isDomain| *1 (|PAdicRationalConstructor| *3 *4)) (|ofCategory| *4 (|PAdicIntegerCategory| *3)))) ((*1 *1 *1) (AND (|ofType| *2 (|Integer|)) (|isDomain| *1 (|PAdicRationalConstructor| *2 *3)) (|ofCategory| *3 (|PAdicIntegerCategory| *2)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|UnivariateTaylorSeriesCategory| *2))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4)))))) 
 (((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|Point| (|DoubleFloat|))) (|isDomain| *4 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|PointCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Point| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *3 *3 *3 *3) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)) (|isDomain| *3 (|DoubleFloat|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|UnivariatePolynomial| *5 *4))) (|isDomain| *1 (|SturmHabichtPackage| *4 *5)) (|isDomain| *3 (|UnivariatePolynomial| *5 *4))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialExtension| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|DifferentialExtension| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DifferentialRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|DifferentialRing|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PartialDifferentialRing| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PartialDifferentialRing| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| (|Vector| (|Integer|)))) (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|GrayCode|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|CombinatorialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1) (|partial| |ofCategory| *1 (|MonadWithUnit|)))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|Finite|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|ModuleMonomial| *2 *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *3)) (|Record| (|:| |index| *2) (|:| |exponent| *3))))))) 
-(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) *2)) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|AlgebraicManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $)))))))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|LinearlyExplicitRingOver| (|Integer|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerLinearDependence| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *1) (|partial| AND (|ofCategory| *1 (|AssociationListAggregate| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Record| (|:| |key| *3) (|:| |entry| *4)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *1 (|TableauxBumpers| *4)) (|isDomain| *3 (|List| (|List| *4)))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|BezoutMatrix| *4 *3 *2 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| *3))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Matrix| *3))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|RepresentationPackage1| *3))))) 
-(((*1 *2 *1 *3 *3 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|AssociationList| (|String|) (|None|))) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *1 (|Expression| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|BagAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Dequeue| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|Heap| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Stack| *3))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|CyclicStreamTools| *3 *2)) (|ofCategory| *2 (|LazyStreamAggregate| *3))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *1 (|IntegerFactorizationPackage| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
+(((*1 *2 *3 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |a| *6) (|:| |b| (|Fraction| *6)) (|:| |h| *6) (|:| |c1| (|Fraction| *6)) (|:| |c2| (|Fraction| *6)) (|:| |t| *6))) (|isDomain| *1 (|TranscendentalRischDESystem| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|isDomain| *2 (|Stream| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
 (((*1 *2 *2) (AND (|isDomain| *2 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *4 (|NonNegativeInteger|)) (|OrderedVariableList| *3) (|DistributedMultivariatePolynomial| *3 (|Fraction| (|Integer|))))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|NonNegativeInteger|)) (|isDomain| *1 (|IdealDecompositionPackage| *3 *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *5)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|InternalRationalUnivariateRepresentationPackage| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *4)) (|:| |coordinates| (|List| (|Polynomial| *4)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *4 *5)) (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|List| (|Record| (|:| |complexRoots| (|SparseUnivariatePolynomial| *5)) (|:| |coordinates| (|List| (|Polynomial| *5)))))) (|isDomain| *1 (|RationalUnivariateRepresentationPackage| *5 *6)) (|isDomain| *3 (|List| (|Polynomial| *5))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|RegularSetDecompositionPackage| *6 *7 *8 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |done| (|List| *4)) (|:| |todo| (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))))) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *1) (|partial| AND (|isDomain| *3 (|Mapping| (|Boolean|) *2)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Mapping| *6 (|List| *6))) (|isDomain| *1 (|UTSodetools| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *4))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *3) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *3)) (|ofCategory| *3 (|ConvertibleTo| *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| *4)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *4 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| *5)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *5 (|ConvertibleTo| *2)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|Numeric| *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 *5 *4)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MappingPackage3| *5 *4 *6))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |basis| (|Matrix| *6)) (|:| |basisDen| *6) (|:| |basisInv| (|Matrix| *6))))) (|isDomain| *1 (|ChineseRemainderToolsForIntegralBases| *5 *6 *7)) (|isDomain| *3 (|Record| (|:| |basis| (|Matrix| *6)) (|:| |basisDen| *6) (|:| |basisInv| (|Matrix| *6)))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|isDomain| *5 (|List| *8)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|Ring|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *8)) (|isDomain| *1 (|FactoringUtilities| *6 *7 *8 *9))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Matrix| *3))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3 *4) (AND (|isDomain| *4 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *4 *3))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LeadingCoefDetermination| *6 *7 *3 *8)) (|ofCategory| *8 (|PolynomialCategory| *3 *7 *6))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|SegmentCategory| *3)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| (|WuWenTsunTriangularSet| *4 *5 *6 *7))) (|isDomain| *1 (|WuWenTsunTriangularSet| *4 *5 *6 *7)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *9)) (|isDomain| *4 (|Mapping| (|Boolean|) *9 *9)) (|isDomain| *5 (|Mapping| *9 *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|List| (|WuWenTsunTriangularSet| *6 *7 *8 *9))) (|isDomain| *1 (|WuWenTsunTriangularSet| *6 *7 *8 *9))))) 
-(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *5 *6 *3 *7 *8)) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|))))) 
-(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|NonNegativeInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Kernel| (|AlgebraicNumber|))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|isDomain| *3 (|List| (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|isDomain| *3 (|Kernel| (|AlgebraicNumber|))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ComplexCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *2))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|FractionalIdeal| *3 *2 *4 *5)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *5 (|Join| (|FramedAlgebra| *2 *4) (|RetractableTo| *2))))) ((*1 *2 *1) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|QuotientFieldCategory| *3)) (|isDomain| *1 (|FramedModule| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *5 (|FramedAlgebra| *2 *4)) (|ofType| *6 (|Vector| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *5) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *5 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Kernel| (|InnerAlgebraicNumber|))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|InnerAlgebraicNumber|))) (|isDomain| *3 (|List| (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|InnerAlgebraicNumber|))) (|isDomain| *3 (|Kernel| (|InnerAlgebraicNumber|))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|MonogenicAlgebra| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|NormInMonogenicAlgebra| *4 *2 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|AlgebraicManipulations| *4 *3)) (|ofCategory| *3 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *4 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *4 (|Kernel| $)))))))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *5 *7)) (|isDomain| *4 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *2 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *7 *5)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *7 (|Ring|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|SparseUnivariatePolynomial| *7)) (|isDomain| *1 (|IntegralBasisPolynomialTools| *5 *4 *6 *7)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *3 *2)) (|ofCategory| *3 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |den| (|Integer|)) (|:| |gcdnum| (|Integer|)))) (|isDomain| *1 (|PointsOfFiniteOrderTools| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PointsOfFiniteOrderTools| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|IntegralBasisTools| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|RetractableTo| (|Fraction| *2)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|BoundIntegerRoots| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1) (AND (|isDomain| *1 (|DenavitHartenbergMatrix| *2)) (|ofCategory| *2 (|Join| (|Field|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *1 (|FourierSeries| *3 *2)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *2 (|Join| (|OrderedSet|) (|AbelianGroup|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *6))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FreeModuleCat| *3 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|MonoidRing| *3 *4))) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5))))) 
 (((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *5))) (|isDomain| *1 (|PolynomialFactorizationByRecursionUnivariate| *4 *5)) (|isDomain| *3 (|SparseUnivariatePolynomial| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|InnerTrigonometricManipulations| *4 *2 *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| (|Complex| *4)) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialExtension| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|DifferentialExtension| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DifferentialRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|DifferentialRing|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PartialDifferentialRing| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PartialDifferentialRing| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|InputForm|)))) (|isDomain| *1 (|RecurrenceOperator| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|AbelianMonoid|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Symbol|)) (|PartialDifferentialRing| (|Symbol|)) (|CombinatorialOpsCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *3 (|Join| (|EuclideanDomain|) (CATEGORY |domain| (SIGNATURE |squareFree| ((|Factored| $) $))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|FunctionFieldIntegralBasis| *3 *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|NumberFieldIntegralBasis| *4 *5)) (|ofCategory| *5 (|FramedAlgebra| *3 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|PAdicWildFunctionFieldIntegralBasis| *4 *3 *5 *6)) (|ofCategory| *6 (|MonogenicAlgebra| *3 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Record| (|:| |basis| (|Matrix| *3)) (|:| |basisDen| *3) (|:| |basisInv| (|Matrix| *3)))) (|isDomain| *1 (|WildFunctionFieldIntegralBasis| *4 *3 *5 *6)) (|ofCategory| *6 (|FramedAlgebra| *3 *5))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|RetractableTo| *3)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *2) (AND (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *4 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PrimitiveFunctionCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|PrimitiveFunctionCategory|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *11)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|BlowUpMethodCategory|)) (|isDomain| *2 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Field|)) (|isDomain| *1 (|InnerMatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *2 *4 *5 *3)) (|ofCategory| *3 (|MatrixCategory| *2 *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SquareMatrixCategory| *3 *2 *4 *5)) (|ofCategory| *4 (|DirectProductCategory| *3 *2)) (|ofCategory| *5 (|DirectProductCategory| *3 *2)) (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|RegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)))) ((*1 *2 *3 *4 *4 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Any|)) (|isDomain| *1 (|AnyFunctions1| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Float|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofCategory| *5 (|RetractableTo| (|Integer|))) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| *2)) (|ofType| *4 (|List| *2)) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| *5)) (|ofCategory| *5 (|FortranMachineTypeCategory|)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Integer|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| (|Float|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Polynomial| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Polynomial| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Expression| (|Integer|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Expression| (|Float|)))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|MyUnivariatePolynomial| *3 *4))) (|isDomain| *1 (|MyExpression| *3 *4)) (|ofType| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |nia| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |mdnia| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|NottinghamGroup| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalODEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalPDEProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RetractableTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (OR (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|not| (|ofCategory| *3 (|Algebra| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|IntegerNumberSystem|))) (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| *3)) (AND (|not| (|ofCategory| *3 (|QuotientFieldCategory| (|Integer|)))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (OR (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
-(((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ComplexCategory&| *3 *2)) (|ofCategory| *3 (|ComplexCategory| *2)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *4 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedAlgebra&| *3 *2 *4)) (|ofCategory| *3 (|FramedAlgebra| *2 *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|NumberFieldIntegralBasis| *3 *4)) (|ofCategory| *4 (|FramedAlgebra| *2 *3)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *4 *5 *5 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Matrix| (|DoubleFloat|))) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|NagInterpolationPackage|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *10 (|PlacesCategory| *5 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *5 *6 *3 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *3 *7 *8 *9 *10 *2 *11 *4 *12)) (|ofCategory| *4 (|DesingTreeCategory| *11))))) 
-(((*1 *2 *2 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|MachineInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|List| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|EuclideanDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|FortranType|)) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|Boolean|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *5 *2)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *6 *7 *2)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *5 *6)) (|ofCategory| *2 (|DirectProductCategory| *4 *6))))) 
-(((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d01AgentsPackage|))))) 
-(((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *4) (|:| |ineq| (|List| *9)))) (|isDomain| *1 (|QuasiComponentPackage| *6 *7 *8 *9 *4)) (|isDomain| *3 (|List| *9)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *9)))) ((*1 *2 *3 *4 *3 *5 *5 *5 *5 *5) (|partial| AND (|isDomain| *5 (|Boolean|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *4) (|:| |ineq| (|List| *9)))) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *6 *7 *8 *9 *4)) (|isDomain| *3 (|List| *9)) (|ofCategory| *4 (|RegularTriangularSetCategory| *6 *7 *8 *9))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| *4))) (|isDomain| *5 (|NonNegativeInteger|)) (|ofCategory| *4 (|PolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |lcmfij| *7) (|:| |totdeg| *5) (|:| |poli| *4) (|:| |polj| *4))) (|isDomain| *1 (|GroebnerInternalPackage| *6 *7 *8 *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|has| *1 (ATTRIBUTE |arbitraryPrecision|)) (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|PositiveInteger|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *2 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *1 (|NormalizationPackage| *4 *5 *6 *2 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *2))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *2 *3 *4))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *3 *4))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternFunctions1| *4 *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|OrderedVariableList| *5))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|List| (|List| (|DistributedMultivariatePolynomial| *5 *6)))) (|isDomain| *1 (|GroebnerSolve| *5 *6 *7)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *7 (|GcdDomain|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *1) (|isDomain| *1 (|Color|)))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|TexFormat|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (|partial| AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |resultant| *3) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Matrix| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| (|Polynomial| *4)))) (|isDomain| *1 (|CoerceVectorMatrixPackage| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphicsDefaults|)))) ((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Vector| *1)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|Vector| *1)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|PAdicIntegerCategory| *2)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|LinearSystemFromPowerSeriesPackage| *5 *3)) (|ofCategory| *3 (|LocalPowerSeriesCategory| *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *6)) (|:| |tower| *7)))) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|QuasiComponentPackage| *3 *4 *5 *6 *7)))) ((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *6)) (|:| |tower| *7)))) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *3 *4 *5 *6 *7))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursiveAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|))))) 
 (((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *1 (|ParametricPlaneCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|ParametricSpaceCurve| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|Product| *2 *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| *4 *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *1 (|LinearOrdinaryDifferentialOperatorsOps| *4 *2)) (|ofCategory| *2 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FGLMIfCanPackage| *4 *5)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *5)))) (|ofCategory| *4 (|GcdDomain|)) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LexTriangularPackage| *4 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|Point| *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|OpenMathConnection|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
-(((*1 *2 *3 *1) (|partial| AND (|isDomain| *3 (|Mapping| (|Boolean|) *2)) (|ofCategory| *1 (|Collection| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *3 (|DivisorCategory| *10)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *3 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Record| (|:| |num| (|List| *6)) (|:| |den| *6))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *3 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Fraction| (|DistributedMultivariatePolynomial| *6 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *4))) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|:| |den| (|DistributedMultivariatePolynomial| *5 *4)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Divisor| (|Places| *5))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|List| (|Fraction| (|DistributedMultivariatePolynomial| *6 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Divisor| (|Places| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |num| (|List| (|DistributedMultivariatePolynomial| *5 *4))) (|:| |den| (|DistributedMultivariatePolynomial| *5 *4)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|isDomain| *1 (|TangentExpansions| *3)) (|ofCategory| *3 (|Field|))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *1 (|Reference| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|UnivariatePolynomial| *5 *4)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|SturmHabichtPackage| *4 *5))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4 *1) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Union| (|Boolean|) "failed")) (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|QuasiAlgebraicSet| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Mapping| *4 (|Integer|))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Kernel| *5))) (|isDomain| *3 (|Symbol|)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *5))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *2 (|DivisorCategory| *9)) (|ofCategory| *10 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *2 (|Result|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|NumericalOptimizationCategory|)) (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|Result|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|GcdDomain|)) (|isDomain| *1 (|CylindricalAlgebraicDecompositionUtilities| *3 *4))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Equation| (|OnePointCompletion| *3))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|OnePointCompletion| *3)) (|isDomain| *1 (|PowerSeriesLimitPackage| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|OnePointCompletion| (|Polynomial| *5)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|OnePointCompletion| (|Fraction| (|Polynomial| *5)))) (|isDomain| *1 (|RationalFunctionLimitPackage| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| (|Fraction| (|Polynomial| *5)))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|OnePointCompletion| *3)) (|isDomain| *1 (|RationalFunctionLimitPackage| *5))))) 
+(((*1 *2 *3 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *3)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Integer|) (|Integer|))) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|NonNegativeInteger|) (|NonNegativeInteger|))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|PolynomialDecomposition| *2 *3)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|RepeatedSquaring| *2)) (|ofCategory| *2 (|Join| (|SetCategory|) (CATEGORY |domain| (SIGNATURE * ($ $ $)))))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|NonCommutativeOperatorDivision| *2 *3)) (|ofCategory| *2 (|MonogenicLinearOperator| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *5))) (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|ComplexCategory| *4)) (|ofCategory| *4 (|IntegerNumberSystem|)) (|isDomain| *1 (|ComplexIntegerSolveLinearPolynomialEquation| *4 *5)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldSolveLinearPolynomialEquation| *4 *5 *3)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|IntegerSolveLinearPolynomialEquation|)))) ((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|InnerModularGcd| *4 *2 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofType| *5 *4) (|ofType| *6 (|Mapping| *4 *4 (|NonNegativeInteger|)))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|isDomain| *2 (|Record| (|:| |sysok| (|Boolean|)) (|:| |z0| (|List| *7)) (|:| |n0| (|List| *7)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *2)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))))) ((*1 *1 *1 *1) (|ofCategory| *1 (|OrderedAbelianMonoidSup|)))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|GaussianFactorizationPackage|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Factored| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |coef| *5) (|:| |radicand| (|List| *5)))) (|isDomain| *1 (|FactoredFunctions| *5)) (|isDomain| *4 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RadicalCategory|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *2 *3 *4)) (|ofCategory| *3 (|FiniteLinearAggregate| *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|))))) 
 (((*1 *2 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Aggregate|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|has| $ (ATTRIBUTE |finiteAggregate|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedMonoid|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Record| (|:| |flg| (|Union| "nil" "sqfr" "irred" "prime")) (|:| |fctr| *4) (|:| |xpnt| (|Integer|)))) (|ofCategory| *4 (|Join| (|UnivariatePolynomialCategory| *3) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $))))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *3 *4))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3 *2 *3 *2 *3) (AND (|isDomain| *2 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *3 (|SingleInteger|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *2 *3 *4 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *6 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|MatrixLinearAlgebraFunctions| *3 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *12 *3 *13)) (|ofCategory| *3 (|DesingTreeCategory| *12))))) 
 (((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|DifferentialVariableCategory| *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *7 *3)) (|ofType| *7 *3) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PackageForPoly| *4 *5 *6 *7)) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *1)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| (|Stream| *3))) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|ComplexCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|OctonionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|QuaternionCategory| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegerNumberSystem|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RationalRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |eq| *5)))) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5)))))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *5 (|List| (|List| (|Union| (|:| |array| *6) (|:| |scalar| *3))))) (|isDomain| *4 (|List| (|Union| (|:| |array| (|List| *3)) (|:| |scalar| (|Symbol|))))) (|isDomain| *6 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4 *5 *6 *3) (AND (|isDomain| *5 (|List| (|List| (|Union| (|:| |array| *6) (|:| |scalar| *3))))) (|isDomain| *4 (|List| (|Union| (|:| |array| (|List| *3)) (|:| |scalar| (|Symbol|))))) (|isDomain| *6 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4 *5 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *5 (|TheSymbolTable|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|SimpleCell| *3 *2)) (|ofCategory| *3 (|RealClosedField|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|BagAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |glbase| (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|:| |glval| (|List| (|Integer|))))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *4 *5)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Tree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *4) (|:| |degree| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|Multiset| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupFactorizer| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Factored| *5)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Multiset| (|NonNegativeInteger|))) (|isDomain| *1 (|GaloisGroupPolynomialUtilities| *4 *5))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|)))))) 
 (((*1 *1 *1 *1) (AND (|isDomain| *1 (|PendantTree| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|PendantTree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *1 (|Expression| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
-(((*1 *2 *3 *4 *5 *5 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|Polynomial| *6)) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| *7)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *7 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|isDomain| *1 (|DefiniteIntegrationTools| *6 *7)))) ((*1 *2 *3 *4 *4 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|SparseUnivariatePolynomial| *6)) (|isDomain| *4 (|OrderedCompletion| *6)) (|ofCategory| *6 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|DefiniteIntegrationTools| *5 *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Tree| *3))) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DoubleFloat|)) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |rank| (|NonNegativeInteger|)) (|:| |eqns| (|List| (|Record| (|:| |det| *7) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|)))))) (|:| |fgb| (|List| *7))))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
+(((*1 *2 *2 *3) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *1 (|TriangularMatrixOperations| *3 *4 *5 *2)) (|ofCategory| *2 (|MatrixCategory| *3 *4 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| *4 *5 *6 *7)) (|ofCategory| *4 (|Join| (|Finite|) (|Field|))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|ofCategory| *7 (|FunctionFieldCategory| *4 *5 *6)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FindOrderFinite| *4 *5 *6 *7)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|InnerTaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|LaurentPolynomial| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *4 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|FiniteDivisor| *6 *7 *4 *8)) (|isDomain| *5 (|Mapping| *9 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|ofCategory| *8 (|FunctionFieldCategory| *6 *7 *4)) (|ofCategory| *9 (|Join| (|Finite|) (|Field|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ReducedDivisor| *6 *7 *4 *8 *9)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|Integer|))) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Vector| *6)) (|isDomain| *1 (|FiniteDivisor| *3 *4 *5 *6)) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|InputForm|)) (|isDomain| *1 (|InputFormFunctions1| *4)) (|ofCategory| *4 (|Type|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
 (((*1 *2 *1) (AND (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|PatternMatchResult| *3 *5)) (|isDomain| *1 (|PatternMatchListResult| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *5 (|ListAggregate| *4))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |ans| (|Fraction| *5)) (|:| |nosol| (|Boolean|)))) (|isDomain| *1 (|TranscendentalRischDE| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FreeModuleCat| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Record| (|:| |k| *4) (|:| |c| *3)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *2 (|Record| (|:| |part1| *3) (|:| |part2| *4))) (|isDomain| *1 (|MakeRecord| *3 *4)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|Type|))))) 
+(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *7))) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *6 *4)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialFactorizationByRecursion| *5 *6 *4 *7))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|GuessOption|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|))) (|isDomain| *4 (|Union| (|Mapping| (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|) (|DoubleFloat|)) "undefined")) (|isDomain| *5 (|Segment| (|DoubleFloat|))) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|ThreeSpace| (|DoubleFloat|))) (|isDomain| *1 (|MeshCreationRoutinesForThreeDimensions|))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| *5)))) (|isDomain| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|List| (|List| (|Polynomial| *5)))) (|isDomain| *1 (|SystemSolvePackage| *5))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FortranScalarType|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SplittingTree| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Mapping| (|List| *4) *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|StreamTensor| *4))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|))) (|isDomain| *1 (|FiniteAlgebraicExtensionField&| *3 *4)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|PositiveInteger|)))) ((*1 *2) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|OnePointCompletion| (|PositiveInteger|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Partition|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *2 *1 *3 *3 *4) (AND (|isDomain| *3 (|Mapping| (|OutputForm|) (|OutputForm|) (|OutputForm|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ListMonoidOps| *5 *6 *7)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|AbelianMonoid|)) (|ofType| *7 *6))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|SparseUnivariateSkewPolynomial| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Automorphism| *3)) (|ofType| *5 (|Mapping| *3 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Plot|)) (|isDomain| *4 (|Fraction| (|Integer|))) (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|Point| (|DoubleFloat|)))))) ((*1 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |brans| (|List| (|List| (|Point| (|DoubleFloat|))))) (|:| |xValues| (|Segment| (|DoubleFloat|))) (|:| |yValues| (|Segment| (|DoubleFloat|))))) (|isDomain| *1 (|TwoDimensionalPlotClipping|)) (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Segment| (|Float|)))) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|AlgebraicNumber|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|AlgebraicNumber|)) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Integer|)))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Integer|))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|GuessOption|))) (|ofCategory| *5 (|Field|)) (|ofType| *10 (|Mapping| *7 *5)) (|ofCategory| *8 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *9 (|Mapping| *5 *8)) (|isDomain| *2 (|List| (|Record| (|:| |function| *7) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *5 *6 *7 *8 *9 *10)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *8) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|Field|)) (|ofType| *9 (|Mapping| *6 *4)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| *6) (|:| |order| (|NonNegativeInteger|)))) (|List| *4) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|Expression| (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|Polynomial| (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *5 (|Integer|))))) (|isDomain| *4 (|List| (|GuessOption|))) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *5 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|))))) (|ofType| *4 (|Symbol|)) (|isDomain| *2 (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|List| (|Record| (|:| |function| (|MyExpression| *4 (|Integer|))) (|:| |order| (|NonNegativeInteger|)))) (|List| (|Fraction| (|MyUnivariatePolynomial| *4 (|Integer|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *3))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|PartialDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *2 (|Result|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|List| (|Record| (|:| |eigval| (|Union| (|Fraction| (|Polynomial| *4)) (|SuchThat| (|Symbol|) (|Polynomial| *4)))) (|:| |geneigvec| (|List| (|Matrix| (|Fraction| (|Polynomial| *4)))))))) (|isDomain| *1 (|EigenPackage| *4)) (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| *4))))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|)))) ((*1 *2 *3 *4 *1) (AND (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Any|)) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofCategory| *4 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|NormRetractPackage| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *5)) (|ofType| *6 (|PositiveInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ExtensionField| *2)) (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|Finite|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|PartialFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RealNumberSystem|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|Collection| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1 *3) (|partial| AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *3 *2)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *4 *5 *3)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|Tuple| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
 (((*1 *1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Result|))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|LinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|LinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|LinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|RoutinesTable|))) ((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamFunctions1| *4)) (|ofCategory| *4 (|Type|)))) ((*1 *1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldSquareFreeDecomposition| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |gen| *3) (|:| |exp| *4)))) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *3))))) 
+(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *5 *6 *7 *8))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|UnivariateFactorize| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|SemiGroup|)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
+(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|NewSparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|ContinuedFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *2 *3 *4 *5 *6 *7 *8 *9 *10)) (|ofCategory| *4 (|PolynomialCategory| *2 *5 (|OrderedVariableList| *3))) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *8 (|PlacesCategory| *2 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *2 (|List| (|Expression| *6))) (|isDomain| *1 (|DegreeReductionPackage| *5 *6)) (|isDomain| *3 (|Expression| *6)) (|ofCategory| *5 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|IntegrationResultToFunction| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|List| (|Expression| *4))) (|isDomain| *1 (|IntegrationResultRFToFunction| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentExpansionCategory| *3 *2)) (|ofCategory| *3 (|OrderedRing|)) (|ofCategory| *2 (|StreamAggregate| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|SegmentExpansionCategory| *4 *2)) (|ofCategory| *4 (|OrderedRing|)) (|ofCategory| *2 (|StreamAggregate| *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| (|Symbol|) *3)) (|isDomain| *1 (|XPolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *1 (|LazardSetSolvingPackage| *3 *4 *5 *6 *7 *2)) (|ofCategory| *7 (|RegularTriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *2 (|SquareFreeRegularTriangularSetCategory| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|d03AgentsPackage|)) (|isDomain| *3 (|Symbol|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|List| *6) "failed") (|Integer|) *6 *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *1) (|isDomain| *1 (|FortranType|)))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|NonNegativeInteger|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranTemplate|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 (|List| *5))) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|List| (|Stream| *4)))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|PolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *1)))) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)))) ((*1 *1 *1) (|ofCategory| *1 (|UniqueFactorizationDomain|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *3 *2)) (|ofCategory| *2 (|Join| (|UnivariatePolynomialCategory| *3) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $)))))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|isDomain| *1 (|IncrementingMaps| *3)) (|ofCategory| *3 (|Join| (|Monoid|) (|AbelianSemiGroup|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |func| *3) (|:| |kers| (|List| (|Kernel| *3))) (|:| |vals| (|List| *3)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Vector| (|List| (|Integer|)))) (|isDomain| *1 (|HallBasis|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|InfiniteTuple| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1) (|ofCategory| *1 (|HyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|SplittingTree| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|)))))) 
+(((*1 *1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *10 (|RegularTriangularSetCategory| *6 *7 *8 *9)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *10) (|:| |ineq| (|List| *9))))) (|isDomain| *1 (|QuasiComponentPackage| *6 *7 *8 *9 *10)) (|isDomain| *3 (|List| *9)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|Boolean|)) (|ofCategory| *10 (|RegularTriangularSetCategory| *6 *7 *8 *9)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|isDomain| *2 (|List| (|Record| (|:| |eq| (|List| *9)) (|:| |tower| *10) (|:| |ineq| (|List| *9))))) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *6 *7 *8 *9 *10)) (|isDomain| *3 (|List| *9))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (|Fraction| *5)) (|:| |c2| (|Fraction| *5)) (|:| |deg| (|NonNegativeInteger|)))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Vector| (|Vector| *5))) (|isDomain| *1 (|RepresentationPackage2| *5)) (|isDomain| *4 (|Vector| *5))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *1) (|isDomain| *1 (|ODEIntensityFunctionsTable|)))) 
-(((*1 *2 *2 *3) (|partial| AND (|ofCategory| *1 (|ModularAlgebraicGcdOperations| *2 *3)) (|ofCategory| *2 (|Type|)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *3 *4 *4 *5 *6) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|Palette|)) (|isDomain| *5 (|PositiveInteger|)) (|isDomain| *6 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *4 (|List| (|DrawOption|))) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *2)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|))))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3 *4 *4 *5 *3 *6) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|isDomain| *6 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|GenusZeroIntegration| *7 *3 *8)) (|ofCategory| *8 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *5 *4 *3 *6) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|isDomain| *6 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *7) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *7 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|GenusZeroIntegration| *7 *3 *8)) (|ofCategory| *8 (|SetCategory|))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *1 (|RepeatedSquaring| *2)) (|ofCategory| *2 (|Join| (|SetCategory|) (CATEGORY |domain| (SIGNATURE * ($ $ $)))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|TemplateUtilities|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *1) (|ofCategory| *1 (|StepThrough|)))) 
+(((*1 *2 *3 *1) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *8)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Complex| (|Integer|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GaussianFactorizationPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PolynomialIdeals| (|Fraction| (|Integer|)) (|DirectProduct| *5 (|NonNegativeInteger|)) (|OrderedVariableList| *4) (|DistributedMultivariatePolynomial| *4 (|Fraction| (|Integer|))))) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IdealDecompositionPackage| *4 *5)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|IntegerPrimesPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UniqueFactorizationDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Fraction| *6)) (|isDomain| *1 (|PadeApproximants| *5 *4 *6)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *5)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|UnivariateTaylorSeries| *5 *6 *7)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|Symbol|)) (|ofType| *7 *5) (|isDomain| *2 (|Fraction| (|UnivariatePolynomial| *6 *5))) (|isDomain| *1 (|PadeApproximantPackage| *5 *6 *7)))) ((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|UnivariateTaylorSeries| *5 *6 *7)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|Symbol|)) (|ofType| *7 *5) (|isDomain| *2 (|Fraction| (|UnivariatePolynomial| *6 *5))) (|isDomain| *1 (|PadeApproximantPackage| *5 *6 *7))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *1 (|SetAggregate| *3)))) ((*1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|GraphImage|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *1 *1) (|isDomain| *1 (|TwoDimensionalViewport|)))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *1 (|Expression| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3) (AND (|ofCategory| *1 (|PolynomialFactorizationExplicit|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *1))) (|isDomain| *3 (|SparseUnivariatePolynomial| *1))))) 
+(((*1 *2 *2 *2 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|FortranType|)) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *2 (|List| *5))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariateFormalPowerSeriesFunctions| *3))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|MultiDictionary| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *2 (|Vector| (|Integer|))) (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1 *1) (|partial| AND (|ofCategory| *1 (|FieldOfPrimeCharacteristic|)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|ArcTrigonometricFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| *4)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Stream| (|List| (|Integer|)))) (|isDomain| *1 (|PartitionsAndPermutations|)) (|isDomain| *3 (|List| (|Integer|)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Color|))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ArrayStack| *3))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|String|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *4 *5)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|HomogeneousDistributedMultivariatePolynomial| *4 *5)) (|isDomain| *1 (|PolToPol| *4 *5))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|HomogeneousDistributedMultivariatePolynomial| *3 *4))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *3 *4))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|OpenMathError|))))) 
+(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *3)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|isDomain| *2 (|List| (|Vector| *5))) (|isDomain| *1 (|InterpolateFormsPackage| *5 *6 *7 *8 *9 *10 *11 *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *3 (|DivisorCategory| *11))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|CombinatorialFunctionCategory|))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|isDomain| *1 (|IntegerCombinatoricFunctions| *2)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3 *4) (AND (|isDomain| *4 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3 *3 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Complex| (|DoubleFloat|)))) (|isDomain| *1 (|ComplexDoubleFloatVector|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Vector| *3))))) 
+(((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|Mapping| (|Boolean|) *9)) (|isDomain| *4 (|Mapping| (|Boolean|) *9 *9)) (|isDomain| *5 (|Mapping| *9 *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *6 *7 *8 *9))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|StreamAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| *5)) (|:| |coeff| (|Fraction| *5)))) (|isDomain| *1 (|RationalIntegration| *4 *5)) (|isDomain| *3 (|Fraction| *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|PartialDifferentialEquationsSolverCategory|)) (|isDomain| *3 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *2 (|Result|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3 *4)) (|isDomain| *1 (|MappingPackage2| *4 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|List| (|RewriteRule| *3 *4 *5))) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|Ruleset| *3 *4 *5))))) 
+(((*1 *2 *3 *4 *4 *5) (AND (|isDomain| *3 (|Mapping| (|Complex| (|DoubleFloat|)) (|Complex| (|DoubleFloat|)))) (|isDomain| *4 (|Segment| (|DoubleFloat|))) (|isDomain| *5 (|Boolean|)) (|isDomain| *2 (|ThreeDimensionalViewport|)) (|isDomain| *1 (|DrawComplex|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *2) (AND (|isDomain| *1 (|FourierComponent| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *2 (|List| (|Expression| (|Integer|)))) (|isDomain| *1 (|RadicalEigenPackage|))))) 
-(((*1 *1 *1 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |a| *6) (|:| |b| (|Fraction| *6)) (|:| |c| (|Fraction| *6)) (|:| |t| *6))) (|isDomain| *1 (|TranscendentalRischDE| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Any|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|AnyFunctions1| *4)) (|ofCategory| *4 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
+(((*1 *2 *1 *1 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|EuclideanDomain|)))) ((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|EuclideanDomain|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|Integer|))))) 
 (((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *2) (AND (|isDomain| *1 (|FourierComponent| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|TrigonometricFunctionCategory|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RandomNumberSource|))))) 
-(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| *1)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *1 (|MonogenicAlgebra| *5 *6)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Matrix| *5))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialExtension| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|DifferentialExtension| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DifferentialRing|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|DifferentialRing|))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|DifferentialVariableCategory| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1) (AND (|ofCategory| *2 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *1 *3) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *2 (|PartialDifferentialRing| *3)) (|isDomain| *1 (|IntegrationResult| *2)) (|isDomain| *3 (|Symbol|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| *4)) (|isDomain| *3 (|List| (|NonNegativeInteger|))) (|ofCategory| *1 (|PartialDifferentialRing| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *1 (|PartialDifferentialRing| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PartialDifferentialRing| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|U32Vector|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Integer|)) (|isDomain| *1 (|U32VectorPolynomialOperations|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RecursiveAggregate| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|Point| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|Point| *3))) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *2 *3) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *4))) (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|LinearPolynomialEquationByFractions| *4))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *7) (|:| |polj| *7))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
+(((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|DoublyLinkedAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|ExtensibleLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
 (((*1 *1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|RewriteRule| *4 *5 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))))) ((*1 *1 *2 *2) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *1 (|RewriteRule| *3 *4 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3))))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *4 *6 *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Matrix| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Matrix| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|Fraction| (|Polynomial| *4)))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Integer|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|RealPolynomialUtilitiesPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|RewriteRule| *4 *5 *2))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|ApplyRules| *4 *5 *2)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|List| (|RewriteRule| *5 *6 *2))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|Ring|) (|PatternMatchable| *5) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *5)))) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|PatternMatchable| *5) (|ConvertibleTo| (|Pattern| *5)))) (|isDomain| *1 (|ApplyRules| *5 *6 *2))))) 
-(((*1 *1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|))) ((*1 *1 *1) (|ofCategory| *1 (|ExpressionSpace|)))) 
-(((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| (|Complex| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Record| (|:| |outval| (|Complex| *4)) (|:| |outmult| (|Integer|)) (|:| |outvect| (|List| (|Matrix| (|Complex| *4))))))) (|isDomain| *1 (|NumericComplexEigenPackage| *4)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *4)) (|ofCategory| *4 (|AbelianMonoidRing| *2 *3))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Mapping| *6 (|NonNegativeInteger|) (|Vector| (|SparseUnivariatePolynomial| *6)))) (|isDomain| *5 (|List| (|NonNegativeInteger|))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|Matrix| (|SparseUnivariatePolynomial| *6))) (|isDomain| *1 (|FractionFreeFastGaussian| *6 *7)) (|ofCategory| *7 (|AbelianMonoidRing| *6 (|NonNegativeInteger|)))))) 
+(((*1 *2 *3 *4 *5 *5 *4 *6) (AND (|isDomain| *4 (|Integer|)) (|isDomain| *6 (|Mapping| (|Void|) (|Vector| *5) (|Vector| *5) (|Float|))) (|isDomain| *3 (|Vector| (|Float|))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|NumericalOrdinaryDifferentialEquations|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| *4) (|:| |degree| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *4))))) 
+(((*1 *2) (|partial| AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *2 *5)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *2 *5)))) ((*1 *2) (|partial| AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *2 *4)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| *2))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|SetAggregate| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Factored| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|FactoredFunctionUtilities| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|Integer|))))) 
 (((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *1 *1) (|partial| |ofCategory| *1 (|CancellationAbelianMonoid|)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FloatingPointSystem|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
 (((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *2 *2) (AND (|isDomain| *2 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|isDomain| *3 (|OrderedVariableList| *4)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
-(((*1 *2 *3 *4 *5 *6) (|partial| AND (|isDomain| *4 (|Mapping| *8 *8)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *7) (|:| |right| *7) (|:| |sol?| (|Boolean|))) (|Integer|) *7)) (|isDomain| *6 (|List| (|Fraction| *8))) (|ofCategory| *7 (|Field|)) (|ofCategory| *8 (|UnivariatePolynomialCategory| *7)) (|isDomain| *3 (|Fraction| *8)) (|isDomain| *2 (|Record| (|:| |answer| (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|:| |a0| *7))) (|isDomain| *1 (|TranscendentalIntegration| *7 *8))))) 
-(((*1 *2 *3 *4 *5 *6 *7 *6) (|partial| AND (|isDomain| *5 (|Record| (|:| |contp| *3) (|:| |factors| (|List| (|Record| (|:| |irr| *10) (|:| |pow| (|Integer|))))))) (|isDomain| *6 (|List| *3)) (|isDomain| *7 (|List| *8)) (|ofCategory| *8 (|OrderedSet|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *10 (|PolynomialCategory| *3 *9 *8)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |polfac| (|List| *10)) (|:| |correct| *3) (|:| |corrfact| (|List| (|SparseUnivariatePolynomial| *3))))) (|isDomain| *1 (|LeadingCoefDetermination| *8 *9 *3 *10)) (|isDomain| *4 (|List| (|SparseUnivariatePolynomial| *3)))))) 
 (((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Vector| *4))) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Vector| *3)))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|LiouvillianFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2) (|partial| AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Record| (|:| |particular| *1) (|:| |basis| (|List| *1)))) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)))) ((*1 *2) (|partial| AND (|isDomain| *2 (|Record| (|:| |particular| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|:| |basis| (|List| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
 (((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1) (|ofCategory| *1 (|RadicalCategory|))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|ofCategory| *1 (|RealClosedField|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealClosedField|)))) 
-(((*1 *1) (|isDomain| *1 (|FortranCode|)))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *1 (|ComplexRootFindingPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Complex| *3)))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OnePointCompletion| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OrderedCompletion| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| *7))) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| *7)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|PolynomialSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|GcdDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Fraction| *7)))) (|isDomain| *1 (|SupFractionFactorizer| *4 *5 *6 *7)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|Fraction| *7))))) ((*1 *2 *1) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|UniqueFactorizationDomain|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|UnivariatePolynomialSquareFree| *4 *3)) (|ofCategory| *3 (|Join| (|UnivariatePolynomialCategory| *4) (|IntegralDomain|) (CATEGORY |domain| (SIGNATURE |gcd| ($ $ $))))))) ((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|SquareFreeRegularTriangularSet| *4 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Vector| *1)) (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *5)) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|InnerNumericFloatSolvePackage| *5 *6 *4)) (|ofCategory| *6 (|Field|)) (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|)))))) 
 (((*1 *2) (AND (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1) (|isDomain| *1 (|Pi|))) ((*1 *1) (|ofCategory| *1 (|TranscendentalFunctionCategory|)))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|IntegerRoots| *2)) (|ofCategory| *2 (|IntegerNumberSystem|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|ElementaryFunctionCategory|))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|Ring|) (|Module| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|XExponentialPackage| *4 *5 *2)) (|ofCategory| *2 (|XPolynomialsCat| *5 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *4 (|Module| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |mval| (|Matrix| *4)) (|:| |invmval| (|Matrix| *4)) (|:| |genIdeal| (|PolynomialIdeals| *4 *5 *6 *7)))) (|isDomain| *1 (|PolynomialIdeals| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|IntegrationResultToFunction| *4 *2)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|IntegrationResultRFToFunction| *4))))) 
-(((*1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DivisionRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Group|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SemiGroup|)) (|isDomain| *2 (|PositiveInteger|))))) 
-(((*1 *2 *3 *3 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|SymmetricGroupCombinatoricFunctions|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
-(((*1 *1 *1 *1) (AND (|isDomain| *1 (|IndexedBits| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4))))))) (|isDomain| *3 (|List| *7)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *7)) (|:| |badPols| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|VectorCategory| *3)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofCategory| *3 (|Type|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 (|List| *2))) (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *5 *2))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategory|)) (|isDomain| *2 (|String|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Mapping| *2 (|NonNegativeInteger|) (|NonNegativeInteger|) *7)) (|isDomain| *4 (|Vector| *7)) (|isDomain| *5 (|NonNegativeInteger|)) (|isDomain| *6 (|Vector| (|SparseUnivariatePolynomial| *2))) (|ofCategory| *7 (|AbelianMonoidRing| *2 *5)) (|ofCategory| *2 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *1 (|FractionFreeFastGaussian| *2 *7))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|XPolynomialRing| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedMonoid|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *2 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Complex| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|SpecialFunctionCategory|)))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| *3))) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| *3))) (|isDomain| *5 (|String|)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *6))) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| *3)) (|:| |f2| (|List| (|OrderedCompletion| *3))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|ElementaryFunctionDefiniteIntegration| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Expression| *5)))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *5))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Expression| *6)))) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *6))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| *5))))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *5))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *5)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Fraction| (|Polynomial| *6))))) (|isDomain| *5 (|String|)) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|:| |f1| (|OrderedCompletion| (|Expression| *6))) (|:| |f2| (|List| (|OrderedCompletion| (|Expression| *6)))) (|:| |fail| "failed") (|:| |pole| "potentialPole"))) (|isDomain| *1 (|RationalFunctionDefiniteIntegration| *6)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| *3 (|List| *3))) (|isDomain| *1 (|FunctionSpaceIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *6 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NumericalIntegrationProblem|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|Segment| (|OrderedCompletion| (|Float|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5 *5 *6) (AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *5 (|Float|)) (|isDomain| *6 (|RoutinesTable|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|String|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *3 (|Expression| (|Float|))) (|isDomain| *4 (|SegmentBinding| (|OrderedCompletion| (|Float|)))) (|isDomain| *5 (|Symbol|)) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|AnnaNumericalIntegrationPackage|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|IntegrationResult| (|Fraction| *5))) (|isDomain| *1 (|RationalIntegration| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|CharacteristicZero|)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Union| (|Expression| *5) (|List| (|Expression| *5)))) (|isDomain| *1 (|IntegrationResultRFToFunction| *5)))) ((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|MultivariateTaylorSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Polynomial| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *2 *4)) (|ofCategory| *4 (|PolynomialCategory| *3 (|IndexedExponents| *2) *2)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (OR (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|ofCategory| *3 (|AlgebraicallyClosedFunctionSpace| (|Integer|))) (|ofCategory| *3 (|PrimitiveFunctionCategory|)) (|ofCategory| *3 (|TranscendentalFunctionCategory|)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)) (|ofCategory| *3 (|Ring|)) (AND (|has| *3 (SIGNATURE |variables| ((|List| *2) *3))) (|has| *3 (SIGNATURE |integrate| (*3 *3 *2))) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |eq| *5)))) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5)))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *7))) (|isDomain| *4 (|Mapping| (|List| *6) *7)) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|List| (|Fraction| *7))) (|isDomain| *1 (|RationalRicDE| *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *7 (|Fraction| *7))) (|isDomain| *4 (|Mapping| (|List| *6) *7)) (|isDomain| *5 (|Mapping| (|Factored| *7) *7)) (|ofCategory| *6 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|List| (|Fraction| *7))) (|isDomain| *1 (|RationalRicDE| *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *5))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|RationalRicDE| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|AlgebraicallyClosedField|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6)))) ((*1 *2 *3) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *5 (|Fraction| *5))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *4 (|AlgebraicallyClosedField|)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *5))) (|isDomain| *1 (|RationalRicDE| *4 *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6))) (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|AlgebraicallyClosedField|)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|List| (|Fraction| *6))) (|isDomain| *1 (|RationalRicDE| *5 *6))))) 
-(((*1 *2 *3 *1) (AND (|isDomain| *3 (|FortranScalarType|)) (|isDomain| *2 (|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|))))))))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|KeyedAccessFile| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Library|)))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IndexedString| *3)) (|ofType| *3 *2))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SetCategory|)) (|isDomain| *2 (|SingleInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Vector| (|Symbol|))) (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|Vector| (|Matrix| *4))))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| *2)) (|ofType| *7 (|Vector| (|Matrix| *4))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|GenericNonAssociativeAlgebra| *3 *4 *5 *6))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Symbol|))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| *2)) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *1) (AND (|isDomain| *1 (|GenericNonAssociativeAlgebra| *2 *3 *4 *5)) (|ofCategory| *2 (|CommutativeRing|)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|Vector| (|Matrix| *2)))))) 
-(((*1 *1 *1) (AND (|isDomain| *1 (|IndexedBits| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
-(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Segment| *3)) (|ofCategory| *3 (|PolynomialCategory| *7 *6 *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| (|Integer|)))) (|isDomain| *1 (|InnerPolySum| *6 *4 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| (|Integer|)))) (|isDomain| *1 (|InnerPolySum| *5 *4 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceSum| *4 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|CombinatorialOpsCategory|) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|CombinatorialOpsCategory|) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceSum| *4 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Polynomial| *5))) (|isDomain| *1 (|RationalFunctionSum| *5)) (|isDomain| *3 (|Polynomial| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Union| (|Fraction| (|Polynomial| *5)) (|Expression| *5))) (|isDomain| *1 (|RationalFunctionSum| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Polynomial| *5))) (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| *3)) (|isDomain| *1 (|RationalFunctionSum| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Fraction| (|Polynomial| *5)))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Union| *3 (|Expression| *5))) (|isDomain| *1 (|RationalFunctionSum| *5))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |coef| (|Fraction| *5)) (|:| |poly| *3))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
-(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StorageEfficientMatrixOperations| *3))))) 
-(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeMonoid| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|AbelianMonoid|)) (|isDomain| *1 (|ListMonoidOps| *4 *2 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofType| *5 *2))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *4)) (|ofCategory| *4 (|OrderedSet|))))) 
-(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|Join| (|Ring|) (|PatternMatchable| *3) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *3)))) (|isDomain| *2 (|List| (|RewriteRule| *3 *4 *5))) (|isDomain| *1 (|Ruleset| *3 *4 *5)) (|ofCategory| *5 (|Join| (|FunctionSpace| *4) (|PatternMatchable| *3) (|ConvertibleTo| (|Pattern| *3))))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
-(((*1 *2 *3 *4 *5 *4 *4 *4) (AND (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *3 (|List| *6)) (|isDomain| *5 (|List| *3)) (|isDomain| *2 (|Record| (|:| |f1| *3) (|:| |f2| (|List| *5)) (|:| |f3| *5) (|:| |f4| (|List| *5)))) (|isDomain| *1 (|TableauxBumpers| *6)) (|isDomain| *4 (|List| *5))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|GcdDomain|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |const| *3) (|:| |nconst| *3))) (|isDomain| *1 (|PatternMatchIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5)))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *2 *3 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ModularDistinctDegreeFactorizer| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
-(((*1 *1 *2 *2) (AND (|isDomain| *2 (|Union| (|:| I (|Expression| (|Integer|))) (|:| F (|Expression| (|Float|))) (|:| CF (|Expression| (|Complex| (|Float|)))) (|:| |switch| (|Switch|)))) (|isDomain| *1 (|Switch|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|isDomain| *1 (|d01AgentsPackage|))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| (|Fraction| *8)) "failed")) (|:| |basis| (|List| (|Vector| (|Fraction| *8)))))) (|isDomain| *1 (|LinearSystemPolynomialPackage| *5 *6 *7 *8))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *5)) (|isDomain| *4 (|List| (|Mapping| *6 (|List| *6)))) (|ofCategory| *5 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *6 (|UnivariateTaylorSeriesCategory| *5)) (|isDomain| *2 (|List| *6)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *5 *6))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|SquareFreeRegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|TemplateUtilities|))))) 
-(((*1 *2 *2 *3 *4 *5) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|Mapping| (|Boolean|) *9)) (|isDomain| *4 (|Mapping| (|Boolean|) *9 *9)) (|isDomain| *5 (|Mapping| *9 *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *6 *7 *8 *9))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Expression| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *2 *3) (AND (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|BezoutMatrix| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|MatrixCategory| *2 *5 *6))))) 
-(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *3 (|SubSpaceComponentProperty|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| *3 *4 *5)) (|isDomain| *2 (|Record| (|:| |id| (|FractionalIdeal| *4 (|Fraction| *4) *5 *6)) (|:| |principalPart| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |poly| *6) (|:| |normal| (|Fraction| *6)) (|:| |special| (|Fraction| *6)))) (|isDomain| *1 (|MonomialExtensionTools| *5 *6)) (|isDomain| *3 (|Fraction| *6)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialDecomposition| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *4) (|partial| AND (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |left| *3) (|:| |right| *3))) (|isDomain| *1 (|PolynomialDecomposition| *3 *5)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *2 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *2 *4 *4 *4 *4 *4) (AND (|isDomain| *2 (|List| *9)) (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|Boolean|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2 *2 *2 *2) (AND (|ofCategory| *2 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *1 *1) (|partial| AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Monoid|)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *2 (|RecursivePolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *4 *2)) (|ofCategory| *2 (|ElementaryFunctionCategory|)) (|ofCategory| *2 (|FunctionSpace| *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|RoutinesTable|)) (|isDomain| *3 (|String|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|GcdDomain|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *6)) (|ofCategory| *6 (|PolynomialCategory| *5 *3 *4)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|PolynomialFactorizationExplicit|)) (|isDomain| *1 (|GeneralPolynomialGcdPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PolynomialFactorizationExplicit|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |poly| *6) (|:| |eq| *3)))) (|isDomain| *1 (|PrimitiveRatRicDE| *5 *6 *3 *7)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *6)) (|ofCategory| *7 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *6))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| (|List| *5) *6)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |poly| *6) (|:| |eq| (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) (|isDomain| *1 (|RationalRicDE| *5 *6)) (|isDomain| *3 (|LinearOrdinaryDifferentialOperator2| *6 (|Fraction| *6)))))) 
-(((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Union| (|Integer|) "failed") *5)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)))) ((*1 *2 *3 *4 *2 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Integer|) "failed") *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|Mapping| (|Union| (|Integer|) "failed") *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|InnerPolySign| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *1) (AND (|isDomain| *1 (|CartesianTensor| *2 *3 *4)) (|ofType| *2 (|Integer|)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|CommutativeRing|))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|CommuteUnivariatePolynomialCategory| *3 *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Equation| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|PolynomialCategory| *5 *4 *2)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *2 *5 *6 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *6)) (SIGNATURE |numer| (*6 $)) (SIGNATURE |denom| (*6 $))))))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RationalFunction| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Table| (|StochasticDifferential| *3) (|StochasticDifferential| *3))) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Stream| *4)) (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3))) ((*1 *1 *2 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|))))) 
-(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *1 (|PolyGroebner| *4))))) 
-(((*1 *2 *3 *4 *2 *5 *6) (AND (|isDomain| *5 (|Record| (|:| |done| (|List| *11)) (|:| |todo| (|List| (|Record| (|:| |val| *3) (|:| |tower| *11)))))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *10)) (|:| |tower| *11)))) (|isDomain| *3 (|List| *10)) (|isDomain| *4 (|List| *11)) (|ofCategory| *10 (|RecursivePolynomialCategory| *7 *8 *9)) (|ofCategory| *11 (|RegularTriangularSetCategory| *7 *8 *9 *10)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *7 *8 *9 *10 *11)))) ((*1 *2 *3 *4 *2 *5 *6) (AND (|isDomain| *5 (|Record| (|:| |done| (|List| *11)) (|:| |todo| (|List| (|Record| (|:| |val| *3) (|:| |tower| *11)))))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|List| *10)) (|:| |tower| *11)))) (|isDomain| *3 (|List| *10)) (|isDomain| *4 (|List| *11)) (|ofCategory| *10 (|RecursivePolynomialCategory| *7 *8 *9)) (|ofCategory| *11 (|SquareFreeRegularTriangularSetCategory| *7 *8 *9 *10)) (|ofCategory| *7 (|GcdDomain|)) (|ofCategory| *8 (|OrderedAbelianMonoidSup|)) (|ofCategory| *9 (|OrderedSet|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *7 *8 *9 *10 *11))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *4))) (|ofCategory| *5 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *2 *5 *6 *7 *8 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *3))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *6 (|Field|)) (|isDomain| *4 (|TaylorSeries| *6)) (|isDomain| *2 (|Mapping| (|Stream| *4) (|Stream| *4))) (|isDomain| *1 (|WeierstrassPreparation| *6)) (|isDomain| *5 (|Stream| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *3 *4 *5 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DoubleFloat|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Float|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|Float|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |discriminant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|Expression| (|DoubleFloat|)))) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Kernel| *1))) (|ofCategory| *1 (|ExpressionSpace|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *1 (|ODEIntegration| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|))))) ((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MyUnivariatePolynomial| *4 *3)) (|ofType| *4 (|Symbol|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *1 (|PolynomialRing| *3 *2)) (|ofCategory| *2 (|CancellationAbelianMonoid|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Partition|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)) (|isDomain| *1 (|SymmetricPolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|UnivariatePolynomial| *4 *3)) (|ofType| *4 (|Symbol|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MultiDictionary| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |entry| *3) (|:| |count| (|NonNegativeInteger|)))))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|OpenMathPackage|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankAlgebra| *4 *5)) (|ofCategory| *4 (|CommutativeRing|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|Matrix| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Stream| (|Integer|))) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Any|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OutputPackage|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *3 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *11 *3 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *3))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|XPolynomialRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedMonoid|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|FreeModuleCat| *3 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|MonoidRing| *3 *4))) (|isDomain| *1 (|MonoidRing| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)))) ((*1 *2 *1) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|PolynomialCategory| *3 *4 *5))))) 
-(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|StringCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Symbol|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *1 (|BlasLevelOne|))))) 
-(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
-(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|CRApackage| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| *5))) (|ofCategory| *5 (|FiniteAbelianMonoidRing| *4 *6)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|NewtonPolygon| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 *2)) (|ofType| *7 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *3 *6 *7 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|DirectProductCategory| *8 *2)) (|ofType| *8 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *6 *3 *7 *8 *4)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *6 *7)) (|ofCategory| *4 (|ProjectiveSpaceCategory| *6))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *2 *1 *3 *4) (AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| *8 *8 *8)) (|isDomain| *4 (|Mapping| (|Boolean|) *8 *8)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FourierComponent| *3)) (|ofCategory| *3 (|OrderedSet|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|CancellationAbelianMonoid|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|FreeGroup| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|FreeMonoid| *3)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4)))) 
-(((*1 *2 *2 *3) (|partial| AND (|isDomain| *3 (|Mapping| *6 *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *4))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *1 (|AlgebraicIntegrate| *4 *5 *6 *7 *2)) (|ofCategory| *2 (|FunctionFieldCategory| *5 *6 *7))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |additions| (|Integer|)) (|:| |multiplications| (|Integer|)) (|:| |exponentiations| (|Integer|)) (|:| |functionCalls| (|Integer|)))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *3) (|:| |polj| *3)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|ElementaryFunctionCategory|))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|Ring|) (|Module| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|XExponentialPackage| *4 *5 *2)) (|ofCategory| *2 (|XPolynomialsCat| *5 *4)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *4 (|Module| (|Fraction| (|Integer|)))) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp12| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp29| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Asp33| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FortranProgramCategory|)) (|isDomain| *2 (|Void|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FileName|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|String|)) (|isDomain| *4 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|OutputForm|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|SpecialOutputPackage|))))) 
+(((*1 *2 *3 *3 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|DivisionRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Group|)) (|isDomain| *2 (|Integer|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|Monoid|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|SemiGroup|)) (|isDomain| *2 (|PositiveInteger|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Any|))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|IndexedBits| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Palette|)) (|isDomain| *1 (|DrawOption|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|AntiSymm| *3 *4)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|ofType| *4 (|List| (|Symbol|))))) ((*1 *1) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *2)) (|ofCategory| *2 (|Finite|)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|FiniteDivisorCategory| *3 *4 *5 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *2 (|FunctionFieldCategory| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|FreeNilpotentLie| *3 *4 *5)) (|ofType| *3 *2) (|ofType| *4 *2) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *2 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|VectorCategory| *3)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofCategory| *3 (|Type|))))) 
+(((*1 *1 *2 *2 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileNameCategory|))))) 
+(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|)))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |mval| (|Matrix| *3)) (|:| |invmval| (|Matrix| *3)) (|:| |genIdeal| (|PolynomialIdeals| *3 *4 *5 *6)))) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|FileName|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranOutputStackPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
-(((*1 *2 *3 *3) (AND (|has| *2 (ATTRIBUTE (|commutative| "*"))) (|ofCategory| *5 (|FiniteLinearAggregate| *2)) (|ofCategory| *6 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Ring|)) (|isDomain| *1 (|BezoutMatrix| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *4 (|MatrixCategory| *2 *5 *6))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *2 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|FiniteSetAggregate| *2)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *2 (|Finite|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|None|)) (|isDomain| *1 (|Any|))))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| (|FortranType|))))) (|isDomain| *1 (|SymbolTable|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *5 *6 *7 *8 *9)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *9)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *9 (|SquareFreeRegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *5 *6 *7 *8 *9))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|FunctionSpaceComplexIntegration| *5 *3)) (|ofCategory| *3 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|IntegrationResult| (|Fraction| (|Polynomial| *5)))) (|isDomain| *1 (|RationalFunctionIntegration| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariatePolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *10)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *6 *7 *8 *9 *10 *2 *11 *3 *12)) (|ofCategory| *3 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *2 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2) (AND (|isDomain| *2 (|Divisor| (|PlacesOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Divisor| (|Places| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Queue| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|MultiDictionary| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |entry| *3) (|:| |count| (|NonNegativeInteger|)))))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|IndexedBits| *2)) (|ofType| *2 (|Integer|)))) ((*1 *1 *1) (|isDomain| *1 (|SingleInteger|)))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7))))) (|ofCategory| *7 (|OrderedRing|)) (|ofCategory| *8 (|Join| (|UnivariatePowerSeriesCategory| *3 *7) (|Field|) (|TranscendentalFunctionCategory|) (CATEGORY |domain| (SIGNATURE |differentiate| ($ $)) (SIGNATURE |integrate| ($ $))))) (|isDomain| *2 (|Union| (|:| |%series| *8) (|:| |%problem| (|Record| (|:| |func| (|String|)) (|:| |prob| (|String|)))))) (|isDomain| *1 (|FunctionSpaceToUnivariatePowerSeries| *6 *3 *7 *8 *9 *10)) (|isDomain| *5 (|String|)) (|ofCategory| *9 (|PartialTranscendentalFunctions| *8)) (|ofType| *10 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Segment| *3)) (|ofCategory| *3 (|PolynomialCategory| *7 *6 *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *7 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| (|Integer|)))) (|isDomain| *1 (|InnerPolySum| *6 *4 *7 *3)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *6 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |num| *3) (|:| |den| (|Integer|)))) (|isDomain| *1 (|InnerPolySum| *5 *4 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *5 *4)))) ((*1 *1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceSum| *4 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|CombinatorialOpsCategory|) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|CombinatorialOpsCategory|) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|FunctionSpaceSum| *4 *2)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| (|Polynomial| *5))) (|isDomain| *1 (|RationalFunctionSum| *5)) (|isDomain| *3 (|Polynomial| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Union| (|Fraction| (|Polynomial| *5)) (|Expression| *5))) (|isDomain| *1 (|RationalFunctionSum| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Polynomial| *5))) (|isDomain| *3 (|Polynomial| *5)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Fraction| *3)) (|isDomain| *1 (|RationalFunctionSum| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|SegmentBinding| (|Fraction| (|Polynomial| *5)))) (|isDomain| *3 (|Fraction| (|Polynomial| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Union| *3 (|Expression| *5))) (|isDomain| *1 (|RationalFunctionSum| *5))))) 
+(((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|d01WeightsPackage|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *2 *3 *4 *5)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|DifferentialVariableCategory| *3)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|))))) 
+(((*1 *2 *3 *4 *4 *4 *4 *5 *5 *5) (AND (|isDomain| *3 (|Mapping| (|Float|) (|Float|))) (|isDomain| *4 (|Float|)) (|isDomain| *2 (|Record| (|:| |value| *4) (|:| |error| *4) (|:| |totalpts| (|Integer|)) (|:| |success| (|Boolean|)))) (|isDomain| *1 (|NumericalQuadrature|)) (|isDomain| *5 (|Integer|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |mat| (|Matrix| (|Fraction| (|Polynomial| *4)))) (|:| |vec| (|List| (|Fraction| (|Polynomial| *4)))) (|:| |rank| (|NonNegativeInteger|)) (|:| |rows| (|List| (|Integer|))) (|:| |cols| (|List| (|Integer|))))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |partsol| (|Vector| (|Fraction| (|Polynomial| *4)))) (|:| |basis| (|List| (|Vector| (|Fraction| (|Polynomial| *4))))))) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|OrderedVariableList| *5))) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Record| (|:| |dpolys| (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|:| |coords| (|List| (|Integer|))))) (|isDomain| *1 (|GroebnerSolve| *5 *6 *7)) (|isDomain| *3 (|List| (|DistributedMultivariatePolynomial| *5 *6))) (|ofCategory| *7 (|GcdDomain|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|ProjectiveSpaceCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3)) (|isDomain| *1 (|IncrementingMaps| *3)) (|ofCategory| *3 (|Join| (|Monoid|) (|AbelianSemiGroup|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *4)) (|isDomain| *1 (|PrimitiveRatRicDE| *4 *2 *3 *5)) (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *2)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *2)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |sinh| (|Stream| *4)) (|:| |cosh| (|Stream| *4)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *4)) (|isDomain| *3 (|Stream| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| *7 *5 *6)) (|isDomain| *1 (|MakeBinaryCompiledFunction| *4 *5 *6 *7)) (|ofCategory| *4 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|)) (|ofCategory| *7 (|Type|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Expression| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |val| (|List| *8)) (|:| |towers| (|List| (|RegularTriangularSet| *5 *6 *7 *8))))) (|isDomain| *1 (|RegularTriangularSet| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8)))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Record| (|:| |val| (|List| *8)) (|:| |towers| (|List| (|SquareFreeRegularTriangularSet| *5 *6 *7 *8))))) (|isDomain| *1 (|SquareFreeRegularTriangularSet| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|d03AgentsPackage|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|RetractableTo| *3)) (|ofCategory| *2 (|Field|)))) ((*1 *1 *2 *2) (AND (|isDomain| *1 (|IntegrationResult| *2)) (|ofCategory| *2 (|Field|)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *4 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *4) (|RadicalCategory|) (|TranscendentalFunctionCategory|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *4 *2)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PrimitiveFunctionCategory|)) (|isDomain| *2 (|Symbol|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|SegmentBinding| *1)) (|ofCategory| *1 (|PrimitiveFunctionCategory|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)))) ((*1 *2 *3 *1) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|RegularTriangularSetCategory| *4 *5 *6 *3))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Automorphism| *5)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariateSkewPolynomialCategoryOps| *5 *3)) (|ofCategory| *3 (|UnivariateSkewPolynomialCategory| *5))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|d03AgentsPackage|)) (|isDomain| *3 (|Symbol|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *4 (|NonNegativeInteger|)) (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *1 (|e04AgentsPackage|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|List| *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|NewtonPolygon| *4 *3 *5 *6))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|PositiveInteger|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *2)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|)))))) 
+(((*1 *1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
+(((*1 *1 *1 *2 *2 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *1 *1 *2 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|)))) ((*1 *2 *1 *3 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *1 (|MappingPackage1| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|List| *5) (|List| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|MappingPackage1| *5)) (|ofCategory| *5 (|SetCategory|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|))) ((*1 *1 *1 *2 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|DoubleFloat|))) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|HomogeneousDistributedMultivariatePolynomial| *4 *5))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|DistributedMultivariatePolynomial| *4 *5))) (|isDomain| *1 (|LinGroebnerPackage| *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Mapping| *5 *5)) (|isDomain| *1 (|ODEIntegration| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|)))))) 
+(((*1 *1 *1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 *3 *3 *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|BalancedBinaryTree| *3)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Mapping| *2 *2 *2)) (|isDomain| *1 (|BalancedBinaryTree| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|List| *6))) (|ofCategory| *6 (|PolynomialCategory| *3 *5 *4)) (|ofCategory| *3 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|ParametricLinearEquations| *3 *4 *5 *6))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1) (AND (|isDomain| *1 (|FortranExpression| *2 *3 *4)) (|ofType| *2 (|List| (|Symbol|))) (|ofType| *3 (|List| (|Symbol|))) (|ofCategory| *4 (|FortranMachineTypeCategory|)))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
+(((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|StringCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
+(((*1 *2 *3 *4 *5 *6 *2 *7 *8) (|partial| AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| *11))) (|isDomain| *3 (|SparseUnivariatePolynomial| *11)) (|isDomain| *4 (|List| *10)) (|isDomain| *5 (|List| *8)) (|isDomain| *6 (|List| (|NonNegativeInteger|))) (|isDomain| *7 (|Vector| (|List| (|SparseUnivariatePolynomial| *8)))) (|ofCategory| *10 (|OrderedSet|)) (|ofCategory| *8 (|EuclideanDomain|)) (|ofCategory| *11 (|PolynomialCategory| *8 *9 *10)) (|ofCategory| *9 (|OrderedAbelianMonoidSup|)) (|isDomain| *1 (|MultivariateLifting| *9 *10 *8 *11))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1) (|isDomain| *1 (|FortranCode|)))) 
+(((*1 *2 *3 *4 *3 *5) (AND (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *6)) (|isDomain| *2 (|Record| (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (|List| (|Integer|))))) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *6 *7 *3 *8 *4 *9 *10)) (|isDomain| *5 (|Integer|)) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *4 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *10 (|PlacesCategory| *6 *9))))) 
+(((*1 *2 *3 *1) (AND (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|IndexedAggregate| *4 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Stream| (|Polynomial| *4)) (|Stream| (|Polynomial| *4)))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|List| (|Record| (|:| |deg| (|NonNegativeInteger|)) (|:| |prod| *3)))) (|isDomain| *1 (|DistinctDegreeFactorize| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1 *2) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerRetractions| *3)) (|ofCategory| *3 (|RetractableTo| *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *2 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *3 *3 *2) (AND (|isDomain| *2 (|Result|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *1 (|d01AgentsPackage|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ODEIntensityFunctionsTable|))))) 
 (((*1 *2 *2) (AND (|isDomain| *1 (|MappingPackage1| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| *2))) (|ofCategory| *4 (|Field|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *2 *3 *4 *5 *6 *7 *8 *9 *10)) (|ofCategory| *4 (|PolynomialCategory| *2 *5 (|OrderedVariableList| *3))) (|ofCategory| *5 (|DirectProductCategory| (|#| *3) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *2)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *2)) (|ofCategory| *8 (|PlacesCategory| *2 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *8 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegrate| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *6 *7 *8))))) 
-(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TabulatedComputationPackage| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *1) (|ofCategory| *1 (|FiniteFieldCategory|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|RegularChain| *4 *5)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3 *4 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Polynomial| *5))) (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *5))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *5 *6 *7)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|List| (|List| (|RealClosure| (|Fraction| *4))))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
 (((*1 *1 *2 *2 *3) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|FloatingPointSystem|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *2 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Record| (|:| |endPointContinuity| (|Union| (|:| |continuous| "Continuous at the end points") (|:| |lowerSingular| "There is a singularity at the lower end point") (|:| |upperSingular| "There is a singularity at the upper end point") (|:| |bothSingular| "There are singularities at both end points") (|:| |notEvaluated| "End point continuity not yet evaluated"))) (|:| |singularitiesStream| (|Union| (|:| |str| (|Stream| (|DoubleFloat|))) (|:| |notEvaluated| "Internal singularities not yet evaluated"))) (|:| |range| (|Union| (|:| |finite| "The range is finite") (|:| |lowerInfinite| "The bottom of range is infinite") (|:| |upperInfinite| "The top of range is infinite") (|:| |bothInfinite| "Both top and bottom points are infinite") (|:| |notEvaluated| "Range not yet evaluated"))))) (|isDomain| *1 (|IntegrationFunctionsTable|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|IntegralDomain|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |lcmfij| *5) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *7) (|:| |polj| *7))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *7))))) 
 (((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| *5 *6 *7 *8)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|ofCategory| *8 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PointsOfFiniteOrder| *4 *5 *6 *7 *8)))) ((*1 *2 *3) (AND (|isDomain| *3 (|FiniteDivisor| (|Fraction| (|Integer|)) *4 *5 *6)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *6 (|FunctionFieldCategory| (|Fraction| (|Integer|)) *4 *5)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PointsOfFiniteOrderRational| *4 *5 *6))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Vector| (|Matrix| *4))) (|isDomain| *1 (|AssociatedEquations| *4 *5)) (|isDomain| *3 (|Matrix| *4)) (|ofCategory| *5 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
+(((*1 *1) (|isDomain| *1 (|OpenMathEncoding|)))) 
 (((*1 *1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *14)) (|ofCategory| *14 (|DesingTreeCategory| *13)) (|ofCategory| *13 (|InfinitlyClosePointCategory| *5 *6 *7 *8 *9 *10 *11 *12 *15)) (|ofCategory| *15 (|BlowUpMethodCategory|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|PolynomialCategory| *5 *8 (|OrderedVariableList| *6))) (|ofCategory| *8 (|DirectProductCategory| (|#| *6) *3)) (|ofCategory| *9 (|ProjectiveSpaceCategory| *5)) (|ofCategory| *10 (|LocalPowerSeriesCategory| *5)) (|ofCategory| *11 (|PlacesCategory| *5 *10)) (|ofCategory| *12 (|DivisorCategory| *11)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|DesingTreePackage| *5 *6 *7 *8 *9 *10 *11 *12 *13 *14 *15))))) 
-(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|OutputForm|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Table| (|Symbol|) (|BasicStochasticDifferential|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| "skip" "MonteCarlo" "deterministic")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| "skip" "MonteCarlo" "deterministic")) (|isDomain| *1 (|GuessOption|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |factor| (|SparseUnivariatePolynomial| *6)) (|:| |exponent| (|Integer|))))) (|ofCategory| *6 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *6 *4 *5)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| (|Matrix| *3))) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Point| *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *4))))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|List| (|Polynomial| *3))))) ((*1 *2) (AND (|isDomain| *2 (|List| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|GenericNonAssociativeAlgebra| *4 *5 *6 *7))) (|isDomain| *2 (|List| (|Polynomial| *4))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *4 *5 *6 *7)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *4 (|CommutativeRing|)) (|ofType| *5 (|PositiveInteger|)) (|ofType| *6 (|List| (|Symbol|))) (|ofType| *7 (|Vector| (|Matrix| *4)))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|)))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| *6 *5)) (|isDomain| *1 (|MakeUnaryCompiledFunction| *4 *5 *6)) (|ofCategory| *4 (|ConvertibleTo| (|InputForm|))) (|ofCategory| *5 (|Type|)) (|ofCategory| *6 (|Type|))))) 
-(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *3))))) 
-(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|PAdicIntegerCategory| *4))))) 
-(((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Record| (|:| |factors| (|List| *3)) (|:| |error| *5)))) (|isDomain| *1 (|ComplexRootFindingPackage| *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *5))))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|OrderedRing|))) (|isDomain| *2 (|List| (|Record| (|:| |factors| (|List| *3)) (|:| |error| *4)))) (|isDomain| *1 (|ComplexRootFindingPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Complex| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |subResultant| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *1 (|TubePlotTools|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|))) (|isDomain| *1 (|IntegrationResultToFunction| *4 *2)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|IntegrationResult| (|Fraction| (|Polynomial| *4)))) (|ofCategory| *4 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|IntegrationResultRFToFunction| *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *2)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *2 (|BlowUpMethodCategory|))))) 
 (((*1 *1 *2 *2 *2 *2) (AND (|isDomain| *1 (|MoebiusTransform| *2)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|InternalPrintPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *2 (|List| (|Segment| (|DoubleFloat|)))) (|isDomain| *1 (|PlotTools|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|Permutation| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|IrrRepSymNatPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|IrrRepSymNatPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|List| (|Permutation| (|Integer|)))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|IrrRepSymNatPackage|))))) 
-(((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *3 *6)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *4 *5 *3)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Partition|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PointsOfFiniteOrderTools| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Fraction| *3)))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *3 *5) (AND (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *6)) (|isDomain| *2 (|Record| (|:| |fnc| *3) (|:| |crv| *3) (|:| |chart| (|List| (|Integer|))))) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *6 *7 *3 *8 *4 *9 *10)) (|isDomain| *5 (|Integer|)) (|ofCategory| *3 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *4 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *10 (|PlacesCategory| *6 *9))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 |RationalNumber|) (|isDomain| *2 (|Mapping| (|Integer|))) (|isDomain| *1 (|RandomIntegerDistributions|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QuaternionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *2 *3 *2 *4) (|partial| AND (|isDomain| *3 (|List| (|Kernel| *2))) (|isDomain| *4 (|Symbol|)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *5 *2))))) 
+(((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|List| (|Fraction| *6))) (|isDomain| *3 (|Fraction| *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|RationalIntegration| *5 *6))))) 
+(((*1 *2 *3 *4 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |totdeg| (|NonNegativeInteger|)) (|:| |pol| *3)))) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *3 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *5 *6 *7 *3))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2) (AND (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *3) (|Finite|)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|UnivariateTaylorSeriesCZero| (|Integer|) |t|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Matrix| (|Fraction| *4)))))) 
+(((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|Record| (|:| |close| *1) (|:| |open| (|List| *7))))) (|isDomain| *3 (|List| *7)) (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *7))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|OrderedIntegralDomain|)) (|ofType| *5 (|Symbol|)) (|isDomain| *2 (|List| (|UnivariatePolynomial| *5 *4))) (|isDomain| *1 (|SturmHabichtPackage| *4 *5)) (|isDomain| *3 (|UnivariatePolynomial| *5 *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Union| (|:| |Null| "null") (|:| |Assignment| "assignment") (|:| |Conditional| "conditional") (|:| |Return| "return") (|:| |Block| "block") (|:| |Comment| "comment") (|:| |Call| "call") (|:| |For| "for") (|:| |While| "while") (|:| |Repeat| "repeat") (|:| |Goto| "goto") (|:| |Continue| "continue") (|:| |ArrayAssignment| "arrayAssignment") (|:| |Save| "save") (|:| |Stop| "stop") (|:| |Common| "common") (|:| |Print| "print"))) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|DoubleFloat|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|EuclideanDomain|)) (|isDomain| *2 (|Fraction| (|Factored| (|Polynomial| *4)))) (|isDomain| *1 (|RationalFunctionFactorizer| *4))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |minor| (|List| (|PositiveInteger|))) (|:| |eq| *3) (|:| |minors| (|List| (|List| (|PositiveInteger|)))) (|:| |ops| (|List| *3)))) (|isDomain| *1 (|AssociatedEquations| *5 *3)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *2 *3 *1) (|partial| AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *4 *2))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |mat| (|Matrix| *5)) (|:| |vec| (|Vector| (|List| (|PositiveInteger|)))))) (|isDomain| *1 (|AssociatedEquations| *5 *3)) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 *2)) (|ofType| *6 *2) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *3 *5 *6)) (|ofCategory| *3 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|TangentExpansions| *2)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Vector| *5))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Vector| *5)) (|isDomain| *1 (|RepresentationPackage2| *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Finite|)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|InfiniteProductCharacteristicZero| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|MonogenicAlgebra| *3 *4)) (|isDomain| *1 (|InfiniteProductFiniteField| *3 *4 *5 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *5)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|Field|) (|Finite|) (|ConvertibleTo| (|Integer|)))) (|isDomain| *1 (|InfiniteProductPrimeField| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|StreamInfiniteProduct| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 (|List| *5))) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *2 (|Mapping| (|Stream| *4) (|List| (|Stream| *4)))) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *5))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|OrthogonalPolynomialFunctions| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Segment| *3)) (|isDomain| *1 (|SegmentBinding| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|UniversalSegment| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |center| *5) (|:| |equation| *5)))) (|isDomain| *1 (|PrimitiveRatDE| *4 *5 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |center| *4) (|:| |equation| *4)))) (|isDomain| *1 (|PrimitiveRatDE| *5 *4 *3 *6)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|List| (|Record| (|:| |center| *5) (|:| |equation| *5)))) (|isDomain| *1 (|PrimitiveRatDE| *4 *5 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *5)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *5))))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|List| (|Record| (|:| |center| *4) (|:| |equation| *4)))) (|isDomain| *1 (|PrimitiveRatDE| *5 *4 *6 *3)) (|ofCategory| *6 (|LinearOrdinaryDifferentialOperatorCategory| *4)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| (|Fraction| *4)))))) 
+(((*1 *1 *2 *2 *2) (AND (|isDomain| *1 (|ParametricSurface| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Vector| *1)) (|isDomain| *4 (|Mapping| *5 *5)) (|ofCategory| *5 (|Field|)) (|ofCategory| *1 (|MonogenicAlgebra| *5 *6)) (|ofCategory| *5 (|CommutativeRing|)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|isDomain| *2 (|Matrix| *5))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Stack| (|String|))) (|isDomain| *1 (|FortranOutputStackPackage|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *5 *6 *2))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Boolean|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|Any|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *3 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Record| (|:| |answer| *3) (|:| |polypart| *3))) (|isDomain| *1 (|TranscendentalIntegration| *5 *3))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)))) (|ofCategory| *5 (|FunctionSpace| *4)) (|isDomain| *2 (|Union| (|:| |overq| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))) (|:| |overan| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))) (|:| |failed| (|Boolean|)))) (|isDomain| *1 (|FunctionSpaceUnivariatePolynomialFactor| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|List| (|Fraction| (|Polynomial| (|Integer|))))) (|isDomain| *4 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|List| *5))) (|isDomain| *1 (|FloatingRealPackage| *5)) (|ofCategory| *5 (|Join| (|OrderedRing|) (|Field|))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|Integer|)))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FloatingRealPackage| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|)))))) 
+(((*1 *2 *3 *4 *5 *3) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Record| (|:| |ans| *6) (|:| |right| *6) (|:| |sol?| (|Boolean|))) (|Integer|) *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Union| (|Record| (|:| |answer| (|Fraction| *7)) (|:| |a0| *6)) (|Record| (|:| |ratpart| (|Fraction| *7)) (|:| |coeff| (|Fraction| *7))) "failed")) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *8 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegrate| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *6 *7 *8))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *4 *3 *5)) (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *3))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|EuclideanDomain|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|MultivariateSquareFree| *4 *5 *6 *3)) (|ofCategory| *3 (|PolynomialCategory| *6 *4 *5))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *5 (|List| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Vector| *4)) (|isDomain| *1 (|ODETools| *4 *3)) (|ofCategory| *3 (|LinearOrdinaryDifferentialOperatorCategory| *4))))) 
+(((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|Vector| *4)) (|isDomain| *3 (|SingleInteger|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *1 (|InnerNormalBasisFieldFunctions| *4))))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|))) ((*1 *1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|Collection| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| *4) (|:| |num| *4)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|FortranType|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|InfiniteTuple| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LieAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *3)))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModuleMonomial| *2 *3 *4)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *3)) (|Record| (|:| |index| *2) (|:| |exponent| *3)))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| *4)))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *3 *4)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|List| (|SplittingNode| *3 *5))) (|isDomain| *1 (|SplittingNode| *3 *5)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| *4) (|:| |tower| *5)))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|List| (|SplittingNode| *4 *5))) (|isDomain| *1 (|SplittingNode| *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |val| *3) (|:| |tower| *4))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingNode| *3 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *2 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|SplittingNode| *2 *3))) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *2 *3)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|SplittingTree| *2 *3))) (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|SuchThat| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |integrand| *3) (|:| |intvar| *3)))) (|isDomain| *1 (|IntegrationResult| *3)) (|ofCategory| *3 (|Field|))))) 
+(((*1 *2 *3 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |quotient| *3) (|:| |remainder| *3))) (|isDomain| *1 (|UnivariatePolynomialDivisionPackage| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2 *1 *1) (AND (|isDomain| *2 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|Heap| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PriorityQueueAggregate| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|SubSpace| *3 *4))) (|isDomain| *1 (|SubSpace| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|U32Vector|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| *3) (|:| |tower| *4)))) (|isDomain| *1 (|RegularTriangularSetGcdPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *2 (|Mapping| (|Point| *3) (|Point| *3))) (|isDomain| *1 (|CoordinateSystems| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|)))))) 
+(((*1 *2 *1) (|partial| AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|PolynomialCategory| *5 *4 *2)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|PolynomialCategoryQuotientFunctions| *4 *2 *5 *6 *3)) (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *6)) (SIGNATURE |numer| (*6 $)) (SIGNATURE |denom| (*6 $))))))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RationalFunction| *4))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|RandomFloatDistributions|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BalancedPAdicRational| *4)) (|ofType| *4 *3) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1 *2) (AND (|ofCategory| *1 (|PAdicIntegerCategory| *3)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1 *3) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|PAdicRational| *4)) (|ofType| *4 *3) (|isDomain| *3 (|Integer|)))) ((*1 *2 *1 *3) (AND (|ofType| *4 *3) (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|PAdicRationalConstructor| *4 *5)) (|isDomain| *3 (|Integer|)) (|ofCategory| *5 (|PAdicIntegerCategory| *4)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RealClosedField|)) (|isDomain| *2 (|Fraction| (|Integer|))))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *2 *3)) (|ofCategory| *2 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *2)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|UnivariatePowerSeriesCategory| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|has| *2 (SIGNATURE ** (*2 *2 *3))) (|has| *2 (SIGNATURE |coerce| (*2 (|Symbol|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Fraction| (|Integer|))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *5 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Equation| *3)) (|isDomain| *5 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|ExpressionToUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *6 (|Integer|))) (|isDomain| *4 (|Equation| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *5 *6)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *3)))) ((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|Mapping| *7 (|Integer|))) (|isDomain| *4 (|Equation| *7)) (|isDomain| *5 (|UniversalSegment| (|Integer|))) (|ofCategory| *7 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *6 *7)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *3)))) ((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *3 (|Mapping| *8 (|Fraction| (|Integer|)))) (|isDomain| *4 (|Equation| *8)) (|isDomain| *5 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *6 (|Fraction| (|Integer|))) (|ofCategory| *8 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *7))) (|ofCategory| *7 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *7 *8)))) ((*1 *2 *3 *4 *5 *6 *7) (AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|Equation| *3)) (|isDomain| *6 (|UniversalSegment| (|Fraction| (|Integer|)))) (|isDomain| *7 (|Fraction| (|Integer|))) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|GenerateUnivariatePowerSeries| *8 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|InnerTaylorSeries| *3)))) ((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Fraction| (|Integer|))) (|:| |c| *4)))) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|NonNegativeInteger|)) (|:| |c| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateTaylorSeriesCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|FunctionSpace| *4)) (|isDomain| *1 (|FunctionalSpecialFunction| *4 *2)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|IntervalCategory| *3)) (|ofCategory| *3 (|Join| (|FloatingPointSystem|) (|TranscendentalFunctionCategory|))) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|LinearOrdinaryDifferentialOperator1| *4)) (|ofCategory| *4 (|FunctionFieldCategory| *5 *6 *7)) (|ofCategory| *5 (|Join| (|Field|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *7 (|UnivariatePolynomialCategory| (|Fraction| *6))) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|PureAlgebraicLODE| *5 *6 *7 *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Record| (|:| |gcd| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef1| (|NewSparseUnivariatePolynomial| *3)) (|:| |coef2| (|NewSparseUnivariatePolynomial| *3)))) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |gcd| *1) (|:| |coef1| *1) (|:| |coef2| *1))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3) (AND (|ofCategory| *1 (|FiniteFieldCategory|)) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Table| (|PositiveInteger|) (|NonNegativeInteger|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|Library|))))) 
+(((*1 *2 *1 *2) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *2 *7 *8 *9 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *2 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Table| (|Symbol|) (|BasicStochasticDifferential|))) (|isDomain| *1 (|BasicStochasticDifferential|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Polynomial| *4))) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ParametricLinearEquations| *4 *5 *6 *7)) (|ofCategory| *7 (|PolynomialCategory| *4 *6 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *2 *10)) (|ofCategory| *3 (|Field|)) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|BlowUpMethodCategory|)) (|ofCategory| *2 (|DivisorCategory| *9))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *2 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|DirectProductCategory| *5 (|NonNegativeInteger|))) (|ofType| *5 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *3 *2 *4 *5)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *3 *4))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *4)) (|isDomain| *1 (|UnivariateTaylorSeriesODESolver| *4 *2)) (|ofCategory| *4 (|Algebra| (|Fraction| (|Integer|))))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FractionFreeFastGaussian| *4 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *4 *3))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *1 (|File| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|TextFile|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DisplayPackage|))))) 
+(((*1 *2 *2 *2 *2) (AND (|isDomain| *2 (|Fraction| (|SparseUnivariatePolynomial| (|Expression| *3)))) (|ofCategory| *3 (|Join| (|IntegralDomain|) (|OrderedSet|))) (|isDomain| *1 (|TransSolvePackageService| *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|RetractableTo| (|Integer|))) (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|IntegerNumberSystem|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|Complex| (|DoubleFloat|)))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|OpenMathErrorKind|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|NumberFormats|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Mapping| (|Stream| (|Polynomial| *4)) (|Stream| (|Polynomial| *4)))) (|isDomain| *1 (|WeierstrassPreparation| *4)) (|ofCategory| *4 (|Field|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Matrix| *5))) (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RepresentationPackage2| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Matrix| *4))) (|ofCategory| *4 (|Field|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|RepresentationPackage2| *4))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PackageForPoly| *4 *2 *5 *6)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *2 (|Record| (|:| |Hermite| *3) (|:| |eqMat| *3))) (|isDomain| *1 (|SmithNormalForm| *4 *5 *6 *3)) (|ofCategory| *3 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *1 *1 *1 *2 *3) (AND (|isDomain| *2 (|Point| *5)) (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)) (|isDomain| *1 (|SubSpace| *4 *5)) (|ofType| *4 (|PositiveInteger|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|DequeueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|FiniteLinearAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3)))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OctonionCategory| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|IntegerNumberTheoryFunctions|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *3 (|PolynomialCategory| *4 *6 (|OrderedVariableList| *5))) (|ofCategory| *6 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *9 (|PlacesCategory| *4 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *4 *5 *3 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|DesingTreePackage| *4 *5 *3 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *12)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|DesingTree| (|InfClsPt| *3 *4 *5)))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|PolynomialCategory| *3 *5 (|OrderedVariableList| *4))) (|ofCategory| *5 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *6 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *7 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *8 (|PlacesCategory| *3 *7)) (|ofCategory| *9 (|DivisorCategory| *8)) (|ofCategory| *10 (|InfinitlyClosePointCategory| *3 *4 *2 *5 *6 *7 *8 *9 *12)) (|ofCategory| *12 (|BlowUpMethodCategory|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *2 *5 *6 *7 *8 *9 *10 *11 *12)) (|ofCategory| *11 (|DesingTreeCategory| *10)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|DistributedMultivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatchResult| *4 *5)) (|ofCategory| *5 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternFunctions1| *5 *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|isDomain| *4 (|Pattern| *5)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternFunctions1| *5 *6))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |lcmfij| *3) (|:| |totdeg| (|NonNegativeInteger|)) (|:| |poli| *6) (|:| |polj| *6)))) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|PolynomialCategory| *4 *3 *5)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GroebnerInternalPackage| *4 *3 *5 *6))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Tree| *3))) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|ofCategory| *2 (|Field|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *2 *3 *4 *5)) (|ofCategory| *5 (|PolynomialCategory| *2 *3 *4))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Point| *3)) (|ofCategory| *3 (|Join| (|Field|) (|TranscendentalFunctionCategory|) (|RadicalCategory|))) (|isDomain| *1 (|CoordinateSystems| *3))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|List| (|List| *7))) (|isDomain| *1 (|GroebnerFactorizationPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|ofCategory| *5 (|Join| (|EuclideanDomain|) (|CharacteristicZero|))) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|List| *8))) (|isDomain| *1 (|GroebnerFactorizationPackage| *5 *6 *7 *8)) (|isDomain| *3 (|List| *8))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|FramedNonAssociativeAlgebra&| *3 *2)) (|ofCategory| *3 (|FramedNonAssociativeAlgebra| *2)))) ((*1 *2) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|))))) 
+(((*1 *1 *1) (|isDomain| *1 (|DoubleFloat|))) ((*1 *1 *1) (|isDomain| *1 (|Float|))) ((*1 *1) (|isDomain| *1 (|Float|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *5 (|FunctionSpace| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|AlgebraicFunction| *4 *5))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Mapping| *5 *4 *4)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Mapping| *5 *4)) (|isDomain| *1 (|MappingPackage2| *4 *5))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Fraction| (|Integer|))) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|ElementaryFunctionStructurePackage| *4 *2)) (|ofCategory| *2 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4)))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| *1 (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *1 (|HomogeneousAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|has| $ (ATTRIBUTE |finiteAggregate|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4))))) 
+(((*1 *2 *3 *4 *4 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|PureAlgebraicIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *3) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *4 (|PrimitiveArray| (|DoubleFloat|))) (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|BlasLevelOne|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|ofCategory| *4 (|Join| (|GcdDomain|) (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DefiniteIntegrationTools| *4 *5)) (|ofCategory| *5 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
+(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Float|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |stiffness| (|Float|)) (|:| |stability| (|Float|)) (|:| |expense| (|Float|)) (|:| |accuracy| (|Float|)) (|:| |intermediateResults| (|Float|)))) (|isDomain| *2 (|Result|)) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *4 (|Factored| *2)) (|ofCategory| *2 (|PolynomialCategory| *7 *5 *6)) (|isDomain| *1 (|MultivariateSquareFree| *5 *6 *7 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|EuclideanDomain|))))) 
 (((*1 *1 *2 *1) (AND (|isDomain| *2 (|Switch|)) (|isDomain| *1 (|FortranCode|))))) 
-(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|Integer|) (|Integer|))) (|isDomain| *1 (|FreeGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| (|NonNegativeInteger|) (|NonNegativeInteger|))) (|isDomain| *1 (|FreeMonoid| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|Mapping| *4 *4)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4) (|isDomain| *1 (|ListMonoidOps| *3 *4 *5)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1 *2 *3) (|partial| AND (|isDomain| *2 (|String|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|RoutinesTable|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|GcdDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|SymbolTable|)) (|isDomain| *1 (|TheSymbolTable|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|ContinuedFraction| *2)) (|ofCategory| *2 (|EuclideanDomain|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SymmetricPolynomial| (|Fraction| (|Integer|)))) (|isDomain| *1 (|CycleIndicators|)) (|isDomain| *3 (|Integer|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|LazyStreamAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *1) (|ofCategory| *1 (|PAdicIntegerCategory| *2))) ((*1 *1 *1) (AND (|ofCategory| *1 (|PowerSeriesCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *4 (|OrderedSet|))))) 
+(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|List| (|Record| (|:| |val| (|Boolean|)) (|:| |tower| *4)))) (|isDomain| *1 (|NormalizationPackage| *5 *6 *7 *3 *4)) (|ofCategory| *4 (|RegularTriangularSetCategory| *5 *6 *7 *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *3 *4 *3 *5 *5) (AND (|isDomain| *3 (|SingleInteger|)) (|isDomain| *5 (|DoubleFloat|)) (|isDomain| *2 (|List| (|PrimitiveArray| *5))) (|isDomain| *1 (|BlasLevelOne|)) (|isDomain| *4 (|PrimitiveArray| *5))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| *6 *5)) (|isDomain| *4 (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *5)) (|ofCategory| *5 (|FiniteFieldCategory|)) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|DistributedMultivariatePolynomial| *6 (|PseudoAlgebraicClosureOfFiniteField| *5))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *5 *6 *7)) (|ofCategory| *7 (|BlowUpMethodCategory|)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *4 (|Integer|)) (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|DirectProductCategory| *7 (|NonNegativeInteger|))) (|ofType| *7 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *5 *2 *6 *7 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *5 *6)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *5)))) ((*1 *2 *2 *3) (AND (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *1 (|PolynomialPackageForCurve| *4 *2 *5 *6 *3)) (|ofCategory| *2 (|FiniteAbelianMonoidRing| *4 *5)) (|ofCategory| *3 (|ProjectiveSpaceCategory| *4))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *1 *2 *3 *1) (AND (|isDomain| *2 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *3 (|Polynomial| (|Integer|))) (|isDomain| *1 (|FortranCode|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|SegmentBinding| (|Polynomial| (|Integer|)))) (|isDomain| *1 (|FortranCode|))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|RealClosedField|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|Boolean|))) ((*1 *1 *1 *1) (|ofCategory| *1 (|BitAggregate|))) ((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *1 *1) (|isDomain| *1 (|InputForm|)))) 
+(((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|MyUnivariatePolynomial| *4 *3)) (|ofType| *4 (|Symbol|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|NewSparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *1 (|PolynomialRing| *3 *2)) (|ofCategory| *2 (|CancellationAbelianMonoid|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedAbelianMonoid|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|Partition|)) (|ofCategory| *2 (|CancellationAbelianMonoid|)) (|isDomain| *1 (|SymmetricPolynomial| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *1 *2 *3 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|UnivariatePolynomial| *4 *3)) (|ofType| *4 (|Symbol|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *2 *3 *3 *4 *4) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Segment| (|Fraction| (|Integer|)))) (|isDomain| *1 (|PlaneAlgebraicCurvePlot|))))) 
+(((*1 *2 *3 *3 *4 *4) (|partial| AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|ContinuedFraction| *6)) (|isDomain| *1 (|PadeApproximants| *5 *4 *6)) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *5)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicStochasticDifferential|)))) ((*1 *2 *3) (AND (|ofCategory| *5 (|Join| (|ConvertibleTo| *2) (|CommutativeRing|))) (|isDomain| *2 (|Pattern| *4)) (|isDomain| *1 (|ComplexPattern| *4 *5 *3)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *3 (|ComplexCategory| *5)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Segment| (|OrderedCompletion| (|Float|))))) (|isDomain| *2 (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DoubleFloat|)) (|isDomain| *1 (|Float|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedAlgebra| *3 *4)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|isDomain| *2 (|Vector| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Vector| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Factored| *1)) (|ofCategory| *1 (|FunctionSpace| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|GeneralPolynomialSet| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|InputForm|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ConvertibleTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Pattern| *3))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|PointCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|RomanNumeral|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *1 *2) (OR (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|not| (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Algebra| (|Integer|))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))) (AND (|isDomain| *2 (|Polynomial| (|Integer|))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Fraction| (|Integer|)))) (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *5 (|ConvertibleTo| (|Symbol|))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|RegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|RegularSetDecompositionPackage| *4 *5 *6 *7 *8)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|SingletonAsOrderedSet|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *2)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *2 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *2 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *2 *4 *5 *6)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *1)) (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |val| (|List| *7)) (|:| |tower| *8))) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *8 (|SquareFreeRegularTriangularSetCategory| *4 *5 *6 *7)) (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|SquareFreeRegularSetDecompositionPackage| *4 *5 *6 *7 *8)))) ((*1 *1 *2 *3 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *5))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *5 (|List| (|Symbol|))) (|isDomain| *2 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|Polynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|Polynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|RealClosure| (|Fraction| *4)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|List| (|Symbol|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|SquareFreeRegularTriangularSet| *4 (|IndexedExponents| (|OrderedVariableList| *6)) (|OrderedVariableList| *6) (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6)))) (|ofCategory| *4 (|Join| (|OrderedRing|) (|EuclideanDomain|) (|CharacteristicZero|) (|RealConstant|))) (|ofType| *6 (|List| (|Symbol|))) (|isDomain| *2 (|List| (|NewSparseMultivariatePolynomial| *4 (|OrderedVariableList| *6)))) (|isDomain| *1 (|ZeroDimensionalSolvePackage| *4 *5 *6)) (|ofType| *5 (|List| (|Symbol|)))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|MergeThing| *3))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4 *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *1 (|FiniteLinearAggregateSort| *4 *2)) (|ofCategory| *2 (|Join| (|FiniteLinearAggregate| *4) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|))))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)) (|isDomain| *2 (|Record| (|:| |quotient| *1) (|:| |remainder| *1))) (|ofCategory| *1 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3 *4 *3) (|partial| AND (|isDomain| *4 (|Symbol|)) (|ofCategory| *5 (|Join| (|IntegralDomain|) (|RetractableTo| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Record| (|:| |ratpart| (|Fraction| (|Polynomial| *5))) (|:| |coeff| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|RationalFunctionIntegration| *5)) (|isDomain| *3 (|Fraction| (|Polynomial| *5)))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Set| (|Symbol|))) (|isDomain| *1 (|ApplicationProgramInterface|)) (|isDomain| *3 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|DistributedMultivariatePolynomial| (|construct| (QUOTE X) (QUOTE Y)) *4)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|isDomain| *2 (|List| (|List| (|NonNegativeInteger|)))) (|isDomain| *1 (|BlowUpPackage| *4 *5 *6 *7 *8)) (|ofCategory| *6 (|FiniteAbelianMonoidRing| *4 *7)) (|ofCategory| *8 (|BlowUpMethodCategory|))))) 
+(((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Record| (|:| |bas| (|GeneralTriangularSet| *4 *5 *6 *7)) (|:| |top| (|List| *7)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *4 *5 *6 *7)) (|isDomain| *3 (|List| *7))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|)))) ((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|Float|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|FileCategory| *3 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|Void|))))) 
+(((*1 *1 *2) (|partial| AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *3 *4 *5 *6)))) ((*1 *1 *2 *3 *4) (|partial| AND (|isDomain| *2 (|List| *8)) (|isDomain| *3 (|Mapping| (|Boolean|) *8 *8)) (|isDomain| *4 (|Mapping| *8 *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *1 (|WuWenTsunTriangularSet| *5 *6 *7 *8))))) 
+(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *4 *3 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *3)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|DifferentialPolynomialCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|DifferentialVariableCategory| *4)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|List| (|NonNegativeInteger|)))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |coef2| *3) (|:| |gcd| *3))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|FiniteFieldPolynomialPackage| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Mapping| (|Boolean|) *9)) (|isDomain| *5 (|Mapping| (|Boolean|) *9 *9)) (|ofCategory| *9 (|RecursivePolynomialCategory| *6 *7 *8)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |bas| *1) (|:| |top| (|List| *9)))) (|isDomain| *3 (|List| *9)) (|ofCategory| *1 (|TriangularSetCategory| *6 *7 *8 *9)))) ((*1 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Boolean|) *8 *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |bas| *1) (|:| |top| (|List| *8)))) (|isDomain| *3 (|List| *8)) (|ofCategory| *1 (|TriangularSetCategory| *5 *6 *7 *8))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Queue| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|TubePlot| *3)) (|ofCategory| *3 (|PlottableSpaceCurveCategory|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
 (((*1 *2 *3) (AND (|isDomain| *3 (|Point| *2)) (|isDomain| *1 (|PointPackage| *2)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *2 (|List| *5)) (|isDomain| *1 (|PatternFunctions1| *4 *5)) (|ofCategory| *5 (|Type|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *1 (|AlgebraicManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|Field|) (|ExpressionSpace|) (CATEGORY |domain| (SIGNATURE |numer| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |denom| ((|SparseMultivariatePolynomial| *3 (|Kernel| $)) $)) (SIGNATURE |coerce| ($ (|SparseMultivariatePolynomial| *3 (|Kernel| $)))))))))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *5 (|EuclideanDomain|)) (|ofCategory| *6 (|FiniteLinearAggregate| *5)) (|ofCategory| *4 (|FiniteLinearAggregate| *5)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| *4 "failed")) (|:| |basis| (|List| *4)))) (|isDomain| *1 (|SmithNormalForm| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *1 (|HeuGcd| *3))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot3D|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Segment| (|DoubleFloat|))) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Vector| *1)) (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *4)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FramedNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Matrix| *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OutputForm|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Segment| *3)) (|isDomain| *1 (|SegmentBinding| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2 *2) (AND (|ofCategory| *1 (|SegmentCategory| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|UniversalSegment| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|PositiveInteger|))) (|isDomain| *1 (|SetOfMIntegersInOneToN| *3 *4)) (|ofType| *3 (|PositiveInteger|)) (|ofType| *4 (|PositiveInteger|))))) 
-(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |op| (|BasicOperator|)) (|:| |arg| (|List| (|Pattern| *3))))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|List| (|Pattern| *4))) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
-(((*1 *2 *2 *3 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|LaplaceTransform| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PlottablePlaneCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|PlottableSpaceCurveCategory|)) (|isDomain| *2 (|Segment| (|DoubleFloat|)))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|IntegerNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|ofCategory| *6 (|Join| (|AlgebraicallyClosedField|) (|FunctionSpace| *5))) (|ofCategory| *5 (|Join| (|OrderedSet|) (|IntegralDomain|) (|RetractableTo| (|Integer|)))) (|ofCategory| *8 (|UnivariatePolynomialCategory| (|Fraction| *7))) (|isDomain| *2 (|IntegrationResult| *3)) (|isDomain| *1 (|AlgebraicIntegrate| *5 *6 *7 *8 *3)) (|ofCategory| *3 (|FunctionFieldCategory| *6 *7 *8))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|AttributeButtons|))))) 
-(((*1 *2 *3 *4 *2) (AND (|isDomain| *3 (|Mapping| *2 *2)) (|isDomain| *4 (|NonNegativeInteger|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|MappingPackageInternalHacks1| *2))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|EuclideanDomain|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|CharacteristicZero|))) (|isDomain| *2 (|Mapping| *5 *5)) (|isDomain| *1 (|ODEIntegration| *4 *5)) (|ofCategory| *5 (|Join| (|AlgebraicallyClosedFunctionSpace| *4) (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|ExponentialOfUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Join| (|Field|) (|OrderedSet|))) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *3 *4 *5 *6 *7)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|)) (|ofCategory| *7 (|SetCategory|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|PositiveInteger|) "arbitrary")) (|isDomain| *1 (|GuessOption|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *2) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *6 (|UnivariatePolynomialCategory| (|Fraction| *5))) (|isDomain| *2 (|List| (|List| *4))) (|isDomain| *1 (|FunctionFieldCategory&| *3 *4 *5 *6)) (|ofCategory| *3 (|FunctionFieldCategory| *4 *5 *6)))) ((*1 *2) (AND (|ofCategory| *1 (|FunctionFieldCategory| *3 *4 *5)) (|ofCategory| *3 (|UniqueFactorizationDomain|)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *5 (|UnivariatePolynomialCategory| (|Fraction| *4))) (|ofCategory| *3 (|Finite|)) (|isDomain| *2 (|List| (|List| *3))))) ((*1 *2) (AND (|ofCategory| *3 (|Finite|)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|PolynomialCategory| *3 *6 (|OrderedVariableList| *4))) (|ofCategory| *6 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofCategory| *7 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *8 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *9 (|PlacesCategory| *3 *8)) (|ofCategory| *10 (|DivisorCategory| *9)) (|ofCategory| *11 (|InfinitlyClosePointCategory| *3 *4 *5 *6 *7 *8 *9 *10 *13)) (|ofCategory| *13 (|BlowUpMethodCategory|)) (|isDomain| *2 (|List| *7)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *3 *4 *5 *6 *7 *8 *9 *10 *11 *12 *13)) (|ofCategory| *12 (|DesingTreeCategory| *11)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *3 *4 *5)) (|ofCategory| *3 (|FiniteFieldCategory|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|List| (|ProjectivePlane| *3))) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|Field|)) (|ofType| *6 (|List| (|Symbol|))) (|ofCategory| *7 (|DirectProductCategory| (|#| *6) (|NonNegativeInteger|))) (|isDomain| *2 (|List| *8)) (|isDomain| *1 (|ProjectiveAlgebraicSetPackage| *5 *6 *3 *7 *8)) (|ofCategory| *3 (|PolynomialCategory| *5 *7 (|OrderedVariableList| *6))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *5))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|IntegralDomain|)))) 
-(((*1 *2 *3 *4) (AND (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|List| (|Stream| *4))) (|isDomain| *1 (|EllipticFunctionsUnivariateTaylorSeries| *4 *5)) (|isDomain| *3 (|Stream| *4)) (|ofCategory| *5 (|UnivariateTaylorSeriesCategory| *4))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Character|))))) 
-(((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Matrix| *5)) (|isDomain| *4 (|Vector| *5)) (|ofCategory| *5 (|Field|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearSystemMatrixPackage1| *5)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|Field|)) (|ofCategory| *6 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|ofCategory| *4 (|Join| (|FiniteLinearAggregate| *5) (CATEGORY |package| (ATTRIBUTE |shallowlyMutable|)))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|LinearSystemMatrixPackage| *5 *6 *4 *3)) (|ofCategory| *3 (|MatrixCategory| *5 *6 *4))))) 
-(((*1 *2 *1 *3 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4))))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|UnivariateLaurentSeriesCategory| *4)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Fraction| (|Polynomial| *4)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *2)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|)))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *3 *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *7)))) ((*1 *2 *2 *3 *3) (AND (|isDomain| *2 (|List| *7)) (|isDomain| *3 (|String|)) (|ofCategory| *7 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *7))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|))))) 
-(((*1 *2 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Kernel| *6))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Kernel| *6)) (|ofCategory| *6 (|FunctionSpace| *5)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|IntegrationTools| *5 *6))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *3 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *2 (|GcdDomain|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *2)) (|ofCategory| *2 (|PolynomialCategory| (|Fraction| (|Polynomial| *6)) *5 *4)) (|isDomain| *1 (|MPolyCatRationalFunctionFactorizer| *5 *4 *6 *2)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *4 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |convert| ((|Symbol|) $))))) (|ofCategory| *6 (|IntegralDomain|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Join| (|GcdDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|BalancedFactorisation| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|GcdDomain|) (|CharacteristicZero|))) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|BalancedFactorisation| *5 *3))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *1 (|Collection| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |exponent| (|NonNegativeInteger|)) (|:| |center| *4) (|:| |num| *4)))) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Join| (|Field|) (|CharacteristicZero|))) (|isDomain| *1 (|FullPartialFractionExpansion| *3 *4)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *3 (|List| (|Polynomial| (|Integer|)))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|FortranType|)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *2 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|InfiniteTuple| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|LieAlgebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *1) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2 *2) (AND (|isDomain| *2 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|LiePolynomial| *3 *4)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|List| *3)))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|ModuleMonomial| *2 *3 *4)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 (|Mapping| (|Boolean|) (|Record| (|:| |index| *2) (|:| |exponent| *3)) (|Record| (|:| |index| *2) (|:| |exponent| *3)))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |key| (|Symbol|)) (|:| |entry| *4)))) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|PatternMatchResult| *3 *4)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *5)) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|List| (|SplittingNode| *3 *5))) (|isDomain| *1 (|SplittingNode| *3 *5)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Record| (|:| |val| *4) (|:| |tower| *5)))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *5 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *2 (|List| (|SplittingNode| *4 *5))) (|isDomain| *1 (|SplittingNode| *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |val| *3) (|:| |tower| *4))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingNode| *3 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *1 (|SplittingNode| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *2 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|SplittingNode| *2 *3))) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *2 *3)))) ((*1 *1 *2 *3 *4) (AND (|isDomain| *4 (|List| (|SplittingTree| *2 *3))) (|isDomain| *1 (|SplittingTree| *2 *3)) (|ofCategory| *2 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|SplittingNode| *3 *4)) (|ofCategory| *3 (|Join| (|SetCategory|) (|Aggregate|))) (|ofCategory| *4 (|Join| (|SetCategory|) (|Aggregate|))) (|isDomain| *1 (|SplittingTree| *3 *4)))) ((*1 *1 *2 *3) (AND (|isDomain| *1 (|SuchThat| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| *3)))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|Vector| (|Matrix| *3)))))) 
+(((*1 *1 *1) (|isDomain| *1 (|RoutinesTable|)))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|)))) ((*1 *2) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|Reference| (|OrderedCompletion| (|Integer|)))) (|isDomain| *3 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *4)))) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *4))))) 
+(((*1 *2 *1 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Tree| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|IntegralDomain|)) (|isDomain| *2 (|Record| (|:| |coef1| *3) (|:| |resultant| *4))) (|isDomain| *1 (|PseudoRemainderSequence| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *1)) (|ofCategory| *1 (|RecursivePolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *1) (AND (|ofCategory| *1 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *4 *5 *6 *3)) (|ofCategory| *4 (|IntegralDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *3 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|)))) 
+(((*1 *2 *3 *4 *5 *6) (AND (|isDomain| *4 (|Boolean|)) (|isDomain| *5 (|Set| (|NonNegativeInteger|))) (|isDomain| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|Record| (|:| |contp| (|Integer|)) (|:| |factors| (|List| (|Record| (|:| |irr| *3) (|:| |pow| (|Integer|))))))) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Record| (|:| |low| (|List| *3)) (|:| |high| (|List| *3)))) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|isDomain| *3 (|Mapping| (|Boolean|) *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *4 *5)))) ((*1 *2 *2 *3) (AND (|isDomain| *2 (|Pattern| *4)) (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *4 *5)))) ((*1 *2 *2 *3 *4) (AND (|isDomain| *2 (|Pattern| *5)) (|isDomain| *3 (|List| (|Symbol|))) (|isDomain| *4 (|Mapping| (|Boolean|) (|List| *6))) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Type|)) (|isDomain| *1 (|PatternFunctions1| *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *5)) (|ofCategory| *5 (|Type|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAttachPredicates| *4 *2 *5)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *5 (|Type|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpaceAttachPredicates| *4 *2 *5)) (|ofCategory| *2 (|FunctionSpace| *4)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|Mapping| (|Boolean|) *5)) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|AttachPredicates| *5)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *4 (|List| (|Mapping| (|Boolean|) *5))) (|ofCategory| *5 (|Type|)) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|AttachPredicates| *5)))) ((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|List| (|Symbol|))) (|isDomain| *3 (|Mapping| (|Boolean|) (|List| *6))) (|ofCategory| *6 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|RewriteRule| *4 *5 *6))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *5 (|DirectProductCategory| *6 (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PackageForPoly| *3 *4 *5 *6)) (|ofCategory| *4 (|FiniteAbelianMonoidRing| *3 *5))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|PolynomialCategory| *4 *7 (|OrderedVariableList| *5))) (|ofCategory| *7 (|DirectProductCategory| (|#| *5) (|NonNegativeInteger|))) (|ofCategory| *8 (|ProjectiveSpaceCategory| *4)) (|ofCategory| *9 (|LocalPowerSeriesCategory| *4)) (|ofCategory| *10 (|PlacesCategory| *4 *9)) (|ofCategory| *11 (|DivisorCategory| *10)) (|ofCategory| *12 (|InfinitlyClosePointCategory| *4 *5 *6 *7 *8 *9 *10 *11 *14)) (|ofCategory| *14 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|GeneralPackageForAlgebraicFunctionField| *4 *5 *6 *7 *8 *9 *10 *11 *12 *13 *14)) (|ofCategory| *13 (|DesingTreeCategory| *12)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionFieldOverFiniteField| *4 *5 *6)) (|ofCategory| (|PseudoAlgebraicClosureOfFiniteField| *4) (|Finite|)) (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|)))) ((*1 *2 *3 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|PackageForAlgebraicFunctionField| *4 *5 *6)) (|ofCategory| *4 (|Finite|)) (|ofCategory| *4 (|Field|)) (|ofType| *5 (|List| (|Symbol|))) (|ofCategory| *6 (|BlowUpMethodCategory|))))) 
+(((*1 *2 *3 *3 *3) (|partial| AND (|ofCategory| *4 (|Join| (|CharacteristicZero|) (|AlgebraicallyClosedField|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| *5))) (|isDomain| *1 (|Kovacic| *4 *5)) (|isDomain| *3 (|Fraction| *5)))) ((*1 *2 *3 *3 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| (|Factored| *6) *6)) (|ofCategory| *6 (|UnivariatePolynomialCategory| *5)) (|ofCategory| *5 (|Join| (|CharacteristicZero|) (|AlgebraicallyClosedField|) (|RetractableTo| (|Integer|)) (|RetractableTo| (|Fraction| (|Integer|))))) (|isDomain| *2 (|SparseUnivariatePolynomial| (|Fraction| *6))) (|isDomain| *1 (|Kovacic| *5 *6)) (|isDomain| *3 (|Fraction| *6))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *3 (|List| (|RewriteRule| *4 *5 *2))) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|Join| (|Ring|) (|PatternMatchable| *4) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *4)))) (|ofCategory| *2 (|Join| (|FunctionSpace| *5) (|PatternMatchable| *4) (|ConvertibleTo| (|Pattern| *4)))) (|isDomain| *1 (|ApplyRules| *4 *5 *2)))) ((*1 *2 *3 *2 *4) (AND (|isDomain| *3 (|List| (|RewriteRule| *5 *6 *2))) (|isDomain| *4 (|PositiveInteger|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|Join| (|Ring|) (|PatternMatchable| *5) (|OrderedSet|) (|ConvertibleTo| (|Pattern| *5)))) (|ofCategory| *2 (|Join| (|FunctionSpace| *6) (|PatternMatchable| *5) (|ConvertibleTo| (|Pattern| *5)))) (|isDomain| *1 (|ApplyRules| *5 *6 *2))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ScriptFormulaFormat|))))) 
 (((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|FreeAbelianMonoidCategory| *2 *4)) (|ofCategory| *4 (|CancellationAbelianMonoid|)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|FreeGroup| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|FreeMonoid| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *2 (|SetCategory|)) (|isDomain| *1 (|ListMonoidOps| *2 *4 *5)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 *4))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|DoubleFloat|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|List| *5)) (|ofCategory| *1 (|PlacesCategory| *4 *5)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|LocalPowerSeriesCategory| *4)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Color|))))) 
-(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|CharacteristicZero|)) (|ofCategory| *3 (|EuclideanDomain|)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *3 *4 *5 *6))))) 
-(((*1 *2 *3 *4 *4 *4 *5 *6 *7) (|partial| AND (|isDomain| *5 (|Symbol|)) (|isDomain| *6 (|Mapping| (|Union| (|Record| (|:| |mainpart| *4) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *4) (|:| |logand| *4))))) "failed") *4 (|List| *4))) (|isDomain| *7 (|Mapping| (|Union| (|Record| (|:| |ratpart| *4) (|:| |coeff| *4)) "failed") *4 *4)) (|ofCategory| *4 (|Join| (|TranscendentalFunctionCategory|) (|AlgebraicallyClosedField|) (|FunctionSpace| *8))) (|ofCategory| *8 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| *3) (|LinearlyExplicitRingOver| *3))) (|isDomain| *3 (|Integer|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|ElementaryRischDESystem| *8 *4))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|TwoDimensionalArrayCategory| *4 *2 *5)) (|ofCategory| *4 (|Type|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *2 (|FiniteLinearAggregate| *4)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|RectangularMatrixCategory| *4 *5 *6 *2 *7)) (|ofCategory| *6 (|Ring|)) (|ofCategory| *7 (|DirectProductCategory| *4 *6)) (|ofCategory| *2 (|DirectProductCategory| *5 *6))))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|QuasiComponentPackage| *5 *6 *7 *8 *3)))) ((*1 *2 *3 *3) (AND (|ofCategory| *4 (|GcdDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|ofCategory| *7 (|RecursivePolynomialCategory| *4 *5 *6)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *4 *5 *6 *7 *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *4 *5 *6 *7)))) ((*1 *2 *3 *4) (AND (|isDomain| *4 (|List| *3)) (|ofCategory| *3 (|RegularTriangularSetCategory| *5 *6 *7 *8)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|SquareFreeQuasiComponentPackage| *5 *6 *7 *8 *3))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TriangularSetCategory| *3 *4 *5 *6)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *6 (|RecursivePolynomialCategory| *3 *4 *5)) (|isDomain| *2 (|List| *5))))) 
+(((*1 *2 *1 *1) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|Record| (|:| |coef1| *1) (|:| |coef2| *1) (|:| |generator| *1))) (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *3))))) 
+(((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|List| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |mainpart| *3) (|:| |limitedlogs| (|List| (|Record| (|:| |coeff| *3) (|:| |logand| *3)))))) (|isDomain| *1 (|ElementaryIntegration| *6 *3))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
+(((*1 *2 *3 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *1 (|DrawOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *2 *1) (AND (|isDomain| *1 (|ArrayStack| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Dequeue| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *2 *1) (AND (|ofCategory| *1 (|StackAggregate| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *2 *1) (AND (|isDomain| *1 (|Stack| *2)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1 *3) (AND (|ofCategory| *1 (|Aggregate|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ArrayStack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Dequeue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Heap| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Queue| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Stack| *4)) (|ofCategory| *4 (|SetCategory|)))) ((*1 *2 *3 *3) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *3 *4) (AND (|isDomain| *4 (|Mapping| (|Boolean|) *3 *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|UserDefinedPartialOrdering| *3))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| (|Symbol|)) (|:| |c| (|XPolynomial| *3))))) (|isDomain| *1 (|XPolynomial| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Record| (|:| |k| *3) (|:| |c| (|XRecursivePolynomial| *3 *4))))) (|isDomain| *1 (|XRecursivePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Ring|))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Kernel| *4)) (|ofCategory| *4 (|OrderedSet|)))) ((*1 *2 *3 *4) (AND (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatch| *5 *3 *4)) (|ofCategory| *3 (|PatternMatchable| *5)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5))))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *6)) (|ofCategory| *6 (|PatternMatchable| *5)) (|ofCategory| *5 (|SetCategory|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|PatternMatch| *5 *6 *4)) (|ofCategory| *4 (|ConvertibleTo| (|Pattern| *5)))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|BasicOperator|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|CombinatorialFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|CommonOperators|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|ExpressionSpace&| *3)) (|ofCategory| *3 (|ExpressionSpace|)))) ((*1 *2 *2) (AND (|ofCategory| *1 (|ExpressionSpace|)) (|isDomain| *2 (|BasicOperator|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|FunctionSpace&| *3 *4)) (|ofCategory| *3 (|FunctionSpace| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|FunctionalSpecialFunction| *3 *4)) (|ofCategory| *4 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|BasicOperator|)) (|isDomain| *1 (|Kernel| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|BasicOperator|)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|LiouvillianFunction| *3 *4)) (|ofCategory| *4 (|Join| (|FunctionSpace| *3) (|RadicalCategory|) (|TranscendentalFunctionCategory|)))))) 
+(((*1 *1 *2 *3 *1) (AND (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *2 (|CommutativeRing|)) (|ofCategory| *3 (|DirectProductCategory| (|#| *4) (|NonNegativeInteger|))) (|ofType| *6 (|Mapping| (|Boolean|) (|Record| (|:| |index| *5) (|:| |exponent| *3)) (|Record| (|:| |index| *5) (|:| |exponent| *3)))) (|isDomain| *1 (|GeneralModulePolynomial| *4 *2 *5 *3 *6 *7)) (|ofCategory| *5 (|OrderedSet|)) (|ofCategory| *7 (|PolynomialCategory| *2 *3 (|OrderedVariableList| *4)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|Union| (|SparseUnivariatePolynomial| *4) (|Vector| (|List| (|Record| (|:| |value| *4) (|:| |index| (|SingleInteger|))))))) (|isDomain| *1 (|FiniteFieldFunctions| *4)) (|ofCategory| *4 (|FiniteFieldCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|SingleInteger|)) (|isDomain| *1 (|BinaryFile|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|CachableSet|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *3 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|FiniteLinearAggregate| *3)) (|ofCategory| *3 (|Type|)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3 *1) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *4)) (|ofCategory| *1 (|FiniteLinearAggregate| *4)) (|ofCategory| *4 (|Type|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Integer|)) (|isDomain| *3 (|CharacterClass|)))) ((*1 *2 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Integer|))))) 
+(((*1 *2 *2 *3 *3) (|partial| AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|EuclideanDomain|) (|OrderedSet|) (|CharacteristicZero|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *1 (|InverseLaplaceTransform| *4 *2)) (|ofCategory| *2 (|Join| (|TranscendentalFunctionCategory|) (|PrimitiveFunctionCategory|) (|SpecialFunctionCategory|) (|AlgebraicallyClosedFunctionSpace| *4)))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *2 *1) (|partial| AND (|isDomain| *2 (|BasicStochasticDifferential|)) (|isDomain| *1 (|StochasticDifferential| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|DrawOption|))) (|isDomain| *4 (|Symbol|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|DrawOption|))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|List| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Union| (|Fraction| (|Polynomial| *5)) (|SuchThat| (|Symbol|) (|Polynomial| *5)))) (|ofCategory| *5 (|GcdDomain|)) (|isDomain| *2 (|List| (|Matrix| (|Fraction| (|Polynomial| *5))))) (|isDomain| *1 (|EigenPackage| *5)) (|isDomain| *4 (|Matrix| (|Fraction| (|Polynomial| *5))))))) 
+(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|IntegerFactorizationPackage| *3)) (|ofCategory| *3 (|IntegerNumberSystem|))))) 
+(((*1 *1 *1) (|ofCategory| *1 (|ArcHyperbolicFunctionCategory|))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateTaylorSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariateLaurentSeries| *3 *4 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesConstructorCategory| *3 *4)))) ((*1 *2 *2) (AND (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *4 (|UnivariateLaurentSeriesCategory| *3)) (|isDomain| *1 (|ElementaryFunctionsUnivariatePuiseuxSeries| *3 *4 *2 *5)) (|ofCategory| *2 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *4)) (|ofCategory| *5 (|PartialTranscendentalFunctions| *4)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctionsNonCommutative| *3)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Algebra| (|Fraction| (|Integer|)))) (|isDomain| *1 (|StreamTranscendentalFunctions| *3))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|FortranScalarType|)) (|isDomain| *2 (|List| (|Union| (|:| |name| (|Symbol|)) (|:| |bounds| (|List| (|Union| (|:| S (|Symbol|)) (|:| P (|Polynomial| (|Integer|))))))))) (|isDomain| *1 (|SymbolTable|))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| *8)) (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *8 (|PolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|isDomain| *2 (|Record| (|:| |particular| (|Union| (|Vector| (|Fraction| *8)) "failed")) (|:| |basis| (|List| (|Vector| (|Fraction| *8)))))) (|isDomain| *1 (|LinearSystemPolynomialPackage| *5 *6 *7 *8))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|)))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|CardinalNumber|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))) (|isDomain| *1 (|TwoFactorize| *4)) (|isDomain| *3 (|SparseUnivariatePolynomial| (|SparseUnivariatePolynomial| *4)))))) 
+(((*1 *2 *3 *1) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|List| *1)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *4)) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |zeros| (|List| *4)) (|:| |extDegree| (|Integer|)))) (|isDomain| *1 (|RootsFindingPackage| *4))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|CharacterClass|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|StringAggregate|)) (|isDomain| *2 (|Character|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|TwoDimensionalArrayCategory| *3 *4 *5)) (|ofCategory| *3 (|Type|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|NonNegativeInteger|))))) 
+(((*1 *2) (AND (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|RadicalCategory|))) (|isDomain| *1 (|ElementaryFunction| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
 (((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
-(((*1 *1) (|isDomain| *1 (|CharacterClass|))) ((*1 *1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TabulatedComputationPackage| *4 *5)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|))))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *5 (|Integer|)) (|ofCategory| *6 (|Field|)) (|ofType| *7 (|List| (|Symbol|))) (|ofCategory| *8 (|DirectProductCategory| (|#| *7) (|NonNegativeInteger|))) (|ofCategory| *9 (|LocalPowerSeriesCategory| *6)) (|isDomain| *2 (|List| *9)) (|isDomain| *1 (|LocalParametrizationOfSimplePointPackage| *6 *7 *4 *8 *3 *9 *10)) (|ofCategory| *4 (|PolynomialCategory| *6 *8 (|OrderedVariableList| *7))) (|ofCategory| *3 (|ProjectiveSpaceCategory| *6)) (|ofCategory| *10 (|PlacesCategory| *6 *9))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|SparseUnivariatePolynomial| *4))) (|ofCategory| *4 (|Field|)) (|isDomain| *2 (|Record| (|:| |zeros| (|List| *4)) (|:| |extDegree| (|Integer|)))) (|isDomain| *1 (|RootsFindingPackage| *4))))) 
+(((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |op| (|BasicOperator|)) (|:| |arg| (|List| (|Pattern| *3))))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1 *3) (|partial| AND (|isDomain| *3 (|BasicOperator|)) (|isDomain| *2 (|List| (|Pattern| *4))) (|isDomain| *1 (|Pattern| *4)) (|ofCategory| *4 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Partition|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2 *2) (|partial| AND (|ofCategory| *3 (|Join| (|IntegralDomain|) (|CharacteristicZero|))) (|isDomain| *1 (|UnivariatePolynomialDecompositionPackage| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *2) (AND (|ofCategory| *3 (|RetractableTo| (|Integer|))) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|AlgebraicFunction| *3 *2)) (|ofCategory| *2 (|FunctionSpace| *3)))) ((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *4)) (|isDomain| *1 (|ComplexCategory&| *3 *4)) (|ofCategory| *3 (|ComplexCategory| *4)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|Ring|)) (|ofCategory| *1 (|ExpressionSpace|)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteAlgebraicExtensionField| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|SparseUnivariatePolynomial| *3)))) ((*1 *2) (AND (|ofCategory| *1 (|MonogenicAlgebra| *3 *2)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *3 *2)) (|ofCategory| *3 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|Permutation| (|Integer|))) (|isDomain| *2 (|Matrix| (|Integer|))) (|isDomain| *1 (|IrrRepSymNatPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|IrrRepSymNatPackage|)))) ((*1 *2 *3 *4) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *4 (|List| (|Permutation| (|Integer|)))) (|isDomain| *2 (|List| (|Matrix| (|Integer|)))) (|isDomain| *1 (|IrrRepSymNatPackage|))))) 
+(((*1 *2 *2) (|partial| AND (|isDomain| *2 (|Expression| (|DoubleFloat|))) (|isDomain| *1 (|ExpertSystemToolsPackage|)))) ((*1 *2 *1) (|partial| AND (|isDomain| *2 (|Record| (|:| |num| (|Pattern| *3)) (|:| |den| (|Pattern| *3)))) (|isDomain| *1 (|Pattern| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *2 *2) (|partial| AND (|ofCategory| *1 (|PartialTranscendentalFunctions| *2)) (|ofCategory| *2 (|TranscendentalFunctionCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|SubSpace| *2 *3)) (|ofType| *2 (|PositiveInteger|)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2) (AND (|ofCategory| *3 (|IntegralDomain|)) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|AlgebraPackage| *3 *4)) (|ofCategory| *4 (|FramedNonAssociativeAlgebra| *3))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|AffineSpaceCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|AffineSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|Algebra| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| *3)) (|ofCategory| *3 (|Field|)) (|ofType| *6 (|Vector| (|Matrix| *3))) (|isDomain| *1 (|AlgebraGivenByStructuralConstants| *3 *4 *5 *6)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|AlgebraicNumber|)))) (|isDomain| *1 (|AlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Any|)) (|isDomain| *1 (|AnyFunctions1| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE JINT) (QUOTE X) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp10| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) (|isDomain| *1 (|Asp19| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|))) (|isDomain| *1 (|Asp1| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct|) (|construct| (QUOTE X) (QUOTE HESS)) (|MachineFloat|)))) (|isDomain| *1 (|Asp20| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|))) (|isDomain| *1 (|Asp24| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp31| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp35| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE EPS)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp41| *3 *4 *5)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE EPS)) (|construct| (QUOTE YA) (QUOTE YB)) (|MachineFloat|)))) (|isDomain| *1 (|Asp42| *3 *4 *5)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) (|isDomain| *1 (|Asp49| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|))) (|isDomain| *1 (|Asp4| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE XC)) (|MachineFloat|)))) (|isDomain| *1 (|Asp50| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp55| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct|) (|construct| (QUOTE X)) (|MachineFloat|)))) (|isDomain| *1 (|Asp6| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp73| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE X) (QUOTE Y)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp74| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp77| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp78| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|)))) (|isDomain| *1 (|Asp7| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|FortranExpression| (|construct| (QUOTE XL) (QUOTE XR) (QUOTE ELAM)) (|construct|) (|MachineFloat|)))) (|isDomain| *1 (|Asp80| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranExpression| (|construct| (QUOTE X)) (|construct| (QUOTE Y)) (|MachineFloat|))) (|isDomain| *1 (|Asp9| *3)) (|ofType| *3 (|Symbol|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ArrayStack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 2)) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|BinaryExpansion|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|ofCategory| *1 (|BlowUpMethodCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|CartesianTensor| *3 *4 *5))) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *5)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)) (|ofType| *4 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SquareMatrix| *4 *5)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|DirectProduct| *4 *5)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|CommutativeRing|)) (|isDomain| *1 (|CartesianTensor| *3 *4 *5)) (|ofType| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Matrix| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| (|Fraction| (|Polynomial| *4))))) (|isDomain| *1 (|CoerceVectorMatrixPackage| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (CATEGORY |domain| (SIGNATURE |elt| ((|String|) $ (|Symbol|))) (SIGNATURE |display| ((|Void|) $)) (SIGNATURE |fullDisplay| ((|Void|) $))))) (|isDomain| *1 (|Database| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 10)) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|DecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|DirichletRing| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|DirichletRing| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Mapping| *3 (|PositiveInteger|))) (|isDomain| *1 (|DirichletRing| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Mapping| *3 (|PositiveInteger|))) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|DirichletRing| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|DataList| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|OrderedSet|)) (|isDomain| *1 (|DataList| *3)))) ((*1 *2 *3) (AND (|isDomain| *3 (|SegmentBinding| (|Expression| *4))) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|) (|ConvertibleTo| (|Float|)))) (|isDomain| *2 (|SegmentBinding| (|Float|))) (|isDomain| *1 (|DrawNumericHack| *4)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|DifferentialVariableCategory| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|ExtAlgBasis|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)) (|isDomain| *1 (|EuclideanModularRing| *3 *2 *4 *5 *6 *7)) (|ofCategory| *3 (|CommutativeRing|)) (|ofCategory| *4 (|AbelianMonoid|)) (|ofType| *5 (|Mapping| *2 *2 *4)) (|ofType| *6 (|Mapping| (|Union| *4 "failed") *4 *4)) (|ofType| *7 (|Mapping| (|Union| *2 "failed") *2 *2 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *4 *5 *6)) (|ofCategory| *4 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *3))) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4) (|ofCategory| *3 (|Join| (|OrderedSet|) (|RetractableTo| (|Integer|)) (|LinearlyExplicitRingOver| (|Integer|)) (|GcdDomain|))) (|isDomain| *1 (|ExponentialExpansion| *3 *4 *5 *6)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FortranCode|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Expression| *5)) (|isDomain| *1 (|FortranExpression| *3 *4 *5)) (|ofType| *3 (|List| (|Symbol|))) (|ofType| *4 (|List| (|Symbol|))) (|ofCategory| *5 (|FortranMachineTypeCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|FiniteAlgebraicExtensionField| *4)) (|isDomain| *1 (|FiniteFieldHomomorphisms| *3 *4 *2)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|ofCategory| *2 (|FiniteAlgebraicExtensionField| *4)) (|isDomain| *1 (|FiniteFieldHomomorphisms| *2 *4 *3)) (|ofCategory| *3 (|FiniteAlgebraicExtensionField| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|XRecursivePolynomial| *3 *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|XDistributedPolynomial| *3 *4)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|FreeLieAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Matrix| (|MachineFloat|))) (|ofCategory| *1 (|FortranMatrixCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranMatrixFunctionCategory|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|FileNameCategory|)) (|isDomain| *2 (|String|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|ofCategory| *1 (|FileNameCategory|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|ScriptFormulaFormat|)) (|isDomain| *1 (|ScriptFormulaFormat1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|ScriptFormulaFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Complex| (|Float|))))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Float|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|Integer|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Complex| (|Float|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineComplex|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineFloat|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Equation| (|Expression| (|MachineInteger|)))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineComplex|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineFloat|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|isDomain| *1 (|FortranProgram| *3 *4 *5 *6)) (|ofType| *3 (|Symbol|)) (|ofType| *4 (|Union| (|:| |fst| (|FortranScalarType|)) (|:| |void| "void"))) (|ofType| *5 (|List| (|Symbol|))) (|ofType| *6 (|SymbolTable|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FourierComponent| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|AbelianGroup|))) (|isDomain| *1 (|FourierSeries| *3 *4)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))))) ((*1 *1 *2) (AND (|isDomain| *1 (|FourierSeries| *2 *3)) (|ofCategory| *2 (|Join| (|CommutativeRing|) (|Algebra| (|Fraction| (|Integer|))))) (|ofCategory| *3 (|Join| (|OrderedSet|) (|AbelianGroup|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Polynomial| (|Fraction| *3)))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| (|Fraction| *3))) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| *3)) (|ofCategory| *3 (|IntegralDomain|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| *3 (|Kernel| *1))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *1 (|FunctionSpace| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|SExpression|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|FortranScalarType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranScalarType|)) (|isDomain| *1 (|FortranType|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|FortranType|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|MachineFloat|))) (|ofCategory| *1 (|FortranVectorCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |localSymbols| (|SymbolTable|)) (|:| |code| (|List| (|FortranCode|))))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|FortranCode|)) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|FortranCode|))) (|ofCategory| *1 (|FortranVectorFunctionCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Vector| (|Fraction| (|Polynomial| *3)))) (|ofCategory| *3 (|CommutativeRing|)) (|ofType| *6 (|Vector| (|Matrix| *3))) (|isDomain| *1 (|GenericNonAssociativeAlgebra| *3 *4 *5 *6)) (|ofType| *4 (|PositiveInteger|)) (|ofType| *5 (|List| (|Symbol|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| (|DoubleFloat|))))) (|isDomain| *1 (|GraphImage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|GraphImage|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|GeneralUnivariatePowerSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Heap| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|RadixExpansion| 16)) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|HexadecimalExpansion|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|HTMLFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseMultivariatePolynomial| (|Integer|) (|Kernel| (|InnerAlgebraicNumber|)))) (|isDomain| *1 (|InnerAlgebraicNumber|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|IndexCard|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *6)) (|ofCategory| *6 (|PolynomialCategory| *3 *4 *5)) (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|PolynomialIdeals| *3 *4 *5 *6)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|AssociatedJordanAlgebra| *3 *2)) (|ofCategory| *2 (|NonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|CoercibleTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|LeftAlgebra| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XPBWPolynomial| *3 *4)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|LieExponentials| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *5 (|PositiveInteger|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *1 (|AssociatedLieAlgebra| *3 *2)) (|ofCategory| *2 (|NonAssociativeAlgebra| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))))) ((*1 *1 *2) (AND (|isDomain| *2 (|Stream| (|Record| (|:| |k| (|Integer|)) (|:| |c| *3)))) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|LocalPowerSeriesCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Magma| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| *3)))) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PrimitiveArray| (|PrimitiveArray| (|PrimitiveArray| *3)))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|ThreeDimensionalMatrix| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Mapping| *3)) (|isDomain| *1 (|MappingPackage1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|MatrixCategory| *3 *4 *2)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *2 (|FiniteLinearAggregate| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|MachineInteger|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|MachineFloat|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|Integer|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Complex| (|Float|))) (|isDomain| *1 (|MachineComplex|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|MachineInteger|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Float|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|Integer|))) (|isDomain| *2 (|Expression| (|MachineInteger|))) (|isDomain| *1 (|MachineInteger|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MakeCachableSet| *2)) (|ofCategory| *2 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|OutputForm|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|MathMLFormat|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ModularField| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|ModMonic| *3 *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |index| *3) (|:| |exponent| *4))) (|isDomain| *1 (|ModuleMonomial| *3 *4 *5)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|SetCategory|)) (|ofType| *5 (|Mapping| (|Boolean|) *2 *2)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |index| *3) (|:| |exponent| *4))) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|SetCategory|)) (|isDomain| *1 (|ModuleMonomial| *3 *4 *5)) (|ofType| *5 (|Mapping| (|Boolean|) *2 *2)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|CommutativeRing|)) (|isDomain| *1 (|ModularRing| *2 *3 *4 *5 *6)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 (|Mapping| *2 *2 *3)) (|ofType| *5 (|Mapping| (|Union| *3 "failed") *3 *3)) (|ofType| *6 (|Mapping| (|Union| *2 "failed") *2 *2 *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Record| (|:| |coef| *3) (|:| |monom| *4)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|Monoid|)) (|isDomain| *1 (|MonoidRing| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|MyUnivariatePolynomial| *3 *4))) (|ofType| *3 (|Symbol|)) (|ofCategory| *4 (|Join| (|Ring|) (|OrderedSet|) (|IntegralDomain|))) (|isDomain| *1 (|MyExpression| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *4)) (|ofCategory| *4 (|Ring|)) (|isDomain| *1 (|MyUnivariatePolynomial| *3 *4)) (|ofType| *3 (|Symbol|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|MyUnivariatePolynomial| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|MyUnivariatePolynomial| *3 *2)) (|ofType| *3 (|Symbol|)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|NonAssociativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| |nia| (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|:| |mdnia| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|List| (|Segment| (|OrderedCompletion| (|DoubleFloat|))))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |var| (|Symbol|)) (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |range| (|Segment| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalIntegrationProblem|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|None|)) (|isDomain| *1 (|NoneFunctions1| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalODEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalODEProblem|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PartialDifferentialRing| *3)) (|isDomain| *1 (|OrdinaryDifferentialRing| *3 *2 *4)) (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 *3))) ((*1 *1 *2) (AND (|ofCategory| *3 (|SetCategory|)) (|ofType| *4 *3) (|isDomain| *1 (|OrdinaryDifferentialRing| *3 *2 *4)) (|ofCategory| *2 (|PartialDifferentialRing| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|OpenMathErrorKind|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Union| (|:| |noa| (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|:| |lsa| (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |lfn| (|List| (|Expression| (|DoubleFloat|)))) (|:| |init| (|List| (|DoubleFloat|))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |fn| (|Expression| (|DoubleFloat|))) (|:| |init| (|List| (|DoubleFloat|))) (|:| |lb| (|List| (|OrderedCompletion| (|DoubleFloat|)))) (|:| |cf| (|List| (|Expression| (|DoubleFloat|)))) (|:| |ub| (|List| (|OrderedCompletion| (|DoubleFloat|)))))) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalOptimizationProblem|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|UnivariateSkewPolynomial| *3 *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Automorphism| *4)) (|ofType| *6 (|Mapping| *4 *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|OrdSetInts|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *3 *4 *5 *6)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|List| (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Polynomial| *3)) (|isDomain| *1 (|OrdinaryWeightedPolynomials| *3 *4 *5 *6)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|List| (|Symbol|))) (|ofType| *5 (|List| (|NonNegativeInteger|))) (|ofType| *6 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Color|)) (|isDomain| *1 (|Palette|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Polynomial| (|AlgebraicNumber|))) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PolynomialAN2Expression|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Fraction| (|Polynomial| (|AlgebraicNumber|)))) (|isDomain| *2 (|Expression| (|Integer|))) (|isDomain| *1 (|PolynomialAN2Expression|)))) ((*1 *1 *2) (AND (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OrderedFreeMonoid| *3)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Record| (|:| |pde| (|List| (|Expression| (|DoubleFloat|)))) (|:| |constraints| (|List| (|Record| (|:| |start| (|DoubleFloat|)) (|:| |finish| (|DoubleFloat|)) (|:| |grid| (|NonNegativeInteger|)) (|:| |boundaryType| (|Integer|)) (|:| |dStart| (|Matrix| (|DoubleFloat|))) (|:| |dFinish| (|Matrix| (|DoubleFloat|)))))) (|:| |f| (|List| (|List| (|Expression| (|DoubleFloat|))))) (|:| |st| (|String|)) (|:| |tol| (|DoubleFloat|)))) (|isDomain| *1 (|NumericalPDEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|NumericalPDEProblem|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Tree| *3)) (|isDomain| *1 (|PendantTree| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|PermutationGroup| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Permutation| *3))) (|isDomain| *1 (|PermutationGroup| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|SetCategory|)) (|isDomain| *1 (|Permutation| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Fraction| (|Factored| *3))) (|ofCategory| *3 (|EuclideanDomain|)) (|isDomain| *1 (|PartialFraction| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| *3)) (|isDomain| *1 (|PartialFraction| *3)) (|ofCategory| *3 (|EuclideanDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Pi|)) (|isDomain| *2 (|Expression| *4)) (|isDomain| *1 (|PiCoercions| *4)) (|ofCategory| *4 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Field|)) (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ProjectiveSpaceCategory| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *2 (|List| *3)))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|Partition|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Fraction| (|Integer|))) (|isDomain| *1 (|RadixExpansion| *3)) (|ofType| *3 (|Integer|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ResolveLatticeCompletion| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Exit|)) (|isDomain| *1 (|ResolveLatticeCompletion| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Field|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|ResidueRing| *3 *4 *5 *2 *6)) (|ofCategory| *2 (|PolynomialCategory| *3 *4 *5)) (|ofType| *6 (|List| *2)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|RetractableTo| *2)) (|ofCategory| *2 (|Type|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Fraction| (|Polynomial| *3))) (|isDomain| *1 (|RationalFunction| *3)) (|ofCategory| *3 (|IntegralDomain|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Integer|)) (|ofCategory| *1 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Matrix| *5)) (|isDomain| *1 (|RectangularMatrix| *3 *4 *5)) (|ofType| *3 (|NonNegativeInteger|)) (|ofType| *4 (|NonNegativeInteger|)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *4 *2)) (|ofCategory| *2 (|PolynomialCategory| *3 (|IndexedExponents| *4) *4)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedSet|)) (|isDomain| *1 (|SparseMultivariateTaylorSeries| *3 *2 *4)) (|ofCategory| *4 (|PolynomialCategory| *3 (|IndexedExponents| *2) *2)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Matrix| *4)) (|isDomain| *1 (|SquareMatrix| *3 *4)) (|ofType| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Character|)) (|ofCategory| *1 (|StringAggregate|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Stack| *3)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3)))) ((*1 *2 *3) (AND (|isDomain| *2 (|Stream| *3)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Switch|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|String|)) (|isDomain| *1 (|Symbol|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Table| (|Symbol|) (|FortranType|))) (|isDomain| *1 (|SymbolTable|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Tableau| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|TexFormat|)) (|isDomain| *1 (|TexFormat1| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|TexFormat|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|TaylorSeries| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|TaylorSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|PrimitiveArray| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Tuple| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| (QUOTE |x|))) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| (QUOTE |x|) *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *3)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariateLaurentSeriesConstructorCategory| *3 *2)) (|ofCategory| *2 (|UnivariateTaylorSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateLaurentSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Segment| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|UniversalSegment| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *3)) (|ofType| *3 (|Symbol|)) (|isDomain| *1 (|UnivariatePolynomial| *3 *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|UnivariatePuiseuxSeriesConstructorCategory| *3 *2)) (|ofCategory| *2 (|UnivariateLaurentSeriesCategory| *3)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariatePuiseuxSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofType| *5 *3))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|ofType| *5 *3) (|isDomain| *1 (|UnivariateTaylorSeries| *3 *4 *5)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Variable| *4)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)) (|ofCategory| *3 (|Ring|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|UnivariatePolynomial| *4 *3)) (|ofCategory| *3 (|Ring|)) (|ofType| *4 (|Symbol|)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *3 *4)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Symbol|)) (|isDomain| *1 (|Variable| *3)) (|ofType| *3 *2))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|GraphImage|)) (|isDomain| *2 (|TwoDimensionalViewport|)) (|isDomain| *1 (|ViewportPackage|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|OutputForm|)) (|isDomain| *1 (|Void|)))) ((*1 *1 *2) (AND (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *4)) (|isDomain| *1 (|WeightedPolynomials| *3 *4 *5 *2 *6 *7 *8)) (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|ofCategory| *2 (|PolynomialCategory| *3 *5 *4)) (|isDomain| *1 (|WeightedPolynomials| *3 *4 *5 *2 *6 *7 *8)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofType| *6 (|List| *4)) (|ofType| *7 (|List| (|NonNegativeInteger|))) (|ofType| *8 (|NonNegativeInteger|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|XAlgebra| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *2) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XRecursivePolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|XDistributedPolynomial| *3 *4)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|LiePolynomial| *3 *4)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *1 (|XPBWPolynomial| *3 *4)))) ((*1 *1 *2) (AND (|isDomain| *1 (|XPolynomialRing| *3 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *2 (|OrderedMonoid|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|isDomain| *1 (|HeuGcd| *2)) (|ofCategory| *2 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Segment| (|PositiveInteger|))) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4)) (|isDomain| *1 (|MatrixManipulation| *4 *5 *6 *2)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|))))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|GaloisGroupFactorizer| *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Integer|)))))) 
+(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|Palette|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|MachineFloat|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|ofCategory| *1 (|UnivariatePolynomialCategory| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|OpenMathDevice|))))) 
+(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|FreeAbelianMonoidCategory| *2 *3)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|CancellationAbelianMonoid|)) (|ofCategory| *3 (|OrderedAbelianMonoid|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Plot3D|))))) 
 (((*1 *1 *1) (AND (|isDomain| *1 (|Factored| *2)) (|ofCategory| *2 (|IntegralDomain|))))) 
-(((*1 *1 *1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Stream| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *1 *1 *1) (AND (|has| *1 (ATTRIBUTE |shallowlyMutable|)) (|ofCategory| *1 (|UnaryRecursiveAggregate| *2)) (|ofCategory| *2 (|Type|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|e04AgentsPackage|))))) 
-(((*1 *2) (AND (|isDomain| *2 (|Void|)) (|isDomain| *1 (|GaloisGroupUtilities| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Record| (|:| |xinit| (|DoubleFloat|)) (|:| |xend| (|DoubleFloat|)) (|:| |fn| (|Vector| (|Expression| (|DoubleFloat|)))) (|:| |yinit| (|List| (|DoubleFloat|))) (|:| |intvals| (|List| (|DoubleFloat|))) (|:| |g| (|Expression| (|DoubleFloat|))) (|:| |abserr| (|DoubleFloat|)) (|:| |relerr| (|DoubleFloat|)))) (|isDomain| *2 (|Float|)) (|isDomain| *1 (|d02AgentsPackage|))))) 
-(((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| (|DoubleFloat|)))) (|isDomain| *1 (|Plot3D|))))) 
-(((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *4 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|TwoDimensionalViewport|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|MatrixCategory| *3 *4 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|FiniteLinearAggregate| *3)) (|ofCategory| *5 (|FiniteLinearAggregate| *3)) (|isDomain| *2 (|List| (|List| *3))))) ((*1 *2 *1) (AND (|ofCategory| *1 (|RectangularMatrixCategory| *3 *4 *5 *6 *7)) (|ofCategory| *5 (|Ring|)) (|ofCategory| *6 (|DirectProductCategory| *4 *5)) (|ofCategory| *7 (|DirectProductCategory| *3 *5)) (|isDomain| *2 (|List| (|List| *5))))) ((*1 *2 *1) (AND (|isDomain| *2 (|List| (|List| *3))) (|isDomain| *1 (|Tableau| *3)) (|ofCategory| *3 (|SetCategory|))))) 
-(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|UniqueFactorizationDomain|)) (|ofCategory| *5 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Record| (|:| |func| *3) (|:| |poly| *3) (|:| |c1| (|Fraction| *5)) (|:| |c2| (|Fraction| *5)) (|:| |deg| (|NonNegativeInteger|)))) (|isDomain| *1 (|ChangeOfVariable| *4 *5 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| (|Fraction| *5)))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|Field|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|Factored| (|SparseUnivariatePolynomial| (|Integer|)))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|FiniteAbelianMonoidRing| *2 *3)) (|ofCategory| *3 (|OrderedAbelianMonoid|)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| (|Integer|))) (|isDomain| *2 (|List| (|Integer|))) (|isDomain| *1 (|HeuGcd| *4)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|UnivariateSkewPolynomialCategory| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|GcdDomain|)))) ((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialCategory| *3 *4 *2)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|GcdDomain|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|String|)) (|isDomain| *1 (|NumberFormats|))))) 
-(((*1 *2 *2) (AND (|ofCategory| *3 (|Join| (|OrderedSet|) (|GcdDomain|))) (|isDomain| *1 (|TranscendentalManipulations| *3 *2)) (|ofCategory| *2 (|Join| (|FunctionSpace| *3) (|TranscendentalFunctionCategory|)))))) 
-(((*1 *2 *1) (AND (|ofCategory| *1 (|PseudoAlgebraicClosureOfPerfectFieldCategory|)) (|isDomain| *2 (|Void|))))) 
-(((*1 *2 *2 *3) (AND (|isDomain| *3 (|List| *2)) (|ofCategory| *2 (|PolynomialCategory| *4 *5 *6)) (|ofCategory| *4 (|EuclideanDomain|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|OrderedSet|)) (|isDomain| *1 (|EuclideanGroebnerBasisPackage| *4 *5 *6 *2))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|FileName|)) (|isDomain| *1 (|Library|))))) 
-(((*1 *2 *3 *4) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *8)) (|ofCategory| *8 (|RecursivePolynomialCategory| *5 *6 *7)) (|ofCategory| *5 (|IntegralDomain|)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *7 (|OrderedSet|)) (|isDomain| *2 (|Record| (|:| |goodPols| (|List| *8)) (|:| |badPols| (|List| *8)))) (|isDomain| *1 (|PolynomialSetUtilitiesPackage| *5 *6 *7 *8)) (|isDomain| *4 (|List| *8))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|FreeLieAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|CommutativeRing|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|LieExponentials| *2 *3 *4)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Join| (|CommutativeRing|) (|Module| (|Fraction| (|Integer|))))) (|ofType| *4 (|PositiveInteger|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|Magma| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|OrderedFreeMonoid| *2)) (|ofCategory| *2 (|OrderedSet|)))) ((*1 *1 *1) (AND (|ofCategory| *1 (|XFreeAlgebra| *2 *3)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|FortranPackage|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|IntegralDomain|) (|GcdDomain|))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|FractionFreeFastGaussian| *4 *5)) (|ofCategory| *5 (|AbelianMonoidRing| *4 *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Vector| (|Matrix| *4))) (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Vector| (|Matrix| (|Polynomial| *4)))) (|isDomain| *1 (|CoerceVectorMatrixPackage| *4))))) 
-(((*1 *1 *2) (AND (|isDomain| *2 (|List| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *1 (|Stream| *3))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
-(((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorization| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|FiniteFieldCategory|)) (|isDomain| *2 (|Factored| *3)) (|isDomain| *1 (|FiniteFieldFactorizationWithSizeParseBySideEffect| *4 *3)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|Stream| (|Stream| *4))) (|isDomain| *2 (|Stream| *4)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *4)) (|ofCategory| *4 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOptionFunctions0|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|GuessOption|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|Plot|))))) 
-(((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|SparseUnivariateTaylorSeries| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| (QUOTE |x|) *4)) (|isDomain| *1 (|UnivariateFormalPowerSeries| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|UnivariateTaylorSeries| *4 *5 *6)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|)) (|ofType| *6 *4))) ((*1 *2 *1 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *2 (|UnivariatePolynomial| *5 *4)) (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *4 *5)) (|ofCategory| *4 (|Ring|)) (|ofType| *5 (|Symbol|))))) 
-(((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|CyclotomicPolynomialPackage|)) (|isDomain| *3 (|Integer|)))) ((*1 *2 *3 *2) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *1 (|NumberTheoreticPolynomialFunctions| *2)) (|ofCategory| *2 (|CommutativeRing|)))) ((*1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *1 (|PolynomialNumberTheoryFunctions|)) (|isDomain| *3 (|Integer|))))) 
-(((*1 *2 *2) (AND (|isDomain| *2 (|OnePointCompletion| (|DoubleFloat|))) (|isDomain| *1 (|DoubleFloatSpecialFunctions|))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Boolean|) *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2)))) ((*1 *2 *2 *3) (AND (|isDomain| *3 (|Mapping| (|Integer|) *2 *2)) (|ofCategory| *2 (|CachableSet|)) (|isDomain| *1 (|SortedCache| *2))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Stream| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *1 (|StreamTaylorSeriesOperations| *3)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateFormalPowerSeries| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeries| *2 *3 *4)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|)) (|ofType| *4 *2))) ((*1 *1 *1) (AND (|isDomain| *1 (|UnivariateTaylorSeriesCZero| *2 *3)) (|ofCategory| *2 (|Ring|)) (|ofType| *3 (|Symbol|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 *3)) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) *3 *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 HPSPEC) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *4 (|Join| (|Ring|) (|Module| (|Fraction| (|Integer|))))) (|ofCategory| *5 (|OrderedSet|)) (|isDomain| *1 (|XExponentialPackage| *4 *5 *2)) (|ofCategory| *2 (|XPolynomialsCat| *5 *4))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|OrderedRing|)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|Permutation| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3 *1) (AND (|ofCategory| *1 (|RealRootCharacterizationCategory| *4 *3)) (|ofCategory| *4 (|Join| (|OrderedRing|) (|Field|))) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|isDomain| *2 (|Integer|)))) ((*1 *2 *3) (|partial| AND (|ofCategory| *4 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *4 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *4))))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *6 *3)))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|Join| (|IntegralDomain|) (|OrderedSet|) (|RetractableTo| *2) (|LinearlyExplicitRingOver| *2) (|GcdDomain|))) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ElementaryFunctionSign| *6 *3)) (|ofCategory| *3 (|Join| (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|) (|FunctionSpace| *6))))) ((*1 *2 *3) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *4))) (|ofCategory| *4 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *4)))) ((*1 *2 *3 *4 *5) (|partial| AND (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|OrderedCompletion| (|Fraction| (|Polynomial| *6)))) (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *6)))) ((*1 *2 *3 *4 *3 *5) (|partial| AND (|isDomain| *3 (|Fraction| (|Polynomial| *6))) (|isDomain| *4 (|Symbol|)) (|isDomain| *5 (|String|)) (|ofCategory| *6 (|GcdDomain|)) (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|RationalFunctionSign| *6)))) ((*1 *2 *3) (|partial| AND (|isDomain| *2 (|Integer|)) (|isDomain| *1 (|ToolsForSign| *3)) (|ofCategory| *3 (|Ring|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|d01AgentsPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemContinuityPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|DoubleFloat|))) (|isDomain| *2 (|List| (|String|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3 *3 *4 *4) (AND (|isDomain| *3 (|U32Vector|)) (|isDomain| *4 (|Integer|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|U32VectorPolynomialOperations|))))) 
+(((*1 *2 *2 *2) (AND (|isDomain| *2 (|List| (|List| *3))) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
+(((*1 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|)))) ((*1 *2 *2) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|ViewDefaultsPackage|))))) 
+(((*1 *2 *2 *2 *3) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|ofCategory| *2 (|IntegralDomain|)) (|isDomain| *1 (|PseudoRemainderSequence| *2 *4)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *2))))) 
+(((*1 *1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *1) (|isDomain| *1 (|OutputForm|))) ((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| (|Integer|))) (|isDomain| *3 (|Integer|)) (|ofCategory| *1 (|PAdicIntegerCategory| *4))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|ListMultiDictionary| *3)) (|ofCategory| *3 (|SetCategory|))))) 
+(((*1 *1 *1 *2) (AND (|isDomain| *2 (|List| (|OutputForm|))) (|isDomain| *1 (|OutputForm|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|Record| (|:| |sub| (|List| (|OutputForm|))) (|:| |sup| (|List| (|OutputForm|))) (|:| |presup| (|List| (|OutputForm|))) (|:| |presub| (|List| (|OutputForm|))) (|:| |args| (|List| (|OutputForm|))))) (|isDomain| *1 (|Symbol|))))) 
+(((*1 *1 *1 *2 *3) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *3 (|Point| *4)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *2 *1 *3 *4) (AND (|isDomain| *3 (|NonNegativeInteger|)) (|isDomain| *4 (|Point| (|DoubleFloat|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|ThreeDimensionalViewport|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|QuotientFieldCategory| *2)) (|ofCategory| *2 (|IntegralDomain|)) (|ofCategory| *2 (|IntegerNumberSystem|)))) ((*1 *1 *1) (|ofCategory| *1 (|RealNumberSystem|)))) 
+(((*1 *1) (|isDomain| *1 (|CharacterClass|))) ((*1 *1 *1) (|isDomain| *1 (|Character|))) ((*1 *1 *1) (|ofCategory| *1 (|StringAggregate|)))) 
+(((*1 *2 *3 *4 *5) (AND (|isDomain| *4 (|Mapping| *7 *7)) (|isDomain| *5 (|Mapping| (|Union| (|Record| (|:| |ratpart| *6) (|:| |coeff| *6)) "failed") *6)) (|ofCategory| *6 (|Field|)) (|ofCategory| *7 (|UnivariatePolynomialCategory| *6)) (|isDomain| *2 (|Record| (|:| |answer| (|IntegrationResult| (|Fraction| *7))) (|:| |a0| *6))) (|isDomain| *1 (|TranscendentalIntegration| *6 *7)) (|isDomain| *3 (|Fraction| *7))))) 
+(((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Dequeue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|Join| (|FloatingPointSystem|) (|RetractableTo| *4) (|Field|) (|TranscendentalFunctionCategory|) (|ElementaryFunctionCategory|))) (|isDomain| *1 (|GaloisGroupFactorizationUtilities| *4 *3 *2)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *1 *1) (|ofCategory| *1 (|IntegerNumberSystem|))) ((*1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|LyndonWord| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|PositiveInteger|)) (|isDomain| *1 (|Magma| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|OrderedFreeMonoid| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|PoincareBirkhoffWittLyndonBasis| *3)) (|ofCategory| *3 (|OrderedSet|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|QueueAggregate| *3)) (|ofCategory| *3 (|Type|)) (|isDomain| *2 (|NonNegativeInteger|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Queue| *3)) (|ofCategory| *3 (|SetCategory|)))) ((*1 *2 *1) (AND (|isDomain| *2 (|NonNegativeInteger|)) (|isDomain| *1 (|Tuple| *3)) (|ofCategory| *3 (|Type|)))) ((*1 *2 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|RadicalCategory|)) (|ofCategory| *2 (|Ring|))))) 
+(((*1 *1 *2) (AND (|isDomain| *2 (|Expression| *3)) (|ofCategory| *3 (|Join| (|Ring|) (|OrderedSet|))) (|isDomain| *1 (|DeRhamComplex| *3 *4)) (|ofType| *4 (|List| (|Symbol|)))))) 
+(((*1 *1 *1 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3))) ((*1 *1 *2 *3 *1) (AND (|isDomain| *1 (|ListMonoidOps| *2 *3 *4)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|AbelianMonoid|)) (|ofType| *4 *3))) ((*1 *1 *1 *1) (AND (|isDomain| *1 (|ThreeDimensionalMatrix| *2)) (|ofCategory| *2 (|Ring|)) (|ofCategory| *2 (|SetCategory|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|BlowUpMethodCategory|)) (|isDomain| *2 (|Boolean|))))) 
+(((*1 *2 *1) (AND (|ofCategory| *1 (|ThreeSpaceCategory| *3)) (|ofCategory| *3 (|Ring|)) (|isDomain| *2 (|List| (|List| (|Point| *3)))))) ((*1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *4 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)))) ((*1 *1 *2) (AND (|isDomain| *2 (|List| (|List| (|Point| *3)))) (|ofCategory| *3 (|Ring|)) (|ofCategory| *1 (|ThreeSpaceCategory| *3)))) ((*1 *1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|List| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2 *3 *3) (AND (|isDomain| *2 (|List| (|List| (|Point| *4)))) (|isDomain| *3 (|Boolean|)) (|ofCategory| *1 (|ThreeSpaceCategory| *4)) (|ofCategory| *4 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|List| *5)))) (|isDomain| *3 (|List| (|SubSpaceComponentProperty|))) (|isDomain| *4 (|SubSpaceComponentProperty|)) (|ofCategory| *1 (|ThreeSpaceCategory| *5)) (|ofCategory| *5 (|Ring|)))) ((*1 *1 *1 *2 *3 *4) (AND (|isDomain| *2 (|List| (|List| (|Point| *5)))) (|isDomain| *3 (|List| (|SubSpaceComponentProperty|))) (|isDomain| *4 (|SubSpaceComponentProperty|)) (|ofCategory| *1 (|ThreeSpaceCategory| *5)) (|ofCategory| *5 (|Ring|))))) 
+(((*1 *2 *3) (AND (|ofCategory| *4 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *4)) (|isDomain| *1 (|PolynomialSolveByFormulas| *3 *4)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)))) ((*1 *2 *3 *3) (AND (|ofCategory| *3 (|Join| (|Field|) (CATEGORY |domain| (SIGNATURE ** ($ $ (|Fraction| (|Integer|))))))) (|isDomain| *2 (|List| *3)) (|isDomain| *1 (|PolynomialSolveByFormulas| *4 *3)) (|ofCategory| *4 (|UnivariatePolynomialCategory| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|PositiveInteger|)) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|Integer|))) (|isDomain| *2 (|PermutationGroup| (|Integer|))) (|isDomain| *1 (|PermutationGroupExamples|))))) 
+(((*1 *1 *2 *3) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|isDomain| *3 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|SparseUnivariatePolynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *2) (AND (|isDomain| *2 (|Polynomial| *1)) (|ofCategory| *1 (|AlgebraicallyClosedField|)))) ((*1 *1 *1 *2) (AND (|isDomain| *2 (|Symbol|)) (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *3)) (|ofCategory| *3 (|Join| (|OrderedSet|) (|IntegralDomain|))))) ((*1 *1 *1) (AND (|ofCategory| *1 (|AlgebraicallyClosedFunctionSpace| *2)) (|ofCategory| *2 (|Join| (|OrderedSet|) (|IntegralDomain|)))))) 
+(((*1 *2 *1 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|BasicOperator|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|OpenMathConnection|)) (|isDomain| *2 (|Any|)) (|isDomain| *1 (|OpenMathServerPackage|))))) 
+(((*1 *1 *1 *2) (AND (|ofCategory| *1 (|PolynomialSetCategory| *3 *4 *2 *5)) (|ofCategory| *3 (|Ring|)) (|ofCategory| *4 (|OrderedAbelianMonoidSup|)) (|ofCategory| *2 (|OrderedSet|)) (|ofCategory| *5 (|RecursivePolynomialCategory| *3 *4 *2))))) 
+(((*1 *2 *3 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Exit|)) (|isDomain| *1 (|OpenMathPackage|))))) 
+(((*1 *1 *1 *1) (|ofCategory| *1 (|NonAssociativeRng|)))) 
 (((*1 *2) (AND (|ofCategory| *4 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|FiniteRankNonAssociativeAlgebra&| *3 *4)) (|ofCategory| *3 (|FiniteRankNonAssociativeAlgebra| *4)))) ((*1 *2) (AND (|ofCategory| *1 (|FiniteRankNonAssociativeAlgebra| *3)) (|ofCategory| *3 (|CommutativeRing|)) (|isDomain| *2 (|Boolean|))))) 
-(((*1 *2 *3 *4 *4 *3 *3 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|SparseUnivariatePolynomial| *3)) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|)))) ((*1 *2 *3 *4 *4 *3 *4 *3 *5) (|partial| AND (|isDomain| *4 (|Kernel| *3)) (|isDomain| *5 (|Fraction| (|SparseUnivariatePolynomial| *3))) (|ofCategory| *3 (|Join| (|FunctionSpace| *6) (|AlgebraicallyClosedField|) (|TranscendentalFunctionCategory|))) (|ofCategory| *6 (|Join| (|GcdDomain|) (|RetractableTo| (|Integer|)) (|OrderedSet|) (|CharacteristicZero|) (|LinearlyExplicitRingOver| (|Integer|)))) (|isDomain| *2 (|Record| (|:| |ratpart| *3) (|:| |coeff| *3))) (|isDomain| *1 (|GenusZeroIntegration| *6 *3 *7)) (|ofCategory| *7 (|SetCategory|))))) 
-(((*1 *2 *3 *4 *5) (AND (|isDomain| *3 (|SparseUnivariatePolynomial| *9)) (|isDomain| *4 (|List| *7)) (|ofCategory| *7 (|OrderedSet|)) (|ofCategory| *9 (|PolynomialCategory| *8 *6 *7)) (|ofCategory| *6 (|OrderedAbelianMonoidSup|)) (|ofCategory| *8 (|EuclideanDomain|)) (|isDomain| *2 (|List| (|NonNegativeInteger|))) (|isDomain| *1 (|MultivariateSquareFree| *6 *7 *8 *9)) (|isDomain| *5 (|NonNegativeInteger|))))) 
-(((*1 *2 *2 *3 *4) (|partial| AND (|isDomain| *4 (|Mapping| *3)) (|ofCategory| *3 (|OrderedSet|)) (|ofCategory| *5 (|OrderedAbelianMonoidSup|)) (|ofCategory| *6 (|IntegralDomain|)) (|ofCategory| *7 (|PolynomialCategory| *6 *5 *3)) (|isDomain| *1 (|GosperSummationMethod| *5 *3 *6 *7 *2)) (|ofCategory| *2 (|Join| (|RetractableTo| (|Fraction| (|Integer|))) (|Field|) (CATEGORY |domain| (SIGNATURE |coerce| ($ *7)) (SIGNATURE |numer| (*7 $)) (SIGNATURE |denom| (*7 $)))))))) 
-(((*1 *1 *1 *1) (AND (|ofCategory| *1 (|PointCategory| *2)) (|ofCategory| *2 (|Ring|)))) ((*1 *2 *2 *2) (AND (|isDomain| *2 (|Point| (|DoubleFloat|))) (|isDomain| *1 (|TubePlotTools|)))) ((*1 *1 *1 *1) (AND (|ofCategory| *1 (|VectorCategory| *2)) (|ofCategory| *2 (|Type|)) (|ofCategory| *2 (|Ring|))))) 
-(((*1 *1 *1) (AND (|ofCategory| *1 (|DivisorCategory| *2)) (|ofCategory| *2 (|SetCategory|))))) 
-(((*1 *1 *1 *1 *2) (|partial| AND (|isDomain| *2 (|Boolean|)) (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *3)) (|ofCategory| *3 (|Ring|))))) 
-(((*1 *2 *3) (AND (|isDomain| *3 (|String|)) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DisplayPackage|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|String|))) (|isDomain| *2 (|Void|)) (|isDomain| *1 (|DisplayPackage|))))) 
-((|say| . 1566162) (|iExquo| . 1566013) (|divOfPole| . 1565916) (|cross| . 1565611) (|GospersMethod| . 1565137) (|myDegree| . 1564722) (|palgextint0| . 1563637) (|jordanAdmissible?| . 1563297) (|Ei2| . 1563172) (|cyclotomic| . 1562700) (|univariatePolynomial| . 1561824) (|debug| . 1561540) (|addiag| . 1561368) (|factorUsingYun| . 1560944) (|mathieu23| . 1560681) (|repeating| . 1560574) (|coerceP| . 1560368) (|DiffC| . 1560122) (|setLegalFortranSourceExtensions| . 1560029) (|mirror| . 1559385) (|selectPolynomials| . 1558968) (|library| . 1558889) (|euclideanNormalForm| . 1558607) (|setTower!| . 1558493) (|sec2cos| . 1558278) (|FormatRoman| . 1558159) (|content| . 1557460) (|cyclotomicFactorization| . 1557290) (|rightRemainder| . 1557152) (|chvar| . 1556764) (|listOfLists| . 1556171) (|region| . 1556012) (|tValues| . 1555913) (|accuracyIF| . 1555506) (|fillPascalTriangle| . 1555391) (|quadratic?| . 1555257) (|setrest!| . 1555004) (|unitNormalize| . 1554913) (|upperCase| . 1554771) (|clipSurface| . 1554649) (|row| . 1554176) (|rischDEsys| . 1553481) (|removeIrreducibleRedundantFactors| . 1553112) (|numberOfHues| . 1553031) (|setParam!| . 1552832) (|integerDecode| . 1552741) (|nthFactor| . 1551894) (|genericRightMinimalPolynomial| . 1551551) (|construct| . 1547231) (|balancedFactorisation| . 1546760) (|pushdterm| . 1546358) (|primitivePart!| . 1546139) (|ksec| . 1545900) (|prefixRagits| . 1545777) (|euclideanGroebner| . 1544883) (|polyPart| . 1544692) (|rationalFunction| . 1544250) (|hasSolution?| . 1543661) (|rowEchWoZeroLines| . 1543546) (|upperCase!| . 1543492) (|lowerCase?| . 1543412) (|sncndn| . 1543168) (|unitCanonical| . 1543115) (|rationalPoints| . 1540800) (|ScanArabic| . 1540681) (|maxSubst| . 1540409) (|string?| . 1540132) (|setAdaptive3D| . 1540055) (|setAdaptive| . 1539980) (|exponentialOrder| . 1539757) (|floor| . 1539557) (|diff| . 1539145) (|iter| . 1538958) (|increase| . 1538734) (|palgintegrate| . 1538238) (|divisors| . 1538102) (|yRange| . 1537873) (|laplace| . 1537487) (|isOp| . 1537127) (|elements| . 1536943) (|segment| . 1536649) (|safety| . 1536415) (|hspace| . 1536334) (|rightRegularRepresentation| . 1536014) (|tRange| . 1535833) (|gcdcofactprim| . 1535690) (|diophantineSystem| . 1535345) (|rootSplit| . 1534940) (|badValues| . 1534754) (|zCoord| . 1534640) (|rootSimp| . 1534083) (|recoverAfterFail| . 1533956) (|mapExpon| . 1533462) (|pop!| . 1533120) (|basisOfCenter| . 1532942) (|repeatUntilLoop| . 1532858) (|iflist2Result| . 1532590) (|geometric| . 1532448) (|localize| . 1531859) (|startStats!| . 1531663) (|polyred| . 1531447) (|hconcat| . 1531307) (|viewWriteAvailable| . 1531212) (|youngGroup| . 1530916) (|algebraic?| . 1530517) (|irreducibleRepresentation| . 1529988) (|calcRanges| . 1529823) (|iprint| . 1529708) (|moebius| . 1529609) (|lastSubResultantEuclidean| . 1529358) (|float?| . 1529081) (|divisorCascade| . 1528499) (|root| . 1528250) (|nextPrimitiveNormalPoly| . 1528074) (|unaryFunction| . 1527832) (|hexDigit| . 1527784) (|conditionsForIdempotents| . 1526560) (|pointData| . 1526404) (|basisOfRightNucloid| . 1526215) (|check| . 1525459) (|copyIto| . 1525323) (|rename!| . 1525229) (|genusTreeNeg| . 1524479) (|comment| . 1524311) (|torsion?| . 1523466) (|jordanAlgebra?| . 1523126) (|coerceListOfPairs| . 1522998) (|iiBesselI| . 1522796) (|OMgetEndBind| . 1522714) (|critT| . 1522332) (|unit?| . 1522245) (|entry| . 1521156) (|exactQuotient!| . 1520705) (|float| . 1520233) (|usingTable?| . 1520064) (|genericRightTraceForm| . 1519749) (|algintegrate| . 1519253) (|actualExtensionV| . 1518748) (|blockConcat| . 1518470) (|id| . 1518375) (|quadratic| . 1517854) (|subResultantGcd| . 1517324) (|var1StepsDefault| . 1517134) (|trace2PowMod| . 1516921) (|maxMixedDegree| . 1516687) (|internalIntegrate| . 1515963) (|KrullNumber| . 1515108) (|symbolTable| . 1514965) (|integer| . 1514588) (|basisOfLeftNucleus| . 1514410) (|merge| . 1513459) (|replaceVarByZero| . 1513173) (|bezoutResultant| . 1512836) (|pushFortranOutputStack| . 1512597) (|palginfieldint| . 1512132) (|mapGen| . 1511504) (|sin?| . 1511381) (|rewriteSetWithReduction| . 1511008) (|probablyZeroDim?| . 1510693) (|multiplicity| . 1509736) (|modTree| . 1509611) (|atrapezoidal| . 1509308) (|idamax| . 1509168) (|rightTraceMatrix| . 1508662) (|linearAssociatedOrder| . 1508478) (|mapdiv| . 1508316) (|string| . 1507866) (|eq| . 1507586) (|monomials| . 1506792) (|pile| . 1506699) (|simplifyExp| . 1506484) (|constant?| . 1506069) (|setDegree!| . 1505862) (|blowUp| . 1505170) (|mainSquareFreePart| . 1504951) (|outputList| . 1504837) (|integers| . 1504669) (|mat| . 1504476) (|regularRepresentation| . 1504070) (|rightQuotient| . 1503932) (|OMunhandledSymbol| . 1503819) (|htrigs| . 1503604) (|duplicates| . 1503417) (|writable?| . 1503328) (|fmecg| . 1502263) (|int| . 1501613) (|tower| . 1501514) (|symmetricSquare| . 1501369) (|viewDeltaYDefault| . 1501189) (|linearPart| . 1501074) (|semiDiscriminantEuclidean| . 1500843) (|rationalApproximation| . 1500310) (|hMonic| . 1500071) (|outputGeneral| . 1499892) (|qqq| . 1499629) (|multiEuclideanTree| . 1499504) (|fi2df| . 1499364) (|setCurve| . 1498161) (|factorGroebnerBasis| . 1497439) (|upDateBranches| . 1496156) (|lexGroebner| . 1495984) (|sinhIfCan| . 1495843) (|invmultisect| . 1495214) (|copyDrift| . 1495002) (|mainVariable| . 1494239) (|swap| . 1493939) (|integral?| . 1493123) (|cotIfCan| . 1492982) (|setScreenResolution| . 1492907) (|normInvertible?| . 1492516) (|kroneckerDelta| . 1492351) (|rubiksGroup| . 1492238) (|signAround| . 1491494) (|polyRicDE| . 1490515) (|gcdPolynomial| . 1489967) (|fullDesTree| . 1489519) (|getExplanations| . 1489397) (|euler| . 1489127) (|mkPrim| . 1488879) (|initiallyReduce| . 1488436) (|key| . 1488173) (|leftOne| . 1488053) (|elementary| . 1487902) (|aCubic| . 1487662) (|initiallyReduced?| . 1486642) (|decompose| . 1483782) (|defineProperty| . 1483564) (|bezoutDiscriminant| . 1483230) (|number?| . 1483076) (|rewriteSetByReducingWithParticularGenerators| . 1482654) (|interpretString| . 1482543) (|stoseInvertible?sqfreg| . 1482132) (|mpsode| . 1481830) (|linSolve| . 1481379) (|associates?| . 1481289) (|functionIsContinuousAtEndPoints| . 1480668) (EQ . 1480450) (|exptMod| . 1480072) (|splitConstant| . 1479669) (|maxrow| . 1479375) (|aRow| . 1479095) (|readLine!| . 1479017) (|rules| . 1478661) (|setlast!| . 1478518) (|nthExpon| . 1477898) (|times!| . 1477757) (|mkIntegral| . 1477448) (|copyslice| . 1477284) (|quadraticNorm| . 1476970) (|coth2trigh| . 1476755) (|sum| . 1474078) (|semiSubResultantGcdEuclidean1| . 1473853) (|romberg| . 1473553) (|rightLcm| . 1473415) (|addmod| . 1473351) (|Not| . 1473221) (|generic| . 1471535) (|hash| . 1470455) (|symbol| . 1470206) (|pack!| . 1470070) (|typeList| . 1469828) (|ricDsolve| . 1466369) (|leadingCoefficientRicDE| . 1465906) (|integrate| . 1452996) (|Gamma| . 1452272) (|one| . 1452060) (|quasiRegular| . 1451813) (|matrixConcat3D| . 1451678) (|tan2trig| . 1451463) (|generalCoefficient| . 1451065) (|latex| . 1450262) (|ode| . 1449997) (|zero| . 1449605) (|quasiMonicPolynomials| . 1449234) (|redpps| . 1448736) (|Or| . 1448600) (|zRange| . 1448484) (|coleman| . 1448324) (^ . 1447724) (|complexExpand| . 1447076) (|front| . 1446821) (|generalPosition| . 1446428) (|removeCoshSq| . 1446213) (|exp| . 1443946) (|approxNthRoot| . 1443804) (|selectFiniteRoutines| . 1443754) (|setfirst!| . 1443611) (|zag| . 1443561) (|pi| . 1443092) (|squareFree| . 1440579) (|infinite?| . 1440331) (|graeffe| . 1440138) (|stop| . 1440093) (|sqrt| . 1439427) (|cCsch| . 1439267) (|distFact| . 1438625) (|explimitedint| . 1438070) (|totolex| . 1437788) (|digit| . 1437740) (|intcompBasis| . 1437478) (|li| . 1437183) (|subtractIfCan| . 1437106) (|erf| . 1436811) (|numFunEvals3D| . 1436737) (|complexEigenvectors| . 1436400) (|round| . 1436345) (|distribute| . 1436237) (|applyRules| . 1435477) (|sylvesterSequence| . 1435285) (|roughSubIdeal?| . 1434974) (|orderIfNegative| . 1434836) (|dmp2rfi| . 1433672) (|rule| . 1433010) (|dilog| . 1432715) (|derivationCoordinates| . 1432431) (|hclf| . 1432242) (|setnext!| . 1432101) (|seed| . 1432015) (|lp| . 1431884) (|sin| . 1430414) (|reopen!| . 1430253) (|radicalEigenvalues| . 1430072) (|cos| . 1428602) (|ruleset| . 1428246) (|bipolarCylindrical| . 1428037) (|const| . 1427871) (|tan| . 1426493) (|critB| . 1426217) (|binomial| . 1425643) (|cot| . 1424448) (|makeTerm| . 1424293) (|coth2tanh| . 1424078) (|sec| . 1422883) (|iomode| . 1422725) (|LPolynomial| . 1419845) (|csc| . 1418650) (|arrayStack| . 1418532) (|ravel| . 1418336) (|headRemainder| . 1417996) (|asin| . 1416615) (|hadamard| . 1416452) (|acos| . 1415071) (|squareFreePolynomial| . 1414614) (|cAcsch| . 1414454) (|atan| . 1412983) (|makeViewport2D| . 1412788) (|set| . 1412578) (|internalInfRittWu?| . 1411829) (|acot| . 1410631) (|expt| . 1410445) (|semiResultantEuclideannaif| . 1410214) (|asec| . 1409016) (|drawCurves| . 1408538) (|canonicalIfCan| . 1408391) (|showTheIFTable| . 1408331) (|acsc| . 1407133) (|result| . 1406889) (|cosh2sech| . 1406674) (|sinh| . 1405299) (|stFuncN| . 1405000) (|fortranLiteral| . 1404890) (|cosh| . 1403515) (|varList| . 1402140) (|normalizeIfCan| . 1401750) (|rotate!| . 1401495) (|tanh| . 1400120) (|numerators| . 1399989) (|lazyPseudoRemainder| . 1399884) (|coth| . 1398692) (|branchPoint?| . 1398151) (|variableName| . 1397941) (|sech| . 1396749) (|Musser| . 1396538) (|concat| . 1395429) (|csch| . 1394237) (|argumentList!| . 1393826) (|generalizedEigenvectors| . 1393475) (|PDESolve| . 1392918) (|asinh| . 1391723) (|groebnerIdeal| . 1391467) (|perspective| . 1391345) (|acosh| . 1390150) (|lepol| . 1389883) (|maxPoints3D| . 1389809) (|atanh| . 1388614) (|complex?| . 1388526) (|triangularSystems| . 1388278) (|acoth| . 1387083) (|iilog| . 1386887) (|asech| . 1385692) (|baseRDE| . 1385362) (|lists| . 1385136) (|cyclicParents| . 1385015) (|dmpToHdmp| . 1384766) (|checkForZero| . 1383875) (|factorPolynomial| . 1383418) (|ptree| . 1383236) (|rationalIfCan| . 1381836) (|delay| . 1381587) (|listAllMono| . 1381305) (|choosemon| . 1381040) (|leader| . 1380793) (|dcopy| . 1380641) (|primPartElseUnitCanonical!| . 1380417) (|BumInSepFFE| . 1380054) (|#| . 1378673) (|closedCurve| . 1378153) (|setref| . 1378068) (|tanAn| . 1377888) (|setAttributeButtonStep| . 1377803) (|dnrm2| . 1377625) (|lBasis| . 1375281) (|find| . 1375140) (|OMreceive| . 1375013) (|modifyPoint| . 1374415) (|log2| . 1374292) (|functionNames| . 1374202) (|getStream| . 1374024) (|zeroDimensional?| . 1373571) (|semiIndiceSubResultantEuclidean| . 1373295) (|directSum| . 1372927) (|pol| . 1372729) (|selectfirst| . 1372605) (|curve| . 1371896) (|cCot| . 1371736) (|compactFraction| . 1371637) (|collectQuasiMonic| . 1371384) (|basisOfRightNucleus| . 1371206) (|normalizedAssociate| . 1370892) (|hexDigit?| . 1370812) (|increasePrecision| . 1370640) (|makeCrit| . 1370181) (|branchIfCan| . 1369192) (|functionIsOscillatory| . 1368889) (|inc| . 1368831) (|removeRedundantFactorsInContents| . 1368509) (|createNormalElement| . 1368378) (|column| . 1367905) (|OMputString| . 1367793) (|univariatePolynomialsGcds| . 1367127) (|coshIfCan| . 1366986) (|fortranTypeOf| . 1366870) (|sizeLess?| . 1366779) (|null| . 1366674) (|maxint| . 1366494) (|aQuartic| . 1366251) (|divisorAtDesingTree| . 1365586) (|e01sff| . 1365366) (|discriminant| . 1363989) (|has?| . 1363875) (|atanIfCan| . 1363734) (|retract| . 1354526) (|curveV| . 1353928) (|digamma| . 1353485) (|replaceVarByOne| . 1353199) (|integral| . 1352214) (|localIntegralBasis| . 1350755) (|getEq| . 1350402) (|unrankImproperPartitions0| . 1350253) (D . 1348698) (FG2F . 1348336) (|symbol?| . 1347947) (|factorSquareFreeByRecursion| . 1347251) (|inverseIntegralMatrix| . 1346967) (|formula| . 1346869) (|pastel| . 1346793) (|singularPointsWithRestriction| . 1346386) (|leftTrace| . 1346269) (|prepareSubResAlgo| . 1345865) (|characteristicSerie| . 1345091) (|groebnerFactorize| . 1343644) (|removeCosSq| . 1343429) (|userOrdered?| . 1343298) (|parabolicCylindrical| . 1343114) (|listConjugateBases| . 1342609) (|minPoints3D| . 1342535) (|curryRight| . 1342292) (|numeric| . 1340715) (|rur| . 1339095) (|stFunc1| . 1338814) (|cardinality| . 1338675) (|radical| . 1338331) (|setelt!| . 1338178) (|tensorProduct| . 1337663) (|sylvesterMatrix| . 1337369) (|leftRemainder| . 1337075) (|tab1| . 1336898) (|assoc| . 1336683) (|branchPointAtInfinity?| . 1336414) (|genericLeftDiscriminant| . 1336105) (|linearlyDependentOverZ?| . 1335919) (|ratPoly| . 1335464) (|setsubmult!| . 1334935) (|index| . 1334400) (|SturmHabichtSequence| . 1334157) (|normalizeAtInfinity| . 1333883) (|OMclose| . 1333801) (|point| . 1332785) (|exprToUPS| . 1331906) (|setleft!| . 1331762) (|iidprod| . 1331564) (|min| . 1331075) (|contract| . 1330293) (|alternative?| . 1329953) (|logpart| . 1329689) (|curry| . 1329489) (|maxLevel| . 1329211) (|extractClosed| . 1329065) (|trailingCoefficient| . 1328908) (|checkExtraValues| . 1328696) (|cSinh| . 1328536) (|toseSquareFreePart| . 1328144) (|upperCase?| . 1328064) (|pseudoRemainder| . 1327958) (|numberPlacesDegExtDeg| . 1326540) (|f2df| . 1326415) (|reduceBasisAtInfinity| . 1326141) (|findCoef| . 1326010) (|rem| . 1325851) (|Ei5| . 1325726) (|factorSFBRlcUnit| . 1324999) (|acscIfCan| . 1324858) (|translate| . 1323835) (|rightMult| . 1323680) (|singularPoints| . 1322067) (|gcd| . 1319647) (|viewDeltaXDefault| . 1319467) (|quo| . 1319308) (|powerSum| . 1319157) (|exponent| . 1318373) (|wordsForStrongGenerators| . 1318220) (|table| . 1317892) (|psolve| . 1311224) (|interReduce| . 1310937) (|dominantTerm| . 1310263) (|excepCoord| . 1310170) (|acschIfCan| . 1310029) (|variationOfParameters| . 1309802) (|third| . 1309704) (|sizeMultiplication| . 1308795) (|generalTwoFactor| . 1308520) (|lllip| . 1308361) (|Ei4| . 1308236) (|sign| . 1305818) (|semiLastSubResultantEuclidean| . 1305584) (|height| . 1304650) (|mkcomm| . 1304522) (|cAtan| . 1304362) (|discriminantEuclidean| . 1304114) (|returns| . 1303478) (|functionName| . 1303268) (|laplacian| . 1302943) (|froot| . 1302388) (|lieAlgebra?| . 1302048) (|removeConstantTerm| . 1301844) (|first| . 1300876) (|rightDiscriminant| . 1300460) (|normal| . 1300326) (|indiceSubResultantEuclidean| . 1300033) (|uniform| . 1299599) (|sequences| . 1299293) (|generalizedInverse| . 1299037) (|f02awf| . 1298866) (|nonSingularModel| . 1298158) (|subset?| . 1298033) (|OMgetEndError| . 1297951) (|f02akf| . 1297774) (|listOfTerms| . 1297125) (|ShiftAction| . 1296901) (|qroot| . 1296337) (|more?| . 1295281) (|f02ajf| . 1295110) (|normalize| . 1294011) (|printCode| . 1293932) (|monomialIntegrate| . 1293578) (|monomialIntPoly| . 1293320) (|f02agf| . 1293149) (|rightGcd| . 1293011) (|universe| . 1292885) (|contains?| . 1292704) (|reseed| . 1292590) (|subNode?| . 1292334) (|generic?| . 1292219) (|right| . 1291638) (|OMputObject| . 1291556) (|infiniteProduct| . 1290670) (|startPolynomial| . 1290401) (|f02aff| . 1290236) (|iiBesselK| . 1290034) (|left| . 1289453) (|OMputEndBVar| . 1289371) (|SturmHabichtMultiple| . 1289124) (|showTypeInOutput| . 1289023) (|f02aef| . 1288849) (|associatorDependence| . 1288450) (|chineseRemainder| . 1287531) (|compose| . 1287246) (|localPointV| . 1286704) (|f02adf| . 1286533) (|palgint0| . 1285518) (|makeSketch| . 1285317) (|escape| . 1285274) (|order| . 1280649) (|generalizedEigenvector| . 1279881) (|f02abf| . 1279713) (|numberOfComputedEntries| . 1279580) (|ocf2ocdf| . 1279411) (|leftMinimalPolynomial| . 1279207) (|reducedQPowers| . 1278972) (|f02aaf| . 1278807) (|screenResolution3D| . 1278733) (|complexRoots| . 1278215) (|setFieldInfo| . 1277973) (|subs2ndVar| . 1277715) (|taylor| . 1273864) (|rationalPlaces| . 1272613) (|measure| . 1267703) (|subHeight| . 1267622) (|chiSquare| . 1267478) (|iicos| . 1267282) (|laurent| . 1264135) (|sub| . 1264085) (|supRittWu?| . 1263867) (|twist| . 1263624) (|packModulus| . 1263358) (|reciprocalPolynomial| . 1263165) (|puiseux| . 1259989) (|sts2stst| . 1259762) (|structuralConstants| . 1258546) (|delta| . 1258360) (|postfix| . 1258310) (|continuedFraction| . 1257381) (|partialNumerators| . 1257250) (|ef2edf| . 1257095) (|associator| . 1257033) (|thetaCoord| . 1256919) (|chiSquare1| . 1256787) (|eigenvalues| . 1256531) (|bsolve| . 1255688) (|polynomial| . 1254891) (|pquo| . 1254511) (|zeta| . 1254428) (|OMgetFloat| . 1254339) (|identity| . 1254201) (|getGraph| . 1254066) (|axServer| . 1253903) (|palgint| . 1253454) (|curryLeft| . 1253211) (|dequeue| . 1252814) (|e01sbf| . 1252555) (|mainCoefficients| . 1252340) (|exp1| . 1252259) (|trivialIdeal?| . 1251988) (|iifact| . 1251818) (|imagI| . 1251615) (|extractSplittingLeaf| . 1251429) (|En| . 1251241) (|gradient| . 1250886) (|reduceLODE| . 1250473) (|reducedSystem| . 1250076) (|OMconnectTCP| . 1249920) (|linear?| . 1249362) (|isobaric?| . 1249087) (|newtonPolySlope| . 1248635) (|rightPower| . 1248449) (|mapExponents| . 1247979) (|contractSolve| . 1247323) (|radicalEigenvector| . 1247085) (|oblateSpheroidal| . 1246876) (|corrPoly| . 1246316) (|checkRur| . 1245871) (|setlocalParam!| . 1245333) (|distinguishedCommonRootsOf| . 1245095) (|split| . 1243022) (|lambda| . 1242931) (|preprocess| . 1242076) (|transCoord| . 1241983) (|imagJ| . 1241780) (|iiacosh| . 1241584) (|goodnessOfFit| . 1241246) (|stoseSquareFreePart| . 1240844) (|vectoraddmul| . 1240674) (|Somos| . 1240402) (|henselFact| . 1239829) (|space| . 1239542) (|leaves| . 1239421) (|remainder| . 1239062) (|option?| . 1238911) (|tanhIfCan| . 1238770) (|palglimint0| . 1237511) (|extractPoint| . 1237364) (|multiple?| . 1237249) (|createMultiplicationTable| . 1236995) (|radicalOfLeftTraceForm| . 1236817) (|toseInvertibleSet| . 1236465) (|makeViewport3D| . 1236109) (|mergeFactors| . 1235966) (|adjunctionDivisor| . 1234110) (|getOrder| . 1233931) (|factorByRecursion| . 1233235) (|divideIfCan| . 1232979) (|dictionary| . 1232753) (|asinhIfCan| . 1232612) (|inBetweenExcpDiv| . 1231950) (|posExpnPart| . 1231850) (|domainOf| . 1231773) (|binomThmExpt| . 1231546) (|firstUncouplingMatrix| . 1231283) (|semiSubResultantGcdEuclidean2| . 1231058) (|insert!| . 1228088) (|cAsech| . 1227928) (|legendre| . 1227655) (|invertibleElseSplit?| . 1227347) (|spherical| . 1227163) (|setMaxPoints| . 1227088) (|lieAdmissible?| . 1226748) (|desingTreeWoFullParam| . 1225468) (|hcrf| . 1225279) (|showTheFTable| . 1225220) (|monicCompleteDecompose| . 1224980) (|mdeg| . 1224754) (|surface| . 1224658) (|difference| . 1224467) (|moebiusMu| . 1224368) (|rational| . 1223048) (|normal?| . 1222522) (|leftDiscriminant| . 1222106) (|standardBasisOfCyclicSubmodule| . 1221871) (|topFortranOutputStack| . 1221779) (|LyndonWordsList| . 1221580) (|parabolic| . 1221396) (|resultantEuclidean| . 1221148) (|countable?| . 1221063) (|maxrank| . 1220495) (|stiffnessAndStabilityOfODEIF| . 1220019) (|lift| . 1218118) (|palgLODE| . 1217515) (|viewport2D| . 1217459) (|lcm| . 1217144) (|meatAxe| . 1216062) (|reduce| . 1209477) (|divergence| . 1209152) (|irreducibleFactors| . 1208786) (|minimalForm| . 1207862) (|iiBeta| . 1207660) (|e02bcf| . 1207455) (|bubbleSort!| . 1206912) (|realRoots| . 1206448) (|additive?| . 1206295) (|e02bbf| . 1206093) (|var2StepsDefault| . 1205903) (|graphState| . 1205650) (|exponential| . 1205287) (|factor1| . 1204807) (|e02baf| . 1204631) (|graphs| . 1204354) (|useEisensteinCriterion?| . 1204199) (|stopTableInvSet!| . 1203506) (|multiServ| . 1203395) (|e02akf| . 1203184) (|superscript| . 1203092) (|extractBottom!| . 1202917) (|addPointLast| . 1202722) (|ldf2vmf| . 1202570) (|pattern| . 1202253) (|divisor| . 1200755) (|e02ajf| . 1200538) (|csc2sin| . 1200323) (|constantKernel| . 1200162) (|cos2sec| . 1199947) (|fullParamInit| . 1199257) (|children| . 1198977) (|e04ycf| . 1198761) (|cache| . 1198645) (|augment| . 1197454) (|multiplyCoefficients| . 1197006) (|quote| . 1196919) (|intensity| . 1196798) (|e04ucf| . 1196254) (|rotate| . 1196007) (|zero?| . 1195291) (|element?| . 1195032) (|dark| . 1194956) (|e04naf| . 1194547) (|digits| . 1193926) (|measure2Result| . 1193480) (|resultant| . 1192597) (|tan2cot| . 1192382) (|karatsubaOnce| . 1192208) (|smaller?| . 1192122) (|datalist| . 1192007) (|e04mbf| . 1191774) (|finiteBound| . 1191589) (|projectivePoint| . 1190848) (|irreducibleFactor| . 1190726) (|monicDecomposeIfCan| . 1190444) (|center| . 1189903) (|e04jaf| . 1189638) (|twoFactor| . 1189332) (|base| . 1188889) (|affinePoint| . 1188766) (|paraboloidal| . 1188582) (|SturmHabicht| . 1188367) (|e04gcf| . 1188108) (|mindegTerm| . 1187910) (|baseRDEsys| . 1187601) (|computeBasis| . 1187388) (|power| . 1187226) (|tanIfCan| . 1187085) (|e04fdf| . 1186826) (|OMserve| . 1186700) (|rhs| . 1186190) (|rectangularMatrix| . 1185990) (|hdmpToP| . 1185767) (|evaluateInverse| . 1185489) (|systemCommand| . 1185376) (|e04dgf| . 1185033) (|superHeight| . 1184952) (|pole?| . 1184633) (|selectOptimizationRoutines| . 1184583) (|pointV| . 1184078) (|denominators| . 1183947) (|f01ref| . 1183720) (|mapSolve| . 1183336) (|trim| . 1183148) (|checkOptions| . 1183018) (|definingInequation| . 1182785) (|ran| . 1182528) (|f01rdf| . 1182292) (|OMgetEndApp| . 1182210) (|pseudoRem| . 1182070) (LODO2FUN . 1181756) (|midpoints| . 1181469) (|iisech| . 1181273) (|f01rcf| . 1181082) (|setFoundPlacesToEmpty| . 1180914) (|vark| . 1180680) (|df2mf| . 1180548) (|csch2sinh| . 1180333) (|partitions| . 1179898) (|/\\| . 1179801) (|iicosh| . 1179605) (|f01qef| . 1179390) (|makeMulti| . 1179172) (|combineFeatureCompatibility| . 1178964) (|imagj| . 1178862) (|desingTree| . 1176893) (|\\/| . 1176796) (|f01qdf| . 1176572) (|autoReduced?| . 1176233) (|removeFirstZeroes| . 1176133) (|plus| . 1175694) (|OMgetAttr| . 1175612) (|lowerPolynomial| . 1175283) (|f01qcf| . 1175104) (|doubleDisc| . 1174869) (|controlPanel| . 1174630) (|withPredicates| . 1174507) (|numberOfChildren| . 1174350) (|bag| . 1173680) (|cAcoth| . 1173520) (|f01mcf| . 1173302) (|getMatch| . 1173123) (|critBonD| . 1172757) (|search| . 1172610) (|nextColeman| . 1172450) (|normal01| . 1172360) (~= . 1171535) (|meshPar2Var| . 1170504) (|f01maf| . 1170199) (|safetyMargin| . 1169857) (|rightRankPolynomial| . 1169090) (|primintegrate| . 1168671) (|power!| . 1168485) (|f01bsf| . 1168183) (|sinhcosh| . 1167942) (|leftFactor| . 1167775) (|convergents| . 1167631) (|dim| . 1167555) (|newLine| . 1167474) (|cCos| . 1167314) (|f01brf| . 1166978) (|showTheSymbolTable| . 1166930) (|octon| . 1166681) (|drawComplexVectorField| . 1166448) (|increment| . 1166296) (|zeroSquareMatrix| . 1166129) (|rowEchelonLocal| . 1165981) (|integerIfCan| . 1165840) (|setEmpty!| . 1165664) (|mask| . 1165606) (|rightExtendedGcd| . 1165386) (|lyndon| . 1165256) (|weierstrass| . 1165049) (|dom| . 1164971) (|factorAndSplit| . 1164812) (|An| . 1164644) (|iisqrt2| . 1164451) (|pureLex| . 1164244) (|nextsubResultant2| . 1164011) (|harmonic| . 1163871) (|lfinfieldint| . 1163499) (|allRootsOf| . 1162457) (|drift| . 1162328) (|OMconnOutDevice| . 1162232) (|listRepresentation| . 1162059) (|parse| . 1161980) (|internalLastSubResultant| . 1161054) (|dec| . 1160996) (|fglmIfCan| . 1160579) (|iitanh| . 1160383) (|gethi| . 1159897) (|plenaryPower| . 1159751) (|laguerre| . 1159590) (|rarrow| . 1159540) (|OMread| . 1159423) (|orbits| . 1159292) (|guess| . 1147793) (|fresnelS| . 1147405) (|viewSizeDefault| . 1147197) (|outlineRender| . 1147075) (|inverseLaplace| . 1146644) (|coefOfFirstNonZeroTerm| . 1146544) (|lazyResidueClass| . 1146018) (|newTypeLists| . 1145932) (|cap| . 1145765) (|square?| . 1145311) (|insertionSort!| . 1144768) (|denomRicDE| . 1144390) (|drawComplex| . 1144126) (|outputSpacing| . 1144014) (|OMconnInDevice| . 1143918) (|leftTrim| . 1143730) (|bitTruth| . 1143617) (|errorKind| . 1143523) (|addMatchRestricted| . 1143348) (|var2Steps| . 1143120) (|lyndonIfCan| . 1142980) (|bombieriNorm| . 1142316) (|gbasis| . 1142015) (|pointInIdeal?| . 1141637) (|cyclePartition| . 1141516) (LE . 1141298) (|singularitiesOf| . 1140433) (|value| . 1140009) (|expintfldpoly| . 1139685) (|subscriptedVariables| . 1139579) (|genericLeftTraceForm| . 1139264) (|writeLine!| . 1139108) (|OMputFloat| . 1138991) (|blockSplit| . 1137621) (|deref| . 1137539) (|exprHasWeightCosWXorSinWX| . 1137169) (|subresultantSequence| . 1136926) (|properties| . 1136814) (BY . 1136693) (|lagrange| . 1136200) (|divide!| . 1136036) (|print| . 1135850) (|cn| . 1135675) (|belong?| . 1133967) (|heap| . 1133856) (|OMgetVariable| . 1133772) (|rightOne| . 1133652) (|middle| . 1133459) (|squareFreePart| . 1132624) (|setErrorBound| . 1132431) (|groebner?| . 1132175) (|interpolateForms| . 1130145) (|swap!| . 1129944) (|getSmgl| . 1129837) (|lastNonNull| . 1129710) (|iicsc| . 1129514) (|patternVariable| . 1129363) (|horizSplit| . 1128741) (|minPoly| . 1128283) (|acoshIfCan| . 1128142) (|numberOfNormalPoly| . 1127990) (|script| . 1127626) (|besselK| . 1127171) (|indicialEquationAtInfinity| . 1126531) (|guessHolo| . 1122196) (|selectIntegrationRoutines| . 1122146) (|ODESolve| . 1121709) (|gcdPrimitive| . 1120905) (|setButtonValue| . 1120675) (|viewZoomDefault| . 1120495) (|imagE| . 1120393) (|flush| . 1120237) (|numerator| . 1119860) (|zeroDimPrime?| . 1119488) (|declare| . 1119370) (|symmetricProduct| . 1119002) (|genericRightDiscriminant| . 1118693) (|pair?| . 1118416) (|infClsPt?| . 1118323) (|radicalSimplify| . 1117985) (|bright| . 1117702) (|semiResultantEuclidean1| . 1117471) (|commutative?| . 1117131) (|readLineIfCan!| . 1117043) (|transcendent?| . 1116925) (|primextendedint| . 1116433) (|OMUnknownSymbol?| . 1116345) (|setStatus!| . 1116138) (|se2rfi| . 1115729) (|laurentIfCan| . 1115542) (|bottom!| . 1115367) (|output| . 1114845) (|associatedEquations| . 1114444) (|nextPartition| . 1114108) (|lfintegrate| . 1113705) (|fortran| . 1113493) (|setRow!| . 1113257) (|symmetricGroup| . 1112955) (|declare!| . 1112196) (|purelyTranscendental?| . 1111910) (|OMreadFile| . 1111801) (|size?| . 1110912) (|numberOfFactors| . 1110535) (|rightDivide| . 1110025) (|isPower| . 1109177) (|outputArgs| . 1108805) (|columns| . 1108227) (|unit| . 1107893) (|cosSinInfo| . 1107759) (|iidigamma| . 1107585) (|series| . 1101717) (|makeVariable| . 1100931) (|primeFactor| . 1100809) (|statusIto| . 1100652) (|numberOfOperations| . 1100364) (|lookup| . 1100096) (|sparsityIF| . 1099953) (|fortranCharacter| . 1099908) (|factorsOfCyclicGroupSize| . 1099755) (|makeop| . 1099449) (|parametric?| . 1099374) (|roman| . 1099212) (|overbar| . 1099165) (|logIfCan| . 1099024) (|OMsetEncoding| . 1098902) (|iiasec| . 1098706) (|merge!| . 1098235) (|divOfZero| . 1098138) (|constantLeft| . 1097898) (|cup| . 1097772) (|assert| . 1097353) (|predicates| . 1097233) (|rroot| . 1096710) (|divideExponents| . 1096555) (|numFunEvals| . 1096483) (|linearlyDependent?| . 1096273) (|besselY| . 1095818) (|frobenius| . 1095638) (|subs1stVar| . 1095380) (|mainPrimitivePart| . 1095161) (|routines| . 1095114) (|leadingIdeal| . 1094886) (|binaryTournament| . 1094763) (|rightRecip| . 1094540) (|list?| . 1094263) (|createLowComplexityNormalBasis| . 1093979) (|lexico| . 1093623) (|ridHack1| . 1093517) (|qShiftC| . 1093268) (|sh| . 1092904) (|pleskenSplit| . 1092420) (|stoseInvertible?reg| . 1092009) (|someBasis| . 1091865) (GE . 1091647) (|pointPlot| . 1090981) (|algebraicSort| . 1090294) (|mainValue| . 1090174) (|optAttributes| . 1089670) (|asechIfCan| . 1089529) (|iiGamma| . 1089355) (|internalAugment| . 1088094) (^= . 1088044) (|updateStatus!| . 1087868) (|resetNew| . 1087797) (|affineRationalPoints| . 1086906) (|decrease| . 1086682) (|resultantReduitEuclidean| . 1086396) (|computeCycleLength| . 1086219) (|basicSet| . 1085364) (|basisOfInterpolateForms| . 1084803) (|randomLC| . 1084450) (|outputAsTex| . 1084206) (|OMgetEndObject| . 1084124) (|selectPDERoutines| . 1084074) (|fortranDoubleComplex| . 1084029) (|commaSeparate| . 1083817) (|derivative| . 1083258) (|algSplitSimple| . 1082886) (|yCoord| . 1082772) (|presuper| . 1082722) (|OMgetEndAtp| . 1082640) (|rk4a| . 1082347) (|padicFraction| . 1082248) (|reverseLex| . 1082041) (|foundZeroes| . 1081923) (|brillhartIrreducible?| . 1081621) (|groebner| . 1079870) (|associative?| . 1079530) (|epilogue| . 1079347) (|flexible?| . 1079007) (|raisePolynomial| . 1078678) (|divide| . 1077719) (|hasHi| . 1077602) (|noLinearFactor?| . 1077451) (|packExps| . 1077244) (|wordInStrongGenerators| . 1077062) (|relerror| . 1076983) (|ramified?| . 1076442) (|LowTriBddDenomInv| . 1076181) (|interpret| . 1075986) (|nonQsign| . 1075863) (|showFortranOutputStack| . 1075761) (|setLabelValue| . 1075673) (|printStats!| . 1075507) (|solveLinearlyOverQ| . 1075284) (|nary?| . 1075200) (|factorUsingMusser| . 1074776) (|associatedSystem| . 1074459) (|degreePartition| . 1073955) (|prologue| . 1073772) (|stoseIntegralLastSubResultant| . 1073367) (|tex| . 1073279) (|bivariate?| . 1072992) (|nthr| . 1072460) (|supersub| . 1072364) (|cycleSplit!| . 1072224) (|factorOfDegree| . 1070803) (|sinIfCan| . 1070662) (|lexTriangular| . 1070357) (|linears| . 1070195) (|vspace| . 1070114) (|rombergo| . 1069814) (|localParamOfSimplePt| . 1069292) (|schwerpunkt| . 1069080) (|lazyVariations| . 1068784) (|mathieu24| . 1068521) (|ref| . 1068439) (|delete| . 1068179) (|stopTable!| . 1067504) (|expenseOfEvaluation| . 1067154) (|createRandomElement| . 1066987) (|desingTreeAtPoint| . 1066323) (|objectOf| . 1066246) (|leftAlternative?| . 1065906) (|dihedralGroup| . 1065604) (|maxDerivative| . 1065326) (|lcmCoef| . 1065185) (|cycleElt| . 1065037) (|padecf| . 1064732) (|minPol| . 1064072) (|fractRadix| . 1063946) (|factorial| . 1063598) (|pseudoQuotient| . 1063455) (|eigenMatrix| . 1063262) (|argument| . 1062906) (|recolor| . 1062641) (|makeSin| . 1062433) (|stoseInvertibleSetreg| . 1062071) (|level| . 1061914) (|collect| . 1061574) (|nthExponent| . 1061452) (|iCompose| . 1061344) (|even?| . 1061003) (|ode1| . 1060775) (|fixPredicate| . 1060477) (|toScale| . 1060265) (|mathieu22| . 1060002) (|critMTonD1| . 1059639) (|mathieu11| . 1059376) (|janko2| . 1059113) (|nullity| . 1057937) (|makeCos| . 1057729) (|exists?| . 1057640) (|setprevious!| . 1057499) (|elliptic?| . 1056969) (|rootOf| . 1055473) (|submod| . 1055409) (|extension| . 1055321) (|SFunction| . 1055161) (|argscript| . 1055069) (|d02cjf| . 1054577) (|sample| . 1053848) (|duplicates?| . 1053721) (|extractIfCan| . 1053567) (|basisOfLeftNucloid| . 1053378) (|findTerm| . 1053180) (|vectorcombination| . 1053007) (|d02bhf| . 1052622) (|OMputApp| . 1052540) (|shallowExpand| . 1052329) (|maxPower| . 1052057) (|d02bbf| . 1051667) (|less?| . 1050451) (|fixedDivisor| . 1050290) (|nullSpace| . 1048583) (|trigs2explogs| . 1048140) (|iiacsch| . 1047944) (|hue| . 1047684) (|rk4f| . 1047397) (|e02ahf| . 1047183) (|rootPower| . 1046626) (|ParCond| . 1046118) (|lazyPremWithDefault| . 1045540) (|substring?| . 1045418) (|alterQuadVar!| . 1045225) (|stoseInternalLastSubResultant| . 1044279) (|ddot| . 1044095) (|multisect| . 1043466) (|guessAlg| . 1039131) (|minRowIndex| . 1038664) (|finiteSeries2LinSys| . 1038414) (|topPredicate| . 1038247) (|sorted?| . 1037920) (|mapUnivariateIfCan| . 1037559) (|multiplicative?| . 1037406) (|restorePrecision| . 1037320) (|char| . 1037164) (|packageCall| . 1037015) (|fortranLogical| . 1036970) (** . 1031126) (|linearPolynomials| . 1030755) (|d03faf| . 1030416) (|every?| . 1029221) (|integralCoordinates| . 1028909) (|symmetricTensors| . 1028575) (|quotValuation| . 1028482) (|applyTransform| . 1028175) (|univariate?| . 1027888) (|d03eef| . 1027511) (|transpose| . 1026659) (|any?| . 1025464) (|next| . 1025368) (|build| . 1024889) (|squareFreeFactors| . 1024570) (|d03edf| . 1024332) (|evalRec| . 1023891) (|keys| . 1023040) (|element| . 1022757) (|fresnelC| . 1022369) (|patternMatchTimes| . 1021899) (|dasum| . 1021721) (|univariatePolynomials| . 1021350) (|antiAssociative?| . 1021010) (|singularAtInfinity?| . 1020741) (|medialSet| . 1020075) (|suffix?| . 1019984) (|fortranCarriageReturn| . 1019904) (|cPower| . 1019741) (F2FG . 1019379) (|airyAi| . 1018936) (|prod| . 1018792) (|primlimitedint| . 1018251) (|evaluate| . 1017260) (|perfectSquare?| . 1017132) (|denomLODE| . 1016309) (|suppOfPole| . 1016184) (|numericIfCan| . 1014816) (|suppOfZero| . 1014691) (|name| . 1014048) (|polyRingToBlUpRing| . 1013650) (|tanSum| . 1013531) (|subResultantChain| . 1013276) (|noncommutativeJordanAlgebra?| . 1012936) (|convertIfCan| . 1012829) (|bits| . 1012477) (|subresultantVector| . 1012277) (|getPickedPoints| . 1012161) (|lazyPseudoQuotient| . 1012056) (|invertibleSet| . 1011770) (|localParamV| . 1011235) (|cyclicCopy| . 1011151) (|constantCoefficientRicDE| . 1010657) (|deepExpand| . 1010446) (|vedf2vef| . 1010269) (|Ei| . 1009852) (|true| . 1009811) (|member?| . 1008342) (|icamax| . 1008196) (|innerEigenvectors| . 1007745) (|introduce!| . 1007635) (|innerint| . 1006995) (|addPoint2| . 1006845) (|vertSplit| . 1006223) (|leftRankPolynomial| . 1005456) (|ldf2lst| . 1005033) (|nextNormalPoly| . 1004857) (|rewriteIdealWithRemainder| . 1004546) (|returnTypeOf| . 1004379) (|LyndonWordsList1| . 1004156) (|coefficients| . 1003313) (|dot| . 1002802) (|algebraicDecompose| . 1001854) (|symbolTableOf| . 1001735) (|getCurve| . 1001631) (|binarySearchTree| . 1001508) (|changeVar| . 1000730) (|reverse!| . 1000271) (|cAcot| . 1000111) (|chartCoord| . 1000018) (|log10| . 999712) (|diagonalMatrix| . 998439) (|mesh| . 997151) (|implies| . 997104) (|sayLength| . 996874) (|copyBSD| . 996750) (|shiftLeft| . 996605) (|numberOfImproperPartitions| . 996496) (|curveColorPalette| . 996362) (|palgRDE| . 995868) (|traceMatrix| . 995244) (|c05nbf| . 994961) (|ReduceOrder| . 994544) (|fractionPart| . 993930) (|prefix?| . 993839) (|equation| . 993104) (|zeroSetSplit| . 989406) (|genericRightNorm| . 989094) (|aLinear| . 988860) (|positiveRemainder| . 988799) (|intPatternMatch| . 988125) (|c05adf| . 987887) (|inverse| . 986158) (|map| . 960750) (|antiCommutator| . 960691) (|binaryTree| . 960508) (|guessRat| . 953455) (|bit?| . 953360) (|expextendedint| . 952854) (|c06gsf| . 952679) (|maxColIndex| . 952212) (|minimalPolynomial| . 951457) (|tensorMap| . 951296) (|leadingExponent| . 950823) (|zeroVector| . 950656) (|deriv| . 950525) (|c06gqf| . 950350) (|bat1| . 950173) (|characteristicPolynomial| . 948228) (|rightScalarTimes!| . 948087) (|displayKind| . 948006) (|antiCommutative?| . 947666) (|pointToPlace| . 947205) (|removeDuplicates!| . 946977) (|c06gcf| . 946805) (|isMult| . 946584) (|primaryDecomp| . 946032) (|squareTop| . 945843) (|explogs2trigs| . 945450) (|c06gbf| . 945278) (|shallowCopy| . 945160) (|lazyPrem| . 944780) (|leftMult| . 944625) (|guessBinRat| . 937572) (|mergeDifference| . 937452) (|makeSUP| . 937299) (|filterUpTo| . 937168) (|c06fuf| . 936954) (|cycle| . 936825) (|adaptive?| . 936753) (|resultantReduit| . 936555) (|halfExtendedSubResultantGcd1| . 936003) (|permanent| . 935783) (|low| . 935693) (|generalizedContinuumHypothesisAssumed| . 935608) (|explicitlyEmpty?| . 935486) (|cot2trig| . 935271) (|cycleEntry| . 935173) (|c06frf| . 934962) (|splitLinear| . 934856) (|sumOfKthPowerDivisors| . 934715) (|finiteBasis| . 934415) (|primitive?| . 934132) (|origin| . 934040) (|maxShift| . 933762) (|binary| . 933572) (|c06fqf| . 933364) (|realSolve| . 931263) (|permutation| . 930906) (|totalGroebner| . 930734) (|radicalSolve| . 928469) (|lambert| . 927976) (E1 . 927819) (|c06fpf| . 927611) (|smith| . 927363) (|randnum| . 927191) (|mathieu12| . 926928) (|atanhIfCan| . 926787) (|changeNameToObjf| . 926671) (|eval| . 915683) (|LiePoly| . 915513) (|minimumExponent| . 915353) (|internalZeroSetSplit| . 914592) (|c06ekf| . 914414) (|quatern| . 914301) (|setCondition!| . 914122) (|child?| . 913964) (|denominator| . 913577) (|createPrimitiveNormalPoly| . 913375) (|guessExpRat| . 906322) (|wronskianMatrix| . 905861) (|selectAndPolynomials| . 905435) (|c06ecf| . 905260) (|subTriSet?| . 904567) (|stopTableGcd!| . 903874) (|chainSubResultants| . 903680) (|replaceDiffs| . 903257) (|leftRegularRepresentation| . 902937) (|goppaCode| . 901637) (|c06ebf| . 901465) (|leastPower| . 901146) (|OMencodingBinary| . 901096) (|split!| . 900925) (|pushucoef| . 900508) (|numberOfDivisors| . 900409) (|radix| . 900256) (|c06eaf| . 900084) (|reducedContinuedFraction| . 899950) (|setMinPoints| . 899875) (|basis| . 898245) (|tube| . 897841) (|s17def| . 897602) (|xCoord| . 897488) (|light| . 897412) (|LiePolyIfCan| . 897039) (|basisOfMiddleNucleus| . 896861) (|Yun| . 896650) (|seriesToOutputForm| . 896297) (|genericRightTrace| . 895985) (|s17dcf| . 895746) (|halfExtendedResultant1| . 895505) (|insertTop!| . 895324) (|cyclotomicDecomposition| . 895158) (|createHN| . 894945) (|OMopenFile| . 894818) (|useSingleFactorBound?| . 894663) (|nthFractionalTerm| . 894533) (|s17akf| . 894374) (|resultantnaif| . 894208) (|ranges| . 893761) (|btwFact| . 893380) (|repeating?| . 893208) (|isamax| . 893074) (|s17ajf| . 892915) (|color| . 892728) (|llprop| . 892571) (|guessRec| . 885518) (|pdf2df| . 885372) (|cLog| . 885212) (|message| . 885132) (|conical| . 884920) (|condition| . 884744) (|s17ahf| . 884585) (|headReduce| . 884142) (|leastAffineMultiple| . 883976) (|constantRight| . 883736) (|UnVectorise| . 883568) (|purelyAlgebraicLeadingMonomial?| . 883282) (|genericLeftTrace| . 882970) (|s17agf| . 882811) (|viewWriteDefault| . 882621) (|getVariableOrder| . 882462) (|transcendentalDecompose| . 880547) (|head| . 880107) (|stack| . 879994) (|s17aff| . 879835) (|OMputInteger| . 879722) (|linearAssociatedExp| . 879535) (|selectsecond| . 879411) (|infLex?| . 879106) (|characteristic| . 877420) (|indices| . 877264) (|s17aef| . 877105) (|commutator| . 877002) (|approximants| . 876858) (|taylorRep| . 876682) (|UP2ifCan| . 876218) (|cAcosh| . 876058) (|makeFloatFunction| . 875620) (|s17adf| . 875461) (|uncorrelated?| . 874871) (|mainForm| . 874770) (|close| . 874495) (|optimize| . 873259) (|argumentListOf| . 873136) (|zeroSetSplitIntoTriangularSystems| . 872777) (|s17acf| . 872618) (|stripCommentsAndBlanks| . 872531) (|innerSolve1| . 872000) (|clikeUniv| . 871782) (|modifyPointData| . 871439) (|oneDimensionalArray| . 871188) (|adaptive| . 870811) (|s15aef| . 870652) (|setClipValue| . 870566) (|newElement| . 869985) (|create3Space| . 869771) (|unvectorise| . 869166) (|Zero| . 868865) (|key?| . 868700) (LT . 868482) (|s15adf| . 868323) (|iiasinh| . 868127) (|sn| . 867952) (|lazyPseudoDivide| . 867045) (|setImagSteps| . 866963) (|drot| . 866739) (|inRadical?| . 866480) (|s14baf| . 866315) (|sPol| . 865961) (|retractIfCan| . 858265) (|decomposeFunc| . 858050) (|rightUnit| . 857889) (|display| . 856617) (|scalarTypeOf| . 856483) (|setexcpDiv!| . 855975) (|s14abf| . 855816) (|minimumDegree| . 854924) (|weakBiRank| . 854732) (|character?| . 854644) (|LyndonBasis| . 854350) (|prinshINFO| . 854086) (|s14aaf| . 853927) (|colorDef| . 853803) (|simplifyPower| . 853646) (|whileLoop| . 853562) (|rotatey| . 853421) (|nthCoef| . 853232) (|polar| . 853048) (|s13adf| . 852889) (|separate| . 852203) (|entry?| . 851969) (|symmetricPower| . 851523) (|makeFR| . 851014) (|fortranDouble| . 850969) (|exprex| . 850748) (|s13acf| . 850589) (|intersect| . 848793) (|physicalLength| . 848510) (|deepCopy| . 848392) (|untab| . 848212) (|leftCharacteristicPolynomial| . 848045) (|s13aaf| . 847886) (|OMsupportsSymbol?| . 847770) (|diagonal?| . 847316) (|zeroDimPrimary?| . 846944) (|createGenericMatrix| . 846765) (|excpDivV| . 846260) (|s01eaf| . 846089) (|iisinh| . 845893) (|basisOfCentroid| . 845704) (|lowerCase!| . 845650) (|chartV| . 845145) (|s21bdf| . 844977) (|rightFactorIfCan| . 844710) (|roughBasicSet| . 844313) (|edf2df| . 844167) (|removeRoughlyRedundantFactorsInPol| . 843877) (|repack1| . 843651) (|trueEqual| . 843557) (|s21bcf| . 843392) (|setPrologue!| . 843203) (|mul| . 843067) (|bfEntry| . 842826) (|limitedint| . 842406) (|or| . 842261) (|s21bbf| . 842096) (|wholePart| . 841672) (|makeEq| . 841355) (|fullOut| . 840225) (|outputForm| . 839282) (|prepareDecompose| . 838255) (|coerceS| . 838034) (|s21baf| . 837872) (|normFactors| . 837529) (|width| . 837226) (|OMputVariable| . 837114) (|plot| . 835231) (|evalADE| . 834790) (|subspace| . 834326) (|s20adf| . 834167) (|roughEqualIdeals?| . 833856) (|cothIfCan| . 833715) (|monicDivide| . 833292) (|polygon| . 832772) (|matrixGcd| . 832420) (|fibonacci| . 832321) (|e02agf| . 832047) (|OMsend| . 831892) (|leftQuotient| . 831598) (|extendedgcd| . 831423) (|coord| . 830793) (|module| . 830132) (|s20acf| . 829973) (|match?| . 829849) (|cyclicEntries| . 829728) (|qPot| . 829549) (|sturmVariationsOf| . 829287) (|bitLength| . 829205) (|bernoulli| . 828894) (|operators| . 828791) (|d01aqf| . 828544) (|setsubMatrix!| . 828318) (|negative?| . 827841) (|bandedHessian| . 827444) (|iiperm| . 827246) (|safeCeiling| . 827083) (|s19adf| . 826924) (|maximumExponent| . 826764) (|primeFrobenius| . 826589) (|copies| . 826474) (|ZetaFunction| . 823564) (|d01apf| . 823311) (|cycleTail| . 823213) (|pomopo!| . 823060) (|fTable| . 821941) (|setRealSteps| . 821859) (|ignore?| . 821502) (|s19acf| . 821343) (|is?| . 820239) (|PollardSmallFactor| . 820114) (|meshFun2Var| . 819700) (|identification| . 819439) (|polygamma| . 818906) (|d01anf| . 818656) (|hermiteH| . 818501) (|extendedIntegrate| . 818120) (|concat!| . 817499) (|norm| . 813986) (|leftScalarTimes!| . 813845) (|d01amf| . 813601) (|findOrderOfDivisor| . 811803) (|isExpt| . 810177) (|deepestInitial| . 809990) (|quadraticForm| . 809827) (|satisfy?| . 809220) (|d01alf| . 808927) (|sqfree| . 808610) (|errorInfo| . 808518) (|empty?| . 807422) (|collectUnder| . 807176) (|rotatez| . 807035) (|label| . 806985) (|shiftHP| . 793761) (|s19abf| . 793602) (|showScalarValues| . 793525) (|adjoint| . 792490) (|leftTraceMatrix| . 791984) (|rquo| . 791076) (|insert| . 790831) (|d01akf| . 790587) (|completeEchelonBasis| . 790421) (|entries| . 789149) (|unitNormal| . 789005) (|symmetricRemainder| . 788944) (|ipow| . 788746) (|s19aaf| . 788587) (|interpolate| . 787298) (|allDegrees| . 787086) (|stopMusserTrials| . 786760) (|setchart!| . 786252) (|yellow| . 786213) (|drotg| . 786066) (|d01ajf| . 785822) (|elColumn2!| . 785524) (|composite| . 785071) (|solveLinearPolynomialEquationByRecursion| . 784357) (|primitiveElement| . 782417) (|localAbs| . 781354) (|s18def| . 781115) (|hasTopPredicate?| . 781000) (|morphism| . 780634) (|doubleFloatFormat| . 780553) (|iisqrt3| . 780360) (|s18dcf| . 780121) (GT . 779903) (|leastMonomial| . 779716) (|viewDefaults| . 779632) (|factorials| . 779109) (|imaginary| . 779011) (|makeUnit| . 778862) (|prolateSpheroidal| . 778653) (|bitCoef| . 778568) (|s18aff| . 778409) (|internalDecompose| . 775434) (|revert| . 774941) (|swapRows!| . 774718) (|tableau| . 774594) (|s18aef| . 774435) (|OMputBVar| . 774353) (|realEigenvalues| . 774148) (|OMsupportsCD?| . 774035) (|redPo| . 773706) (|horizConcat| . 773248) (|s18adf| . 773089) (|seriesSolve| . 769019) (|foundPlaces| . 768851) (|getCode| . 768765) (|blue| . 768726) (|diagonal| . 768522) (|reshape| . 767793) (|integralAtInfinity?| . 767521) (|s18acf| . 767362) (|enqueue!| . 767098) (|unprotectedRemoveRedundantFactors| . 766808) (|slope| . 765862) (|birth| . 765744) (|f04qaf| . 765427) (|showAllElements| . 765283) (|useEisensteinCriterion| . 765125) (|outputFixed| . 764946) (|hex| . 764842) (|lprop| . 764694) (|limitedIntegrate| . 764254) (|f04mcf| . 764013) (|cExp| . 763853) (|displayAsGF| . 763720) (|divideIfCan!| . 763376) (|exteriorDifferential| . 763229) (|multiset| . 762946) (|f04mbf| . 762526) (|complexNumericIfCan| . 759471) (|solveRetract| . 759139) (|roughBase?| . 758831) (|position!| . 758741) (|qShiftAction| . 758514) (|sumOfSquares| . 758398) (|f04maf| . 758148) (|OMgetBVar| . 758066) (|enterPointData| . 757893) (|eigenvectors| . 757506) (|oddlambert| . 757013) (|f04jgf| . 756788) (|rewriteIdealWithHeadRemainder| . 756477) (|alphabetic| . 756429) (|numberOfFractionalTerms| . 756302) (|lex| . 756171) (|basisOfCommutingElements| . 755993) (|specialTrigs| . 755707) (|mapBivariate| . 755344) (|f04faf| . 755157) (|complexNumeric| . 751470) (|status| . 750998) (|listYoungTableaus| . 750835) (|leftExactQuotient| . 750521) (|unmakeSUP| . 750368) (|kernels| . 750269) (|maxIndex| . 750108) (|f04axf| . 749876) (|orbit| . 748732) (|listVariable| . 748452) (|cartesian| . 748268) (|showTheRoutinesTable| . 748221) (|hessian| . 747866) (|f04atf| . 747679) (|clearTheIFTable| . 747588) (|OMopenString| . 747464) (|univariate| . 744517) (|laurentRep| . 744340) (~ . 744249) (|selectODEIVPRoutines| . 744199) (|quadraticBezier| . 744043) (|f04asf| . 743859) (|factor| . 732030) (|setOrder| . 731712) (|isPlus| . 730771) (|repSq| . 730581) (|integralBasis| . 728849) (|fortranLiteralLine| . 728739) (|homogeneous| . 728467) (|imag| . 727727) (|dimensions| . 727374) (|algebraicSet| . 726970) (|splitDenominator| . 725379) (|Ci| . 725084) (|tree| . 724420) (|goodPoint| . 724180) (SEGMENT . 723910) (|read!| . 723779) (|f04arf| . 723595) (|directProduct| . 723466) (|unitsColorDefault| . 723292) (|dihedral| . 723141) (|infinityNorm| . 722827) (|exprHasAlgebraicWeight| . 722498) (|linearMatrix| . 722298) (|iiacoth| . 722102) (|destruct| . 721617) (|stiffnessAndStabilityFactor| . 721405) (|setSingularPoints| . 720156) (|beauzamyBound| . 719814) (|f04adf| . 719609) (|setClosed| . 719474) (|minIndex| . 719313) (|monomial| . 716416) (|computePowers| . 716227) (|endSubProgram| . 716146) (|guessADE| . 709093) (|nlde| . 708866) (|generalLambert| . 708237) (|multivariate| . 706568) (|leftRecip| . 706345) (|sincos| . 706106) (|integralBasisAtInfinity| . 705835) (|solveLinearPolynomialEquation| . 704847) (|iiAiryBi| . 704673) (|extendedEuclidean| . 704394) (|vconcat| . 704254) (|affineSingularPoints| . 702894) (|digit?| . 702814) (|bivariateSLPEBR| . 702417) (|OMputEndAttr| . 702335) (|getShiftRec| . 701845) (|addMatch| . 701673) (|homogeneous?| . 701355) (|continue| . 701267) (|createNormalPrimitivePoly| . 701065) (|figureUnits| . 700911) (|bernoulliB| . 700696) (|inv| . 699490) (|apply| . 698747) (|product| . 697654) (|Si| . 697359) (|setright!| . 697215) (|initial| . 696968) (|option| . 696485) (|expintegrate| . 696052) (|coordinate| . 695656) (|ground?| . 695070) (|retractable?| . 694259) (|homogenize| . 692454) (|ellipticCylindrical| . 692245) (|ground| . 692010) (|new| . 690904) (|basisOfInterpolateFormsForFact| . 690343) (|brace| . 689999) (|replace| . 689884) (= . 688733) (|mapmult| . 688599) (|modularGcd| . 688337) (|dcabs1| . 688206) (|cTan| . 688046) (|groebgen| . 687714) (|f07fef| . 687519) (|lastSubResultant| . 686664) (|leadingMonomial| . 685572) (|cons| . 685413) (|prime?| . 684677) (|commonDenominator| . 683818) (|identitySquareMatrix| . 683651) (|f07fdf| . 683465) (|leadingCoefficient| . 681441) (|copy| . 680470) (< . 679962) (|And| . 679826) (|expandLog| . 679611) (|mix| . 679289) (|unitVector| . 678562) (|singular?| . 678021) (|rowEch| . 677879) (|top| . 677537) (|f07aef| . 677300) (|primitiveMonomials| . 677094) (|relativeApprox| . 676534) (> . 676401) (|mainKernel| . 676301) (|linearBezier| . 676148) (|integerBound| . 675929) (|mantissa| . 675757) (|f07adf| . 675598) (|degreeOfMinimalForm| . 675344) (|reductum| . 673309) (<= . 672927) (|mapUnivariate| . 672266) (|gderiv| . 672089) (|skewSFunction| . 671926) (|principal?| . 671618) (|generalSqFr| . 671343) (|explicitEntries?| . 671221) (>= . 671088) (|partition| . 670886) (|cAcos| . 670726) (|s17dlf| . 670484) (|shufflein| . 670328) (|tableForDiscreteLogarithm| . 670167) (|listSD| . 669981) (|readIfCan!| . 669708) (|dAndcExp| . 669481) (|stirling2| . 669362) (|monomial2series| . 669152) (|s17dhf| . 668948) (|multiple| . 668672) (|axesColorDefault| . 668498) (|list| . 668084) (|univcase| . 667805) (|cycleLength| . 667668) (|inf| . 667518) (|s17dgf| . 667314) (|extract!| . 666812) (|optional| . 666536) (|isAbsolutelyIrreducible?| . 666128) (+ . 663433) (|tubePlot| . 662142) (|quickSort| . 661884) (|f02xef| . 661655) (|real?| . 660906) (|quoByVar| . 660801) (|fixedPointExquo| . 660607) (- . 657787) (|normalDenom| . 657565) (|splitSquarefree| . 657285) (|machineFraction| . 657190) (|nil| . 657116) (|f02wef| . 656899) (|not| . 656716) (|optpair| . 656579) (|approximate| . 655448) (/ . 651355) (|mapUp!| . 651073) (|numberOfComposites| . 650941) (|f02fjf| . 650154) (|mightHaveRoots| . 649930) (|freeOf?| . 649519) (|fintegrate| . 648955) (|taylorQuoByVar| . 648850) (|max| . 648283) (|swapColumns!| . 648060) (|f02bjf| . 647820) (|OMbindTCP| . 647694) (|update| . 647531) (|daxpy| . 647344) (|expandPower| . 647129) (|refine| . 645357) (|removeDuplicates| . 645197) (|applyQuote| . 644543) (|f02bbf| . 644334) (|SturmHabichtCoefficients| . 644119) (|idealSimplify| . 643886) (|parent| . 643768) (|extend| . 641529) (|meshPar1Var| . 641199) (|solveid| . 640964) (|innerSolve| . 640645) (|f02axf| . 640468) (|charpol| . 640203) (|rest| . 639427) (|placesAbove| . 638079) (|deepestTail| . 637892) (|printInfo| . 634987) (|logical?| . 634899) (|countRealRoots| . 634687) (|reverse| . 634285) (|palglimint| . 633714) (|possiblyNewVariety?| . 633359) (|inR?| . 633244) (|setDifference| . 633130) (|tanh2trigh| . 632915) (|MPtoMPT| . 632666) (|setEpilogue!| . 632477) (|idealiser| . 631857) (|getBadValues| . 631737) (|writeObj| . 631584) (|mapMatrixIfCan| . 631182) (|setIntersection| . 631068) (|OMcloseConn| . 630982) (|iipolygamma| . 630780) (|invertible?| . 630162) (|incrementKthElement| . 630008) (|inverseColeman| . 629848) (|shellSort| . 629590) (|realEigenvectors| . 629292) (|guessHP| . 621825) (|setUnion| . 621711) (|stosePrepareSubResAlgo| . 621297) (|lhs| . 620787) (|fortranInteger| . 620742) (|iiBesselY| . 620540) (|open| . 620251) (|heapSort| . 619993) (|size| . 618054) (|translateToOrigin| . 616926) (|changeBase| . 616599) (|typeLists| . 616389) (|hasPredicate?| . 616274) (|cylindrical| . 616090) (|outputMeasure| . 615970) (|substitute| . 615865) (|drawStyle| . 615743) (|negAndPosEdge| . 615449) (|zeroDim?| . 614909) (|lazyGintegrate| . 614659) (|att2Result| . 613762) (|makeGraphImage| . 613160) (|powers| . 613025) (|index?| . 612866) (|explicitlyFinite?| . 612748) (|besselJ| . 612293) (|halfExtendedResultant2| . 612052) (|false| . 612011) (|asinIfCan| . 611870) (|insertBottom!| . 611689) (|supDimElseRittWu?| . 610996) (|quadTransform| . 610576) (|Lazard2| . 610365) (|polynomialZeros| . 610097) (|listBranches| . 609836) (|eulerPhi| . 609737) (|clearDenominator| . 608848) (|makeYoungTableau| . 608691) (|high| . 608601) (|radicalRoots| . 608037) (|numericalIntegration| . 607412) (|move| . 607143) (|splitNodeOf!| . 606635) (|sech2cosh| . 606420) (|minordet| . 605686) (|tanQ| . 605315) (|npcoef| . 604678) (|binaryFunction| . 604402) (|rightRank| . 604210) (|completeHensel| . 603976) (|setProperty| . 603862) (|clipWithRanges| . 603568) (|guessPRec| . 596515) (|critM| . 596245) (|unparse| . 596166) (|leftRank| . 595974) (|numer| . 594711) (|rootOfIrreduciblePoly| . 594299) (|comparison| . 594164) (|internalIntegrate0| . 593755) (|rootKerSimp| . 593119) (|cschIfCan| . 592978) (|denom| . 591735) (|solveLinear| . 591211) (|evenlambert| . 590718) (|sort| . 589994) (|aspFilename| . 589903) (|shrinkable| . 589642) (|clipPointsDefault| . 589474) (|kernel| . 588957) (|extensionDegree| . 588269) (|symmetric?| . 587815) (|gcdprim| . 587672) (|nand| . 587574) (|enterInCache| . 587300) (|draw| . 579270) (|subNodeOf?| . 578974) (|abelianGroup| . 578813) (|reduction| . 578263) (|conjug| . 577983) (|changeWeightLevel| . 577362) (|makeObject| . 572891) (|queue| . 572778) (UTS2UP . 572465) (|leftPower| . 572279) (|OMputBind| . 572197) (|rdregime| . 571575) (|doubleRank| . 571383) (|coef| . 570783) (|reducedDiscriminant| . 570498) (|symFunc| . 570192) (|pow| . 569792) (|strongGenerators| . 569652) (|iiatanh| . 569456) (|monom| . 569005) (|definingField| . 568814) (|decimal| . 568714) (|putColorInfo| . 568561) (|algDsolve| . 568026) (|infinity| . 567835) (|factorSquareFreePolynomial| . 567646) (|getDomains| . 567514) (|terms| . 566898) (|putGraph| . 566735) (|rootRadius| . 566349) (|laguerreL| . 566039) (|numberOfMonomials| . 565544) (|ramifMult| . 565451) (|newtonPolygon| . 565049) (|internal?| . 564903) (|setMinPoints3D| . 564826) (|setVariableOrder| . 564564) (|polyRDE| . 564101) (|highCommonTerms| . 563897) (|complexIntegrate| . 563178) (|range| . 562966) (|OMgetApp| . 562884) (|traverse| . 562715) (|lfextendedint| . 562277) (|interpolateFormsForFact| . 560267) (|alternating| . 560116) (|printStatement| . 560022) (|iisec| . 559826) (|mainCharacterization| . 559562) (|removeRoughlyRedundantFactorsInPols| . 558954) (|differentialVariables| . 558679) (|pointDominateBy| . 556925) (|subSet| . 556776) (|cond| . 556608) (|scan| . 554614) (|Vectorise| . 554446) (|OMputError| . 554364) (|df2fi| . 554224) (|partialFraction| . 553581) (|property| . 553460) (|OMgetInteger| . 553375) (|obj| . 553304) (|monomRDEsys| . 552853) (|consnewpol| . 552353) (|delete!| . 552073) (|iiabs| . 551899) (|cyclicEqual?| . 551784) (|truncate| . 551426) (|rdHack1| . 551193) (|expr| . 550944) (|crushedSet| . 550657) (|depth| . 550036) (|units| . 549409) (|removeZero| . 549153) (|distdfact| . 548836) (|resultantEuclideannaif| . 548588) (|totalfract| . 548152) (|initParLocLeaves| . 547462) (|comp| . 547206) (|rangePascalTriangle| . 546948) (|bandMatrix| . 546386) (|removeRedundantFactorsInPols| . 546064) (|exquo| . 544564) (|squareFreePrim| . 544288) (|nor| . 544190) (|count| . 541725) (|nullary| . 541599) (|realZeros| . 539328) (|integralDerivationMatrix| . 538982) (|div| . 538932) (|minset| . 538578) (|remainder!| . 538417) (RF2UTS . 538077) (|goto| . 537989) (|cSec| . 537829) (|removeConjugate| . 537254) (|code| . 536011) (|closeComponent| . 535811) (|zeroMatrix| . 535284) (|initials| . 535003) (|eisensteinIrreducible?| . 534845) (|DiffAction| . 534621) (|partialQuotients| . 534490) (|viewpoint| . 532565) (|conjugate| . 531535) (|subMultV| . 531009) (|saturate| . 530519) (|op| . 530363) (|alphanumeric| . 530315) (|expenseOfEvaluationIF| . 529908) (|ScanFloatIgnoreSpacesIfCan| . 529789) (|localUnquote| . 529441) (|uniform01| . 529351) (|principalIdeal| . 529185) (|exprToXXP| . 528625) (|nodeOf?| . 528378) (|solveInField| . 527441) (|mvar| . 527014) (|padicallyExpand| . 526862) (|rename| . 526768) (|green| . 526729) (|rspace| . 526645) (|pushdown| . 525541) (|lfextlimint| . 525031) (|affineAlgSetLocal| . 524514) (|listOfMonoms| . 524296) (|maxTower| . 524179) (|mulmod| . 524115) (|finiteSeries2LinSysWOVectorise| . 523865) (|bipolar| . 523656) (|closed?| . 523431) (|bfKeys| . 523341) (|point?| . 523220) (|expPot| . 523032) (|double?| . 522944) (|getMultiplicationMatrix| . 522287) (|powerAssociative?| . 522145) (|OMlistSymbols| . 522024) (|linearAssociatedLog| . 521646) (|compBound| . 521424) (|presub| . 521374) (|computeCycleEntry| . 521233) (|extendedSubResultantGcd| . 520613) (|nthRootIfCan| . 520430) (|csubst| . 520102) (|integer?| . 519603) (|boundOfCauchy| . 519408) (|tanh2coth| . 519193) (|createNormalPoly| . 518991) (|determinant| . 518004) (|setPoly| . 517866) (|factorFraction| . 517649) (|fortranReal| . 517604) (|overset?| . 517191) (GF2FG . 516798) (|newSubProgram| . 516689) (|Beta| . 516042) (|quotientByP| . 515980) (|leaf?| . 515548) (|mesh?| . 515427) (|primextintfrac| . 515100) (|makeResult| . 514826) (|backOldPos| . 514464) (|realElementary| . 513783) (|makingStats?| . 513614) (|tanNa| . 513492) (|legendreP| . 513282) (|degreeSubResultantEuclidean| . 512989) (|radPoly| . 512647) (|represents| . 511518) (|gnuDraw| . 510659) (|nextSubsetGray| . 510519) (|primitivePart| . 509352) (|failed| . 509045) (|simplifyLog| . 508830) (|quotient| . 508371) (|minColIndex| . 507904) (|OMUnknownCD?| . 507816) (|indiceSubResultant| . 507608) (|constDsolve| . 507080) (|toroidal| . 506871) (|ratDenom| . 505184) (|complexEigenvalues| . 504952) (|kmax| . 504746) (|OMputSymbol| . 504631) (|imagk| . 504529) (|recur| . 504170) (|noKaratsuba| . 503996) (|nsqfree| . 503471) (|pointColorPalette| . 503337) (|multiEuclidean| . 503236) (|factorsOfDegree| . 502977) (|checkPrecision| . 502888) (|clearCache| . 502775) (|OMgetEndAttr| . 502693) (|stoseInvertibleSetsqfreg| . 502331) (|setOfMinN| . 502147) (|neglist| . 502014) (|primes| . 501875) (|fprindINFO| . 501475) (|graphCurves| . 500875) (|rightCharacteristicPolynomial| . 500708) (|coordinates| . 498582) (|nextsousResultant2| . 498410) (|reduced?| . 497619) (|clearFortranOutputStack| . 497517) (|tryFunctionalDecomposition| . 497359) (|brillhartTrials| . 497041) (|constantIfCan| . 496870) (|Ei6| . 496745) (|iisin| . 496549) (|extDegree| . 496424) (|resetAttributeButtons| . 496343) (|basisOfRightAnnihilator| . 496162) (|patternMatch| . 492037) (|identityMatrix| . 491869) (|triangular?| . 491561) (|iiacsc| . 491365) (|minGbasis| . 491098) (|rootPoly| . 490697) (|retractToGrn| . 490529) (|cCoth| . 490369) (|colorFunction| . 489988) (|dequeue!| . 489733) (|leftUnits| . 489106) (|changeName| . 488987) (|pade| . 488072) (|genericLeftMinimalPolynomial| . 487729) (|magnitude| . 487575) (|basisOfNucleus| . 487397) (|copy!| . 487259) (|minrank| . 486691) (|cCosh| . 486531) (|taylorIfCan| . 486345) (|getZechTable| . 485724) (|bivariatePolynomials| . 485353) (|chebyshevU| . 485040) (|mkAnswer| . 484695) (|factorSqFree| . 484110) (|dflist| . 483889) (|tubePoints| . 483661) (|cosIfCan| . 483520) (|removeZeroes| . 482221) (|rightTrace| . 482104) (|polarCoordinates| . 481856) (|complementaryBasis| . 481582) (|infix| . 481436) (|members| . 480404) (|separateDegrees| . 480149) (|completeSmith| . 479814) (|lflimitedint| . 479289) (|compiledFunction| . 478765) (|cCsc| . 478605) (|qsetelt!| . 478193) (|iipow| . 477995) (|integralLastSubResultant| . 477600) (|summary| . 477508) (|var1Steps| . 477280) (|acotIfCan| . 477139) (|setTopPredicate| . 476986) (|musserTrials| . 476660) (|biRank| . 476468) (|ideal| . 475566) (|selectOrPolynomials| . 475140) (|classNumber| . 473852) (|show| . 473693) (|updatF| . 473320) (|over| . 473270) (|problemPoints| . 472768) (|rangeIsFinite| . 472209) (|distance| . 472085) (|infieldint| . 471831) (|parametrize| . 468548) (|complexZeros| . 467847) (|e02aef| . 467648) (|alphabetic?| . 467568) (|triangulate| . 466891) (|hdmpToDmp| . 466642) (|scanOneDimSubspaces| . 466390) (|pseudoDivide| . 465661) (|iiAiryAi| . 465487) (|lazy?| . 465365) (|getGoodPrime| . 465094) (|imagK| . 464891) (|tryFunctionalDecomposition?| . 464736) (|c02agf| . 464533) (|firstNumer| . 464434) (|iiexp| . 464238) (|expIfCan| . 464097) (|mapCoef| . 463902) (|inrootof| . 463683) (|c02aff| . 463480) (|redPol| . 463210) (|showIntensityFunctions| . 462635) (|iiBesselJ| . 462433) (|map!| . 461218) (|e02adf| . 461042) (|degreeSubResultant| . 460834) (|cAsec| . 460674) (|perfectNthPower?| . 460504) (|gcdcofact| . 460361) (|physicalLength!| . 460103) (|numberOfPrimitivePoly| . 459951) (|c05pbf| . 459664) (|sturmSequence| . 459475) (|showAttributes| . 458376) (|coefChoose| . 458069) (|Frobenius| . 457480) (|monicLeftDivide| . 456952) (|OMputEndApp| . 456870) (|setPosition| . 456747) (|curveColor| . 456590) (|quartic| . 456063) (|root?| . 455917) (|credits| . 455825) (|iiacos| . 455629) (|prinb| . 455337) (|pointValue| . 455090) (|mainDefiningPolynomial| . 454970) (|compile| . 454849) (|endOfFile?| . 454770) (|subPolSet?| . 454021) (|Nul| . 453928) (|alternatingGroup| . 453626) (|stoseInvertibleSet| . 453264) (|discreteLog| . 453041) (|clearTheFTable| . 452951) (|cubic| . 452427) (|leadingTerm| . 452249) (|qfactor| . 451879) (|e01sef| . 451659) (|One| . 451214) (|largest| . 450867) (|initTable!| . 450701) (|algebraicOf| . 450413) (|crest| . 450192) (|previous| . 450096) (|e01saf| . 449920) (|symmetricDifference| . 449823) (|exQuo| . 448856) (|wholeRagits| . 448733) (|asimpson| . 448430) (|e01daf| . 448251) (|infix?| . 448170) (|monicModulo| . 447878) (|lowerCase| . 447736) (|finiteSeries2Vector| . 447516) (|nextPrimitivePoly| . 447340) (|internalSubPolSet?| . 446591) (|bezoutMatrix| . 446297) (|e01bhf| . 446083) (|diagonalProduct| . 445575) (|hitherPlane| . 445454) (|summation| . 444843) (|eyeDistance| . 444722) (|dn| . 444547) (|e01bgf| . 444365) (|random| . 443112) (|back| . 442857) (|lazyIntegrate| . 442626) (|numberOfCycles| . 442496) (|prefix| . 442400) (|partialDenominators| . 442269) (|e01bff| . 442087) (|createLowComplexityTable| . 441837) (|trapezoidalo| . 441537) (|polCase| . 441190) (|sqfrFactor| . 441068) (|e01bef| . 440895) (|asecIfCan| . 440754) (|ramifiedAtInfinity?| . 440485) (|printingInfo?| . 440316) (|select!| . 439984) (|multMonom| . 439505) (|e01baf| . 439326) (|showAll?| . 439188) (|setScreenResolution3D| . 439111) (|drawToScale| . 438943) (|unrankImproperPartitions1| . 438794) (|indexName| . 438584) (|iidsum| . 438386) (|e02zaf| . 438201) (|null?| . 437924) (|certainlySubVariety?| . 437606) (|atom?| . 437329) (|multiplyExponents| . 436851) (|integralMatrix| . 436567) (|e02gaf| . 436359) (|blankSeparate| . 436266) (|dimensionOfIrreducibleRepresentation| . 436128) (|setFoundZeroes| . 436007) (|cTanh| . 435847) (|call| . 435766) (|e02dff| . 435575) (|lazyPquo| . 435195) (|mainMonomial| . 435008) (|makeprod| . 434881) (|guessPade| . 430546) (|intChoose| . 429953) (|e02def| . 429771) (|bumptab1| . 429600) (|processTemplate| . 429426) (|integralMatrixAtInfinity| . 429142) (|connect| . 428983) (|mainVariable?| . 428709) (|inHallBasis?| . 428592) (|e02ddf| . 428327) (|pToHdmp| . 428104) (NOT . 427849) (|rightNorm| . 427732) (|printTypes| . 427547) (|moduleSum| . 427161) (|sort!| . 426806) (|e02dcf| . 426499) (|OMencodingSGML| . 426449) (OR . 426231) (|limitPlus| . 425391) (|linearDependence| . 425169) (UP2UTS . 424898) (|systemSizeIF| . 424491) (|e02daf| . 424220) (|localParam| . 424049) (AND . 423831) (|adaptive3D?| . 423757) (|normDeriv2| . 423432) (|numberRatPlacesExtDeg| . 422023) (|stirling1| . 421904) (|e02bef| . 421612) (|evalIfCan| . 417525) (|polyRing2UPUP| . 417087) (|rootsOf| . 416276) (|pascalTriangle| . 416113) (|e02bdf| . 415946) (|reset| . 415063) (|screenResolution| . 414826) (|OMwrite| . 413495) (|deleteRoutine!| . 413409) (|component| . 412891) (|f2st| . 412771) (|outerProduct| . 412622) (|copyInto!| . 412450) (|write| . 411805) (|minusInfinity| . 411616) (|transform| . 411352) (|charthRoot| . 411100) (|euclideanSize| . 411001) (|relationsIdeal| . 410602) (|save| . 410557) (|jacobi| . 410455) (|plusInfinity| . 410266) (|useSingleFactorBound| . 410108) (|unravel| . 409912) (|lifting1| . 409209) (|child| . 409049) (|genericLeftNorm| . 408737) (|setleaves!| . 408608) (|HenselLift| . 408303) (|Aleph| . 408207) (|algebraicVariables| . 407926) (|setProperties| . 407811) (|solve1| . 407545) (|lastNonNul| . 407418) (|numericalOptimization| . 406828) (|d| . 406661) (|limit| . 404444) (|nonLinearPart| . 404329) (|palgextint| . 403845) (|triangSolve| . 402763) (|rootNormalize| . 402403) (|printHeader| . 402109) (|moreAlgebraic?| . 401416) (|cot2tan| . 401201) (|wholeRadix| . 401078) (|palgLODE0| . 399815) (|box| . 399632) (|normalElement| . 399320) (|pfaffian| . 399093) (* . 390880) (|slash| . 390830) (|functionIsFracPolynomial?| . 390512) (|particularSolution| . 389500) (|graphImage| . 389456) (|maxdeg| . 389165) (|moduloP| . 389069) (|leadingSupport| . 388923) (|trapezoidal| . 388623) (Y . 388186) (|compdegd| . 387800) (|countRealRootsMultiple| . 387556) (|dswap| . 387344) (|complexElementary| . 386071) (|allPairsAmong| . 385525) (|d01gbf| . 385227) (|rightFactorCandidate| . 385031) (|firstExponent| . 384776) (|effective?| . 384651) (|iibinom| . 384453) (|externalList| . 384363) (|complexSolve| . 383270) (|d01gaf| . 383099) (|startTable!| . 382352) (|double| . 382166) (|eq?| . 381511) (|stoseInvertible?| . 380741) (|flagFactor| . 380561) (|e| . 380375) (|blowUpWithExcpDiv| . 379685) (|options| . 379264) (|d01fcf| . 378969) (|getMeasure| . 378857) (|viewPhiDefault| . 378677) (|nextNormalPrimitivePoly| . 378501) (|mindeg| . 378213) (|cAsinh| . 378053) (|d01bbf| . 377887) (|removeSquaresIfCan| . 377600) (|primlimintfrac| . 377199) (|complement| . 377070) (|leftUnit| . 376909) (|arg1| . 376761) (|diag| . 376558) (|d01asf| . 376311) (|super| . 376261) (|separateFactors| . 375710) (|theCurve| . 374516) (|pointSizeDefault| . 374326) (|arg2| . 374178) (|intersectionDivisor| . 372112) (|lazyEvaluate| . 372018) (|currentSubProgram| . 371937) (|complexLimit| . 370968) (|critMonD1| . 370602) (|rightTrim| . 370414) (|d02raf| . 369978) (|leftLcm| . 369684) (|setColumn!| . 369448) (|mr| . 369144) (|pointColor| . 368987) (|secIfCan| . 368846) (|operation| . 368348) (|reorder| . 367708) (|d02kef| . 366868) (|nullary?| . 366784) (|factorset| . 366439) (|xor| . 366291) (|safeFloor| . 366128) (|encode| . 366011) (|d02gbf| . 365605) (|aromberg| . 365302) (|semicolonSeparate| . 365209) (|insertRoot!| . 365111) (|getRef| . 364942) (|pdf2ef| . 364787) (|d02gaf| . 364465) (|quasiComponent| . 364134) (|subResultantGcdEuclidean| . 363892) (|doubleResultant| . 363576) (|createIrreduciblePoly| . 363374) (|d02ejf| . 362796) (|redmat| . 362418) (|setchildren!| . 362252) (|paren| . 361979) (|remove| . 361013) (|nextLatticePermutation| . 360864) (|match| . 359522) (|previousTower| . 359439) (|findCycle| . 359188) (|localReal?| . 358964) (|wordInGenerators| . 358782) (|lifting| . 358201) (|axes| . 357766) (|fracPart| . 357466) (|LazardQuotient| . 357197) (|prime| . 357058) (|minPoints| . 356821) (|nodes| . 356700) (|objects| . 356422) (|stronglyReduce| . 356166) (|positiveSolve| . 354678) (|columnSpace| . 354423) (|karatsuba| . 354204) (|createMultiplicationMatrix| . 353970) (|stFunc2| . 353672) (|composites| . 353551) (|aColumn| . 353271) (|predicate| . 353070) (|overlabel| . 353020) (|nextSublist| . 352626) (|basisOfLeftAnnihilator| . 352445) (|rightAlternative?| . 352105) (|algebraicCoefficients?| . 351819) (|block| . 351724) (|vectorise| . 351430) (|constantOperator| . 351260) (|tanintegrate| . 350861) (|removeSinhSq| . 350646) (|isTimes| . 349712) (|newReduc| . 349492) (|elt| . 340431) (|stronglyReduced?| . 339869) (|OMencodingUnknown| . 339819) (|trace| . 339002) (|chebyshevT| . 338689) (|setelt| . 336287) (|plotPolar| . 335658) (|orthonormalBasis| . 335466) (|leftExtendedGcd| . 335246) (|invertIfCan| . 334938) (|halfExtendedSubResultantGcd2| . 334386) (|opeval| . 334108) (|totalDegree| . 333395) (|union| . 332799) (|resize| . 332536) (|trigs| . 331928) (|mulbyscalar| . 331764) (|uncouplingMatrices| . 331520) (|outputFloating| . 331341) (|doubleComplex?| . 331253) (|permutationGroup| . 331113) (|reduceRowOnList| . 330960) (|nthRoot| . 330586) (|tablePow| . 330312) (|log| . 327978) (|unexpand| . 327662) (|ode2| . 327428) (|monicRightDivide| . 326900) (|points| . 326741) (|cycles| . 326603) (|iteratedInitials| . 326388) (|tomodpa| . 326196) (F . 326049) (|extendIfCan| . 325783) (|optional?| . 325668) (|setvalue!| . 325530) (|coercePreimagesImages| . 325402) (|printInfo!| . 325203) (|forLoop| . 324922) (|bracket| . 324785) (|iitan| . 324589) (|inspect| . 324087) (|quotVecSpaceBasis| . 323962) (|prindINFO| . 323565) (|node| . 323459) (|subscript| . 323367) (|conjugates| . 323251) (|stoseLastSubResultant| . 322846) (|abs| . 321916) (|cAsin| . 321756) (|exprToGenUPS| . 320877) (|rational?| . 319067) (|complexNormalize| . 317794) (|totalDifferential| . 317613) (|fixedPoints| . 317466) (|permutations| . 317322) (|degOneCoef| . 317028) (|variable| . 316337) (|fractionFreeGauss!| . 316039) (|parts| . 314893) (|input| . 314641) (|direction| . 314501) (|validExponential| . 314092) (|commutativeEquality| . 313909) (|notelem| . 313743) (|test| . 313699) (|transcendenceDegree| . 313378) (|one?| . 312963) (|setmult!| . 312434) (|mainMonomials| . 312219) (|append| . 312139) (|modularGcdPrimitive| . 311877) (|rowEchWoZeroLinesWOVectorise| . 311762) (|setsymbName!| . 311225) (|precision| . 310814) (|real| . 309874) (|setTex!| . 309783) (|function| . 309074) (|shiftRoots| . 308911) (|infieldIntegrate| . 308652) (|recip| . 306668) (|complex| . 306564) (|internalSubQuasiComponent?| . 305851) (|fortranComplex| . 305806) (|ScanRoman| . 305687) (|sup| . 305475) (|pushup| . 304371) (|inverseIntegralMatrixAtInfinity| . 304087) (|eigenvector| . 303770) (|irreducible?| . 303161) (|solve| . 286343) (|sinh2csch| . 286128) (|empty| . 285158) (|truncatedmuladd| . 284991) (|type| . 284852) (|cubicBezier| . 284693) (|minimize| . 284412) (|rightExactQuotient| . 284264) (|tubeRadiusDefault| . 284056) (|odd?| . 283715) (|filename| . 283621) (|generator| . 282537) (|ord| . 282457) (|totalLex| . 282250) (|OMputEndObject| . 282168) (|red| . 282129) (|popFortranOutputStack| . 282039) (|reducedForm| . 281938) (|setValue!| . 281759) (|positive?| . 281282) (|startTableInvSet!| . 280517) (|outputAsFortran| . 279645) (|solid| . 279546) (|trunc| . 279203) (|rischNormalize| . 278742) (|scalarMatrix| . 278310) (|directory| . 278222) (|nilFactor| . 278100) (|conditionP| . 277779) (|quasiAlgebraicSet| . 277515) (|dscal| . 277334) (|simplify| . 276654) (|constantOpIfCan| . 276474) (|createPrimitivePoly| . 276272) (|monomRDE| . 275871) (|complexForm| . 275186) (|hyperelliptic| . 274632) (|lquo| . 273724) (|edf2efi| . 273554) (|ParCondList| . 272953) (|clipParametric| . 272375) (|subCase?| . 271546) (|idealiserMatrix| . 271236) (|factorSquareFree| . 269272) (|zeroOf| . 268601) (|makeSeries| . 268356) (|leadingBasisTerm| . 268094) (|subsInVar| . 267805) (|any| . 267699) (|remove!| . 266449) (|groebSolve| . 266084) (|modularFactor| . 265873) (|rst| . 265779) (|fullDisplay| . 265172) (|iicot| . 264976) (|itsALeaf!| . 264808) (|coerceImages| . 264689) (|inGroundField?| . 264571) (|linGenPos| . 264227) (|simpson| . 263927) (|lo| . 263837) (|indicialEquations| . 262044) (|cyclicSubmodule| . 261798) (|quotedOperators| . 261452) (|wrregime| . 260799) (|differentiate| . 256443) (|squareMatrix| . 256288) (|incr| . 256076) (|wreath| . 255950) (|rowEchelon| . 254324) (|acsch| . 253129) (|initializeParamOfPlaces| . 251717) (|updatD| . 251351) (|variables| . 249135) (|hi| . 249045) (|reduceLineOverLine| . 248926) (|overlap| . 248488) (|finite?| . 248158) (|leftDivide| . 247424) (|lineColorDefault| . 247250) (|times| . 247002) (|alphanumeric?| . 246922) (|RemainderList| . 246536) (|truncatedmultiplication| . 246397) (|subMatrix| . 245587) (|vector| . 245363) (|parametersOf| . 245273) (|iiacot| . 245077) (|dzasum| . 244887) (|normalDeriv| . 244577) (|anfactor| . 244156) (|getButtonValue| . 244041) (|normalise| . 243925) (|bringDown| . 243386) (|interval| . 242898) (|OMgetType| . 242814) (|phiCoord| . 242700) (|evalat| . 242561) (|setPredicates| . 242438) (|completeEval| . 242047) (|genericPosition| . 241629) (|quasiRegular?| . 241326) (|mainVariables| . 241055) (|scale| . 240573) (|appendPoint| . 240450) (|lfunc| . 240367) (|simpsono| . 240067) (|izamax| . 239881) (|linearDependenceOverZ| . 239674) (|besselI| . 239219) (|infRittWu?| . 237974) (|changeMeasure| . 237859) (|title| . 237413) (|degree| . 232610) (|in?| . 231988) (|cSin| . 231828) (|style| . 231618) (|rightUnits| . 230991) (|iicoth| . 230795) (|imagi| . 230693) (|normalizedDivide| . 230143) (|UpTriBddDenomInv| . 229882) (|common| . 229762) (|edf2fi| . 229607) (|singRicDE| . 228514) (|removeRoughlyRedundantFactorsInContents| . 228192) (|init| . 227961) (|weights| . 227371) (|removeSuperfluousCases| . 226586) (|OMReadError?| . 226498) (|setStatus| . 226215) (|antisymmetric?| . 225761) (|t| . 225617) (|OMgetBind| . 225535) (|inconsistent?| . 224777) (|alterDrift!| . 224587) (|qnew| . 223985) (|stepBlowUp| . 223228) (|dioSolve| . 222908) (|OMgetSymbol| . 222778) (|sumOfDivisors| . 222679) (|solid?| . 222583) (|external?| . 222501) (|extendedint| . 222155) (|cAtanh| . 221995) (|shift| . 221464) (|assign| . 217002) (|definingEquations| . 216741) (|semiResultantEuclidean2| . 216510) (|generate| . 216028) (|dmpToP| . 215816) (|separant| . 215569) (|resetVariableOrder| . 215477) (|extractProperty| . 215313) (|semiResultantReduitEuclidean| . 215044) (|cyclic?| . 214814) (|incrementBy| . 214659) (|replaceKthElement| . 214502) (|ScanFloatIgnoreSpaces| . 214393) (|supp| . 214268) (|approxSqrt| . 214168) (|ratDsolve| . 212361) (|bat| . 212190) (|addBadValue| . 211918) (|univariateSolve| . 209677) (|void| . 209639) (|expand| . 207747) (|pmintegrate| . 206616) (|cyclic| . 206465) (|sortConstraints| . 206132) (|numberOfIrreduciblePoly| . 205980) (|readable?| . 205891) (|viewPosDefault| . 205677) (|varselect| . 205471) (|curve?| . 205350) (|filterWhile| . 205096) (|rank| . 202617) (|zerosOf| . 201539) (|node?| . 201381) (|shiftRight| . 201236) (|listexp| . 200903) (|randomR| . 200180) (|sbt| . 200077) (|filterUntil| . 199823) (|selectNonFiniteRoutines| . 199773) (|computeInt| . 199350) (|pointLists| . 199237) (|rk4qc| . 198451) (|quoted?| . 198336) (|numberOfPlacesOfDegree| . 196927) (|expandTrigProducts| . 196526) (|select| . 195708) (|viewport3D| . 195650) (|nthFlag| . 195473) (|toseInvertible?| . 194723) (|iiasin| . 194527) (|sin2csc| . 194312) (|plus!| . 194171) (|pr2dmp| . 193820) (|rCoord| . 193706) (|reportInstantiations| . 193583) (|lintgcd| . 193412) (|xRange| . 193183) (|fortranLinkerArgs| . 193095) (|eulerE| . 192880) (|diffHP| . 179656) (|aQuadratic| . 179419) (|central?| . 179238) (|leviCivitaSymbol| . 179073) (|tubeRadius| . 178865) (|create| . 177260) (|prinpolINFO| . 176968) (|loopPoints| . 176751) (|close!| . 176579) (|whatInfinity| . 176448) (|jacobian| . 175882) (|factorList| . 175320) (|LyndonCoordinates| . 175026) (|fixedPoint| . 174694) (|numberOfValuesNeeded| . 174268) (|lllp| . 174119) (|conditions| . 173915) (|Hausdorff| . 173650) (|car| . 173401) (|po| . 173245) (|resetBadValues| . 173158) (|ptFunc| . 172814) (|radicalEigenvectors| . 172516) (|cdr| . 172267) (|getDatabase| . 172058) (|createThreeSpace| . 171953) (|matrix| . 170936) (|length| . 169416) (|makeRecord| . 169239) (|rightMinimalPolynomial| . 169035) (|ffactor| . 168728) (|open?| . 168596) (|OMputEndError| . 168514) (|messagePrint| . 168409) (|reduceByQuasiMonic| . 168153) (|scripts| . 167797) (|dimension| . 166439) (|tail| . 166064) (|iicsch| . 165868) (|genusNeg| . 164019) (|listLoops| . 163855) (|torsionIfCan| . 162878) (F2EXPRR . 162688) (|powmod| . 162624) (|showArrayValues| . 162547) (|tracePowMod| . 162334) (|getAncestors| . 162202) (|prem| . 161822) (|simpleBounds?| . 161679) (|biringToPolyRing| . 161281) (|elliptic| . 160521) (|rationalPower| . 160303) (|listAllMonoExp| . 159992) (|maxDegree| . 159714) (|invmod| . 159653) (|qinterval| . 159500) (|setMaxPoints3D| . 159423) (|BasicMethod| . 159276) (|dznrm2| . 159086) (|error| . 158608) (|fullOutput| . 155833) (|movedPoints| . 155595) (|nextPrime| . 155487) (|badNum| . 154961) (|leadingIndex| . 154488) (|pushuconst| . 154117) (|semiDegreeSubResultantEuclidean| . 153841) (|indicialEquation| . 153088) (|symbNameV| . 152554) (|reduceRow| . 152432) (|coerceL| . 152211) (|numberOfComponents| . 151470) (|coefficient| . 148447) (|lazyIrreducibleFactors| . 148081) (|generalizedContinuumHypothesisAssumed?| . 147999) (|coHeight| . 147678) (|clipBoolean| . 147544) (|exponential1| . 147454) (|setFormula!| . 147353) (|rowEchLocal| . 147208) (|rischDE| . 146476) (|constant| . 145510) (|areEquivalent?| . 144838) (|push!| . 144484) (|closedCurve?| . 144363) (|sizePascalTriangle| . 144234) (|showRegion| . 144112) (|fullInfClsPt| . 143664) (|monic?| . 143264) (|df2st| . 142895) (|schema| . 142681) (|atoms| . 142455) (|shiftInfoRec| . 141885) (|monomial?| . 140969) (|linear| . 140451) (|maxPoints| . 140214) (|expint| . 139833) (|karatsubaDivide| . 139620) (|ddFact| . 139386) (|hypergeometric0F1| . 139167) (|mapDown!| . 138876) (|logGamma| . 138663) (|cfirst| . 138442) (|squareFreeLexTriangular| . 137981) (|intermediateResultsIF| . 137574) (|acothIfCan| . 137433) (|linkToFortran| . 136586) (|components| . 136465) (|sechIfCan| . 136324) (|startTableGcd!| . 135559) (|ratpart| . 135468) (|removeSuperfluousQuasiComponents| . 134781) (|complete| . 134209) (|yCoordinates| . 133897) (|HermiteIntegrate| . 133140) (|constantToUnaryFunction| . 132987) (|subResultantsChain| . 132783) (|genus| . 130321) (|leftFactorIfCan| . 130096) (|OMlistCDs| . 130005) (|rightZero| . 129889) (|OMParseError?| . 129801) (|cAcsc| . 129641) (|useNagFunctions| . 129219) (|fortranCompilerName| . 129131) (|absolutelyIrreducible?| . 128541) (|operator| . 126623) (|shuffle| . 126467) (|anticoord| . 126171) (|OMmakeConn| . 126076) (|setpoint!| . 125568) (|possiblyInfinite?| . 125450) (|lastSubResultantElseSplit| . 125148) (|last| . 124560) (|flexibleArray| . 124299) (|diagonals| . 124177) (|rootBound| . 123835) (|clearTheSymbolTable| . 123650) (|frst| . 123556) (|unary?| . 123472) (|decreasePrecision| . 123300) (|shanksDiscLogAlgorithm| . 123070) (|factorCantorZassenhaus| . 122570) (|representationType| . 122444) (|characteristicSet| . 121778) (|firstSubsetGray| . 121641) (|qelt| . 121034) (|rows| . 120456) (|antisymmetricTensors| . 120036) (|generalInterpolation| . 118069) (|coerce| . 77707) (|algint| . 77324) (|cSech| . 77164) (|kovacic| . 76371) (|solveLinearPolynomialEquationByFractions| . 76114) (|elRow1!| . 75819) (|cscIfCan| . 75678) (|minus!| . 75402) (|isQuotient| . 75103) (|evenInfiniteProduct| . 74217) (|df2ef| . 74077) (|write!| . 73943) (|collectUpper| . 73697) (|toseLastSubResultant| . 73302) (|OMputEndAtp| . 73220) (|iFTable| . 72625) (|equality| . 72490) (|companionBlocks| . 72249) (|enumerate| . 71980) (|regime| . 71063) (|selectMultiDimensionalRoutines| . 71013) (|nrows| . 70524) (|scripted?| . 70447) (|LazardQuotient2| . 70175) (|affineAlgSet| . 69264) (|removeRedundantFactors| . 67774) (|FormatArabic| . 67655) (|acosIfCan| . 67514) (|rootProduct| . 66957) (|ncols| . 66468) (|genusTree| . 65750) (|sumSquares| . 65614) (|powern| . 65406) (|dfRange| . 65273) (|B1solve| . 64569) (|reindex| . 64361) (|fill!| . 63986) (|doublyTransitive?| . 63832) (|zoom| . 63303) (|iroot| . 63067) (|leftGcd| . 62773) (|normalForm| . 62186) (|socf2socdf| . 61993) (|normalized?| . 60973) (|exponents| . 60882) (|exactQuotient| . 60431) (|position| . 59549) (|generalInfiniteProduct| . 58545) (|balancedBinaryTree| . 58405) (|failed?| . 58036) (|OMencodingXML| . 57986) (|gramschmidt| . 57861) (|subst| . 57416) (|rk4| . 56839) (|leftNorm| . 56722) (|jacobiIdentity?| . 56382) (|zaxpy| . 56171) (|subQuasiComponent?| . 54732) (|createPrimitiveElement| . 54677) (|perfectSqrt| . 54567) (|polygon?| . 54446) (|Is| . 53229) (|tab| . 53067) (|placesOfDegree| . 50824) (|elem?| . 50705) (|firstDenom| . 50574) (|pToDmp| . 50362) (|critpOrder| . 49977) (|multinomial| . 49830) (|suchThat| . 47898) (|headReduced?| . 46878) (|outputAsScript| . 46634) (|definingPolynomial| . 45390) (|bumprow| . 45101) (|hermite| . 44695) (|iiasech| . 44499) (|and| . 44354) (|slex| . 44195) (|extractIndex| . 44038) (|copyfirst| . 43877) (|roughUnitIdeal?| . 43569) (|OMputAtp| . 43487) (|numberOfVariables| . 42632) (|purelyAlgebraic?| . 42066) (|lyndon?| . 41908) (|addPoint| . 41313) (|getlo| . 40827) (|rotatex| . 40686) (|lighting| . 40559) (|bumptab| . 40339) (|nextItem| . 40279) (|pointColorDefault| . 40105) (|ShiftC| . 39859) (|scaleRoots| . 39696) (|top!| . 39521) (|clearTable!| . 39355) (|expressIdealMember| . 39249) (|vertConcat| . 38791) (|pdct| . 38711) (|dimensionsOf| . 38277) (|Ei3| . 38152) (|factors| . 37465) (|extendedResultant| . 37173) (|exprHasLogarithmicWeights| . 36867) (|fffg| . 36426) (|pmComplexintegrate| . 35847) (|primintfldpoly| . 35578) (|graphStates| . 35129) (|tubePointsDefault| . 34939) (|OMgetAtp| . 34857) (|LagrangeInterpolation| . 34662) (|Lazard| . 34454) (|droot| . 34229) (|setcurve!| . 33628) (|multV| . 33102) (|primPartElseUnitCanonical| . 32878) (|rewriteIdealWithQuasiMonicGenerators| . 32502) (|second| . 32404) (|shade| . 32215) (|getOp| . 31828) (|convert| . 23254) (|bandedJacobian| . 22854) (|getMultiplicationTable| . 22076) (|generators| . 21683) (|quasiMonic?| . 21468) (|clip| . 20126) (|lSpaceBasis| . 19826) (|poisson| . 19684) (|flatten| . 19638) (|generateIrredPoly| . 19440) (|iiatan| . 19244) (|cycleRagits| . 19121) (|knownInfBasis| . 18814) (|fractRagits| . 18689) (|changeThreshhold| . 18574) (|fullPartialFraction| . 18351) (|OMgetString| . 18267) (|modulus| . 17117) (|airyBi| . 16674) (|returnType!| . 16131) (|OMgetObject| . 16049) (|OMgetError| . 15967) (|testDim| . 15659) (|palgRDE0| . 14560) (|midpoint| . 14291) (|ceiling| . 14091) (|credPol| . 13821) (|OMgetEndBVar| . 13739) (|mulbybinomial| . 13417) (|arity| . 13312) (|elRow2!| . 13014) (|completeHermite| . 12703) (|debug3D| . 12626) (|OMputEndBind| . 12544) (|integralRepresents| . 12267) (|leftZero| . 12151) (|OMreadStr| . 12042) (|weighted| . 11832) (|newton| . 11652) (|edf2ef| . 11497) (|rationalPoint?| . 10895) (|matrixDimensions| . 10743) (|deleteProperty!| . 10657) (|mainContent| . 10438) (|weight| . 9534) (|virtualDegree| . 9256) (|singleFactorBound| . 8533) (|nextIrreduciblePoly| . 8357) (|isList| . 8220) (|testModulus| . 8009) (|cRationalPower| . 7827) (|distinguishedRootsOf| . 7431) (|Ei1| . 7306) (|RittWuCompare| . 7078) (|showClipRegion| . 6956) (|hasoln| . 6509) (|xn| . 6302) (|charClass| . 6125) (|OMputAttr| . 6043) (|perfectNthRoot| . 5711) (|copyQuadVar| . 5499) (|prevPrime| . 5391) (|maxRowIndex| . 4924) (|sdf2lst| . 4495) (|symbolIfCan| . 4373) (|extractTop!| . 4198) (|cyclicGroup| . 3896) (|createZechTable| . 3685) (|oddintegers| . 3517) (|setlocalPoint!| . 2972) (|monicRightFactorIfCan| . 2708) (|initializeGroupForWordProblem| . 2435) (|oddInfiniteProduct| . 1549) (|viewThetaDefault| . 1369) (|omError| . 1236) (|permutationRepresentation| . 467) (|insertMatch| . 295) (|selectSumOfSquaresRoutines| . 245) (|removeSinSq| . 30)) 
\ No newline at end of file
+(((*1 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|))))) 
+(((*1 *2 *2) (AND (|isDomain| *2 (|Matrix| *3)) (|ofCategory| *3 (|Field|)) (|isDomain| *1 (|LinesOpPack| *3))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|Expression| (|DoubleFloat|))) (|isDomain| *2 (|Expression| (|Float|))) (|isDomain| *1 (|ExpertSystemToolsPackage|))))) 
+(((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|ofCategory| (|AlgebraicNumber|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|AlgebraicNumber|))) (|UnivariateFormalPowerSeries| (|AlgebraicNumber|)))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|AlgebraicNumber|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|AlgebraicNumber|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|AlgebraicNumber|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|AlgebraicNumber|))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|AlgebraicNumber|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessAlgebraicNumber|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| *4 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *4))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| *4) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessFinite| *4)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *4 (|Join| (|FiniteFieldCategory|) (|ConvertibleTo| (|Integer|)))))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Integer|)) (|RetractableTo| *3)) (|ofCategory| (|Integer|) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|)))) (|UnivariateFormalPowerSeries| (|Fraction| (|Integer|))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Integer|) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Integer|)))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Integer|)))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Integer|)) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessInteger|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 (|Symbol|))) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) (|Symbol|) *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|))))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| (|Symbol|)) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| (|Symbol|)) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|ofCategory| *7 (|Join| (|OrderedSet|) (|IntegralDomain|))) (|ofType| *8 (|Mapping| *4 *7)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| *4)) (|UnivariateFormalPowerSeries| *4))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| |exprStream| (|Mapping| (|Stream| *6) *6 *3)) (|:| A (|Mapping| *5 (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| *5))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| *4) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| *4)))) (|:| AX (|Mapping| *6 (|NonNegativeInteger|) *3 *6)) (|:| C (|Mapping| (|List| *5) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|Guess| *4 *5 *6 *7 *8 *9)) (|ofCategory| *4 (|RetractableTo| *3)) (|ofCategory| *5 (|RetractableTo| *3)) (|ofCategory| *4 (|Field|)) (|ofCategory| *5 (|GcdDomain|)) (|ofCategory| *6 (|Join| (|FunctionSpace| (|Integer|)) (|IntegralDomain|) (|RetractableTo| *7) (|RetractableTo| *3) (|RetractableTo| (|Integer|)) (|CombinatorialOpsCategory|) (|PartialDifferentialRing| *3) (CATEGORY |domain| (SIGNATURE * ($ $ $)) (SIGNATURE / ($ $ $)) (SIGNATURE ** ($ $ $)) (SIGNATURE |numerator| ($ $)) (SIGNATURE |denominator| ($ $)) (SIGNATURE |ground?| ((|Boolean|) $))))) (|ofType| *9 (|Mapping| *6 *4)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) (|Symbol|))) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) (|Symbol|) (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|))))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|ofCategory| (|Fraction| (|Polynomial| (|Integer|))) (|RetractableTo| *3)) (|ofCategory| (|Polynomial| (|Integer|)) (|RetractableTo| *3)) (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| (|Record| (|:| |guessStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|))))) (|UnivariateFormalPowerSeries| (|Fraction| (|Polynomial| (|Integer|)))))) (|:| |degreeStream| (|Stream| (|NonNegativeInteger|))) (|:| |testStream| (|Mapping| (|Stream| (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))))) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| |exprStream| (|Mapping| (|Stream| (|Expression| (|Integer|))) (|Expression| (|Integer|)) *3)) (|:| A (|Mapping| (|Polynomial| (|Integer|)) (|NonNegativeInteger|) (|NonNegativeInteger|) (|SparseUnivariatePolynomial| (|Polynomial| (|Integer|))))) (|:| AF (|Mapping| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|)))) (|NonNegativeInteger|) (|NonNegativeInteger|) (|UnivariateFormalPowerSeries| (|SparseUnivariatePolynomial| (|Fraction| (|Polynomial| (|Integer|))))))) (|:| AX (|Mapping| (|Expression| (|Integer|)) (|NonNegativeInteger|) *3 (|Expression| (|Integer|)))) (|:| C (|Mapping| (|List| (|Polynomial| (|Integer|))) (|NonNegativeInteger|)))) (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessPolynomial|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|List| (|GuessOption|))) (|isDomain| *2 HPSPEC) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 (|Symbol|)))) ((*1 *2 *3) (AND (|isDomain| *3 (|Symbol|)) (|isDomain| *2 (|Mapping| HPSPEC (|List| (|GuessOption|)))) (|isDomain| *1 (|GuessUnivariatePolynomial| *4)) (|ofType| *4 *3)))) 
+(((*1 *2 *3 *3) (AND (|ofCategory| *4 (|Ring|)) (|ofCategory| *2 (|MatrixCategory| *4 *5 *6)) (|isDomain| *1 (|BezoutMatrix| *4 *3 *2 *5 *6)) (|ofCategory| *3 (|UnivariatePolynomialCategory| *4)) (|ofCategory| *5 (|FiniteLinearAggregate| *4)) (|ofCategory| *6 (|FiniteLinearAggregate| *4))))) 
+(((*1 *1 *1) (AND (|ofCategory| *1 (|SExpressionCategory| *2 *3 *4 *5 *6)) (|ofCategory| *2 (|SetCategory|)) (|ofCategory| *3 (|SetCategory|)) (|ofCategory| *4 (|SetCategory|)) (|ofCategory| *5 (|SetCategory|)) (|ofCategory| *6 (|SetCategory|))))) 
+(((*1 *1 *1) (AND (|isDomain| *1 (|InnerSparseUnivariatePowerSeries| *2)) (|ofCategory| *2 (|Algebra| (|Fraction| (|Integer|)))) (|ofCategory| *2 (|Ring|))))) 
+((|cExp| . 1571308) (|car| . 1571059) (|sylvesterMatrix| . 1570765) (|shiftHP| . 1557541) (|edf2ef| . 1557386) (|rowEchWoZeroLinesWOVectorise| . 1557271) (|cdr| . 1557022) (|antiCommutative?| . 1556682) (|antiCommutator| . 1556623) (|OMunhandledSymbol| . 1556510) (|collectUpper| . 1556264) (|OMreceive| . 1556137) (|has?| . 1556023) (|zeroOf| . 1555352) (|symmetricGroup| . 1555050) (|linear| . 1554532) (|mesh| . 1553244) (|infClsPt?| . 1553151) (|plus| . 1552712) (|totalDifferential| . 1552531) (|length| . 1551011) (|primintegrate| . 1550592) (|upperCase| . 1550450) (|ceiling| . 1550250) (|modifyPointData| . 1549907) (|scripts| . 1549551) (|duplicates?| . 1549424) (|root| . 1549175) (|Lazard| . 1548967) (|var1StepsDefault| . 1548777) (|quotVecSpaceBasis| . 1548652) (|copyslice| . 1548488) (|ldf2lst| . 1548065) (|sign| . 1545647) (|Hausdorff| . 1545382) (|diffHP| . 1532158) (|evenlambert| . 1531665) (|enterInCache| . 1531391) (|rubiksGroup| . 1531278) (|unitNormalize| . 1531187) (|setMinPoints3D| . 1531110) (|highCommonTerms| . 1530906) (|OMputEndAttr| . 1530824) (|shiftRight| . 1530679) (|minimumExponent| . 1530519) (|axes| . 1530084) (|stopMusserTrials| . 1529758) (|cyclicGroup| . 1529456) (|rows| . 1528878) (|gcdprim| . 1528735) (|coerce| . 1488373) (|radicalOfLeftTraceForm| . 1488195) (|shallowCopy| . 1488077) (|birth| . 1487959) (|asechIfCan| . 1487818) (|isQuotient| . 1487519) (|irreducibleRepresentation| . 1486990) (|definingPolynomial| . 1485746) (|leftFactorIfCan| . 1485521) (|cyclePartition| . 1485400) (|isOp| . 1485040) (|distinguishedCommonRootsOf| . 1484802) (|localParamOfSimplePt| . 1484280) (|startStats!| . 1484084) (|clipSurface| . 1483962) (|iisqrt2| . 1483769) (|nrows| . 1483280) (|trim| . 1483092) (|distinguishedRootsOf| . 1482696) (|generalSqFr| . 1482421) (|Aleph| . 1482325) (|iiexp| . 1482129) (|ncols| . 1481640) (|adaptive?| . 1481568) (|linSolve| . 1481117) (|typeList| . 1480875) (|acsch| . 1479680) (|BasicMethod| . 1479533) (|eigenvector| . 1479216) (|cyclotomicDecomposition| . 1479050) (|option?| . 1478899) (|alterDrift!| . 1478709) (|OMgetEndAttr| . 1478627) (|inverseLaplace| . 1478196) (|position| . 1477314) (|createLowComplexityNormalBasis| . 1477030) (|OMputBind| . 1476948) (|multMonom| . 1476469) (|operator| . 1474551) (|is?| . 1473447) (|RemainderList| . 1473061) (|less?| . 1471845) (|push!| . 1471491) (|toScale| . 1471279) (|rightLcm| . 1471141) (|lflimitedint| . 1470616) (|leftExtendedGcd| . 1470396) (|algebraicVariables| . 1470115) (|subQuasiComponent?| . 1468676) (|nthFactor| . 1467829) (|formula| . 1467731) (|applyRules| . 1466971) (|kovacic| . 1466178) (|numberPlacesDegExtDeg| . 1464760) (|listVariable| . 1464480) (|atanIfCan| . 1464339) (|suchThat| . 1462407) (|getOrder| . 1462228) (|btwFact| . 1461847) (|overlabel| . 1461797) (|initiallyReduced?| . 1460777) (|semiResultantEuclidean1| . 1460546) (|cyclicEqual?| . 1460431) (|makeSeries| . 1460186) (|viewDeltaYDefault| . 1460006) (|selectODEIVPRoutines| . 1459956) (|yCoord| . 1459842) (|iicosh| . 1459646) (|setClosed| . 1459511) (|enqueue!| . 1459247) (|basicSet| . 1458392) (|mathieu24| . 1458129) (|createIrreduciblePoly| . 1457927) (|subResultantGcdEuclidean| . 1457685) (|weights| . 1457095) (|palgextint0| . 1456010) (|medialSet| . 1455344) (|flush| . 1455188) (|coth2tanh| . 1454973) (|outputFixed| . 1454794) (|rangePascalTriangle| . 1454536) (|roughBasicSet| . 1454139) (|flexible?| . 1453799) (|newtonPolySlope| . 1453347) (|getAncestors| . 1453215) (|extendedIntegrate| . 1452834) (|karatsubaDivide| . 1452621) (|quickSort| . 1452363) (|mergeDifference| . 1452243) (|convert| . 1443669) (|cSinh| . 1443509) (|padecf| . 1443204) (|makeSketch| . 1443003) (|fmecg| . 1441938) (|flatten| . 1441892) (|and| . 1441747) (|mainValue| . 1441627) (|forLoop| . 1441346) (|acschIfCan| . 1441205) (|translateToOrigin| . 1440077) (|tanh2coth| . 1439862) (|drot| . 1439638) (|optional?| . 1439523) (|call| . 1439442) (|normInvertible?| . 1439051) (|complete| . 1438479) (|symbolTableOf| . 1438360) (|shiftLeft| . 1438215) (|repeatUntilLoop| . 1438131) (|coefChoose| . 1437824) (|iflist2Result| . 1437556) (|rotate| . 1437309) (|ignore?| . 1436952) (|dnrm2| . 1436774) (|palglimint| . 1436203) (|every?| . 1435008) (|tanQ| . 1434637) (|diag| . 1434434) (|reducedForm| . 1434333) (|mesh?| . 1434212) (|droot| . 1433987) (|log2| . 1433864) (|fullInfClsPt| . 1433416) (|rightDiscriminant| . 1433000) (|deriv| . 1432869) (|factorGroebnerBasis| . 1432147) (|sqfrFactor| . 1432025) (|second| . 1431927) (|OMputVariable| . 1431815) (|parabolic| . 1431631) (|leadingIdeal| . 1431403) (|cyclicParents| . 1431282) (|critMonD1| . 1430916) (|satisfy?| . 1430309) (|setCurve| . 1429106) (|desingTree| . 1427137) (|eulerPhi| . 1427038) (|exprex| . 1426817) (|imagi| . 1426715) (|reverse!| . 1426256) (|hitherPlane| . 1426135) (|addPointLast| . 1425940) (|completeHermite| . 1425629) (|replaceVarByOne| . 1425343) (|iilog| . 1425147) (|isAbsolutelyIrreducible?| . 1424739) (|cfirst| . 1424518) (|ScanRoman| . 1424399) (|OMParseError?| . 1424311) (|dzasum| . 1424121) (|odd?| . 1423780) (|decomposeFunc| . 1423565) (|say| . 1423341) (|readIfCan!| . 1423068) (|resultantEuclideannaif| . 1422820) (|ShiftC| . 1422574) (|ode1| . 1422346) (|subs1stVar| . 1422088) (|debug| . 1421804) (|screenResolution3D| . 1421730) (|intensity| . 1421609) (|excpDivV| . 1421104) (|inconsistent?| . 1420346) (|copyIto| . 1420210) (|setpoint!| . 1419702) (|library| . 1419623) (|tableForDiscreteLogarithm| . 1419462) (|cot2trig| . 1419247) (|extendedSubResultantGcd| . 1418627) (|Ei2| . 1418502) (|algDsolve| . 1417967) (|positive?| . 1417490) (|iipolygamma| . 1417288) (|series| . 1411420) (|approximate| . 1410289) (|exponential1| . 1410199) (|mainVariable| . 1409436) (|conical| . 1409224) (|toseSquareFreePart| . 1408832) (|iicos| . 1408636) (|tomodpa| . 1408444) (|merge| . 1407493) (|divideIfCan| . 1407237) (|notelem| . 1407071) (|construct| . 1402751) (|lowerCase| . 1402609) (|expPot| . 1402421) (|variationOfParameters| . 1402194) (|squareFreePrim| . 1401918) (|integral?| . 1401102) (|algintegrate| . 1400606) (|OMputSymbol| . 1400491) (|expextendedint| . 1399985) (|realRoots| . 1399521) (|UP2ifCan| . 1399057) (|monomialIntPoly| . 1398799) (|showTypeInOutput| . 1398698) (|redPol| . 1398428) (|clearFortranOutputStack| . 1398326) (|derivationCoordinates| . 1398042) (|surface| . 1397946) (|indicialEquations| . 1396153) (|segment| . 1395859) (|taylorIfCan| . 1395673) (|legendreP| . 1395463) (|stFuncN| . 1395164) (|identityMatrix| . 1394996) (|infiniteProduct| . 1394110) (|scanOneDimSubspaces| . 1393858) (|tanSum| . 1393739) (|degreeOfMinimalForm| . 1393485) (|associatedSystem| . 1393168) (|getMatch| . 1392989) (|associatedEquations| . 1392588) (|factorFraction| . 1392371) (|integerDecode| . 1392280) (|operation| . 1391782) (|subresultantSequence| . 1391539) (|zeroSetSplitIntoTriangularSystems| . 1391180) (|powerAssociative?| . 1391038) (|integralMatrix| . 1390754) (|ZetaFunction| . 1387844) (|updatF| . 1387471) (|limitedint| . 1387051) (|validExponential| . 1386642) (|genericLeftTrace| . 1386330) (|imagI| . 1386127) (|moebius| . 1386028) (|chartV| . 1385523) (|complexExpand| . 1384875) (|cosSinInfo| . 1384741) (|comment| . 1384573) (|OMencodingBinary| . 1384523) (|uncouplingMatrices| . 1384279) (|eq| . 1383999) (|OMgetBVar| . 1383917) (|float| . 1383445) (|removeSinhSq| . 1383230) (|endOfFile?| . 1383151) (|positiveSolve| . 1381663) (|createPrimitiveElement| . 1381608) (|id| . 1381513) (|clearTheIFTable| . 1381422) (|quasiMonic?| . 1381207) (|changeName| . 1381088) (|integer| . 1380711) (|setfirst!| . 1380568) (|separateDegrees| . 1380313) (|roughSubIdeal?| . 1380002) (|crest| . 1379781) (|iiatanh| . 1379585) (|entry?| . 1379351) (|localize| . 1378762) (|returns| . 1378126) (|corrPoly| . 1377566) (|nextNormalPoly| . 1377390) (|string| . 1376940) (|log10| . 1376634) (|outlineRender| . 1376512) (|createPrimitivePoly| . 1376310) (|setFormula!| . 1376209) (|superscript| . 1376117) (|repeating| . 1376010) (|semiResultantEuclideannaif| . 1375779) (|minset| . 1375425) (|mapUp!| . 1375143) (|diff| . 1374731) (|totolex| . 1374449) (|lazyPquo| . 1374069) (|pdf2ef| . 1373914) (|truncate| . 1373556) (|fixedPoint| . 1373224) (|zoom| . 1372695) (|associator| . 1372633) (|polyPart| . 1372442) (|extDegree| . 1372317) (|negAndPosEdge| . 1372023) (|stronglyReduced?| . 1371461) (|child| . 1371301) (|varList| . 1369926) (|monicRightDivide| . 1369398) (|augment| . 1368207) (|integral| . 1367222) (|elliptic?| . 1366692) (|OMencodingXML| . 1366642) (|key| . 1366379) (|preprocess| . 1365524) (|expenseOfEvaluation| . 1365174) (|extractClosed| . 1365028) (|nthFractionalTerm| . 1364898) (|associative?| . 1364558) (|binaryFunction| . 1364282) (|sinhcosh| . 1364041) (|cylindrical| . 1363857) (|denomRicDE| . 1363479) (|increment| . 1363327) (|accuracyIF| . 1362920) (|pointV| . 1362415) (|genericPosition| . 1361997) (|B1solve| . 1361293) (|polygon?| . 1361172) (|aromberg| . 1360869) (|separant| . 1360622) (|OMgetInteger| . 1360537) (|exprHasLogarithmicWeights| . 1360231) (|extractBottom!| . 1360056) (|sum| . 1357379) (|entry| . 1356290) (|exprToUPS| . 1355411) (|Not| . 1355281) (|duplicates| . 1355094) (|queue| . 1354981) (|symbol| . 1354732) (|lazyPrem| . 1354352) (|adjunctionDivisor| . 1352496) (|symbolTable| . 1352353) (|obj| . 1352282) (|complement| . 1352153) (|pushFortranOutputStack| . 1351914) (|one| . 1351702) (|backOldPos| . 1351340) (|submod| . 1351276) (|filename| . 1351182) (|zero| . 1350790) (|generator| . 1349706) (|curveColor| . 1349549) (|Or| . 1349413) (|predicates| . 1349293) (|popFortranOutputStack| . 1349203) (^ . 1348603) (|primeFactor| . 1348481) (|remainder!| . 1348320) (|outputAsFortran| . 1347448) (|exp| . 1345181) (|critBonD| . 1344815) (|setScreenResolution3D| . 1344738) (|numberOfOperations| . 1344450) (|pi| . 1343981) (|innerSolve1| . 1343450) (|closedCurve?| . 1343329) (|complementaryBasis| . 1343055) (|sqrt| . 1342389) (|rightUnits| . 1341762) (|Ci| . 1341467) (|taylorQuoByVar| . 1341362) (|associatorDependence| . 1340963) (|cAtan| . 1340803) (|li| . 1340508) (|zag| . 1340458) (|someBasis| . 1340314) (|mantissa| . 1340142) (|erf| . 1339847) (|minColIndex| . 1339380) (|mergeFactors| . 1339237) (|difference| . 1339046) (|hyperelliptic| . 1338492) (|numberOfFactors| . 1338115) (|rk4f| . 1337828) (|fffg| . 1337387) (|DiffAction| . 1337163) (|rule| . 1336501) (|concat!| . 1335880) (|removeIrreducibleRedundantFactors| . 1335511) (|critpOrder| . 1335126) (|dilog| . 1334831) (|lo| . 1334741) (|associates?| . 1334651) (|solveLinearPolynomialEquationByFractions| . 1334394) (|closedCurve| . 1333874) (|children| . 1333594) (|differentiate| . 1329238) (|sin| . 1327768) (|incr| . 1327556) (|extendedEuclidean| . 1327277) (|retractable?| . 1326466) (|monomRDE| . 1326065) (|matrixConcat3D| . 1325930) (|cos| . 1324460) (|hi| . 1324370) (|drawComplex| . 1324106) (|ruleset| . 1323750) (|irreducibleFactor| . 1323628) (|rightDivide| . 1323118) (|tan| . 1321740) (|PDESolve| . 1321183) (|extendedint| . 1320837) (|possiblyInfinite?| . 1320719) (|rewriteSetByReducingWithParticularGenerators| . 1320297) (|vector| . 1320073) (|cot| . 1318878) (|basisOfInterpolateFormsForFact| . 1318317) (|linear?| . 1317759) (|internalSubQuasiComponent?| . 1317046) (|errorInfo| . 1316954) (|sec| . 1315759) (|stoseInvertibleSetsqfreg| . 1315397) (|computeBasis| . 1315184) (|dmpToHdmp| . 1314935) (|inR?| . 1314820) (|csc| . 1313625) (|ShiftAction| . 1313401) (|ravel| . 1313205) (|numberOfHues| . 1313124) (|shuffle| . 1312968) (|createNormalPoly| . 1312766) (|asin| . 1311385) (|getStream| . 1311207) (|discreteLog| . 1310984) (|nextPartition| . 1310648) (|removeDuplicates!| . 1310420) (|acos| . 1309039) (|slash| . 1308989) (|columnSpace| . 1308734) (|fortranTypeOf| . 1308618) (|ridHack1| . 1308512) (|atan| . 1307041) (|primeFrobenius| . 1306866) (|blankSeparate| . 1306773) (|set| . 1306563) (|pade| . 1305648) (|prime?| . 1304912) (|acot| . 1303714) (|element?| . 1303455) (|init| . 1303224) (|OMclose| . 1303142) (|cot2tan| . 1302927) (|interpretString| . 1302816) (|asec| . 1301618) (|palglimint0| . 1300359) (|controlPanel| . 1300120) (|ode2| . 1299886) (|numberOfPlacesOfDegree| . 1298477) (|acsc| . 1297279) (|cyclicSubmodule| . 1297033) (|chvar| . 1296645) (|evenInfiniteProduct| . 1295759) (|prepareDecompose| . 1294732) (|iExquo| . 1294583) (|sinh| . 1293208) (|generate| . 1292726) (|decimal| . 1292626) (|rischNormalize| . 1292165) (|incrementBy| . 1292010) (|squareFreePart| . 1291175) (|posExpnPart| . 1291075) (|cosh| . 1289700) (|shift| . 1289169) (|fortranInteger| . 1289124) (|tubeRadius| . 1288916) (|tanintegrate| . 1288517) (|yRange| . 1288288) (|debug3D| . 1288211) (|tanh| . 1286836) (|expand| . 1284944) (|OMgetApp| . 1284862) (|actualExtensionV| . 1284357) (|lastNonNull| . 1284230) (|OMUnknownSymbol?| . 1284142) (|outputAsTex| . 1283898) (|coth| . 1282706) (|filterWhile| . 1282452) (|isTimes| . 1281518) (|extractTop!| . 1281343) (|explicitEntries?| . 1281221) (|henselFact| . 1280648) (|OMgetEndError| . 1280566) (|sech| . 1279374) (|filterUntil| . 1279120) (|characteristicSet| . 1278454) (|modTree| . 1278329) (|listOfMonoms| . 1278111) (|stoseInvertibleSet| . 1277749) (|concat| . 1276640) (|se2rfi| . 1276231) (|csch| . 1275039) (|select| . 1274221) (|wholePart| . 1273797) (|Frobenius| . 1273208) (|setTopPredicate| . 1273055) (|semiResultantEuclidean2| . 1272824) (|asinh| . 1271629) (|multiEuclideanTree| . 1271504) (|guessRat| . 1264451) (|clip| . 1263109) (|outputForm| . 1262166) (|messagePrint| . 1262061) (|acosh| . 1260866) (|rightCharacteristicPolynomial| . 1260699) (|listYoungTableaus| . 1260536) (|increase| . 1260312) (|youngGroup| . 1260016) (|genericRightMinimalPolynomial| . 1259673) (|atanh| . 1258478) (|iiAiryBi| . 1258304) (|makeMulti| . 1258086) (|imagE| . 1257984) (|extensionDegree| . 1257296) (|tensorMap| . 1257135) (|result| . 1256891) (|acoth| . 1255696) (|meshFun2Var| . 1255282) (|bernoulliB| . 1255067) (|functionNames| . 1254977) (|nthRootIfCan| . 1254794) (|bivariateSLPEBR| . 1254397) (|makeRecord| . 1254220) (|asech| . 1253025) (|selectPolynomials| . 1252608) (|leadingTerm| . 1252430) (|lists| . 1252204) (|symbolIfCan| . 1252082) (|randnum| . 1251910) (|lastNonNul| . 1251783) (|OMgetObject| . 1251701) (|packageCall| . 1251552) (|lSpaceBasis| . 1251252) (|multiplyCoefficients| . 1250804) (|order| . 1246179) (|LowTriBddDenomInv| . 1245918) (|maxrank| . 1245350) (|df2ef| . 1245210) (|ptree| . 1245028) (|extractSplittingLeaf| . 1244842) (|OMputString| . 1244730) (|degreePartition| . 1244226) (|cyclicCopy| . 1244142) (|groebgen| . 1243810) (|inspect| . 1243308) (|stablePol| . 1243157) (|linkToFortran| . 1242310) (|leadingCoefficientRicDE| . 1241847) (|leader| . 1241600) (|fullParamInit| . 1240910) (|imagk| . 1240808) (|guessAlg| . 1236473) (|elColumn2!| . 1236175) (|#| . 1234794) (|extension| . 1234706) (|pfaffian| . 1234479) (|guessADE| . 1227426) (|nthRoot| . 1227052) (|mainContent| . 1226833) (|OMencodingSGML| . 1226783) (|infinite?| . 1226535) (|sumSquares| . 1226399) (|csch2sinh| . 1226184) (|sup| . 1225972) (|nextPrimitivePoly| . 1225796) (|hasoln| . 1225349) (|modularGcdPrimitive| . 1225087) (|solveLinearPolynomialEquation| . 1224099) (|eyeDistance| . 1223978) (|leftLcm| . 1223684) (|lexico| . 1223328) (|cubic| . 1222804) (|fortranLiteralLine| . 1222694) (|presuper| . 1222644) (|expt| . 1222458) (|leftFactor| . 1222291) (|mapExpon| . 1221797) (|stosePrepareSubResAlgo| . 1221383) (|complexLimit| . 1220414) (|squareFreeBasis| . 1220209) (|numericalOptimization| . 1219619) (|setexcpDiv!| . 1219111) (|varselect| . 1218905) (|linearAssociatedExp| . 1218718) (|gderiv| . 1218541) (|setStatus| . 1218258) (|numberOfVariables| . 1217403) (|rarrow| . 1217353) (|argumentList!| . 1216942) (|rewriteIdealWithRemainder| . 1216631) (|countRealRootsMultiple| . 1216387) (|cAsinh| . 1216227) (|empty?| . 1215131) (|distance| . 1215007) (|removeSuperfluousCases| . 1214222) (|finiteSeries2Vector| . 1214002) (|digamma| . 1213559) (|quotientByP| . 1213497) (|represents| . 1212368) (|minPoints| . 1212131) (|coerceP| . 1211925) (|halfExtendedResultant1| . 1211684) (|lquo| . 1210776) (|printTypes| . 1210591) (|epilogue| . 1210408) (|leftRemainder| . 1210114) (|oddintegers| . 1209946) (|blue| . 1209907) (|chebyshevU| . 1209594) (|intermediateResultsIF| . 1209187) (|numberOfComputedEntries| . 1209054) (|argscript| . 1208962) (|groebSolve| . 1208597) (|addBadValue| . 1208325) (|gcdBasis| . 1208120) (|romberg| . 1207820) (|retract| . 1198612) (|internalZeroSetSplit| . 1197851) (|determinant| . 1196864) (|factorByRecursion| . 1196168) (|monomials| . 1195374) (|lieAdmissible?| . 1195034) (|sizePascalTriangle| . 1194905) (|hasSolution?| . 1194316) (|useSingleFactorBound| . 1194158) (|initials| . 1193877) (|denominators| . 1193746) (|makeSin| . 1193538) (|identity| . 1193400) (|integerBound| . 1193181) (|leastPower| . 1192862) (|fortranReal| . 1192817) (|cAtanh| . 1192657) (|badNum| . 1192131) (F2FG . 1191769) (|insertMatch| . 1191597) (|dcopy| . 1191445) (|mapUnivariate| . 1190784) (|ratPoly| . 1190329) (|OMgetEndObject| . 1190247) (|withPredicates| . 1190124) (|setsymbName!| . 1189587) (|norm| . 1186074) (|any?| . 1184879) (|semiLastSubResultantEuclidean| . 1184645) (|lazyPseudoRemainder| . 1184540) (|maxDegree| . 1184262) (|sec2cos| . 1184047) (|linearAssociatedLog| . 1183669) (BY . 1183548) (|cAsin| . 1183388) (|polCase| . 1183041) (|gcdBasisAdd| . 1182833) (|binomial| . 1182259) (|regularRepresentation| . 1181853) (|divOfZero| . 1181756) (|resetAttributeButtons| . 1181675) (|completeEval| . 1181284) (|numeric| . 1179707) (|previous| . 1179611) (LODO2FUN . 1179297) (|readLineIfCan!| . 1179209) (|find| . 1179068) (|algebraicDecompose| . 1178120) (|radical| . 1177776) (|genericLeftNorm| . 1177464) (|singularitiesOf| . 1176599) (|att2Result| . 1175702) (|monomRDEsys| . 1175251) (|PollardSmallFactor| . 1175126) (|generalLambert| . 1174497) (|cycleElt| . 1174349) (|bag| . 1173679) (|simpson| . 1173379) (|divisors| . 1173243) (|pseudoRemainder| . 1173137) (|factorPolynomial| . 1172680) (|setsubMatrix!| . 1172454) (|setProperties| . 1172339) (|initiallyReduce| . 1171896) (|index| . 1171361) (|rightRecip| . 1171138) (|iipow| . 1170940) (|makeYoungTableau| . 1170783) (|nextSubsetGray| . 1170643) (D . 1169088) (|point| . 1168072) (|rationalFunction| . 1167630) (|removeZeroes| . 1166331) (|integralRepresents| . 1166054) (|quasiRegular?| . 1165751) (|setRow!| . 1165515) (|iiatan| . 1165319) (|min| . 1164830) (|pointPlot| . 1164164) (|imagJ| . 1163961) (|setAdaptive| . 1163886) (|subresultantVector| . 1163686) (|safetyMargin| . 1163344) (|extractProperty| . 1163180) (|finiteSeries2LinSysWOVectorise| . 1162930) (|irreducibleFactors| . 1162564) (|ratDsolve| . 1160757) (|setRealSteps| . 1160675) (|maximumExponent| . 1160515) (|findCoef| . 1160384) (|exponent| . 1159600) (|constantKernel| . 1159439) (|subMatrix| . 1158629) (|csubst| . 1158301) (|cup| . 1158175) (|startTable!| . 1157428) (|assoc| . 1157213) (|daxpy| . 1157026) (|balancedFactorisation| . 1156555) (|denominator| . 1156168) (|divOfPole| . 1156071) (|stopTableInvSet!| . 1155378) (|laguerre| . 1155217) (|monicLeftDivide| . 1154689) (|internalAugment| . 1153428) (|tryFunctionalDecomposition?| . 1153273) (|generalTwoFactor| . 1152998) (|basisOfInterpolateForms| . 1152437) (|setSingularPoints| . 1151188) (|invertibleElseSplit?| . 1150880) (|setelt!| . 1150727) (|prevPrime| . 1150619) (|sinhIfCan| . 1150478) (|blockConcat| . 1150200) (|separe| . 1150015) (|infLex?| . 1149710) (|brillhartIrreducible?| . 1149408) (|setErrorBound| . 1149215) (|stirling2| . 1149096) (|pseudoDivide| . 1148367) (|vspace| . 1148286) (|toseInvertibleSet| . 1147934) (|sub| . 1147884) (|rightPower| . 1147698) (|hasHi| . 1147581) (|charpol| . 1147316) (|one?| . 1146901) (|frst| . 1146807) (|arity| . 1146702) (|qqq| . 1146439) (|rightMult| . 1146284) (|numFunEvals| . 1146212) (|third| . 1146114) (|column| . 1145641) (|rightRemainder| . 1145503) (|viewPhiDefault| . 1145323) (|setClipValue| . 1145237) (|hconcat| . 1145097) (|latex| . 1144294) (|cAcos| . 1144134) (|extendIfCan| . 1143868) (|multinomial| . 1143721) (|height| . 1142787) (|lhs| . 1142277) (|outputGeneral| . 1142098) (|addMatchRestricted| . 1141923) (|karatsuba| . 1141704) (|shallowExpand| . 1141493) (|sdf2lst| . 1141064) (|previousTower| . 1140981) (|dimensionOfIrreducibleRepresentation| . 1140843) (|nodes| . 1140722) (|mapExponents| . 1140252) (|LiePolyIfCan| . 1139879) (|reverseLex| . 1139672) (|first| . 1138704) (|maxrow| . 1138410) (|viewWriteDefault| . 1138220) (|monicRightFactorIfCan| . 1137956) (|quoByVar| . 1137851) (|normal| . 1137717) (|useSingleFactorBound?| . 1137562) (|ramified?| . 1137021) (|completeSmith| . 1136686) (|selectNonFiniteRoutines| . 1136636) (|removeRoughlyRedundantFactorsInPol| . 1136346) (|makeFR| . 1135837) (|qShiftC| . 1135588) (|pushup| . 1134484) (|blockSplit| . 1133114) (|uncorrelated?| . 1132524) (|psolve| . 1125856) (|noLinearFactor?| . 1125705) (|factorSquareFreePolynomial| . 1125516) (|singleFactorBound| . 1124793) (|fortranLiteral| . 1124683) (|relativeApprox| . 1124123) (|alphanumeric?| . 1124043) (|computePowers| . 1123854) (|exteriorDifferential| . 1123707) (|lfextendedint| . 1123269) (|algebraicOf| . 1122981) (|triangular?| . 1122673) (|wholeRadix| . 1122550) (|pointSizeDefault| . 1122360) (|constantCoefficientRicDE| . 1121866) (|checkExtraValues| . 1121654) (|lintgcd| . 1121483) (|right| . 1120902) (|quasiComponent| . 1120571) (|linearlyDependentOverZ?| . 1120385) (|makeprod| . 1120258) (|e01sff| . 1120038) (|f02aff| . 1119873) (|specialise| . 1119616) (|tubePlot| . 1118325) (|f02aef| . 1118151) (|width| . 1117848) (|left| . 1117267) (|copyfirst| . 1117106) (|OMwrite| . 1115775) (|remainder| . 1115416) (|pointData| . 1115260) (|excepCoord| . 1115167) (|resultantSet| . 1114926) (|meatAxe| . 1113844) (|conjugate| . 1112814) (|normal01| . 1112724) (|safety| . 1112490) (|f02adf| . 1112319) (|unrankImproperPartitions0| . 1112170) (|projectionSet| . 1111929) (|reciprocalPolynomial| . 1111736) (|consnewpol| . 1111236) (|outputSpacing| . 1111124) (|aLinear| . 1110890) (|rowEchelonLocal| . 1110742) (|updatD| . 1110376) (|f02abf| . 1110208) (|principalSubResultantSet| . 1109973) (|pointColorPalette| . 1109839) (|clikeUniv| . 1109621) (|iiBesselI| . 1109419) (|supRittWu?| . 1109201) (|maxDerivative| . 1108923) (|linearMatrix| . 1108723) (|f02aaf| . 1108558) (|discriminantSet| . 1108317) (|iidprod| . 1108119) (|generalPosition| . 1107726) (|normal?| . 1107200) (|taylor| . 1103349) (|sbt| . 1103246) (|measure| . 1098336) (|returnType!| . 1097793) (|xor| . 1097645) (|cylindricalDecomposition| . 1097201) (|physicalLength!| . 1096943) (|abelianGroup| . 1096782) (|laurent| . 1093635) (|sample| . 1092906) (|cLog| . 1092746) (|showTheSymbolTable| . 1092698) (|dequeue!| . 1092443) (|basisOfMiddleNucleus| . 1092265) (|coefficientSet| . 1092033) (|thetaCoord| . 1091919) (|quote| . 1091832) (|puiseux| . 1088656) (|seed| . 1088570) (|fullDesTree| . 1088122) (|delta| . 1087936) (|fractionFreeGauss!| . 1087638) (|explicitlyFinite?| . 1087520) (|leftUnit| . 1087359) (|crushedSet| . 1087072) (|atoms| . 1086846) (|lowerPolynomial| . 1086517) (|selectOrPolynomials| . 1086091) (|zeta| . 1086008) (|double?| . 1085920) (|graphs| . 1085643) (|polynomial| . 1084846) (|gcdcofactprim| . 1084703) (|drift| . 1084574) (|decreasePrecision| . 1084402) (|OMputApp| . 1084320) (|normalizeIfCan| . 1083930) (|lllp| . 1083781) (|oddlambert| . 1083288) (|clearTable!| . 1083122) (|cSec| . 1082962) (|diagonalProduct| . 1082454) (|rightRank| . 1082262) (|removeZero| . 1082006) (|integralBasis| . 1080274) (|drawCurves| . 1079796) (|leadingSupport| . 1079650) (|noKaratsuba| . 1079476) (|listLoops| . 1079312) (|resultantnaif| . 1079146) (|idealSimplify| . 1078913) (|eulerE| . 1078698) (|stiffnessAndStabilityOfODEIF| . 1078222) (|fresnelC| . 1077834) (|elRow2!| . 1077536) (|partialQuotients| . 1077405) (|OMlistSymbols| . 1077284) (|null?| . 1077007) (|columns| . 1076429) (|curry| . 1076229) (|rightRegularRepresentation| . 1075909) (|acoshIfCan| . 1075768) (|mainMonomial| . 1075581) (|infix| . 1075435) (|lambda| . 1075344) (|scripted?| . 1075267) (|rightZero| . 1075151) (|getCurve| . 1075047) (|resetNew| . 1074976) (|graphCurves| . 1074376) (|curve?| . 1074255) (|integralBasisAtInfinity| . 1073984) (|elements| . 1073800) (|palginfieldint| . 1073335) (|colorFunction| . 1072954) (|hermite| . 1072548) (|maxPoints3D| . 1072474) (|wholeRagits| . 1072351) (|expandTrigProducts| . 1071950) (|startTableGcd!| . 1071185) (|airyAi| . 1070742) (|iisqrt3| . 1070549) (|localAbs| . 1069486) (|aRow| . 1069206) (|pmintegrate| . 1068075) (|untab| . 1067895) (|dequeue| . 1067498) (|leftTrace| . 1067381) (|setValue!| . 1067202) (|OMread| . 1067085) (|pdf2df| . 1066939) (|mindegTerm| . 1066741) (|useNagFunctions| . 1066319) (|createMultiplicationTable| . 1066065) (|setlocalParam!| . 1065527) (|OMgetType| . 1065443) (|e01sbf| . 1065184) (|points| . 1065025) (|coth2trigh| . 1064810) (|uniform| . 1064376) (|int| . 1063726) (|conjug| . 1063446) (** . 1057602) (|listRepresentation| . 1057429) (|fill!| . 1057054) (|gcdPolynomial| . 1056506) (|endSubProgram| . 1056425) (|quadTransform| . 1056005) (|setchart!| . 1055497) (|normalDeriv| . 1055187) (|splitNodeOf!| . 1054679) (|semiSubResultantGcdEuclidean2| . 1054454) (|HermiteIntegrate| . 1053697) (|splitSquarefree| . 1053417) (|chiSquare1| . 1053285) (|symmetric?| . 1052831) (|hadamard| . 1052668) (|rootsOf| . 1051857) (|numFunEvals3D| . 1051783) (|unravel| . 1051587) (|DiffC| . 1051341) (|terms| . 1050725) (|leadingExponent| . 1050252) (|laurentIfCan| . 1050065) (|setProperty| . 1049951) (|lyndon?| . 1049793) (|setchildren!| . 1049627) (|hcrf| . 1049438) (|simplify| . 1048758) (|ocf2ocdf| . 1048589) (|virtualDegree| . 1048311) (|newTypeLists| . 1048225) (|ipow| . 1048027) (|removeCosSq| . 1047812) (|dictionary| . 1047586) (|redpps| . 1047088) (|iisinh| . 1046892) (|multV| . 1046366) (|rules| . 1046010) (|rightExactQuotient| . 1045862) (|sn| . 1045687) (|nthCoef| . 1045498) (|genericLeftTraceForm| . 1045183) (|subs2ndVar| . 1044925) (|nullary| . 1044799) (|e02bcf| . 1044594) (|functionIsContinuousAtEndPoints| . 1043973) (|euclideanSize| . 1043874) (|e02bbf| . 1043672) (|firstUncouplingMatrix| . 1043409) (|e02baf| . 1043233) (|numberOfComponents| . 1042492) (|semiDiscriminantEuclidean| . 1042261) (|mapmult| . 1042127) (|graeffe| . 1041934) (|firstSubsetGray| . 1041797) (|e02akf| . 1041586) (|mr| . 1041282) (|pattern| . 1040965) (|functionIsOscillatory| . 1040662) (|minimize| . 1040381) (|xn| . 1040174) (|e02ajf| . 1039957) (|e04ycf| . 1039741) (|cache| . 1039625) (|primitivePart| . 1038458) (|homogenize| . 1036653) (|lcm| . 1036338) (|elliptic| . 1035578) (|e04ucf| . 1035034) (|OMreadStr| . 1034925) (|myDegree| . 1034510) (|e04naf| . 1034101) (|isPower| . 1033253) (|unit| . 1032919) (|e04mbf| . 1032686) (|pushdown| . 1031582) (|center| . 1031041) (|getCode| . 1030955) (|e04jaf| . 1030690) (|minimumDegree| . 1029798) (|e04gcf| . 1029539) (|rk4qc| . 1028753) (|LazardQuotient| . 1028484) (|e04fdf| . 1028225) (|symFunc| . 1027919) (|supersub| . 1027823) (|leftNorm| . 1027706) (|cRationalPower| . 1027524) (|e04dgf| . 1027181) (|systemCommand| . 1027068) (|rootPoly| . 1026667) (|divisor| . 1025169) (|f01ref| . 1024942) (|leftExactQuotient| . 1024628) (|besselY| . 1024173) (F2EXPRR . 1023983) (|sumOfDivisors| . 1023884) (|f01rdf| . 1023648) (|constDsolve| . 1023120) (|pleskenSplit| . 1022636) (|f01rcf| . 1022445) (|mainPrimitivePart| . 1022226) (|printStats!| . 1022060) (|iisech| . 1021864) (|f01qef| . 1021649) (|baseRDE| . 1021319) (|inverse| . 1019590) (|datalist| . 1019475) (|internalSubPolSet?| . 1018726) (|f01qdf| . 1018502) (|transcendent?| . 1018384) (|tubePointsDefault| . 1018194) (|desingTreeWoFullParam| . 1016914) (|distribute| . 1016806) (|f01qcf| . 1016627) (|reseed| . 1016513) (|generalizedContinuumHypothesisAssumed| . 1016428) (|comparison| . 1016293) (|f01mcf| . 1016075) (|zeroDimPrime?| . 1015703) (|search| . 1015556) (|f01maf| . 1015251) (|newSubProgram| . 1015142) (|lyndonIfCan| . 1015002) (|rightNorm| . 1014885) (|f01bsf| . 1014583) (|jacobian| . 1014017) (|rem| . 1013858) (|f01brf| . 1013522) (|newtonPolygon| . 1013120) (|integralLastSubResultant| . 1012725) (|innerint| . 1012085) (|prologue| . 1011902) (|quo| . 1011743) (|movedPoints| . 1011505) (|reduceLODE| . 1011092) (|triangularSystems| . 1010844) (|getRef| . 1010675) (|/\\| . 1010578) (|lex| . 1010447) (|complexEigenvalues| . 1010215) (|\\/| . 1010118) (|LiePoly| . 1009948) (|showArrayValues| . 1009871) (|getExplanations| . 1009749) (|radicalRoots| . 1009185) (|affineAlgSetLocal| . 1008668) (|mvar| . 1008241) (|ideal| . 1007339) (|sorted?| . 1007012) (|putGraph| . 1006849) (~= . 1006024) (|numberOfComposites| . 1005892) (|pair?| . 1005615) (|lieAlgebra?| . 1005275) (|An| . 1005107) (|figureUnits| . 1004953) (|leftTrim| . 1004765) (|univcase| . 1004486) (|affinePoint| . 1004363) (|polyRing2UPUP| . 1003925) (|expintfldpoly| . 1003601) (|basisOfLeftAnnihilator| . 1003420) (|mapMatrixIfCan| . 1003018) (|value| . 1002594) (|splitLinear| . 1002488) (|normalDenom| . 1002266) (|pow| . 1001866) (|subCase?| . 1001037) (|dom| . 1000959) (|quotedOperators| . 1000613) (|constantRight| . 1000373) (|internalInfRittWu?| . 999624) (|scale| . 999142) (|properties| . 999030) (|euclideanNormalForm| . 998748) (|print| . 998562) (|areEquivalent?| . 997890) (|addiag| . 997718) (|digits| . 997097) (|intersectionDivisor| . 995031) (|colorDef| . 994907) (|aCubic| . 994667) (|karatsubaOnce| . 994493) (|leftGcd| . 994199) (|nextLatticePermutation| . 994050) (|postfix| . 994000) (|patternMatchTimes| . 993530) (|unaryFunction| . 993288) (|zaxpy| . 993077) (|shiftRoots| . 992914) (|monomial?| . 991998) (|script| . 991634) (|radPoly| . 991292) (|icamax| . 991146) (|statusIto| . 990989) (|trigs| . 990381) (LE . 990163) (|multiplicative?| . 990010) (|Ei4| . 989885) (|printStatement| . 989791) (|selectAndPolynomials| . 989365) (|leftOne| . 989245) (|shiftInfoRec| . 988675) (|createLowComplexityTable| . 988425) (|declare| . 988307) (|cCosh| . 988147) (|bright| . 987864) (|firstNumer| . 987765) (|indices| . 987609) (|OMputObject| . 987527) (|pr2dmp| . 987176) (|newLine| . 987095) (|origin| . 987003) (|constantIfCan| . 986832) (|roughBase?| . 986524) (|fi2df| . 986384) (|output| . 985862) (|legendre| . 985589) (|base| . 985146) (|selectIntegrationRoutines| . 985096) (|fortran| . 984884) (|computeInt| . 984461) (|numerators| . 984330) (|directSum| . 983962) (|removeRoughlyRedundantFactorsInPols| . 983354) (|pushdterm| . 982952) (|basisOfCentroid| . 982763) (|infieldint| . 982509) (|interpolate| . 981220) (|stop| . 981175) (|pomopo!| . 981022) (|printCode| . 980943) (|countRealRoots| . 980731) (|suppOfZero| . 980606) (|heapSort| . 980348) (|list?| . 980071) (|rename| . 979977) (|nextIrreduciblePoly| . 979801) (|doubleResultant| . 979485) (|seriesToOutputForm| . 979132) (|LyndonWordsList| . 978933) (Y . 978496) (|bombieriNorm| . 977832) (|stirling1| . 977713) (|complexEigenvectors| . 977376) (|problemPoints| . 976874) (|phiCoord| . 976760) (|inf| . 976610) (|contractSolve| . 975954) (|zeroSetSplit| . 972256) (|integralMatrixAtInfinity| . 971972) (|reorder| . 971332) (|sumOfKthPowerDivisors| . 971191) (|OMgetEndBVar| . 971109) (|semiResultantReduitEuclidean| . 970840) (|cAcoth| . 970680) (|even?| . 970339) (|finite?| . 970009) (|squareFreeFactors| . 969690) (|leviCivitaSymbol| . 969525) (|factorCantorZassenhaus| . 969025) (|hermiteH| . 968870) (|laurentRep| . 968693) (|yellow| . 968654) (|connect| . 968495) (|coleman| . 968335) (|paren| . 968062) (|rationalApproximation| . 967529) (|fglmIfCan| . 967112) (|constant?| . 966697) (|float?| . 966420) (|basisOfLeftNucleus| . 966242) (|credPol| . 965972) (|lazyPseudoDivide| . 965065) (|extractPoint| . 964918) (|setAttributeButtonStep| . 964833) (|Ei| . 964416) (|string?| . 964139) (|setOfMinN| . 963955) (|suppOfPole| . 963830) (|viewport2D| . 963774) (|lepol| . 963507) (|variablesOf| . 963383) (|showTheFTable| . 963324) (|particularSolution| . 962312) (|vark| . 962078) (|effective?| . 961953) (|mapGen| . 961325) (|numberOfPrimitivePoly| . 961173) (|assert| . 960754) (|hue| . 960494) (|more?| . 959438) (|paraboloidal| . 959254) (|stoseInvertible?sqfreg| . 958843) (|lifting| . 958262) (GE . 958044) (|subscript| . 957952) (|rootSplit| . 957547) (|leftRegularRepresentation| . 957227) (|prime| . 957088) (|components| . 956967) (|canonicalIfCan| . 956820) (|permutationGroup| . 956680) (|closeComponent| . 956480) (|interpret| . 956285) (|projection| . 956187) (|setColumn!| . 955951) (|horizSplit| . 955329) (|copies| . 955214) (|diagonals| . 955092) (|iisin| . 954896) (|unmakeSUP| . 954743) (|internal?| . 954597) (|tex| . 954509) (|createNormalElement| . 954378) (|roman| . 954216) (^= . 954166) (|certainlySubVariety?| . 953848) (|autoReduced?| . 953509) (|setEpilogue!| . 953320) (|jacobiIdentity?| . 952980) (|integrate| . 940070) (|factorSFBRlcUnit| . 939343) (|alphabetic| . 939295) (|tan2trig| . 939080) (|generalInfiniteProduct| . 938076) (|genus| . 935614) (|makeCell| . 935293) (|red| . 935254) (|cCoth| . 935094) (|discriminant| . 933717) (|graphState| . 933464) (|sparsityIF| . 933321) (|distFact| . 932679) (|direction| . 932539) (|rationalPlaces| . 931288) (|initParLocLeaves| . 930598) (|mapdiv| . 930436) (|separate| . 929750) (|dn| . 929575) (|computeCycleEntry| . 929434) (|aspFilename| . 929343) (|rewriteSetWithReduction| . 928970) (|level| . 928813) (|leftDiscriminant| . 928397) (|edf2fi| . 928242) (|OMputAttr| . 928160) (|conditionP| . 927839) (|mainVariableOf| . 927724) (|simplifyPower| . 927567) (UTS2UP . 927254) (|OMgetError| . 927172) (|OMUnknownCD?| . 927084) (|oddInfiniteProduct| . 926198) (|rightScalarTimes!| . 926057) (|dmp2rfi| . 924893) (|setMinPoints| . 924818) (|delete| . 924558) (|packExps| . 924351) (|ReduceOrder| . 923934) (|systemSizeIF| . 923527) (|middle| . 923334) (|mightHaveRoots| . 923110) (|rootSimp| . 922553) (|setLegalFortranSourceExtensions| . 922460) (|adjoint| . 921425) (|approximants| . 921281) (|round| . 921226) (|translate| . 920203) (|table| . 919875) (|lazyPremWithDefault| . 919297) (|collect| . 918957) (|completeEchelonBasis| . 918791) (|cycleSplit!| . 918651) (|omError| . 918518) (|kroneckerDelta| . 918353) (|anfactor| . 917932) (|maxPower| . 917660) (|rischDE| . 916928) (|simplifyLog| . 916713) (|variableName| . 916503) (|collectUnder| . 916257) (|computeCycleLength| . 916080) (|primes| . 915941) (|stoseSquareFreePart| . 915539) (|leadingIndex| . 915066) (= . 913915) (|cothIfCan| . 913774) (|substring?| . 913652) (|evaluate| . 912661) (|genericRightTraceForm| . 912346) (|write!| . 912212) (|create3Space| . 911998) (|bits| . 911646) (|wordInGenerators| . 911464) (|coefficients| . 910621) (< . 910113) (|mapCoef| . 909918) (|limitedIntegrate| . 909478) (|LyndonWordsList1| . 909255) (|purelyAlgebraicLeadingMonomial?| . 908969) (|functionName| . 908759) (> . 908626) (|OMconnOutDevice| . 908530) (|findOrderOfDivisor| . 906732) (|d03faf| . 906393) (|fullOut| . 905263) (|mathieu23| . 905000) (<= . 904618) (|supp| . 904493) (|exQuo| . 903526) (|d03eef| . 903149) (|partialNumerators| . 903018) (|createGenericMatrix| . 902839) (|next| . 902743) (>= . 902610) (|laplace| . 902224) (|rationalIfCan| . 900824) (|d03edf| . 900586) (|stiffnessAndStabilityFactor| . 900374) (|selectOptimizationRoutines| . 900324) (|decrease| . 900100) (|getMultiplicationMatrix| . 899443) (|factorSqFree| . 898858) (|dfRange| . 898725) (|block| . 898630) (|generalizedInverse| . 898374) (|suffix?| . 898283) (|negative?| . 897806) (|getButtonValue| . 897691) (+ . 894996) (|bitTruth| . 894883) (|deref| . 894801) (|rst| . 894707) (|rightQuotient| . 894569) (|differentialVariables| . 894294) (- . 891474) (|rootRadius| . 891088) (|outputList| . 890974) (|basis| . 889344) (|showAllElements| . 889200) (|palgint0| . 888185) (|char| . 888029) (/ . 883936) (|factorsOfCyclicGroupSize| . 883783) (|totalDegree| . 883070) (|univariateSolve| . 880829) (|degreeSubResultantEuclidean| . 880536) (|maxdeg| . 880245) (|scaleRoots| . 880082) (|replace| . 879967) (|prem| . 879587) (|writeLine!| . 879431) (|stopTable!| . 878756) (|numberOfDivisors| . 878657) (|OMmakeConn| . 878562) (FG2F . 878200) (|scan| . 876206) (|totalGroebner| . 876034) (|true| . 875993) (|showFortranOutputStack| . 875891) (|parametrize| . 872608) (|schwerpunkt| . 872396) (|Ei6| . 872271) (|normDeriv2| . 871946) (|fractRagits| . 871821) (|getEq| . 871468) (|shanksDiscLogAlgorithm| . 871238) (|expint| . 870857) (|extract!| . 870355) (|affineSingularPoints| . 868995) (|affineAlgSet| . 868084) (|polar| . 867900) (|reducedQPowers| . 867665) (|permutations| . 867521) (|iitan| . 867325) (|classNumber| . 866037) (|bandedHessian| . 865640) (|inrootof| . 865421) (|ratDenom| . 863734) (|objectOf| . 863657) (|homogeneous?| . 863339) (|branchPointAtInfinity?| . 863070) (|OMsend| . 862915) (|linearPolynomials| . 862544) (|resetVariableOrder| . 862452) (|cosIfCan| . 862311) (|oneDimensionalArray| . 862060) (|setButtonValue| . 861830) (|morphism| . 861464) (|df2mf| . 861332) (|solve1| . 861066) (|setEmpty!| . 860890) (|squareTop| . 860701) (|subTriSet?| . 860008) (|localParam| . 859837) (|linearBezier| . 859684) (|bezoutResultant| . 859347) (|guessPRec| . 852294) (|nullity| . 851118) (|boundOfCauchy| . 850923) (|orbits| . 850792) (|cschIfCan| . 850651) (|pointColorDefault| . 850477) (|viewZoomDefault| . 850297) (GF2FG . 849904) (|c05nbf| . 849621) (|equation| . 848886) (|subNode?| . 848630) (|prefix?| . 848539) (|orbit| . 847395) (|univariatePolynomials| . 847024) (|name| . 846381) (|getMeasure| . 846269) (|bezoutDiscriminant| . 845935) (|dcabs1| . 845804) (|saturate| . 845314) (|c05adf| . 845076) (|map| . 819668) (|viewport3D| . 819610) (|setScreenResolution| . 819535) (|removeRedundantFactors| . 818045) (|multiplyExponents| . 817567) (|chartCoord| . 817474) (|nullary?| . 817390) (|convertIfCan| . 817283) (|gbasis| . 816982) (|bitCoef| . 816897) (|cross| . 816592) (|c06gsf| . 816417) (|atanhIfCan| . 816276) (|changeBase| . 815949) (|nand| . 815851) (|reindex| . 815643) (|nonLinearPart| . 815528) (|infieldIntegrate| . 815269) (|hessian| . 814914) (|getGraph| . 814779) (|c06gqf| . 814604) (|bernoulli| . 814293) (|lineColorDefault| . 814119) (|gramschmidt| . 813994) (|hexDigit| . 813946) (|oblateSpheroidal| . 813737) (|iiacsch| . 813541) (|approxNthRoot| . 813399) (|squareFreePolynomial| . 812942) (|c06gcf| . 812770) (|unprotectedRemoveRedundantFactors| . 812480) (|secIfCan| . 812339) (|shade| . 812150) (|digit| . 812102) (|iibinom| . 811904) (|insertBottom!| . 811723) (|tubePoints| . 811495) (|setPoly| . 811357) (|c06gbf| . 811185) (|leftUnits| . 810558) (|genusNeg| . 808709) (|lowerCase?| . 808629) (|escape| . 808586) (|iiperm| . 808388) (|permutation| . 808031) (|sortConstraints| . 807698) (|prinb| . 807406) (|c06fuf| . 807192) (|LyndonBasis| . 806898) (|blowUpWithExcpDiv| . 806208) (|checkForZero| . 805317) (|smaller?| . 805231) (|drawComplexVectorField| . 804998) (|iidigamma| . 804824) (|subResultantGcd| . 804294) (|mainCoefficients| . 804079) (|c06frf| . 803868) (|simpsono| . 803568) (|explimitedint| . 803013) (|polarCoordinates| . 802765) (|parabolicCylindrical| . 802581) (|irreducible?| . 801972) (|cAcsch| . 801812) (|copy!| . 801674) (|plenaryPower| . 801528) (|c06fqf| . 801320) (|diagonal?| . 800866) (|lexGroebner| . 800694) (|transcendentalDecompose| . 798779) (|f2df| . 798654) (|c06fpf| . 798446) (|zRange| . 798330) (|factorset| . 797985) (|compactFraction| . 797886) (|closed?| . 797661) (|coerceListOfPairs| . 797533) (|algebraicSet| . 797129) (|eval| . 786141) (|recolor| . 785876) (|var1Steps| . 785648) (|doubleComplex?| . 785560) (|euclideanGroebner| . 784666) (|groebner| . 782915) (|c06ekf| . 782737) (|OMgetBind| . 782655) (|unitVector| . 781928) (|blowUp| . 781236) (|power| . 781074) (|finiteBound| . 780889) (|simpleBounds?| . 780746) (|rur| . 779126) (|characteristicSerie| . 778352) (|c06ecf| . 778177) (|removeFirstZeroes| . 778077) (|primitivePart!| . 777858) (|iicot| . 777662) (|child?| . 777504) (|exprToGenUPS| . 776625) (|invmod| . 776564) (|c06ebf| . 776392) (|tan2cot| . 776177) (|OMputError| . 776095) (|quoted?| . 775980) (|region| . 775821) (|iitanh| . 775625) (|subset?| . 775500) (|realElementary| . 774819) (|polynomialZeros| . 774551) (|extend| . 772312) (|evalRec| . 771871) (|c06eaf| . 771699) (|packModulus| . 771433) (|minPoly| . 770975) (|patternMatch| . 766850) (|primitiveElement| . 764910) (|whileLoop| . 764826) (|checkOptions| . 764696) (|s17def| . 764457) (|expressIdealMember| . 764351) (|characteristicPolynomial| . 762406) (|insert!| . 759436) (|hash| . 758356) (|extractIndex| . 758199) (|randomR| . 757476) (|integralCoordinates| . 757164) (|external?| . 757082) (|cTanh| . 756922) (|coefficient| . 753899) (|s17dcf| . 753660) (|stoseInvertible?| . 752890) (|permanent| . 752670) (|discriminantEuclidean| . 752422) (|nodeOf?| . 752175) (|neglist| . 752042) (|vertSplit| . 751420) (|aQuartic| . 751177) (|stoseIntegralLastSubResultant| . 750772) (|s17akf| . 750613) (|topPredicate| . 750446) (|pack!| . 750310) (|hMonic| . 750071) (|repSq| . 749881) (|maxLevel| . 749603) (|setlocalPoint!| . 749058) (|lfextlimint| . 748548) (|monicModulo| . 748256) (|s17ajf| . 748097) (|headRemainder| . 747757) (|moreAlgebraic?| . 747064) (|palgRDE0| . 745965) (|coerceL| . 745744) (|intPatternMatch| . 745070) (|primintfldpoly| . 744801) (|condition| . 744625) (|lazyEvaluate| . 744531) (|s17ahf| . 744372) (|swapColumns!| . 744149) (|csc2sin| . 743934) (|regime| . 743017) (|stoseInternalLastSubResultant| . 742071) (|trunc| . 741728) (|index?| . 741569) (|s17aff| . 741410) (|s17agf| . 741251) (|numericalIntegration| . 740626) (|lift| . 738725) (|stoseInvertible?reg| . 738314) (|Is| . 737097) (|OMReadError?| . 737009) (|schema| . 736795) (|coshIfCan| . 736654) (|viewpoint| . 734729) (|diophantineSystem| . 734384) (|setVariableOrder| . 734122) (|reduce| . 727537) (|evalat| . 727398) (|guessPade| . 723063) (|ode| . 722798) (|mathieu12| . 722535) (|s17aef| . 722376) (|cosh2sech| . 722161) (|ParCondList| . 721560) (|color| . 721373) (|solveRetract| . 721041) (|subResultantChain| . 720786) (|rootBound| . 720444) (|numberOfChildren| . 720287) (|dec| . 720229) (|monomialIntegrate| . 719875) (|transform| . 719611) (|sincos| . 719372) (|s17adf| . 719213) (|lllip| . 719054) (|close| . 718779) (|optimize| . 717543) (|intChoose| . 716950) (|sumOfSquares| . 716834) (|factorsOfDegree| . 716575) (|modifyPoint| . 715977) (|unvectorise| . 715372) (|s17acf| . 715213) (|OMputEndObject| . 715131) (|LyndonCoordinates| . 714837) (|outputMeasure| . 714717) (|mainVariable?| . 714443) (|df2fi| . 714303) (|rowEch| . 714161) (|s15aef| . 714002) (|extractIfCan| . 713848) (|fixedDivisor| . 713687) (|mainVariables| . 713416) (|exponential| . 713053) (|numberOfNormalPoly| . 712901) (|normalElement| . 712589) (|mulmod| . 712525) (|socf2socdf| . 712332) (|compdegd| . 711946) (|s15adf| . 711787) (|vectoraddmul| . 711617) (|plotPolar| . 710988) (|generic?| . 710873) (|rroot| . 710350) (|divergence| . 710025) (|raisePolynomial| . 709696) (|upperCase?| . 709616) (|pointColor| . 709459) (|optAttributes| . 708955) (|s14baf| . 708790) (|setParam!| . 708591) (|orthonormalBasis| . 708399) (|iisec| . 708203) (|univariate?| . 707916) (|cardinality| . 707777) (|display| . 706505) (|s14abf| . 706346) (|changeMeasure| . 706231) (|commutator| . 706128) (|noncommutativeJordanAlgebra?| . 705788) (|largest| . 705441) (|fintegrate| . 704877) (|bat| . 704706) (|lazyResidueClass| . 704180) (|linearPart| . 704065) (|iiacot| . 703869) (|totalfract| . 703433) (|s14aaf| . 703274) (|clipPointsDefault| . 703106) (|companionBlocks| . 702865) (|fortranComplex| . 702820) (|errorKind| . 702726) (|composites| . 702605) (|iomode| . 702447) (|tryFunctionalDecomposition| . 702289) (|lookup| . 702021) (|s13adf| . 701862) (|approxSqrt| . 701762) (|continuedFraction| . 700833) (|polyRicDE| . 699854) (|stack| . 699741) (|multiplicity| . 698784) (|zerosOf| . 697706) (|innerEigenvectors| . 697255) (|s13acf| . 697096) (|rowEchelon| . 695470) (|polygamma| . 694937) (|linGenPos| . 694593) (|alphabetic?| . 694513) (|deleteRoutine!| . 694427) (|innerSolve| . 694108) (|rotatey| . 693967) (|algSplitSimple| . 693595) (|content| . 692896) (|s13aaf| . 692737) (|SturmHabichtMultiple| . 692490) (|insertionSort!| . 691947) (|nextPrimitiveNormalPoly| . 691771) (|gradient| . 691416) (|Zero| . 691115) (|s01eaf| . 690944) (|listexp| . 690611) (LT . 690393) (|mulbyscalar| . 690229) (|listAllMono| . 689947) (|pointDominateBy| . 688193) (|minimalPolynomial| . 687438) (|ran| . 687181) (|laplacian| . 686856) (|signAround| . 686112) (|s21bdf| . 685944) (|extendedResultant| . 685652) (|algebraicCoefficients?| . 685366) (|LazardQuotient2| . 685094) (|unexpand| . 684778) (|unrankImproperPartitions1| . 684629) (|exists?| . 684540) (|bandedJacobian| . 684140) (|select!| . 683808) (|createNormalPrimitivePoly| . 683606) (|changeThreshhold| . 683491) (|s21bcf| . 683326) (|hdmpToDmp| . 683077) (|setTower!| . 682963) (|partitions| . 682528) (|besselJ| . 682073) (|remove!| . 680823) (|antiAssociative?| . 680483) (|gcdcofact| . 680340) (|getDatabase| . 680131) (|s21bbf| . 679966) (|objects| . 679688) (|rootOf| . 678192) (|hypergeometric0F1| . 677973) (|universe| . 677847) (|imagK| . 677644) (|iiacoth| . 677448) (|logpart| . 677184) (|listSD| . 676998) (|s21baf| . 676836) (|trapezoidalo| . 676536) (|retractIfCan| . 668840) (RF2UTS . 668500) (|hdmpToP| . 668277) (|OMreadFile| . 668168) (|cn| . 667993) (|fTable| . 666874) (|addPoint| . 666279) (|s20adf| . 666120) (|logIfCan| . 665979) (|tValues| . 665880) (|delete!| . 665600) (|completeHensel| . 665366) (|normalized?| . 664346) (|splitConstant| . 663943) (|e02agf| . 663669) (|showTheIFTable| . 663609) (|pdct| . 663529) (|qelt| . 662922) (|ddot| . 662738) (|makeop| . 662432) (|transpose| . 661580) (|s20acf| . 661421) (|isPlus| . 660480) (|match?| . 660356) (|bumptab| . 660136) (|setPrologue!| . 659947) (|typeLists| . 659737) (|solid?| . 659641) (|elementary| . 659490) (|iroot| . 659254) (|alternative?| . 658914) (|internalDecompose| . 655939) (|d01aqf| . 655692) (|LagrangeInterpolation| . 655497) (|leftDivide| . 654763) (|complexNormalize| . 653490) (|relerror| . 653411) (|iidsum| . 653213) (|indexName| . 653003) (|power!| . 652817) (|frobenius| . 652637) (|s19adf| . 652478) (|permutationRepresentation| . 651709) (|slex| . 651550) (|setCondition!| . 651371) (|palgRDE| . 650877) (|or| . 650732) (|nary?| . 650648) (|lazy?| . 650526) (|d01apf| . 650273) (|nlde| . 650046) (|eigenMatrix| . 649853) (|dznrm2| . 649663) (|xRange| . 649434) (|squareFree| . 646921) (|s19acf| . 646762) (|repeating?| . 646590) (|evalIfCan| . 642503) (|sinIfCan| . 642362) (|splitDenominator| . 640771) (|genusTree| . 640053) (|invertibleSet| . 639767) (|mainSquareFreePart| . 639548) (|ord| . 639468) (|numberOfImproperPartitions| . 639359) (|d01anf| . 639109) (|generalCoefficient| . 638711) (|Gamma| . 637987) (|listAllMonoExp| . 637676) (|samplePoint| . 637412) (|hexDigit?| . 637332) (|idamax| . 637192) (|nonSingularModel| . 636484) (|d01amf| . 636240) (|factorSquareFree| . 634276) (|stripCommentsAndBlanks| . 634189) (|plot| . 632306) (|weierstrass| . 632099) (|qsetelt!| . 631687) (|quotValuation| . 631594) (|nextsubResultant2| . 631361) (|d01alf| . 631068) (|bandMatrix| . 630506) (|fracPart| . 630206) (|groebner?| . 629950) (|subspace| . 629486) (|torsionIfCan| . 628509) (|resultantReduit| . 628311) (|s19abf| . 628152) (|genericRightNorm| . 627840) (|padicFraction| . 627741) (|bipolarCylindrical| . 627532) (|expenseOfEvaluationIF| . 627125) (|unit?| . 627038) (|izamax| . 626852) (|module| . 626191) (|insert| . 625946) (|d01akf| . 625702) (|quasiAlgebraicSet| . 625438) (|reduceRow| . 625316) (|putColorInfo| . 625163) (|curveColorPalette| . 625029) (|ptFunc| . 624685) (|sayLength| . 624455) (|s19aaf| . 624296) (|headReduce| . 623853) (|mkPrim| . 623605) (|iiBesselJ| . 623403) (|factorAndSplit| . 623244) (|diagonalMatrix| . 621971) (|guess| . 610472) (|definingEquations| . 610211) (|d01ajf| . 609967) (|pointInIdeal?| . 609589) (|dot| . 609078) (|OMgetEndBind| . 608996) (|setMaxPoints| . 608921) (|bumptab1| . 608750) (|Musser| . 608539) (|s18def| . 608300) (|sts2stst| . 608073) (|symmetricPower| . 607627) (|po| . 607471) (|resetBadValues| . 607384) (|zeroSquareMatrix| . 607217) (|wordInStrongGenerators| . 607035) (|s18dcf| . 606796) (|tRange| . 606615) (|entries| . 605343) (|polyred| . 605127) (|getGoodPrime| . 604856) (|magnitude| . 604702) (|mapUnivariateIfCan| . 604341) (|swap!| . 604140) (|s18aff| . 603981) (|lBasis| . 601637) (|acotIfCan| . 601496) (|transCoord| . 601403) (|expandPower| . 601188) (|imaginary| . 601090) (|palgextint| . 600606) (|monicDivide| . 600183) (|s18aef| . 600024) (|meshPar2Var| . 598993) (|setnext!| . 598852) (|applyTransform| . 598545) (|acscIfCan| . 598404) (|var2Steps| . 598176) (|tracePowMod| . 597963) (|s18adf| . 597804) (|solve| . 580986) (|removeSuperfluousQuasiComponents| . 580299) (|rationalPower| . 580081) (|OMopenFile| . 579954) (|eigenvectors| . 579567) (|mainKernel| . 579467) (|localIntegralBasis| . 578008) (|exponents| . 577917) (|reshape| . 577188) (|sqfree| . 576871) (|s18acf| . 576712) (|iiGamma| . 576538) (|squareFreeLexTriangular| . 576077) (|box| . 575894) (|critM| . 575624) (|redmat| . 575246) (|conditionsForIdempotents| . 574022) (|label| . 573972) (|heap| . 573861) (|f04qaf| . 573544) (|mulbybinomial| . 573222) (|currentSubProgram| . 573141) (|lastSubResultant| . 572286) (|critT| . 571904) (|component| . 571386) (|generalizedEigenvectors| . 571035) (|palgint| . 570586) (|f04mcf| . 570345) (|OMlistCDs| . 570254) (|lyndon| . 570124) (|split| . 568051) (|findCycle| . 567800) (|cyclicEntries| . 567679) (|solveLinear| . 567155) (GT . 566937) (|revert| . 566444) (|f04mbf| . 566024) (|front| . 565769) (|sturmSequence| . 565580) (|makeVariable| . 564794) (|mirror| . 564150) (|adaptive| . 563773) (|Ei1| . 563648) (|stFunc2| . 563350) (|f04maf| . 563100) (|zeroMatrix| . 562573) (|goppaCode| . 561273) (|toroidal| . 561064) (|generateIrredPoly| . 560866) (|listOfTerms| . 560217) (|basisOfLeftNucloid| . 560028) (|multiServ| . 559917) (|f04jgf| . 559692) (|sizeMultiplication| . 558783) (|factor1| . 558303) (|stepBlowUp| . 557546) (|createThreeSpace| . 557441) (|OMputEndBind| . 557359) (|mapDown!| . 557068) (|meshPar1Var| . 556738) (|f04faf| . 556551) (|coHeight| . 556230) (|setprevious!| . 556089) (|En| . 555901) (|tanhIfCan| . 555760) (|semicolonSeparate| . 555667) (|cartesian| . 555483) (|divisorAtDesingTree| . 554818) (|goto| . 554730) (|f04axf| . 554498) (|rightTraceMatrix| . 553992) (|iteratedInitials| . 553777) (|rightGcd| . 553639) (|tableau| . 553515) (|pureLex| . 553308) (|alphanumeric| . 553260) (|f04atf| . 553073) (|aQuadratic| . 552836) (~ . 552745) (|divide| . 551786) (|rational?| . 549976) (|mindeg| . 549688) (|cCsc| . 549528) (|halfExtendedSubResultantGcd2| . 548976) (|fullPartialFraction| . 548753) (|Somos| . 548481) (|f04asf| . 548297) (|mpsode| . 547995) (|setPredicates| . 547872) (|clearTheFTable| . 547782) (|OMputInteger| . 547669) (|cycleEntry| . 547571) (|position!| . 547481) (|homogeneous| . 547209) (|evalADE| . 546768) (|iiacos| . 546572) (|appendPoint| . 546449) (|style| . 546239) (|inBetweenExcpDiv| . 545577) (|divideExponents| . 545422) (|binary| . 545232) (|declare!| . 544473) (SEGMENT . 544203) (|qinterval| . 544050) (|f04arf| . 543866) (|hex| . 543762) (|rhs| . 543252) (|polyRingToBlUpRing| . 542854) (|stFunc1| . 542573) (|eigenvalues| . 542317) (|top!| . 542142) (|minPol| . 541482) (|swapRows!| . 541259) (|multiset| . 540976) (|numberOfValuesNeeded| . 540550) (|rCoord| . 540436) (|null| . 540331) (|viewDefaults| . 540247) (|multisect| . 539618) (|isamax| . 539484) (|ksec| . 539245) (|f04adf| . 539040) (|patternVariable| . 538889) (|expIfCan| . 538748) (|weight| . 537844) (|OMgetFloat| . 537755) (|quasiMonicPolynomials| . 537384) (|setvalue!| . 537246) (|OMbindTCP| . 537120) (|radicalSimplify| . 536782) (|belong?| . 535074) (|useEisensteinCriterion?| . 534919) (|trace2PowMod| . 534706) (|common| . 534586) (|sinh2csch| . 534371) (|rootPower| . 533814) (|FormatArabic| . 533695) (|radicalEigenvalues| . 533514) (|cSech| . 533354) (|measure2Result| . 532908) (|zero?| . 532192) (|digit?| . 532112) (|checkRur| . 531667) (|OMputBVar| . 531585) (|nthExpon| . 530965) (|status| . 530493) (|definingField| . 530302) (|linearDependenceOverZ| . 530095) (|factorUsingMusser| . 529671) (|charthRoot| . 529419) (|continue| . 529331) (|hasTopPredicate?| . 529216) (|ODESolve| . 528779) (|SturmHabichtCoefficients| . 528564) (|projectivePoint| . 527823) (|rectangularMatrix| . 527623) (|genericLeftDiscriminant| . 527314) (|split!| . 527143) (|initial| . 526896) (|option| . 526413) (|deepestTail| . 526226) (|midpoint| . 525957) (|indiceSubResultantEuclidean| . 525664) (|floor| . 525464) (|fillPascalTriangle| . 525349) (|intcompBasis| . 525087) (|generalizedEigenvector| . 524319) (|new| . 523213) (|unparse| . 523134) (|inRadical?| . 522875) (|asinhIfCan| . 522734) (|initTable!| . 522568) (|safeCeiling| . 522405) (|subsInVar| . 522116) (|divideIfCan!| . 521772) (|quadraticBezier| . 521616) (|prinpolINFO| . 521324) (|uniform01| . 521234) (|f07fef| . 521039) (|optpair| . 520902) (|lifting1| . 520199) (|OMgetSymbol| . 520069) (|tree| . 519405) (|cycle| . 519276) (|displayKind| . 519195) (|f07fdf| . 519009) (|integers| . 518841) (|probablyZeroDim?| . 518526) (|And| . 518390) (|clearTheSymbolTable| . 518205) (|makeSUP| . 518052) (|algebraic?| . 517653) (|theCurve| . 516459) (|leftMult| . 516304) (|hspace| . 516223) (|f07aef| . 515986) (|replaceKthElement| . 515829) (|viewPosDefault| . 515615) (|expintegrate| . 515182) (|createZechTable| . 514971) (|setFieldInfo| . 514729) (|fortranCharacter| . 514684) (|OMgetString| . 514600) (|f07adf| . 514441) (|delay| . 514192) (|partialFraction| . 513549) (|coerceS| . 513328) (|leftAlternative?| . 512988) (|green| . 512949) (|fullOutput| . 510174) (|specialTrigs| . 509888) (|recip| . 507904) (|sort!| . 507549) (|biringToPolyRing| . 507151) (|solveid| . 506916) (|doublyTransitive?| . 506762) (|drotg| . 506615) (|constantOperator| . 506445) (|realEigenvalues| . 506240) (|s17dlf| . 505998) (|leftRankPolynomial| . 505231) (|match| . 503889) (|rightAlternative?| . 503549) (|dAndcExp| . 503322) (|rational| . 502002) (|genericLeftMinimalPolynomial| . 501659) (|matrixGcd| . 501307) (|pointToCell| . 501095) (|s17dhf| . 500891) (|multiple| . 500615) (|freeOf?| . 500204) (|product| . 499111) (|filterUpTo| . 498980) (|arg1| . 498832) (|s17dgf| . 498628) (|solveLinearPolynomialEquationByRecursion| . 497914) (|calcRanges| . 497749) (|optional| . 497473) (|tail| . 497098) (|apply| . 496355) (|alterQuadVar!| . 496162) (|intersect| . 494366) (|arg2| . 494218) (|getlo| . 493732) (|argument| . 493376) (|normalForm| . 492789) (|f02xef| . 492560) (|slope| . 491614) (NOT . 491359) (|drawStyle| . 491237) (|pile| . 491144) (|close!| . 490972) (|listConjugateBases| . 490467) (|f02wef| . 490250) (|semiSubResultantGcdEuclidean1| . 490025) (|not| . 489842) (|monic?| . 489442) (|brace| . 489098) (OR . 488880) (|rightOne| . 488760) (|pseudoRem| . 488620) (E1 . 488463) (|f02fjf| . 487676) (|leaves| . 487555) (|mul| . 487419) (|cons| . 487260) (AND . 487042) (|quasiRegular| . 486795) (|ef2edf| . 486640) (|maxint| . 486460) (|makeCrit| . 486001) (|quotient| . 485542) (|f02bjf| . 485302) (|possiblyNewVariety?| . 484947) (|update| . 484784) (|copy| . 483813) (|poisson| . 483671) (|const| . 483505) (|asecIfCan| . 483364) (|top| . 483022) (|applyQuote| . 482368) (|f02bbf| . 482159) (|invertible?| . 481541) (|symmetricTensors| . 481207) (|constantOpIfCan| . 481027) (|separateFactors| . 480476) (|maxMixedDegree| . 480242) (|deleteProperty!| . 480156) (|f02axf| . 479979) (|cAsech| . 479819) (|mkIntegral| . 479510) (|partition| . 479308) (|loopPoints| . 479091) (|rowEchLocal| . 478946) (|printInfo| . 476041) (|f02awf| . 475870) (|invertIfCan| . 475562) (|insertTop!| . 475381) (|singularPointsWithRestriction| . 474974) (|foundZeroes| . 474856) (|bringDown| . 474317) (|representationType| . 474191) (|f02akf| . 474014) (|lfintegrate| . 473611) (|gcd| . 471191) (|primPartElseUnitCanonical!| . 470967) (|polygon| . 470447) (|rightMinimalPolynomial| . 470243) (|coord| . 469613) (|f02ajf| . 469442) (|pastel| . 469366) (|list| . 468952) (|monicDecomposeIfCan| . 468670) (|inHallBasis?| . 468553) (|iifact| . 468383) (|f02agf| . 468212) (|numberOfCycles| . 468082) (|enumerate| . 467813) (|truncatedmultiplication| . 467674) (|zeroDim?| . 467134) (|rename!| . 467040) (|reducedSystem| . 466643) (|bottom!| . 466468) (|OMgetVariable| . 466384) (|normFactors| . 466041) (|in?| . 465419) (|SFunction| . 465259) (|elem?| . 465140) (|fixPredicate| . 464842) (|nil| . 464768) (* . 456555) (|UpTriBddDenomInv| . 456294) (|dihedralGroup| . 455992) (|findTerm| . 455794) (|setAdaptive3D| . 455717) (|hasPredicate?| . 455602) (|equality| . 455467) (|besselK| . 455012) (|OMputEndAtp| . 454930) (|subHeight| . 454849) (|Beta| . 454202) (|wordsForStrongGenerators| . 454049) (|leadingBasisTerm| . 453787) (|pToDmp| . 453575) (|lastSubResultantEuclidean| . 453324) (|bezoutMatrix| . 453030) (|removeDuplicates| . 452870) (|rdregime| . 452248) (|encode| . 452131) (|getPickedPoints| . 452015) (|getOp| . 451628) (|tanh2trigh| . 451413) (|false| . 451372) (|empty| . 450402) (|stronglyReduce| . 450146) (|bat1| . 449969) (|rest| . 449193) (|swap| . 448893) (|halfExtendedSubResultantGcd1| . 448341) (|complexElementary| . 447068) (|exactQuotient| . 446617) (|reverse| . 446215) (|polyRDE| . 445752) (|maxColIndex| . 445285) (|selectSumOfSquaresRoutines| . 445235) (|curryLeft| . 444992) (|selectsecond| . 444868) (|guessHolo| . 440533) (|goodPoint| . 440293) (|mix| . 439971) (|setDifference| . 439857) (|normalizedDivide| . 439307) (|OMgetEndApp| . 439225) (|evaluateInverse| . 438947) (|OMsupportsCD?| . 438834) (|setIntersection| . 438720) (|hclf| . 438531) (|setStatus!| . 438324) (|purelyAlgebraic?| . 437758) (|updateStatus!| . 437582) (|LPolynomial| . 434702) (|setDegree!| . 434495) (|iiabs| . 434321) (|subNodeOf?| . 434025) (|parametric?| . 433950) (|axServer| . 433787) (|setUnion| . 433673) (|check| . 432917) (|unary?| . 432833) (|selectMultiDimensionalRoutines| . 432783) (|solveInField| . 431846) (|indiceSubResultant| . 431638) (|getDomains| . 431506) (|size?| . 430617) (|size| . 428678) (|ellipticCylindrical| . 428469) (|degree| . 423666) (|sort| . 422942) (|idealiser| . 422322) (|substitute| . 422217) (|rewriteIdealWithQuasiMonicGenerators| . 421841) (|maxShift| . 421563) (|copyQuadVar| . 421351) (|iiacsc| . 421155) (|binomThmExpt| . 420928) (|cAcot| . 420768) (|changeNameToObjf| . 420652) (|allRootsOf| . 419610) (|quadraticForm| . 419447) (|hasDimension?| . 419125) (|enterPointData| . 418952) (|prindINFO| . 418555) (|reduceBasisAtInfinity| . 418281) (|lastSubResultantElseSplit| . 417979) (|sturmVariationsOf| . 417717) (|isExpt| . 416091) (|complexRoots| . 415573) (|curve| . 414864) (|subscriptedVariables| . 414758) (|selectFiniteRoutines| . 414708) (|recoverAfterFail| . 414581) (|showScalarValues| . 414504) (|redPo| . 414175) (|sizeLess?| . 414084) (|addmod| . 414020) (|symmetricRemainder| . 413959) (|parts| . 412813) (|leaf?| . 412381) (|df2st| . 412012) (|BumInSepFFE| . 411649) (|ldf2vmf| . 411497) (|nthFlag| . 411320) (|fortranDouble| . 411275) (|normalise| . 411159) (|createPrimitiveNormalPoly| . 410957) (|modulus| . 409807) (|unitCanonical| . 409754) (|purelyTranscendental?| . 409468) (|OMopenString| . 409344) (|traverse| . 409175) (|readLine!| . 409097) (|coefOfFirstNonZeroTerm| . 408997) (|OMputFloat| . 408880) (|convergents| . 408736) (|cCos| . 408576) (|displayAsGF| . 408443) (|internalLastSubResultant| . 407517) (|cond| . 407349) (|llprop| . 407192) (|acothIfCan| . 407051) (|fortranLinkerArgs| . 406963) (|atrapezoidal| . 406660) (|type| . 406521) (|rdHack1| . 406288) (|isMult| . 406067) (|pointLists| . 405954) (|removeSinSq| . 405739) (|OMencodingUnknown| . 405689) (|depth| . 405068) (|screenResolution| . 404831) (|deepestInitial| . 404644) (|monomial2series| . 404434) (|comp| . 404178) (|mainDefiningPolynomial| . 404058) (|toseLastSubResultant| . 403663) (|ScanFloatIgnoreSpacesIfCan| . 403544) (|count| . 401079) (|leftRank| . 400887) (|nextSublist| . 400493) (|factorial| . 400145) (|open?| . 400013) (|implies| . 399966) (|numerator| . 399589) (|symmetricSquare| . 399444) (|reduction| . 398894) (|getSmgl| . 398787) (|elRow1!| . 398492) (|divisorCascade| . 397910) (|setright!| . 397766) (|bivariate?| . 397479) (|low| . 397389) (|property| . 397268) (|truncatedmuladd| . 397101) (|partialDenominators| . 396970) (|allSimpleCells| . 396491) (|expr| . 396242) (|halfExtendedResultant2| . 396001) (|lcmCoef| . 395860) (|units| . 395233) (|sin?| . 395110) (|exquo| . 393610) (|horizConcat| . 393152) (|div| . 393102) (|pToHdmp| . 392879) (|code| . 391636) (|bsolve| . 390793) (|root?| . 390647) (|op| . 390491) (|vertConcat| . 390033) (|rotatex| . 389892) (|setLabelValue| . 389804) (|minGbasis| . 389537) (|failed| . 389230) (|multiple?| . 389115) (|iiacosh| . 388919) (|torsion?| . 388074) (|coordinates| . 385948) (|harmonic| . 385808) (|traceMatrix| . 385184) (|standardBasisOfCyclicSubmodule| . 384949) (|checkPrecision| . 384860) (|clearCache| . 384747) (|fixedPoints| . 384600) (|fractionPart| . 383986) (|cap| . 383819) (|singularPoints| . 382206) (|flexibleArray| . 381945) (|arrayStack| . 381827) (|leftZero| . 381711) (|radicalEigenvectors| . 381413) (|rank| . 378934) (|wronskianMatrix| . 378473) (|pquo| . 378093) (|rightFactorCandidate| . 377897) (|airyBi| . 377454) (|overset?| . 377041) (|nthExponent| . 376919) (|supDimElseRittWu?| . 376226) (|exprHasWeightCosWXorSinWX| . 375856) (|HenselLift| . 375551) (|copyInto!| . 375379) (|stoseInvertibleSetreg| . 375017) (|symmetricProduct| . 374649) (|vectorcombination| . 374476) (|zeroVector| . 374309) (|laguerreL| . 373999) (|getBadValues| . 373879) (|wrregime| . 373226) (|whatInfinity| . 373095) (|conditions| . 372891) (|numberOfMonomials| . 372396) (|triangulate| . 371719) (|groebnerFactorize| . 370272) (|orderIfNegative| . 370134) (|seriesSolve| . 366064) (|var2StepsDefault| . 365874) (|fresnelS| . 365486) (|besselI| . 365031) (|predicate| . 364830) (|f2st| . 364710) (|isList| . 364573) (|gethi| . 364087) (|padicallyExpand| . 363935) (|summary| . 363843) (|times!| . 363702) (|finiteBasis| . 363402) (|mathieu11| . 363139) (|numberOfFractionalTerms| . 363012) (|show| . 362853) (|makingStats?| . 362684) (|keys| . 361833) (|deepExpand| . 361622) (|cubicBezier| . 361463) (|internalIntegrate0| . 361054) (|quadraticNorm| . 360740) (|e02aef| . 360541) (|returnTypeOf| . 360374) (|resize| . 360111) (|guessExpRat| . 353058) (|sechIfCan| . 352917) (|simplifyExp| . 352702) (|exp1| . 352621) (|clipParametric| . 352043) (|rationalPoint?| . 351441) (|dimensionsOf| . 351007) (|removeSquaresIfCan| . 350720) (|constant| . 349754) (|c02agf| . 349551) (|removeRedundantFactorsInContents| . 349229) (|mat| . 349036) (|GospersMethod| . 348562) (|axesColorDefault| . 348388) (|trueEqual| . 348294) (|interpolateFormsForFact| . 346284) (|c02aff| . 346081) (|logical?| . 345993) (|aColumn| . 345713) (|e02adf| . 345537) (|incrementKthElement| . 345383) (|realSolve| . 343282) (|overlap| . 342844) (|nilFactor| . 342722) (|linearlyDependent?| . 342512) (|MPtoMPT| . 342263) (|degOneCoef| . 341969) (|adaptive3D?| . 341895) (|c05pbf| . 341608) (|showAttributes| . 340509) (|stopTableGcd!| . 339816) (|rewriteIdealWithHeadRemainder| . 339505) (|tab| . 339343) (|graphStates| . 338894) (|pole?| . 338575) (|setleft!| . 338431) (|doubleFloatFormat| . 338350) (|radix| . 338197) (|divide!| . 338033) (|OMserve| . 337907) (|credits| . 337815) (|compile| . 337694) (|sncndn| . 337450) (|froot| . 336895) (|cAcosh| . 336735) (|univariatePolynomial| . 335859) (|leftQuotient| . 335565) (|dflist| . 335344) (|key?| . 335179) (|minRowIndex| . 334712) (|e01sef| . 334492) (|setrest!| . 334239) (|outputAsScript| . 333995) (|binarySearchTree| . 333872) (|makeCos| . 333664) (|printInfo!| . 333465) (|trivialIdeal?| . 333194) (|element| . 332911) (|e01saf| . 332735) (|replaceDiffs| . 332312) (|guessRec| . 325259) (|matrixDimensions| . 325107) (|opeval| . 324829) (|infix?| . 324748) (|max| . 324181) (|e01daf| . 324002) (|linearAssociatedOrder| . 323818) (|curveV| . 323220) (|indicialEquationAtInfinity| . 322580) (|explicitlyEmpty?| . 322458) (|vectorise| . 322164) (|e01bhf| . 321950) (|basisOfNucleus| . 321772) (|setmult!| . 321243) (|e01bgf| . 321061) (|subPolSet?| . 320312) (|imagj| . 320210) (|cyclic?| . 319980) (|random| . 318727) (|functionIsFracPolynomial?| . 318409) (|e01bff| . 318227) (|showIntensityFunctions| . 317652) (|bumprow| . 317363) (|firstExponent| . 317108) (|tanAn| . 316928) (|binaryTournament| . 316805) (|fprindINFO| . 316405) (|internalIntegrate| . 315681) (|abs| . 314751) (|e01bef| . 314578) (|KrullNumber| . 313723) (|kmax| . 313517) (|e01baf| . 313338) (|rombergo| . 313038) (|inverseColeman| . 312878) (|setTex!| . 312787) (|last| . 312199) (|OMputAtp| . 312117) (|identitySquareMatrix| . 311950) (|qShiftAction| . 311723) (|iFTable| . 311128) (|iiBesselY| . 310926) (|e02zaf| . 310741) (|conjugates| . 310625) (|One| . 310180) (|normalizeAtInfinity| . 309906) (|genericRightDiscriminant| . 309597) (|dim| . 309521) (|primextintfrac| . 309194) (|prod| . 309050) (|e02gaf| . 308842) (|rootOfIrreduciblePoly| . 308430) (|positiveRemainder| . 308369) (|perfectSquare?| . 308241) (|RittWuCompare| . 308013) (|commonDenominator| . 307154) (|e02dff| . 306963) (|build| . 306484) (|e02def| . 306302) (|semiDegreeSubResultantEuclidean| . 306026) (|row| . 305553) (|dark| . 305477) (|zCoord| . 305363) (|primaryDecomp| . 304811) (|complexIntegrate| . 304092) (|UnVectorise| . 303924) (|e02ddf| . 303659) (|sech2cosh| . 303444) (|nthr| . 302912) (|shellSort| . 302654) (|testModulus| . 302443) (|midpoints| . 302156) (|e02dcf| . 301849) (|factorSquareFreeByRecursion| . 301153) (|retractToGrn| . 300985) (|mapBivariate| . 300622) (|e02daf| . 300351) (|parametersOf| . 300261) (|high| . 300171) (|coercePreimagesImages| . 300043) (|member?| . 298574) (|combineFeatureCompatibility| . 298366) (|guessHP| . 290899) (|diagonal| . 290695) (|e02bef| . 290403) (|collectQuasiMonic| . 290150) (|members| . 289118) (|fibonacci| . 289019) (|e02bdf| . 288852) (|changeVar| . 288074) (|minPoints3D| . 288000) (|reset| . 287117) (|qnew| . 286515) (|back| . 286260) (|Ei3| . 286135) (|iiasinh| . 285939) (|powmod| . 285875) (|ScanFloatIgnoreSpaces| . 285766) (|outerProduct| . 285617) (|write| . 284972) (|rotate!| . 284717) (|minusInfinity| . 284528) (|save| . 284483) (|fortranLogical| . 284438) (|linears| . 284276) (|pushucoef| . 283859) (|xCoord| . 283745) (|subResultantsChain| . 283541) (|plusInfinity| . 283352) (|insertRoot!| . 283254) (|singular?| . 282713) (|lagrange| . 282220) (|chiSquare| . 282076) (|argumentListOf| . 281953) (|complexNumeric| . 278266) (|fortranCarriageReturn| . 278186) (|limit| . 275969) (|mkAnswer| . 275624) (|dimension| . 274142) (|presub| . 274092) (|kernels| . 273993) (|d| . 273826) (|leftCharacteristicPolynomial| . 273659) (|cotIfCan| . 273518) (|restorePrecision| . 273432) (|minrank| . 272864) (|point?| . 272743) (|univariate| . 269796) (|generalInterpolation| . 267829) (|setMaxPoints3D| . 267752) (|bivariatePolynomials| . 267381) (|topFortranOutputStack| . 267289) (|cycleLength| . 267152) (|factor| . 255323) (|processTemplate| . 255149) (|lfinfieldint| . 254777) (|symbol?| . 254388) (|coerceImages| . 254269) (|tensorProduct| . 253754) (|imag| . 253014) (|weakBiRank| . 252822) (|complex?| . 252734) (|countable?| . 252649) (|principalIdeal| . 252483) (|minordet| . 251749) (|directProduct| . 251620) (|factorUsingYun| . 251196) (|prepareSubResAlgo| . 250792) (|localParamV| . 250257) (|getMultiplicationTable| . 249479) (|relationsIdeal| . 249080) (|destruct| . 248595) (|rotatez| . 248454) (|Si| . 248159) (|scalarMatrix| . 247727) (|rspace| . 247643) (|linearDependence| . 247421) (|d01gbf| . 247123) (|monomial| . 244226) (|writeObj| . 244073) (|d01gaf| . 243902) (|superHeight| . 243821) (|showClipRegion| . 243699) (|OMputEndBVar| . 243617) (|trapezoidal| . 243317) (|multivariate| . 241648) (|charClass| . 241471) (|quadratic?| . 241337) (|number?| . 241183) (|leftPower| . 240997) (|d01fcf| . 240702) (|options| . 240281) (|foundPlaces| . 240113) (|e| . 239927) (|multiEuclidean| . 239826) (|groebnerIdeal| . 239570) (|iCompose| . 239462) (|rquo| . 238554) (|d01bbf| . 238388) (|ref| . 238306) (|logGamma| . 238093) (|rightUnit| . 237932) (|repack1| . 237706) (|d01asf| . 237459) (|commaSeparate| . 237247) (|vconcat| . 237107) (|inv| . 235901) (|ramifMult| . 235808) (|limitPlus| . 234968) (|outputArgs| . 234596) (|iter| . 234409) (|headReduced?| . 233389) (|ground?| . 232803) (|ramifiedAtInfinity?| . 232534) (|cSin| . 232374) (|d02raf| . 231938) (|moduloP| . 231842) (|rightTrim| . 231654) (|unitsColorDefault| . 231480) (|composite| . 231027) (|ground| . 230792) (|primitive?| . 230509) (|complexSolve| . 229416) (|characteristic| . 227730) (|maxSubst| . 227458) (|d02kef| . 226618) (|perspective| . 226496) (|leadingMonomial| . 225404) (|localPointV| . 224862) (|symbNameV| . 224328) (|qroot| . 223764) (|rk4| . 223187) (|d02gbf| . 222781) (|merge!| . 222310) (|leadingCoefficient| . 220286) (|introduce!| . 220176) (|inc| . 220118) (|cCot| . 219958) (|palgLODE| . 219355) (|primlimintfrac| . 218954) (|d02gaf| . 218632) (|primitiveMonomials| . 218426) (|range| . 218214) (|tower| . 218115) (|iiBeta| . 217913) (|bitLength| . 217831) (|perfectNthRoot| . 217499) (|variableOf| . 217321) (|d02ejf| . 216743) (|reductum| . 214708) (|setleaves!| . 214579) (|iprint| . 214464) (|cCsch| . 214304) (|lprop| . 214156) (|real?| . 213407) (|geometric| . 213265) (|d02cjf| . 212773) (|modularFactor| . 212562) (|double| . 212376) (|makeGraphImage| . 211774) (|guessBinRat| . 204721) (|constantLeft| . 204481) (|d02bhf| . 204096) (|OMconnectTCP| . 203940) (|overbar| . 203893) (|mkcomm| . 203765) (|commutative?| . 203425) (|fortranCompilerName| . 203337) (|refine| . 201565) (|d02bbf| . 201175) (|squareMatrix| . 201020) (|usingTable?| . 200851) (|physicalLength| . 200568) (|setsubmult!| . 200039) (|e02ahf| . 199825) (|node?| . 199667) (|eq?| . 199012) (UP2UTS . 198741) (|baseRDEsys| . 198432) (|reducedContinuedFraction| . 198298) (|spherical| . 198114) (|quartic| . 197587) (|makeFloatFunction| . 197149) (|addMatch| . 196977) (|copyDrift| . 196765) (|outputFloating| . 196586) (|mapSolve| . 196202) (|read!| . 196071) (|univariatePolynomialsGcds| . 195405) (|principal?| . 195097) (|allPairsAmong| . 194551) (|showRegion| . 194429) (|mathieu22| . 194166) (|plus!| . 194025) (|prinshINFO| . 193761) (|remove| . 192795) (|identification| . 192534) (|cycleRagits| . 192411) (|realEigenvectors| . 192113) (|Yun| . 191902) (|graphImage| . 191858) (|iiasec| . 191662) (|chebyshevT| . 191349) (|initializeParamOfPlaces| . 189937) (|newReduc| . 189717) (|cTan| . 189557) (|elt| . 180496) (|isobaric?| . 180221) (|trace| . 179404) (|listOfLists| . 178811) (|rationalPoints| . 176496) (|upDateBranches| . 175213) (|doubleDisc| . 174978) (|setelt| . 172576) (|ranges| . 172129) (|nonQsign| . 172006) (|iiBesselK| . 171804) (|makeEq| . 171487) (|printHeader| . 171193) (|infRittWu?| . 169948) (|pointValue| . 169701) (|fractRadix| . 169575) (|qfactor| . 169205) (|upperCase!| . 169151) (|pmComplexintegrate| . 168572) (|anticoord| . 168276) (|setcurve!| . 167675) (|numericIfCan| . 166307) (|semiIndiceSubResultantEuclidean| . 166031) (|Ei5| . 165906) (|rightRankPolynomial| . 165139) (|changeWeightLevel| . 164518) (|twoFactor| . 164212) (|selectPDERoutines| . 164162) (|powern| . 163954) (|copyBSD| . 163830) (|edf2df| . 163684) (|sh| . 163320) (|octon| . 163071) (|primPartElseUnitCanonical| . 162847) (|integralDerivationMatrix| . 162501) (|iiAiryAi| . 162327) (|acosIfCan| . 162186) (|initializeGroupForWordProblem| . 161913) (|monicCompleteDecompose| . 161673) (|lazyIntegrate| . 161442) (|makeViewport3D| . 161086) (F . 160939) (|localUnquote| . 160591) (|drawToScale| . 160423) (|mdeg| . 160197) (|light| . 160121) (|nextsousResultant2| . 159949) (|fortranDoubleComplex| . 159904) (|subtractIfCan| . 159827) (|qPot| . 159648) (|leftScalarTimes!| . 159507) (|alternating| . 159356) (|wreath| . 159230) (|genericRightTrace| . 158918) (|affineRationalPoints| . 158027) (|union| . 157431) (|bfEntry| . 157190) (|makeUnit| . 157041) (|vedf2vef| . 156864) (|decompose| . 154004) (|atom?| . 153727) (|clipWithRanges| . 153433) (|readable?| . 153344) (|twist| . 153101) (|prefix| . 153005) (|leftTraceMatrix| . 152499) (|normalize| . 151400) (|rootProduct| . 150843) (|createMultiplicationMatrix| . 150609) (|scalarTypeOf| . 150475) (|nsqfree| . 149950) (|subSet| . 149801) (|extendedgcd| . 149626) (|placesOfDegree| . 147383) (|log| . 145049) (|bipolar| . 144840) (|ffactor| . 144533) (|zeroDimPrimary?| . 144161) (|createRandomElement| . 143994) (|lazyGintegrate| . 143744) (|mainForm| . 143643) (|nextPrime| . 143535) (|dasum| . 143357) (|input| . 143105) (|variable| . 142414) (|beauzamyBound| . 142072) (|OMconnInDevice| . 141976) (|exactQuotient!| . 141525) (|structuralConstants| . 140309) (|lazyVariations| . 140013) (|powers| . 139878) (|test| . 139834) (|jordanAdmissible?| . 139494) (|rowEchWoZeroLines| . 139379) (|reduceLineOverLine| . 139260) (|algebraicSort| . 138573) (|makeViewport2D| . 138378) (|expandLog| . 138163) (|square?| . 137709) (|balancedBinaryTree| . 137569) (|yCoordinates| . 137257) (|integerIfCan| . 137116) (|pop!| . 136774) (|sylvesterSequence| . 136582) (|OMputEndError| . 136500) (|showAll?| . 136362) (|biRank| . 136170) (|numer| . 134907) (|real| . 133967) (|dscal| . 133786) (|dihedral| . 133635) (|ParCond| . 133127) (|pushuconst| . 132756) (|OMgetEndAtp| . 132674) (|mainCharacterization| . 132410) (|createHN| . 132197) (|denom| . 130954) (|complex| . 130850) (|iiasin| . 130654) (|showTheRoutinesTable| . 130607) (|asinIfCan| . 130466) (|indicialEquation| . 129713) (|lighting| . 129586) (|smith| . 129338) (|kernel| . 128821) (|skewSFunction| . 128658) (|exprHasAlgebraicWeight| . 128329) (|inverseIntegralMatrixAtInfinity| . 128045) (|itsALeaf!| . 127877) (|nullSpace| . 126170) (|userOrdered?| . 126039) (|removeRoughlyRedundantFactorsInContents| . 125717) (|draw| . 117687) (|derivative| . 117128) (|constantToUnaryFunction| . 116975) (|makeTerm| . 116820) (|complexNumericIfCan| . 113765) (|transcendenceDegree| . 113444) (|singularAtInfinity?| . 113175) (|cycles| . 113037) (|basisOfRightAnnihilator| . 112856) (|makeObject| . 108385) (|dswap| . 108173) (|Nul| . 108080) (|absolutelyIrreducible?| . 107490) (|dimensions| . 107137) (|getShiftRec| . 106647) (|parse| . 106568) (|rightFactorIfCan| . 106301) (|npcoef| . 105664) (|coef| . 105064) (|iicsch| . 104868) (|critB| . 104592) (|lfunc| . 104509) (|leastMonomial| . 104322) (|OMcloseConn| . 104236) (|coordinate| . 103840) (|fullDisplay| . 103233) (|inverseIntegralMatrix| . 102949) (|monom| . 102498) (|algint| . 102115) (|append| . 102035) (|recur| . 101676) (|infinity| . 101485) (|badValues| . 101299) (|tubeRadiusDefault| . 101091) (|makeResult| . 100817) (|brillhartTrials| . 100499) (|character?| . 100411) (|function| . 99702) (|leftRecip| . 99479) (|newElement| . 98898) (|clearDenominator| . 98009) (|Lazard2| . 97798) (|maxIndex| . 97637) (|space| . 97350) (|trigs2explogs| . 96907) (|commutativeEquality| . 96724) (|roughEqualIdeals?| . 96413) (|dominantTerm| . 95739) (|addPoint2| . 95589) (|htrigs| . 95374) (|doubleRank| . 95182) (|dioSolve| . 94862) (|clipBoolean| . 94728) (|compBound| . 94506) (|cAsec| . 94346) (|antisymmetric?| . 93892) (|rischDEsys| . 93197) (|iicoth| . 93001) (|compiledFunction| . 92477) (|precision| . 92066) (|numberOfIrreduciblePoly| . 91914) (|zeroDimensional?| . 91461) (|normalizedAssociate| . 91147) (|rightExtendedGcd| . 90927) (|branchIfCan| . 89938) (|setFoundPlacesToEmpty| . 89770) (|numberRatPlacesExtDeg| . 88361) (|modularGcd| . 88099) (|minimalForm| . 87175) (|shufflein| . 87019) (|reduceByQuasiMonic| . 86763) (|chainSubResultants| . 86569) (|message| . 86489) (|generators| . 86096) (|branchPoint?| . 85555) (|genusTreeNeg| . 84805) (|rootNormalize| . 84445) (|leastAffineMultiple| . 84279) (|interpolateForms| . 82249) (|contains?| . 82068) (|maxPoints| . 81831) (|reopen!| . 81670) (|node| . 81564) (|setPosition| . 81441) (|open| . 81152) (|factorList| . 80590) (|exptMod| . 80212) (|cPower| . 80049) (|radicalSolve| . 77784) (|tube| . 77380) (|binaryTree| . 77197) (|basisOfRightNucleus| . 77019) (|exponentialOrder| . 76796) (|writable?| . 76707) (|finiteSeries2LinSys| . 76457) (|invmultisect| . 75828) (|shrinkable| . 75567) (|defineProperty| . 75349) (|unitNormal| . 75205) (|primextendedint| . 74713) (|FormatRoman| . 74594) (|OMsetEncoding| . 74472) (|cscIfCan| . 74331) (|gcdPrimitive| . 73527) (|viewDeltaXDefault| . 73347) (|strongGenerators| . 73207) (|central?| . 73026) (|chineseRemainder| . 72107) (|integralAtInfinity?| . 71835) (|increasePrecision| . 71663) (|generic| . 69977) (|integer?| . 69478) (|cyclotomic| . 69006) (|removeConstantTerm| . 68802) (|reduceRowOnList| . 68649) (|ratpart| . 68558) (|pointToPlace| . 68097) (|variables| . 65881) (|roughUnitIdeal?| . 65573) (|symmetricDifference| . 65476) (|dmpToP| . 65264) (|deepCopy| . 65146) (|cycleTail| . 65048) (|move| . 64779) (|directory| . 64691) (|interReduce| . 64404) (|times| . 64156) (|edf2efi| . 63986) (|infinityNorm| . 63672) (|parent| . 63554) (|OMgetAttr| . 63472) (|perfectNthPower?| . 63302) (|replaceVarByZero| . 63016) (|cAcsc| . 62856) (|basisOfCenter| . 62678) (|distdfact| . 62361) (|tablePow| . 62087) (|singRicDE| . 60994) (|cos2sec| . 60779) (|Vectorise| . 60611) (|ricDsolve| . 57152) (|bubbleSort!| . 56609) (|iiasech| . 56413) (|janko2| . 56150) (|create| . 54545) (|placesAbove| . 53197) (|sin2csc| . 52982) (|weighted| . 52772) (|SturmHabichtSequence| . 52529) (|eisensteinIrreducible?| . 52371) (|nor| . 52273) (|iicsc| . 52077) (|rightTrace| . 51960) (|setref| . 51875) (|denomLODE| . 51052) (|fixedPointExquo| . 50858) (|bracket| . 50721) (|summation| . 50110) (|setImagSteps| . 50028) (|getZechTable| . 49407) (|prefixRagits| . 49284) (|resultant| . 48401) (|curryRight| . 48158) (|over| . 48108) (|inGroundField?| . 47990) (|any| . 47884) (|randomLC| . 47531) (|title| . 47085) (|startPolynomial| . 46816) (|rangeIsFinite| . 46257) (|subMultV| . 45731) (|lp| . 45600) (|map!| . 44385) (|radicalEigenvector| . 44147) (|moebiusMu| . 44048) (|jordanAlgebra?| . 43708) (|pascalTriangle| . 43545) (|lexTriangular| . 43240) (|tanIfCan| . 43099) (|setlast!| . 42956) (|routines| . 42909) (|minIndex| . 42748) (|failed?| . 42379) (|quatern| . 42266) (|reducedDiscriminant| . 41981) (|totalLex| . 41774) (|stoseLastSubResultant| . 41369) (|viewSizeDefault| . 41161) (|startTableInvSet!| . 40396) (EQ . 40178) (|t| . 40034) (|critMTonD1| . 39671) (|sPol| . 39317) (|quadratic| . 38796) (|primlimitedint| . 38255) (|printingInfo?| . 38086) (|viewThetaDefault| . 37906) (|trailingCoefficient| . 37749) (|idealiserMatrix| . 37439) (|mask| . 37381) (|removeCoshSq| . 37166) (|perfectSqrt| . 37056) (|removeRedundantFactorsInPols| . 36734) (|goodnessOfFit| . 36396) (|definingInequation| . 36163) (|cyclic| . 36012) (|newton| . 35832) (|assign| . 31370) (|ScanArabic| . 31251) (|OMsupportsSymbol?| . 31135) (|viewWriteAvailable| . 31040) (|firstDenom| . 30909) (|knownInfBasis| . 30602) (|basisOfRightNucloid| . 30413) (|flagFactor| . 30233) (|interval| . 29745) (|compose| . 29460) (|removeConjugate| . 28885) (|lazyIrreducibleFactors| . 28519) (|factorials| . 27996) (|useEisensteinCriterion| . 27838) (|getVariableOrder| . 27679) (|moduleSum| . 27293) (|toseInvertible?| . 26543) (|resultantEuclidean| . 26295) (|solid| . 26196) (|localReal?| . 25972) (|testDim| . 25664) (|factors| . 24977) (|nextItem| . 24917) (|lambert| . 24424) (|palgintegrate| . 23928) (|operators| . 23825) (|setOrder| . 23507) (|mainMonomials| . 23292) (|OMgetAtp| . 23210) (|contract| . 22428) (|complexForm| . 21743) (|machineFraction| . 21648) (|leftMinimalPolynomial| . 21444) (|minus!| . 21168) (|tanNa| . 21046) (|triangSolve| . 19964) (|lazyPseudoQuotient| . 19859) (|domainOf| . 19782) (|ddFact| . 19548) (|realZeros| . 17277) (|solveLinearlyOverQ| . 17054) (|listBranches| . 16793) (|head| . 16353) (|additive?| . 16200) (|palgLODE0| . 14937) (|maxRowIndex| . 14470) (|taylorRep| . 14294) (|rk4a| . 14001) (|antisymmetricTensors| . 13581) (|rootKerSimp| . 12945) (|reportInstantiations| . 12822) (|setFoundZeroes| . 12701) (|bit?| . 12606) (|jacobi| . 12504) (|euler| . 12234) (|super| . 12184) (|tab1| . 12007) (|bfKeys| . 11917) (|pol| . 11719) (|safeFloor| . 11556) (|nextColeman| . 11396) (|matrix| . 10379) (|asimpson| . 10076) (|gnuDraw| . 9217) (|lowerCase!| . 9163) (|selectfirst| . 9039) (|complexZeros| . 8338) (|prolateSpheroidal| . 8129) (|exprToXXP| . 7569) (|degreeSubResultant| . 7361) (|pseudoQuotient| . 7218) (|powerSum| . 7067) (|void| . 7029) (|desingTreeAtPoint| . 6365) (|subst| . 5920) (|factorOfDegree| . 4499) (|explogs2trigs| . 4106) (|cyclotomicFactorization| . 3936) (|nextNormalPrimitivePoly| . 3760) (|generalizedContinuumHypothesisAssumed?| . 3678) (|reduced?| . 2887) (|alternatingGroup| . 2585) (|maxTower| . 2468) (|sequences| . 2162) (|basisOfCommutingElements| . 1984) (|externalList| . 1894) (|resultantReduitEuclidean| . 1608) (|error| . 1130) (|musserTrials| . 804) (|OMputEndApp| . 722) (|allDegrees| . 510) (|choosemon| . 245) (|SturmHabicht| . 30)) 
\ No newline at end of file
diff --git a/src/share/algebra/users.daase/index.kaf b/src/share/algebra/users.daase/index.kaf
index 4909966..e251d7b 100644
--- a/src/share/algebra/users.daase/index.kaf
+++ b/src/share/algebra/users.daase/index.kaf
@@ -1,4 +1,4 @@
-236822              (|ProjectiveAlgebraicSetPackage|)
+237625              (|ProjectiveAlgebraicSetPackage|)
 (|ProjectiveAlgebraicSetPackage|)
 (|AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |BlowUpPackage| |DesingTreePackage| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField|)
 (|AffinePlane|)
@@ -58,11 +58,12 @@
 (|BalancedBinaryTree| |BinarySearchTree| |BinaryTournament|)
 (|SetOfMIntegersInOneToN|)
 (|DesingTreePackage|)
-(|AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |AnyFunctions1| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BasicType&| |BezoutMatrix| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |BitAggregate&| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |Cell| |ChangeOfVariable| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclicStreamTools| |CylindricalAlgebraicDecompositionPackage| |CylindricalAlgebraicDecompositionUtilities| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |EvaluateCycleIndicators| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemContinuityPackage1| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |FGLMIfCanPackage| |Factored| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |File| |FileName| |FindOrderFinite| |FiniteAbelianMonoidRing&| |FiniteAbelianMonoidRingFunctions2| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteDivisorCategory&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerLinearDependence| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegralDomain&| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KeyedAccessFile| |KeyedDictionary&| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagPolynomialRootsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |None| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedSet&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |Palette| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |Pattern| |PatternFunctions1| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListAggregate| |PatternMatchListResult| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchQuotientFieldCategory| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchSymbol| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PolToPol| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFactorize| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SegmentFunctions2| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleCell| |SingleInteger| |SingletonAsOrderedSet| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamFunctions1| |StreamFunctions2| |StreamFunctions3| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |TableauxBumpers| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesConstructorCategory&| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UniversalSegmentFunctions2| |UserDefinedPartialOrdering| |Variable| |Vector| |VectorFunctions2| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|PrimitiveRatDE| |RationalLODE|)
 (|GaloisGroupFactorizer|)
 (|CliffordAlgebra| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |Equation| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |HomogeneousDirectProduct| |InnerFiniteField| |InnerPrimeField| |OrderedDirectProduct| |PrimeField| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |RectangularMatrix| |SplitHomogeneousDirectProduct|)
 (|CartesianTensorFunctions2|)
+(|CylindricalAlgebraicDecompositionPackage|)
 (|AlgebraicFunctionField| |AlgebraicIntegration| |PureAlgebraicIntegration| |RadicalFunctionField|)
 (|AxiomServer| |Character| |CharacterClass| |Float| |FortranTemplate| |HTMLFormat| |IndexedBits| |IndexedString| |LieExponentials| |MathMLFormat| |NumberFormats| |OutputForm| |RadixExpansion| |RecursivePolynomialCategory&| |ScriptFormulaFormat| |String| |StringAggregate&| |Symbol| |TemplateUtilities| |TexFormat| |Tree|)
 (|Character| |IndexedString| |MathMLFormat| |String| |StringAggregate&|)
@@ -88,6 +89,7 @@
 (|GraphImage| |ThreeDimensionalViewport|)
 (|LazyStreamAggregate&| |Stream|)
 (|GaloisGroupFactorizer| |UnivariateFactorize|)
+(|CylindricalAlgebraicDecompositionPackage| |SimpleCell|)
 (|Database|)
 (|OperationsQuery|)
 (|ElementaryFunctionDefiniteIntegration| |RationalFunctionDefiniteIntegration|)
@@ -166,7 +168,7 @@
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranType| |SimpleFortranProgram| |SymbolTable|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranCode| |FortranPackage| |SymbolTable| |TheSymbolTable|)
 (|FourierSeries|)
-(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
+(|AbelianMonoidRing&| |AlgFactor| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp31| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp80| |Asp9| |BalancedPAdicRational| |BinaryExpansion| |BoundIntegerRoots| |ChangeOfVariable| |CoerceVectorMatrixPackage| |CombinatorialFunction| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexRootFindingPackage| |ContinuedFraction| |CycleIndicators| |CylindricalAlgebraicDecompositionPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |DoubleFloat| |DoubleFloatSpecialFunctions| |DoubleResultantPackage| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |Factored| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionFunctions2| |FractionalIdeal| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |Guess| |GuessInteger| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerModularGcd| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |Integer| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LieSquareMatrix| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |ModMonic| |ModularField| |MonogenicAlgebra&| |MonomialExtensionTools| |MultipleMap| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonLinearSolvePackage| |NormalizationPackage| |NumberTheoreticPolynomialFunctions| |Numeric| |ODEIntegration| |Octonion| |OctonionCategory&| |OnePointCompletion| |OrderedCompletion| |OrderedDirectProduct| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrthogonalPolynomialFunctions| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |Plot| |Plot3D| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursionUnivariate| |PolynomialNumberTheoryFunctions| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveRatDE| |PrimitiveRatRicDE| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PureAlgebraicLODE| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRetractions| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StructuralConstantsPackage| |SturmHabichtPackage| |SupFractionFactorizer| |SymmetricPolynomial| |SystemSolvePackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ToolsForSign| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |TwoDimensionalPlotClipping| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesFunctions2| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |XExponentialPackage| |XPBWPolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01WeightsPackage| |d01aqfAnnaType| |d02AgentsPackage| |e04AgentsPackage| |e04ucfAnnaType|)
 (|FractionFreeFastGaussianFractions| |Guess|)
 (|Guess|)
 (|FiniteDivisor| |FiniteDivisorFunctions2| |FractionalIdealFunctions2| |FramedModule| |HyperellipticFiniteDivisor| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational|)
@@ -255,7 +257,7 @@
 (|ComplexTrigonometricManipulations| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |TrigonometricManipulations|)
 (|AssociationList| |BalancedPAdicRational| |BasicOperatorFunctions1| |BinaryExpansion| |Bits| |Boolean| |CharacterClass| |CommonOperators| |Complex| |ComplexCategory&| |ComplexDoubleFloatVector| |DataList| |DecimalExpansion| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleFloatVector| |EqTable| |ExponentialExpansion| |Export3D| |Expression| |Factored| |FlexibleArray| |Float| |FortranPackage| |FortranProgram| |Fraction| |FunctionSpace&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GnuDraw| |HashTable| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IndexedBits| |IndexedFlexibleArray| |IndexedList| |IndexedOneDimensionalArray| |IndexedString| |IndexedVector| |InnerTable| |InputFormFunctions1| |Integer| |IntegerNumberSystem&| |Kernel| |KeyedAccessFile| |Library| |LiouvillianFunction| |List| |ListMultiDictionary| |MachineComplex| |MachineInteger| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OpenMathPackage| |OrderedVariableList| |OrderlyDifferentialPolynomial| |PAdicRational| |PAdicRationalConstructor| |Pi| |Point| |Polynomial| |PolynomialCategory&| |PrimitiveArray| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadixExpansion| |RectangularMatrix| |RecursivePolynomialCategory&| |RegularChain| |RegularTriangularSet| |Result| |RomanNumeral| |RoutinesTable| |SequentialDifferentialPolynomial| |Set| |SingleInteger| |SparseMultivariatePolynomial| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stream| |String| |StringTable| |Symbol| |SymbolTable| |Table| |TemplateUtilities| |TopLevelDrawFunctions| |U16Vector| |U32Vector| |U8Vector| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |Vector| |WuWenTsunTriangularSet|)
 (|FunctionSpace&|)
-(|AbelianGroup&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |Bezier| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |Guess| |GuessFinite| |GuessFiniteFunctions| |HTMLFormat| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ArrayStack| |Asp10| |Asp19| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp55| |Asp73| |Asp74| |Asp77| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |Bezier| |BezoutMatrix| |BinaryExpansion| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Color| |CombinatorialFunction| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ContinuedFraction| |CoordinateSystems| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |EigenPackage| |ElementaryFunction| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |Equation| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtensibleLinearAggregate&| |Factored| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregate&| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FloatingPointSystem&| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FractionalIdealFunctions2| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FramedNonAssociativeAlgebraFunctions2| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyRetractableTo&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GosperSummationMethod| |GraphImage| |GraphicsDefaults| |GrayCode| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Group&| |Guess| |GuessFinite| |GuessFiniteFunctions| |HTMLFormat| |HallBasis| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperbolicFunctionCategory&| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfiniteProductCharacteristicZero| |InfiniteProductFiniteField| |InfiniteProductPrimeField| |InfinitlyClosePoint| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerBits| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRetractions| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |LeftAlgebra&| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorsOps| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListAggregate&| |ListMonoidOps| |ListToMap| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |MakeFloatCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonAssociativeRing&| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericContinuedFraction| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedRing&| |OrderedVariableList| |OrderingFunctions| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialFraction| |Partition| |PartitionsAndPermutations| |Pattern| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPolynomialCategory| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |PiCoercions| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |Polynomial| |PolynomialCategory&| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSolveByFormulas| |PowerSeriesCategory&| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |QuadraticForm| |Quaternion| |QuaternionCategory&| |QuotientFieldCategory&| |RadicalCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RadixUtilities| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RandomNumberSource| |RationalFactorize| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReductionOfOrder| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleCell| |SingleInteger| |SmithNormalForm| |SortPackage| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamInfiniteProduct| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StructuralConstantsPackage| |SturmHabichtPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TemplateUtilities| |TexFormat| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalFunctionCategory&| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariateLaurentSeriesFunctions2| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |Vector| |VectorCategory&| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|RandomIntegerDistributions|)
 (|ComplexRootFindingPackage| |GaloisGroupUtilities| |Guess| |IntegerNumberSystem&| |IrrRepSymNatPackage| |MultivariateLifting| |RepresentationPackage1| |SetOfMIntegersInOneToN| |SymmetricGroupCombinatoricFunctions|)
 (|CyclotomicPolynomialPackage| |Factored| |GaussianFactorizationPackage| |IntegerNumberSystem&| |NumberFieldIntegralBasis|)
@@ -302,7 +304,7 @@
 (|SystemSolvePackage|)
 (|InterpolateFormsPackage| |LinearSystemFromPowerSeriesPackage|)
 (|Expression| |PowerSeriesLimitPackage|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |AxiomServer| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |Bezier| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LocalParametrizationOfSimplePointPackage| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttachPredicates| |AttributeButtons| |AxiomServer| |BagAggregate&| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |Bezier| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |BoundIntegerRoots| |CRApackage| |CardinalNumber| |CartesianTensor| |CartesianTensorFunctions2| |Cell| |Character| |CharacterClass| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |CoerceVectorMatrixPackage| |Collection&| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexRootFindingPackage| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |ContinuedFraction| |CycleIndicators| |CyclotomicPolynomialPackage| |CylindricalAlgebraicDecompositionPackage| |CylindricalAlgebraicDecompositionUtilities| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DictionaryOperations&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DisplayPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |EllipticFunctionsUnivariateTaylorSeries| |EqTable| |Equation| |ErrorFunctions| |EuclideanDomain&| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Evalable&| |EvaluateCycleIndicators| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExpertSystemToolsPackage1| |ExpertSystemToolsPackage2| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceFunctions2| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |ExtAlgBasis| |ExtensibleLinearAggregate&| |FGLMIfCanPackage| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoredFunctions2| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FiniteSetAggregateFunctions2| |FlexibleArray| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GnuDraw| |GosperSummationMethod| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |GroebnerSolve| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HTMLFormat| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedAggregate&| |IndexedBits| |IndexedDirectProductObject| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerEvalable&| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerMatrixQuotientFieldFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegrationFunctionsTable| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |Kernel| |KernelFunctions2| |KeyedAccessFile| |KeyedDictionary&| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazardSetSolvingPackage| |LazyStreamAggregate&| |LeadingCoefDetermination| |LexTriangularPackage| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |LiouvillianFunction| |List| |ListFunctions2| |ListFunctions3| |ListMonoidOps| |ListMultiDictionary| |ListToMap| |LocalParametrizationOfSimplePointPackage| |LyndonWord| |MPolyCatFunctions2| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MRationalFactorize| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |MappingPackage1| |MathMLFormat| |Matrix| |MatrixCategory&| |MatrixCommonDenominator| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |MergeThing| |MeshCreationRoutinesForThreeDimensions| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModuleOperator| |MoebiusTransform| |MonogenicAlgebra&| |MonoidRing| |MonoidRingFunctions2| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormRetractPackage| |NormalizationPackage| |NumberFieldIntegralBasis| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |NumericTubePlot| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODEIntegration| |ODEIntensityFunctionsTable| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OpenMathError| |OpenMathPackage| |OppositeMonogenicLinearOperator| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximants| |Palette| |ParadoxicalCombinatorsForStreams| |ParametricLinearEquations| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |PartialFractionPackage| |Partition| |PartitionsAndPermutations| |Pattern| |PatternFunctions1| |PatternFunctions2| |PatternMatch| |PatternMatchFunctionSpace| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPolynomialCategory| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchResultFunctions2| |PatternMatchTools| |PendantTree| |Permutation| |PermutationGroup| |PermutationGroupExamples| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PlotTools| |PoincareBirkhoffWittLyndonBasis| |Point| |PointFunctions2| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |PointsOfFiniteOrderTools| |PolyGroebner| |Polynomial| |PolynomialCategory&| |PolynomialCategoryQuotientFunctions| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialInterpolationAlgorithms| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetCategory&| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PowerSeriesLimitPackage| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet| |QuasiAlgebraicSet2| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RationalFactorize| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionIntegration| |RationalFunctionSign| |RationalIntegration| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealSolvePackage| |RealZeroPackage| |RealZeroPackageQ| |RectangularMatrix| |RecurrenceOperator| |RecursiveAggregate&| |RecursivePolynomialCategory&| |ReductionOfOrder| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentFunctions2| |SequentialDifferentialPolynomial| |Set| |SetAggregate&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleCell| |SimpleFortranProgram| |SingleInteger| |SmithNormalForm| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamAggregate&| |StreamFunctions2| |StreamTaylorSeriesOperations| |StreamTensor| |StreamTranscendentalFunctions| |String| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |SubSpaceComponentProperty| |SupFractionFactorizer| |Switch| |Symbol| |SymbolTable| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TableauxBumpers| |TangentExpansions| |TaylorSeries| |TaylorSolve| |TexFormat| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TopLevelDrawFunctionsForPoints| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDESystem| |Tree| |TriangularSetCategory&| |TrigonometricManipulations| |TubePlot| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UnaryRecursiveAggregate&| |UniqueFactorizationDomain&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCommonDenominator| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UnivariateTaylorSeriesODESolver| |UniversalSegment| |UserDefinedPartialOrdering| |UserDefinedVariableOrdering| |Vector| |VectorCategory&| |VectorFunctions2| |ViewDefaultsPackage| |ViewportPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AlgebraPackage| |Asp19| |Asp55| |DirichletRing| |ElementaryFunctionSign| |FiniteSetAggregateFunctions2| |FramedNonAssociativeAlgebra&| |GaloisGroupFactorizer| |GenericNonAssociativeAlgebra| |Guess| |LieSquareMatrix| |MatrixCommonDenominator| |MatrixManipulation| |PAdicWildFunctionFieldIntegralBasis| |PermutationGroupExamples| |RealSolvePackage| |TaylorSolve| |ThreeSpace| |TwoDimensionalPlotClipping| |UnivariateTaylorSeriesODESolver|)
 (|FreeGroup| |FreeMonoid| |InnerFreeAbelianMonoid|)
 (|IntegerFactorizationPackage|)
@@ -367,7 +369,7 @@
 (|BlowUpPackage|)
 (|ElementaryFunctionODESolver|)
 (|RationalRicDE|)
-(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |BlowUpPackage| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |Guess| |GuessOption| |GuessOptionFunctions0| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AbelianGroup&| |AbelianMonoid&| |AbelianMonoidRing&| |AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Aggregate&| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraPackage| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicHermiteIntegration| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |ApplyRules| |ApplyUnivariateSkewPolynomial| |ArrayStack| |Asp19| |Asp20| |Asp27| |Asp28| |Asp30| |Asp31| |Asp34| |Asp35| |Asp41| |Asp42| |Asp55| |Asp74| |Asp77| |AssociatedEquations| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |Automorphism| |BalancedBinaryTree| |BalancedFactorisation| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicOperator| |BasicOperatorFunctions1| |BezoutMatrix| |BinaryExpansion| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |BinaryTreeCategory&| |Bits| |BlowUpPackage| |Boolean| |BoundIntegerRoots| |BrillhartTests| |CRApackage| |CardinalNumber| |CartesianTensor| |Cell| |ChangeOfVariable| |Character| |CharacterClass| |CharacteristicPolynomialInMonogenicalAlgebra| |CharacteristicPolynomialPackage| |ChineseRemainderToolsForIntegralBases| |CliffordAlgebra| |Collection&| |CommonOperators| |CommuteUnivariatePolynomialCategory| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootFindingPackage| |ConstantLODE| |ContinuedFraction| |CoordinateSystems| |CyclicStreamTools| |CyclotomicPolynomialPackage| |CylindricalAlgebraicDecompositionPackage| |CylindricalAlgebraicDecompositionUtilities| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |Dictionary&| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialRing&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DiophantineSolutionPackage| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistinctDegreeFactorize| |DistributedMultivariatePolynomial| |DivisionRing&| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatSpecialFunctions| |DoubleFloatVector| |DoubleResultantPackage| |DrawComplex| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |EuclideanDomain&| |EuclideanModularRing| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToUnivariatePowerSeries| |ExtAlgBasis| |ExtensibleLinearAggregate&| |ExtensionField&| |Factored| |FactoredFunctionUtilities| |FactoredFunctions| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |Field&| |FieldOfPrimeCharacteristic&| |FindOrderFinite| |Finite&| |FiniteAbelianMonoidRing&| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteFieldSolveLinearPolynomialEquation| |FiniteFieldSquareFreeDecomposition| |FiniteLinearAggregateFunctions2| |FiniteLinearAggregateSort| |FiniteRankAlgebra&| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranExpression| |FourierSeries| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedAlgebra&| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionFieldIntegralBasis| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizationUtilities| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GaloisGroupUtilities| |GaussianFactorizationPackage| |GcdDomain&| |GenExEuclid| |GeneralDistributedMultivariatePolynomial| |GeneralHenselPackage| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GraphImage| |GrayCode| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerSolve| |Group&| |Guess| |GuessOption| |GuessOptionFunctions0| |HallBasis| |HashTable| |Heap| |HeuGcd| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteProductFiniteField| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerMatrixLinearAlgebraFunctions| |InnerModularGcd| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySign| |InnerPolySum| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |Integer| |IntegerCombinatoricFunctions| |IntegerFactorizationPackage| |IntegerMod| |IntegerNumberSystem&| |IntegerNumberTheoryFunctions| |IntegerPrimesPackage| |IntegerRoots| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegralBasisTools| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InterfaceGroebnerPackage| |InternalRationalUnivariateRepresentationPackage| |InterpolateFormsPackage| |IntersectionDivisorPackage| |Interval| |InverseLaplaceTransform| |IrrRepSymNatPackage| |IrredPolyOverFiniteField| |Kernel| |KernelFunctions2| |KeyedAccessFile| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LazyStreamAggregate&| |LeadingCoefDetermination| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinGroebnerPackage| |LinearAggregate&| |LinearDependence| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LinearOrdinaryDifferentialOperatorCategory&| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearOrdinaryDifferentialOperatorsOps| |LinearPolynomialEquationByFractions| |LinearSystemFromPowerSeriesPackage| |LinearSystemMatrixPackage| |LinearSystemMatrixPackage1| |LinearSystemPolynomialPackage| |LinesOpPack| |List| |ListAggregate&| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |LocalParametrizationOfSimplePointPackage| |Localize| |LyndonWord| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MakeCachableSet| |MappingPackage1| |MappingPackageInternalHacks1| |Matrix| |MatrixCategory&| |MatrixCategoryFunctions2| |MatrixLinearAlgebraFunctions| |MatrixManipulation| |ModMonic| |ModularDistinctDegreeFactorizer| |ModularField| |ModularHermitianRowReduction| |ModularRing| |Module&| |ModuleOperator| |MoebiusTransform| |MonadWithUnit&| |MonogenicAlgebra&| |Monoid&| |MonoidRing| |MonomialExtensionTools| |MultFiniteFactorize| |MultiVariableCalculusFunctions| |Multiset| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NewtonPolygon| |NonCommutativeOperatorDivision| |NonLinearFirstOrderODESolver| |NonNegativeInteger| |NormInMonogenicAlgebra| |NormRetractPackage| |NormalizationPackage| |NottinghamGroup| |NumberFieldIntegralBasis| |NumberFormats| |NumberTheoreticPolynomialFunctions| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |ODETools| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |Operator| |OppositeMonogenicLinearOperator| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OrthogonalPolynomialFunctions| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PadeApproximantPackage| |PadeApproximants| |ParametricLinearEquations| |ParametricPlaneCurve| |ParametricPlaneCurveFunctions2| |ParametricSpaceCurve| |ParametricSpaceCurveFunctions2| |ParametricSurface| |ParametricSurfaceFunctions2| |ParametrizationPackage| |PartialDifferentialRing&| |PartialFraction| |Partition| |Pattern| |PatternFunctions2| |PatternMatchIntegerNumberSystem| |PatternMatchIntegration| |PatternMatchPushDown| |PatternMatchTools| |PendantTree| |Permanent| |Permutation| |PermutationGroup| |Pi| |PlaneAlgebraicCurvePlot| |PoincareBirkhoffWittLyndonBasis| |Point| |PointPackage| |PointsOfFiniteOrder| |PointsOfFiniteOrderRational| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialComposition| |PolynomialDecomposition| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolationAlgorithms| |PolynomialNumberTheoryFunctions| |PolynomialPackageForCurve| |PolynomialRing| |PolynomialRoots| |PolynomialSetUtilitiesPackage| |PolynomialSolveByFormulas| |PolynomialSquareFree| |PositiveInteger| |PowerSeriesCategory&| |PrecomputedAssociatedEquations| |PrimeField| |PrimitiveArray| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PseudoLinearNormalForm| |PseudoRemainderSequence| |PureAlgebraicIntegration| |PushVariables| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |Queue| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RandomDistributions| |RandomFloatDistributions| |RandomIntegerDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealPolynomialUtilitiesPackage| |RealRootCharacterizationCategory&| |RealZeroPackage| |RectangularMatrix| |RectangularMatrixCategory&| |RectangularMatrixCategoryFunctions2| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReduceLODE| |ReducedDivisor| |ReductionOfOrder| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetCategory&| |RegularTriangularSetGcdPackage| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RetractSolvePackage| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RootsFindingPackage| |RoutinesTable| |SExpressionOf| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SmithNormalForm| |SortPackage| |SortedCache| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |StorageEfficientMatrixOperations| |Stream| |StreamAggregate&| |StreamTaylorSeriesOperations| |StreamTranscendentalFunctions| |String| |StringAggregate&| |StringTable| |StructuralConstantsPackage| |SturmHabichtPackage| |SubResultantPackage| |SubSpace| |Symbol| |SymmetricFunctions| |SymmetricGroupCombinatoricFunctions| |SymmetricPolynomial| |SystemODESolver| |SystemSolvePackage| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TangentExpansions| |TaylorSeries| |TaylorSolve| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalHermiteIntegration| |TranscendentalIntegration| |TranscendentalManipulations| |TranscendentalRischDE| |TranscendentalRischDESystem| |Tree| |TriangularMatrixOperations| |TriangularSetCategory&| |TubePlotTools| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalPlotClipping| |TwoDimensionalViewport| |TwoFactorize| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnaryRecursiveAggregate&| |UnivariateFactorize| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePolynomialCategoryFunctions2| |UnivariatePolynomialDecompositionPackage| |UnivariatePolynomialDivisionPackage| |UnivariatePolynomialMultiplicationPackage| |UnivariatePolynomialSquareFree| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateSkewPolynomialCategoryOps| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Vector| |VectorCategory&| |ViewDefaultsPackage| |WeierstrassPreparation| |WeightedPolynomials| |WildFunctionFieldIntegralBasis| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XExponentialPackage| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01aqfAnnaType| |d01fcfAnnaType| |d02AgentsPackage| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|AlgebraicFunction| |Any| |AnyFunctions1| |BasicOperator| |BasicOperatorFunctions1| |CombinatorialFunction| |CommonOperators| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionalSpecialFunction| |LaplaceTransform| |LiouvillianFunction| |ModuleOperator| |NoneFunctions1| |RecurrenceOperator|)
 (|AnyFunctions1| |ModuleOperator|)
 (|InternalRationalUnivariateRepresentationPackage| |LazardSetSolvingPackage| |LexTriangularPackage| |RationalUnivariateRepresentationPackage| |ZeroDimensionalSolvePackage|)
@@ -398,7 +400,7 @@
 (|AffineAlgebraicSetComputeWithGroebnerBasis| |DesingTreePackage| |DistributedMultivariatePolynomial| |FGLMIfCanPackage| |GeneralDistributedMultivariatePolynomial| |GroebnerSolve| |Guess| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InterpolateFormsPackage| |LexTriangularPackage| |LinGroebnerPackage| |LocalParametrizationOfSimplePointPackage| |MultivariatePolynomial| |PolToPol| |ProjectiveAlgebraicSetPackage| |QuasiAlgebraicSet2| |RationalUnivariateRepresentationPackage| |RegularChain| |ZeroDimensionalSolvePackage|)
 (|FullPartialFractionExpansion|)
 (|FullPartialFractionExpansion| |LinearOrdinaryDifferentialOperatorsOps| |OrderlyDifferentialPolynomial|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteTuple| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |Algebra&| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinaryRecursiveAggregate&| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpPackage| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CRApackage| |CardinalNumber| |CartesianTensor| |Cell| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DesingTreePackage| |DictionaryOperations&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DifferentialVariableCategory&| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionODESolver| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |EqTable| |Equation| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionToOpenMath| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FiniteSetAggregate&| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionSpace&| |GaloisGroupFactorizationUtilities| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousAggregate&| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfiniteTuple| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |InternalRationalUnivariateRepresentationPackage| |IntersectionDivisorPackage| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |LeftAlgebra&| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixCategory&| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonAssociativeRing&| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OneDimensionalArrayAggregate&| |OnePointCompletion| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |Plot| |Plot3D| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PrimeField| |PrimitiveArray| |PrintPackage| |Product| |ProjectiveAlgebraicSetPackage| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |QuotientFieldCategory&| |RadicalFunctionField| |RadixExpansion| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealNumberSystem&| |RealZeroPackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularTriangularSet| |RepresentationPackage1| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |Ring&| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |ScriptFormulaFormat1| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SimpleCell| |SimpleFortranProgram| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |SquareMatrixCategory&| |Stack| |StochasticDifferential| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringAggregate&| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |TableAggregate&| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TaylorSolve| |TexFormat| |TexFormat1| |TextFile| |TheSymbolTable| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |TopLevelDrawFunctionsForCompiledFunctions| |Tree| |TriangularSetCategory&| |Tuple| |TwoDimensionalArray| |TwoDimensionalArrayCategory&| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateSkewPolynomialCategory&| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |UniversalSegment| |Variable| |Vector| |Void| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|DirichletRing| |GenUFactorize| |Guess| |IndexCard| |InternalRationalUnivariateRepresentationPackage| |NormalizationPackage| |NumericalOrdinaryDifferentialEquations| |NumericalQuadrature| |RationalInterpolation| |RationalUnivariateRepresentationPackage| |SparseUnivariatePolynomialExpressions| |TabulatedComputationPackage| |TaylorSolve| |ZeroDimensionalSolvePackage|)
 (|PAdicRational|)
 (|BalancedPAdicRational| |PAdicRational|)
@@ -444,7 +446,7 @@
 (|PointsOfFiniteOrder| |PointsOfFiniteOrderRational|)
 (|FGLMIfCanPackage| |GroebnerSolve|)
 (|FunctionFieldCategory&| |PrimitiveElement|)
-(|AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |CoerceVectorMatrixPackage| |ComplexPatternMatch| |ComplexRootPackage| |DefiniteIntegrationTools| |DiophantineSolutionPackage| |EigenPackage| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |FGLMIfCanPackage| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranType| |FramedNonAssociativeAlgebra&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenericNonAssociativeAlgebra| |IdealDecompositionPackage| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |LexTriangularPackage| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NonLinearSolvePackage| |Numeric| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrdinaryWeightedPolynomials| |ParametricLinearEquations| |PartialFractionPackage| |PatternMatch| |Pi| |PlaneAlgebraicCurvePlot| |PolToPol| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PrimitiveElement| |PushVariables| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealSolvePackage| |RecursivePolynomialCategory&| |RepresentationPackage1| |RetractSolvePackage| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariateTaylorSeries| |StructuralConstantsPackage| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |WeierstrassPreparation| |ZeroDimensionalSolvePackage| |e04AgentsPackage| |e04mbfAnnaType| |e04nafAnnaType|)
+(|AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |Asp1| |Asp10| |Asp19| |Asp20| |Asp24| |Asp30| |Asp31| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |CoerceVectorMatrixPackage| |ComplexPatternMatch| |ComplexRootPackage| |CylindricalAlgebraicDecompositionPackage| |DefiniteIntegrationTools| |DiophantineSolutionPackage| |EigenPackage| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |Expression| |FGLMIfCanPackage| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranType| |FramedNonAssociativeAlgebra&| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpacePrimitiveElement| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenericNonAssociativeAlgebra| |IdealDecompositionPackage| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |LexTriangularPackage| |MPolyCatPolyFactorizer| |MPolyCatRationalFunctionFactorizer| |MyExpression| |MyUnivariatePolynomial| |NewSparseMultivariatePolynomial| |NonLinearSolvePackage| |Numeric| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrdinaryWeightedPolynomials| |ParametricLinearEquations| |PartialFractionPackage| |PatternMatch| |Pi| |PlaneAlgebraicCurvePlot| |PolToPol| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PrimitiveElement| |PushVariables| |RadicalEigenPackage| |RadicalSolvePackage| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionFactorizer| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealSolvePackage| |RecursivePolynomialCategory&| |RepresentationPackage1| |RetractSolvePackage| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariateTaylorSeries| |StructuralConstantsPackage| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TopLevelDrawFunctionsForAlgebraicCurves| |TransSolvePackage| |UnivariateFormalPowerSeries| |UnivariateLaurentSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |WeierstrassPreparation| |ZeroDimensionalSolvePackage| |e04AgentsPackage| |e04mbfAnnaType| |e04nafAnnaType|)
 (|CombinatorialFunction| |DifferentialSparseMultivariatePolynomial| |ElementaryFunctionStructurePackage| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerTrigonometricManipulations| |MRationalFactorize| |ParametricLinearEquations| |PolynomialAN2Expression| |PolynomialCategory&| |PolynomialFunctions2| |QuasiAlgebraicSet2| |RationalFunction| |RealSolvePackage| |TransSolvePackage| |TranscendentalManipulations|)
 (|AlgFactor| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |ElementaryFunctionLODESolver| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Expression| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |GenusZeroIntegration| |RationalFunction| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign|)
 (|AlgebraicallyClosedField&|)
@@ -465,7 +467,7 @@
 (|DefiniteIntegrationTools| |ElementaryFunctionSign| |LaplaceTransform| |d01AgentsPackage|)
 (|AssociatedEquations|)
 (|FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldNormalBasis| |InterfaceGroebnerPackage|)
-(|BlasLevelOne| |Character| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple| |U32VectorPolynomialOperations|)
+(|BlasLevelOne| |Character| |CylindricalAlgebraicDecompositionPackage| |DistinctDegreeFactorize| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldFactorization| |FiniteFieldFactorizationWithSizeParseBySideEffect| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |IndexedFlexibleArray| |InnerIndexedTwoDimensionalArray| |InnerNumericFloatSolvePackage| |LinearSystemMatrixPackage| |MatrixLinearAlgebraFunctions| |ModMonic| |NumberFormats| |PrecomputedAssociatedEquations| |PrimitiveArrayFunctions2| |RadicalFunctionField| |ReductionOfOrder| |StorageEfficientMatrixOperations| |SubResultantPackage| |Symbol| |ThreeDimensionalMatrix| |TranscendentalIntegration| |Tuple| |U32VectorPolynomialOperations|)
 (|FunctionSpacePrimitiveElement|)
 (|PrimitiveRatRicDE| |RationalLODE| |RationalRicDE|)
 (|RationalRicDE|)
@@ -500,7 +502,7 @@
 (|ElementaryFunctionLODESolver| |GenusZeroIntegration| |LinearOrdinaryDifferentialOperatorFactorizer| |PureAlgebraicLODE| |RationalRicDE|)
 (|ElementaryFunctionLODESolver| |Kovacic| |LinearOrdinaryDifferentialOperatorFactorizer|)
 (|ZeroDimensionalSolvePackage|)
-(|RightOpenIntervalRootCharacterization|)
+(|RightOpenIntervalRootCharacterization| |SimpleCell|)
 (|PlaneAlgebraicCurvePlot|)
 (|DefiniteIntegrationTools| |InnerNumericFloatSolvePackage| |RealZeroPackageQ|)
 (|Guess|)
@@ -529,6 +531,7 @@
 (|SequentialDifferentialPolynomial|)
 (|ApplicationProgramInterface| |BasicOperator| |BasicStochasticDifferential| |ExpressionSpace&| |Factored| |GaloisGroupFactorizer| |GeneralPolynomialSet| |IntegerPrimesPackage| |ModularHermitianRowReduction| |MonoidRing| |ParametricLinearEquations| |Pattern| |Permutation| |PermutationGroup| |PolynomialSetCategory&| |QuasiAlgebraicSet| |RandomDistributions| |SymmetricGroupCombinatoricFunctions| |ThreeDimensionalViewport| |ThreeSpace|)
 (|AlgebraicFunctionField| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |RadicalFunctionField|)
+(|Cell| |CylindricalAlgebraicDecompositionPackage|)
 (|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunctionField| |AlgebraicNumber| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlasLevelOne| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |Commutator| |Complex| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexRootFindingPackage| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawOption| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionSign| |EqTable| |Equation| |EuclideanModularRing| |Exit| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteDivisor| |FiniteField| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FlexibleArray| |Float| |FortranCode| |FortranExpression| |FortranProgram| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GraphImage| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerNormalBasisFieldFunctions| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InputForm| |Integer| |IntegerMod| |IntegrationResult| |Interval| |Kernel| |KeyedAccessFile| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MathMLFormat| |Matrix| |MatrixLinearAlgebraFunctions| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NottinghamGroup| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalPDEProblem| |NumericalQuadrature| |Octonion| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathServerPackage| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedCompletionFunctions2| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |PartialFraction| |Partition| |Pattern| |PatternMatchIntegration| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |QuadraticForm| |QuasiAlgebraicSet| |Quaternion| |Queue| |RadicalFunctionField| |RadixExpansion| |RandomDistributions| |RationalFunctionLimitPackage| |RationalFunctionSign| |RealClosure| |RectangularMatrix| |Reference| |RegularChain| |RegularTriangularSet| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeRegularTriangularSet| |SquareMatrix| |Stack| |StochasticDifferential| |Stream| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Symbol| |SymmetricPolynomial| |Table| |TaylorSeries| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |Tree| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U32VectorPolynomialOperations| |U8Matrix| |U8Vector| |UTSodetools| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|ExponentialOfUnivariatePuiseuxSeries| |GeneralUnivariatePowerSeries| |InnerSparseUnivariatePowerSeries| |ModMonic| |MultivariateSquareFree| |MyUnivariatePolynomial| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePowerSeriesCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero|)
 (|TranscendentalRischDESystem|)
@@ -536,7 +539,7 @@
 (|AlgebraicFunction| |AlgebraicManipulations| |AlgebraicNumber| |CombinatorialFunction| |ComplexTrigonometricManipulations| |DifferentialSparseMultivariatePolynomial| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |Expression| |ExpressionSpaceODESolver| |FunctionSpace&| |FunctionSpaceFunctions2| |FunctionSpacePrimitiveElement| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GosperSummationMethod| |Guess| |InnerAlgebraicNumber| |InnerTrigonometricManipulations| |IntegrationResultToFunction| |IntegrationTools| |InverseLaplaceTransform| |LaplaceTransform| |MRationalFactorize| |MultFiniteFactorize| |MultivariatePolynomial| |MyExpression| |NewSparseMultivariatePolynomial| |NonLinearFirstOrderODESolver| |ODEIntegration| |OrderlyDifferentialPolynomial| |PatternMatchFunctionSpace| |PatternMatchIntegration| |PointsOfFiniteOrder| |Polynomial| |PureAlgebraicIntegration| |RecurrenceOperator| |SequentialDifferentialPolynomial| |StochasticDifferential| |TransSolvePackage| |TranscendentalManipulations|)
 (|TaylorSeries|)
 (|SparseUnivariatePuiseuxSeries|)
-(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MatrixCategory&| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |RootsFindingPackage| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |U32VectorPolynomialOperations| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
+(|AffineAlgebraicSetComputeWithGroebnerBasis| |AffineAlgebraicSetComputeWithResultant| |AlgFactor| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicMultFact| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |BalancedPAdicInteger| |BalancedPAdicRational| |BinaryExpansion| |BlowUpPackage| |BoundIntegerRoots| |CharacteristicPolynomialInMonogenicalAlgebra| |ChineseRemainderToolsForIntegralBases| |Complex| |ComplexCategory&| |ComplexFactorization| |ComplexIntegerSolveLinearPolynomialEquation| |ComplexPatternMatch| |ComplexRootPackage| |ConstantLODE| |ContinuedFraction| |CyclotomicPolynomialPackage| |CylindricalAlgebraicDecompositionPackage| |DecimalExpansion| |DefiniteIntegrationTools| |DegreeReductionPackage| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DistributedMultivariatePolynomial| |DoubleFloat| |DoubleResultantPackage| |EigenPackage| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |EuclideanModularRing| |ExpertSystemContinuityPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSpaceODESolver| |FGLMIfCanPackage| |Factored| |FactoringUtilities| |FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber| |FactorisationOverPseudoAlgebraicClosureOfRationalNumber| |FiniteAlgebraicExtensionField&| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldFunctions| |FiniteFieldHomomorphisms| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteFieldPolynomialPackage| |FiniteFieldPolynomialPackage2| |FiniteRankNonAssociativeAlgebra&| |Float| |FloatingComplexPackage| |FortranExpression| |Fraction| |FractionFreeFastGaussian| |FractionFreeFastGaussianFractions| |FractionalIdeal| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |GaloisGroupFactorizer| |GaloisGroupPolynomialUtilities| |GcdDomain&| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralPackageForAlgebraicFunctionField| |GeneralPolynomialGcdPackage| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |GosperSummationMethod| |GroebnerSolve| |Guess| |HexadecimalExpansion| |HomogeneousDistributedMultivariatePolynomial| |IdealDecompositionPackage| |InfiniteProductFiniteField| |InnerAlgFactor| |InnerAlgebraicNumber| |InnerFiniteField| |InnerMultFact| |InnerNormalBasisFieldFunctions| |InnerNumericEigenPackage| |InnerNumericFloatSolvePackage| |InnerPAdicInteger| |InnerPolySum| |InnerPrimeField| |InnerTrigonometricManipulations| |Integer| |IntegerCombinatoricFunctions| |IntegerSolveLinearPolynomialEquation| |IntegralBasisPolynomialTools| |IntegrationResult| |IntegrationResultFunctions2| |IntegrationResultToFunction| |IntegrationTools| |Interval| |InverseLaplaceTransform| |IrredPolyOverFiniteField| |Kovacic| |LaplaceTransform| |LaurentPolynomial| |LeadingCoefDetermination| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperatorFactorizer| |LinearPolynomialEquationByFractions| |LinearSystemPolynomialPackage| |LocalParametrizationOfSimplePointPackage| |MPolyCatFunctions2| |MPolyCatFunctions3| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MachineFloat| |MachineInteger| |MatrixCategory&| |ModMonic| |ModularField| |MultFiniteFactorize| |MultivariateFactorize| |MultivariateLifting| |MultivariatePolynomial| |MultivariateSquareFree| |MyExpression| |MyUnivariatePolynomial| |NPCoef| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NewtonInterpolation| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NormInMonogenicAlgebra| |NormRetractPackage| |NumberTheoreticPolynomialFunctions| |NumericComplexEigenPackage| |NumericRealEigenPackage| |OrderlyDifferentialPolynomial| |OrdinaryDifferentialRing| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |PAdicWildFunctionFieldIntegralBasis| |PackageForAlgebraicFunctionField| |PackageForAlgebraicFunctionFieldOverFiniteField| |PackageForPoly| |PartialFraction| |PartialFractionPackage| |PatternMatchIntegration| |Pi| |PiCoercions| |PlaneAlgebraicCurvePlot| |PointsOfFiniteOrder| |Polynomial| |PolynomialCategory&| |PolynomialCategoryLifting| |PolynomialCategoryQuotientFunctions| |PolynomialFactorizationByRecursion| |PolynomialFactorizationByRecursionUnivariate| |PolynomialFactorizationExplicit&| |PolynomialGcdPackage| |PolynomialIdeals| |PolynomialInterpolation| |PolynomialNumberTheoryFunctions| |PolynomialSquareFree| |PolynomialToUnivariatePolynomial| |PrimeField| |PrimitiveElement| |PrimitiveRatDE| |PrimitiveRatRicDE| |ProjectiveAlgebraicSetPackage| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFactorize| |RationalFunctionFactor| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosedField&| |RealClosure| |RealZeroPackageQ| |RecurrenceOperator| |RecursivePolynomialCategory&| |ReducedDivisor| |RetractSolvePackage| |RomanNumeral| |RootsFindingPackage| |SequentialDifferentialPolynomial| |SimpleAlgebraicExtension| |SimpleCell| |SingleInteger| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePolynomialFunctions2| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SupFractionFactorizer| |SymmetricFunctions| |SystemSolvePackage| |TangentExpansions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalIntegration| |TranscendentalManipulations| |TwoFactorize| |U32VectorPolynomialOperations| |UnivariateFactorize| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |WeierstrassPreparation| |WeightedPolynomials| |ZeroDimensionalSolvePackage|)
 (|ExpressionSolve| |TaylorSolve|)
 (|AlgebraicIntegration| |DefiniteIntegrationTools| |ElementaryFunctionLODESolver| |FiniteFieldPolynomialPackage2| |FunctionSpace&| |FunctionSpaceReduce| |GenusZeroIntegration| |Guess| |InnerAlgebraicNumber| |InnerPolySum| |InnerTrigonometricManipulations| |IntegrationResultFunctions2| |MultivariateLifting| |Pi| |PiCoercions| |PointsOfFiniteOrder| |PolynomialCategoryQuotientFunctions| |PureAlgebraicIntegration| |RadicalSolvePackage| |RealClosedField&| |TranscendentalIntegration| |TranscendentalManipulations|)
 (|LinearOrdinaryDifferentialOperator| |UnivariateSkewPolynomial|)
@@ -559,13 +562,13 @@
 (|ElementaryFunctionsUnivariateLaurentSeries| |InfiniteProductFiniteField| |SparseMultivariateTaylorSeries| |StreamInfiniteProduct| |StreamTranscendentalFunctionsNonCommutative| |UnivariateTaylorSeriesCategory&|)
 (|UnivariateTaylorSeriesCategory&|)
 (|AffinePlane| |AffinePlaneOverPseudoAlgebraicClosureOfFiniteField| |AffineSpace| |AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AnonymousFunction| |AntiSymm| |Any| |ArrayStack| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AssociatedJordanAlgebra| |AssociatedLieAlgebra| |AssociationList| |AttributeButtons| |Automorphism| |AxiomServer| |BalancedBinaryTree| |BalancedPAdicInteger| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |BinaryFile| |BinarySearchTree| |BinaryTournament| |BinaryTree| |Bits| |BlowUpWithHamburgerNoether| |BlowUpWithQuadTrans| |Boolean| |CardinalNumber| |CartesianTensor| |Character| |CharacterClass| |CliffordAlgebra| |Color| |CombinatorialFunction| |CommonOperators| |Commutator| |Complex| |ComplexCategory&| |ComplexDoubleFloatMatrix| |ComplexDoubleFloatVector| |ComplexPattern| |ComplexPatternMatch| |ComplexRootFindingPackage| |ComplexTrigonometricManipulations| |ContinuedFraction| |DataList| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DenavitHartenbergMatrix| |Dequeue| |DesingTree| |DictionaryOperations&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductMatrixModule| |DirectProductModule| |DirichletRing| |DiscreteLogarithmPackage| |DisplayPackage| |DistributedMultivariatePolynomial| |Divisor| |DoubleFloat| |DoubleFloatMatrix| |DoubleFloatVector| |DrawComplex| |DrawOption| |DrawOptionFunctions0| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryFunctionsUnivariateLaurentSeries| |ElementaryFunctionsUnivariatePuiseuxSeries| |ElementaryIntegration| |ElementaryRischDE| |EqTable| |Equation| |ErrorFunctions| |EuclideanGroebnerBasisPackage| |EuclideanModularRing| |Exit| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Export3D| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceFunctions1| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionTubePlot| |ExtAlgBasis| |Factored| |File| |FileName| |FiniteAlgebraicExtensionField&| |FiniteDivisor| |FiniteField| |FiniteFieldCategory&| |FiniteFieldCyclicGroup| |FiniteFieldCyclicGroupExtension| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtension| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasis| |FiniteFieldNormalBasisExtension| |FiniteFieldNormalBasisExtensionByPolynomial| |FiniteRankNonAssociativeAlgebra&| |FlexibleArray| |Float| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranOutputStackPackage| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranTemplate| |FortranType| |FourierComponent| |FourierSeries| |Fraction| |FractionalIdeal| |FramedModule| |FramedNonAssociativeAlgebra&| |FreeAbelianGroup| |FreeAbelianMonoid| |FreeGroup| |FreeModule| |FreeModule1| |FreeMonoid| |FreeNilpotentLie| |FullPartialFractionExpansion| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAssertions| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceReduce| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralModulePolynomial| |GeneralPolynomialSet| |GeneralSparseTable| |GeneralTriangularSet| |GeneralUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GnuDraw| |GraphImage| |GroebnerFactorizationPackage| |GroebnerInternalPackage| |GroebnerPackage| |Guess| |GuessOption| |GuessOptionFunctions0| |HTMLFormat| |HashTable| |Heap| |HexadecimalExpansion| |HomogeneousDirectProduct| |HomogeneousDistributedMultivariatePolynomial| |HyperellipticFiniteDivisor| |IndexCard| |IndexedBits| |IndexedDirectProductAbelianGroup| |IndexedDirectProductAbelianMonoid| |IndexedDirectProductObject| |IndexedDirectProductOrderedAbelianMonoid| |IndexedDirectProductOrderedAbelianMonoidSup| |IndexedExponents| |IndexedFlexibleArray| |IndexedList| |IndexedMatrix| |IndexedOneDimensionalArray| |IndexedString| |IndexedTwoDimensionalArray| |IndexedVector| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerFiniteField| |InnerFreeAbelianMonoid| |InnerIndexedTwoDimensionalArray| |InnerPAdicInteger| |InnerPrimeField| |InnerSparseUnivariatePowerSeries| |InnerTable| |InnerTaylorSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |Integer| |IntegerMod| |IntegrationResult| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InternalRationalUnivariateRepresentationPackage| |Interval| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |Library| |LieExponentials| |LiePolynomial| |LieSquareMatrix| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperator1| |LinearOrdinaryDifferentialOperator2| |LiouvillianFunction| |List| |ListMonoidOps| |ListMultiDictionary| |LocalAlgebra| |Localize| |LyndonWord| |MachineComplex| |MachineFloat| |MachineInteger| |Magma| |MakeCachableSet| |MakeFloatCompiledFunction| |MathMLFormat| |Matrix| |ModMonic| |ModularField| |ModularRing| |ModuleMonomial| |ModuleOperator| |MoebiusTransform| |MonoidRing| |MoreSystemCommands| |Multiset| |MultivariatePolynomial| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseMultivariatePolynomial| |NewSparseUnivariatePolynomial| |NonNegativeInteger| |None| |NormalizationPackage| |NottinghamGroup| |NumberFormats| |NumericalIntegrationProblem| |NumericalODEProblem| |NumericalOptimizationProblem| |NumericalOrdinaryDifferentialEquations| |NumericalPDEProblem| |NumericalQuadrature| |ODEIntegration| |Octonion| |OctonionCategory&| |OneDimensionalArray| |OnePointCompletion| |OpenMathConnection| |OpenMathDevice| |OpenMathEncoding| |OpenMathError| |OpenMathErrorKind| |OpenMathPackage| |OpenMathServerPackage| |OperationsQuery| |Operator| |OppositeMonogenicLinearOperator| |OrdSetInts| |OrderedCompletion| |OrderedDirectProduct| |OrderedFreeMonoid| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OrderlyDifferentialVariable| |OrdinaryDifferentialRing| |OrdinaryWeightedPolynomials| |OutputForm| |OutputPackage| |PAdicInteger| |PAdicRational| |PAdicRationalConstructor| |Palette| |ParametricLinearEquations| |PartialFraction| |Partition| |Pattern| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchListResult| |PatternMatchResult| |PendantTree| |Permutation| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PoincareBirkhoffWittLyndonBasis| |Point| |PointsOfFiniteOrder| |Polynomial| |PolynomialIdeals| |PolynomialRing| |PositiveInteger| |PowerSeriesLimitPackage| |PrimeField| |PrimitiveArray| |Product| |ProjectivePlane| |ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField| |ProjectiveSpace| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |QuadraticForm| |QuasiAlgebraicSet| |QuasiComponentPackage| |Quaternion| |QuaternionCategory&| |QueryEquation| |Queue| |RadicalFunctionField| |RadixExpansion| |RationalFunctionDefiniteIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalUnivariateRepresentationPackage| |RealClosure| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |Reference| |RegularChain| |RegularSetDecompositionPackage| |RegularTriangularSet| |RegularTriangularSetGcdPackage| |RepresentationPackage2| |ResidueRing| |Result| |RewriteRule| |RightOpenIntervalRootCharacterization| |RomanNumeral| |RoutinesTable| |RuleCalled| |Ruleset| |SExpression| |SExpressionOf| |ScriptFormulaFormat| |Segment| |SegmentBinding| |SequentialDifferentialPolynomial| |SequentialDifferentialVariable| |Set| |SetCategory&| |SetOfMIntegersInOneToN| |SimpleAlgebraicExtension| |SingleInteger| |SingletonAsOrderedSet| |SparseMultivariatePolynomial| |SparseMultivariateTaylorSeries| |SparseTable| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateSkewPolynomial| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SplittingNode| |SplittingTree| |SquareFreeQuasiComponentPackage| |SquareFreeRegularSetDecompositionPackage| |SquareFreeRegularTriangularSet| |SquareFreeRegularTriangularSetGcdPackage| |SquareMatrix| |Stack| |StochasticDifferential| |Stream| |StreamTranscendentalFunctions| |StreamTranscendentalFunctionsNonCommutative| |String| |StringTable| |SubSpace| |SubSpaceComponentProperty| |SuchThat| |Switch| |Symbol| |SymbolTable| |SymmetricPolynomial| |Table| |Tableau| |TabulatedComputationPackage| |TaylorSeries| |TemplateUtilities| |TexFormat| |TextFile| |ThreeDimensionalMatrix| |ThreeDimensionalViewport| |ThreeSpace| |ToolsForSign| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TranscendentalManipulations| |Tree| |TrigonometricManipulations| |Tuple| |TwoDimensionalArray| |TwoDimensionalViewport| |U16Matrix| |U16Vector| |U32Matrix| |U32Vector| |U8Matrix| |U8Vector| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariatePolynomial| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UniversalSegment| |Variable| |Vector| |ViewDefaultsPackage| |ViewportPackage| |WeightedPolynomials| |WuWenTsunTriangularSet| |XDistributedPolynomial| |XPBWPolynomial| |XPolynomial| |XPolynomialRing| |XRecursivePolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03eefAnnaType| |d03fafAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
-(|InnerNumericFloatSolvePackage| |TranscendentalIntegration|)
+(|CylindricalAlgebraicDecompositionPackage| |InnerNumericFloatSolvePackage| |TranscendentalIntegration|)
 (|Export3D| |ThreeSpace|)
 (|MeshCreationRoutinesForThreeDimensions| |SubSpace| |ThreeDimensionalViewport| |ThreeSpace|)
 (|EigenPackage| |PolynomialIdeals| |RadicalEigenPackage| |RadicalSolvePackage|)
 (|Expression|)
 (|Asp12| |Asp30| |Asp35| |Asp55| |Asp74| |Asp8| |FortranCode|)
-(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |Boolean| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DesingTreePackage| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
+(|AlgebraGivenByStructuralConstants| |AlgebraicFunction| |AlgebraicFunctionField| |AlgebraicIntegrate| |AlgebraicIntegration| |AlgebraicManipulations| |AlgebraicNumber| |AlgebraicallyClosedField&| |AlgebraicallyClosedFunctionSpace&| |AnnaNumericalIntegrationPackage| |AnnaNumericalOptimizationPackage| |AnnaOrdinaryDifferentialEquationPackage| |AnnaPartialDifferentialEquationPackage| |AntiSymm| |Any| |ApplicationProgramInterface| |ApplyRules| |Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |AttachPredicates| |AttributeButtons| |BalancedPAdicRational| |BasicFunctions| |BasicOperator| |BasicOperatorFunctions1| |BasicStochasticDifferential| |BinaryExpansion| |Boolean| |Cell| |CombinatorialFunction| |CommonOperators| |Complex| |ComplexCategory&| |ComplexPattern| |ComplexPatternMatch| |ComplexRootPackage| |ComplexTrigonometricManipulations| |ConstantLODE| |CylindricalAlgebraicDecompositionPackage| |Database| |DeRhamComplex| |DecimalExpansion| |DefiniteIntegrationTools| |DesingTreePackage| |DifferentialExtension&| |DifferentialPolynomialCategory&| |DifferentialSparseMultivariatePolynomial| |DirectProduct| |DirectProductCategory&| |DirectProductMatrixModule| |DirectProductModule| |DrawOption| |DrawOptionFunctions0| |DrawOptionFunctions1| |EigenPackage| |ElementaryFunction| |ElementaryFunctionDefiniteIntegration| |ElementaryFunctionLODESolver| |ElementaryFunctionODESolver| |ElementaryFunctionSign| |ElementaryFunctionStructurePackage| |ElementaryIntegration| |ElementaryRischDE| |ElementaryRischDESystem| |Equation| |ExpertSystemContinuityPackage| |ExpertSystemToolsPackage| |ExponentialExpansion| |ExponentialOfUnivariatePuiseuxSeries| |Expression| |ExpressionSolve| |ExpressionSpace&| |ExpressionSpaceODESolver| |ExpressionToOpenMath| |ExpressionToUnivariatePowerSeries| |ExpressionTubePlot| |FGLMIfCanPackage| |Factored| |FiniteFieldCyclicGroupExtensionByPolynomial| |FiniteFieldExtensionByPolynomial| |FiniteFieldNormalBasisExtensionByPolynomial| |Float| |FloatingComplexPackage| |FloatingRealPackage| |FortranCode| |FortranCodePackage1| |FortranExpression| |FortranPackage| |FortranProgram| |FortranScalarType| |FortranType| |Fraction| |FramedNonAssociativeAlgebra&| |FullPartialFractionExpansion| |FullyEvalableOver&| |FunctionCalled| |FunctionFieldCategory&| |FunctionSpace&| |FunctionSpaceAttachPredicates| |FunctionSpaceComplexIntegration| |FunctionSpaceIntegration| |FunctionSpacePrimitiveElement| |FunctionSpaceSum| |FunctionSpaceToExponentialExpansion| |FunctionSpaceToUnivariatePowerSeries| |FunctionSpaceUnivariatePolynomialFactor| |FunctionalSpecialFunction| |GenUFactorize| |GeneralDistributedMultivariatePolynomial| |GeneralUnivariatePowerSeries| |GenerateUnivariatePowerSeries| |GenericNonAssociativeAlgebra| |GenusZeroIntegration| |Guess| |GuessAlgebraicNumber| |GuessFinite| |GuessInteger| |GuessOption| |GuessOptionFunctions0| |GuessPolynomial| |GuessUnivariatePolynomial| |HexadecimalExpansion| |HomogeneousDirectProduct| |HyperellipticFiniteDivisor| |IdealDecompositionPackage| |IndexCard| |InfClsPt| |InfinitlyClosePoint| |InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField| |InnerAlgebraicNumber| |InnerNumericFloatSolvePackage| |InnerSparseUnivariatePowerSeries| |InnerTrigonometricManipulations| |InputForm| |InputFormFunctions1| |IntegrationResult| |IntegrationResultRFToFunction| |IntegrationResultToFunction| |IntegrationTools| |InternalPrintPackage| |InverseLaplaceTransform| |Kernel| |KeyedAccessFile| |LaplaceTransform| |LaurentPolynomial| |LexTriangularPackage| |Library| |LieSquareMatrix| |LinGroebnerPackage| |LinearOrdinaryDifferentialOperator| |LinearOrdinaryDifferentialOperatorsOps| |LiouvillianFunction| |List| |ListMultiDictionary| |MPolyCatRationalFunctionFactorizer| |MachineComplex| |MakeBinaryCompiledFunction| |MakeFloatCompiledFunction| |MakeFunction| |MakeUnaryCompiledFunction| |Matrix| |ModMonic| |MonogenicAlgebra&| |Multiset| |MyExpression| |MyUnivariatePolynomial| |NAGLinkSupportPackage| |NagEigenPackage| |NagFittingPackage| |NagIntegrationPackage| |NagInterpolationPackage| |NagLapack| |NagLinearEquationSolvingPackage| |NagMatrixOperationsPackage| |NagOptimisationPackage| |NagOrdinaryDifferentialEquationsPackage| |NagPartialDifferentialEquationsPackage| |NagPolynomialRootsPackage| |NagRootFindingPackage| |NagSeriesSummationPackage| |NagSpecialFunctionsPackage| |NeitherSparseOrDensePowerSeries| |NewSparseUnivariatePolynomial| |NonLinearFirstOrderODESolver| |NonLinearSolvePackage| |NumberFormats| |NumericComplexEigenPackage| |NumericRealEigenPackage| |ODEIntegration| |Octonion| |OctonionCategory&| |OpenMathDevice| |OpenMathError| |OpenMathErrorKind| |OrdSetInts| |OrderedDirectProduct| |OrderedVariableList| |OrderlyDifferentialPolynomial| |OutputForm| |PAdicRational| |PAdicRationalConstructor| |ParametricLinearEquations| |PartialFractionPackage| |Pattern| |PatternFunctions2| |PatternMatch| |PatternMatchAssertions| |PatternMatchIntegration| |PatternMatchKernel| |PatternMatchPushDown| |PatternMatchResult| |PatternMatchSymbol| |PermutationGroup| |Pi| |Places| |PlacesOverPseudoAlgebraicClosureOfFiniteField| |PlaneAlgebraicCurvePlot| |Plcs| |PlotFunctions1| |PolToPol| |Polynomial| |PolynomialAN2Expression| |PolynomialFunctions2| |PolynomialIdeals| |PolynomialToUnivariatePolynomial| |PowerSeriesLimitPackage| |PrimitiveElement| |PseudoAlgebraicClosureOfAlgExtOfRationalNumber| |PseudoAlgebraicClosureOfFiniteField| |PseudoAlgebraicClosureOfRationalNumber| |PureAlgebraicIntegration| |PushVariables| |QuasiAlgebraicSet2| |Quaternion| |QuaternionCategory&| |QueryEquation| |QuotientFieldCategory&| |RadicalEigenPackage| |RadicalFunctionField| |RadicalSolvePackage| |RadixExpansion| |RationalFunction| |RationalFunctionDefiniteIntegration| |RationalFunctionFactor| |RationalFunctionIntegration| |RationalFunctionLimitPackage| |RationalFunctionSign| |RationalFunctionSum| |RationalInterpolation| |RationalLODE| |RationalRicDE| |RationalUnivariateRepresentationPackage| |RealClosure| |RealSolvePackage| |RectangularMatrix| |RecurrenceOperator| |RecursivePolynomialCategory&| |RepresentationPackage1| |Result| |RetractSolvePackage| |RewriteRule| |RomanNumeral| |RoutinesTable| |RuleCalled| |SExpression| |SegmentBinding| |SegmentBindingFunctions2| |SequentialDifferentialPolynomial| |Set| |SimpleAlgebraicExtension| |SimpleCell| |SimpleFortranProgram| |SingletonAsOrderedSet| |SparseUnivariateLaurentSeries| |SparseUnivariatePolynomial| |SparseUnivariatePolynomialExpressions| |SparseUnivariatePuiseuxSeries| |SparseUnivariateTaylorSeries| |SpecialOutputPackage| |SplitHomogeneousDirectProduct| |SquareMatrix| |SquareMatrixCategory&| |StochasticDifferential| |StructuralConstantsPackage| |Switch| |Symbol| |SymbolTable| |SystemSolvePackage| |TaylorSeries| |TheSymbolTable| |ThreeDimensionalMatrix| |TopLevelDrawFunctions| |TopLevelDrawFunctionsForAlgebraicCurves| |TopLevelDrawFunctionsForCompiledFunctions| |TransSolvePackage| |TransSolvePackageService| |TranscendentalManipulations| |TrigonometricManipulations| |UnivariateFormalPowerSeries| |UnivariateLaurentSeries| |UnivariateLaurentSeriesConstructor| |UnivariateLaurentSeriesConstructorCategory&| |UnivariatePolynomial| |UnivariatePolynomialCategory&| |UnivariatePuiseuxSeries| |UnivariatePuiseuxSeriesConstructor| |UnivariatePuiseuxSeriesWithExponentialSingularity| |UnivariateSkewPolynomial| |UnivariateTaylorSeries| |UnivariateTaylorSeriesCZero| |UnivariateTaylorSeriesCategory&| |Variable| |Vector| |WeierstrassPreparation| |XPolynomial| |ZeroDimensionalSolvePackage| |d01AgentsPackage| |d01TransformFunctionType| |d01WeightsPackage| |d01ajfAnnaType| |d01akfAnnaType| |d01alfAnnaType| |d01amfAnnaType| |d01anfAnnaType| |d01apfAnnaType| |d01aqfAnnaType| |d01asfAnnaType| |d01fcfAnnaType| |d01gbfAnnaType| |d02AgentsPackage| |d02bbfAnnaType| |d02bhfAnnaType| |d02cjfAnnaType| |d02ejfAnnaType| |d03AgentsPackage| |d03eefAnnaType| |e04AgentsPackage| |e04dgfAnnaType| |e04fdfAnnaType| |e04gcfAnnaType| |e04jafAnnaType| |e04mbfAnnaType| |e04nafAnnaType| |e04ucfAnnaType|)
 (|Asp1| |Asp10| |Asp12| |Asp19| |Asp20| |Asp24| |Asp27| |Asp28| |Asp29| |Asp30| |Asp31| |Asp33| |Asp34| |Asp35| |Asp4| |Asp41| |Asp42| |Asp49| |Asp50| |Asp55| |Asp6| |Asp7| |Asp73| |Asp74| |Asp77| |Asp78| |Asp8| |Asp80| |Asp9| |FortranPackage| |FortranProgram| |TheSymbolTable|)
 (|TangentExpansions|)
 (|IrrRepSymNatPackage| |RepresentationPackage1|)
@@ -667,4 +670,4 @@
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
 (|AnnaNumericalOptimizationPackage|)
-(("e04ucfAnnaType" 0 236785) ("e04nafAnnaType" 0 236748) ("e04mbfAnnaType" 0 236711) ("e04jafAnnaType" 0 236674) ("e04gcfAnnaType" 0 236637) ("e04fdfAnnaType" 0 236600) ("e04dgfAnnaType" 0 236563) ("e04AgentsPackage" 0 236424) ("d03eefAnnaType" 0 236381) ("d03AgentsPackage" 0 236362) ("d02ejfAnnaType" 0 236318) ("d02cjfAnnaType" 0 236274) ("d02bhfAnnaType" 0 236230) ("d02bbfAnnaType" 0 236186) ("d02AgentsPackage" 0 236116) ("d01gbfAnnaType" 0 236080) ("d01fcfAnnaType" 0 236044) ("d01asfAnnaType" 0 236008) ("d01aqfAnnaType" 0 235972) ("d01apfAnnaType" 0 235936) ("d01anfAnnaType" 0 235900) ("d01amfAnnaType" 0 235864) ("d01alfAnnaType" 0 235828) ("d01akfAnnaType" 0 235792) ("d01ajfAnnaType" 0 235756) ("d01WeightsPackage" 0 235703) ("d01TransformFunctionType" 0 235667) ("d01AgentsPackage" 0 235414) ("XRecursivePolynomial" 0 235365) ("XPolynomialRing" 0 235338) ("XPBWPolynomial" 0 235318) ("XDistributedPolynomial" 0 235228) ("WildFunctionFieldIntegralBasis" 0 235188) ("WeightedPolynomials" 0 235156) ("Void" 0 230760) ("ViewportPackage" 0 230672) ("ViewDefaultsPackage" 0 230460) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 230151) ("VectorCategory&" 0 NIL) ("Vector" 0 225035) ("Variable" 0 224660) ("UserDefinedPartialOrdering" 0 224598) ("UniversalSegmentFunctions2" 0 224564) ("UniversalSegment" 0 223698) ("UnivariateTaylorSeriesFunctions2" 0 223660) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeriesCZero" 0 223531) ("UnivariateTaylorSeries" 0 223370) ("UnivariateSkewPolynomialCategoryOps" 0 223335) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 223272) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 223212) ("UnivariatePuiseuxSeries" 0 222991) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 222872) ("UnivariatePolynomialDivisionPackage" 0 222827) ("UnivariatePolynomialDecompositionPackage" 0 222801) ("UnivariatePolynomialCommonDenominator" 0 222588) ("UnivariatePolynomialCategoryFunctions2" 0 221464) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 221155) ("UnivariateLaurentSeriesFunctions2" 0 221117) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 221089) ("UnivariateLaurentSeries" 0 220989) ("UnivariateFormalPowerSeriesFunctions" 0 220979) ("UnivariateFormalPowerSeries" 0 220891) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("U8Vector" 0 220878) ("U32Vector" 0 220832) ("U16Vector" 0 220818) ("TwoFactorize" 0 220765) ("TwoDimensionalViewport" 0 220592) ("TwoDimensionalPlotClipping" 0 220546) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 220530) ("TubePlotTools" 0 220489) ("TubePlot" 0 220404) ("TrigonometricManipulations" 0 220219) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 220029) ("Tree" 0 219987) ("TranscendentalRischDESystem" 0 219959) ("TranscendentalRischDE" 0 219915) ("TranscendentalManipulations" 0 219799) ("TranscendentalIntegration" 0 219731) ("TranscendentalHermiteIntegration" 0 219701) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 219679) ("TopLevelDrawFunctionsForCompiledFunctions" 0 219653) ("TopLevelDrawFunctions" 0 219641) ("ToolsForSign" 0 219534) ("ThreeSpace" 0 219282) ("ThreeDimensionalViewport" 0 219155) ("ThreeDimensionalMatrix" 0 219112) ("TheSymbolTable" 0 219062) ("TextFile" 0 219021) ("TexFormat" 0 219006) ("TemplateUtilities" 0 218986) ("TaylorSolve" 0 218966) ("TaylorSeries" 0 218939) ("TangentExpansions" 0 218900) ("TabulatedComputationPackage" 0 218764) ("Tableau" 0 218744) ("TableAggregate&" 0 NIL) ("Table" 0 218089) ("SystemSolvePackage" 0 217984) ("SystemODESolver" 0 217962) ("SymmetricPolynomial" 0 217916) ("SymmetricGroupCombinatoricFunctions" 0 217867) ("SymmetricFunctions" 0 217845) ("SymbolTable" 0 217566) ("Symbol" 0 209438) ("Switch" 0 209375) ("SupFractionFactorizer" 0 209360) ("SuchThat" 0 209280) ("SubSpaceComponentProperty" 0 209186) ("SubSpace" 0 209160) ("SubResultantPackage" 0 209098) ("StringAggregate&" 0 NIL) ("String" 0 197829) ("StreamTranscendentalFunctionsNonCommutative" 0 197793) ("StreamTranscendentalFunctions" 0 197580) ("StreamTaylorSeriesOperations" 0 197151) ("StreamInfiniteProduct" 0 197085) ("StreamFunctions3" 0 196892) ("StreamFunctions2" 0 196389) ("StreamFunctions1" 0 196351) ("StreamAggregate&" 0 NIL) ("Stream" 0 194488) ("StorageEfficientMatrixOperations" 0 194477) ("Stack" 0 194439) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 194306) ("SquareFreeRegularTriangularSetGcdPackage" 0 194179) ("SquareFreeRegularTriangularSet" 0 194082) ("SquareFreeRegularSetDecompositionPackage" 0 194047) ("SquareFreeQuasiComponentPackage" 0 193870) ("SplittingTree" 0 193843) ("SplittingNode" 0 193800) ("SparseUnivariateTaylorSeries" 0 193734) ("SparseUnivariateSkewPolynomial" 0 193668) ("SparseUnivariatePolynomialFunctions2" 0 193154) ("SparseUnivariatePolynomialExpressions" 0 193120) ("SparseUnivariatePolynomial" 0 186449) ("SparseUnivariateLaurentSeries" 0 186415) ("SparseMultivariateTaylorSeries" 0 186398) ("SparseMultivariatePolynomial" 0 185141) ("SortedCache" 0 185112) ("SmithNormalForm" 0 185080) ("SingletonAsOrderedSet" 0 184383) ("SingleInteger" 0 176660) ("SimpleAlgebraicExtension" 0 176529) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 176091) ("SequentialDifferentialVariable" 0 176054) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 175939) ("SegmentBindingFunctions2" 0 175897) ("SegmentBinding" 0 175530) ("Segment" 0 174445) ("ScriptFormulaFormat" 0 174420) ("SExpressionOf" 0 174404) ("SExpression" 0 174175) ("RoutinesTable" 0 173584) ("RootsFindingPackage" 0 173448) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 173432) ("RewriteRule" 0 173387) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 173361) ("Result" 0 172290) ("RepeatedSquaring" 0 172049) ("RepeatedDoubling" 0 171866) ("RegularTriangularSetGcdPackage" 0 171808) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 171791) ("RegularSetDecompositionPackage" 0 171766) ("RegularChain" 0 171711) ("Reference" 0 171328) ("ReductionOfOrder" 0 171295) ("ReduceLODE" 0 171273) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RecurrenceOperator" 0 171263) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 171183) ("RealSolvePackage" 0 171155) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 171113) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 171081) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 170991) ("RationalLODE" 0 170852) ("RationalIntegration" 0 170731) ("RationalFunctionSign" 0 170673) ("RationalFunctionIntegration" 0 170639) ("RationalFunctionFactor" 0 170606) ("RationalFunction" 0 170558) ("RationalFactorize" 0 170328) ("RandomNumberSource" 0 170248) ("RadixExpansion" 0 170186) ("RadicalSolvePackage" 0 170164) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 170141) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 170129) ("QueryEquation" 0 170116) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 170103) ("QuasiComponentPackage" 0 169989) ("QuasiAlgebraicSet" 0 169966) ("QuadraticForm" 0 169946) ("PushVariables" 0 169919) ("PureAlgebraicIntegration" 0 169842) ("PseudoRemainderSequence" 0 169757) ("PseudoLinearNormalForm" 0 169737) ("PseudoAlgebraicClosureOfRationalNumber" 0 169620) ("PseudoAlgebraicClosureOfFiniteField" 0 169349) ("ProjectiveSpace" 0 169329) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 169216) ("ProjectivePlane" 0 169111) ("ProjectiveAlgebraicSetPackage" 0 169018) ("Product" 0 168977) ("PrintPackage" 0 168951) ("PrimitiveRatRicDE" 0 168933) ("PrimitiveRatDE" 0 168880) ("PrimitiveElement" 0 168846) ("PrimitiveArray" 0 168058) ("PrimeField" 0 167965) ("PrecomputedAssociatedEquations" 0 167941) ("PowerSeriesLimitPackage" 0 167849) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 158060) ("PolynomialSquareFree" 0 158036) ("PolynomialSolveByFormulas" 0 158012) ("PolynomialSetUtilitiesPackage" 0 157615) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 157512) ("PolynomialRing" 0 157344) ("PolynomialPackageForCurve" 0 157247) ("PolynomialNumberTheoryFunctions" 0 157193) ("PolynomialInterpolationAlgorithms" 0 157165) ("PolynomialIdeals" 0 157114) ("PolynomialGcdPackage" 0 157038) ("PolynomialFunctions2" 0 156842) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 156779) ("PolynomialFactorizationByRecursion" 0 156755) ("PolynomialDecomposition" 0 156725) ("PolynomialCategoryQuotientFunctions" 0 156326) ("PolynomialCategoryLifting" 0 155691) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 153321) ("PolyGroebner" 0 153275) ("PolToPol" 0 153238) ("PointsOfFiniteOrderTools" 0 153184) ("PointsOfFiniteOrder" 0 153161) ("PointPackage" 0 153020) ("Point" 0 152584) ("PoincareBirkhoffWittLyndonBasis" 0 152547) ("PlotTools" 0 152532) ("Plot3D" 0 152465) ("Plot" 0 152328) ("Plcs" 0 152269) ("PlaneAlgebraicCurvePlot" 0 152225) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 152173) ("Places" 0 152136) ("PiCoercions" 0 152114) ("Pi" 0 152078) ("PermutationGroup" 0 152049) ("Permutation" 0 151954) ("PatternMatchTools" 0 151891) ("PatternMatchSymbol" 0 151880) ("PatternMatchResultFunctions2" 0 151833) ("PatternMatchResult" 0 150415) ("PatternMatchQuotientFieldCategory" 0 150388) ("PatternMatchPushDown" 0 150267) ("PatternMatchPolynomialCategory" 0 150230) ("PatternMatchListResult" 0 150185) ("PatternMatchListAggregate" 0 150168) ("PatternMatchKernel" 0 150125) ("PatternMatchIntegration" 0 150006) ("PatternMatchIntegerNumberSystem" 0 149981) ("PatternMatchFunctionSpace" 0 149966) ("PatternFunctions1" 0 149896) ("Pattern" 0 148363) ("PartitionsAndPermutations" 0 148263) ("Partition" 0 148146) ("PartialDifferentialRing&" 0 NIL) ("ParametrizationPackage" 0 148027) ("ParametricSurface" 0 147927) ("ParametricSpaceCurve" 0 147824) ("ParametricPlaneCurve" 0 147721) ("ParadoxicalCombinatorsForStreams" 0 147520) ("Palette" 0 147318) ("PackageForPoly" 0 147011) ("PAdicRationalConstructor" 0 146969) ("PAdicInteger" 0 146951) ("OutputPackage" 0 146581) ("OutputForm" 0 136754) ("OrderlyDifferentialVariable" 0 136648) ("OrderlyDifferentialPolynomial" 0 136615) ("OrderedVariableList" 0 136062) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 135910) ("OrderedCompletionFunctions2" 0 135839) ("OrderedCompletion" 0 135056) ("OrdSetInts" 0 135022) ("OpenMathPackage" 0 134996) ("OpenMathErrorKind" 0 134978) ("OpenMathEncoding" 0 134800) ("OpenMathDevice" 0 134618) ("OpenMathConnection" 0 134592) ("OnePointCompletionFunctions2" 0 134559) ("OnePointCompletion" 0 133746) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 133677) ("OctonionCategory&" 0 NIL) ("ODETools" 0 133629) ("ODEIntensityFunctionsTable" 0 133566) ("ODEIntegration" 0 133457) ("NumericalPDEProblem" 0 133414) ("NumericalOptimizationProblem" 0 133358) ("NumericalODEProblem" 0 133314) ("NumericalIntegrationProblem" 0 133251) ("NumericTubePlot" 0 133205) ("NumericRealEigenPackage" 0 133184) ("Numeric" 0 133145) ("NumberTheoreticPolynomialFunctions" 0 133115) ("NumberFormats" 0 133085) ("NormalizationPackage" 0 132912) ("NoneFunctions1" 0 132877) ("None" 0 132576) ("NonNegativeInteger" 0 116734) ("NonLinearSolvePackage" 0 116716) ("NonLinearFirstOrderODESolver" 0 116684) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewtonPolygon" 0 116666) ("NewtonInterpolation" 0 116656) ("NewSparseUnivariatePolynomialFunctions2" 0 116620) ("NewSparseUnivariatePolynomial" 0 116542) ("NewSparseMultivariatePolynomial" 0 116430) ("NeitherSparseOrDensePowerSeries" 0 116343) ("NagPartialDifferentialEquationsPackage" 0 116324) ("NagOrdinaryDifferentialEquationsPackage" 0 116254) ("NagOptimisationPackage" 0 116098) ("NagIntegrationPackage" 0 115926) ("NagEigenPackage" 0 115905) ("NPCoef" 0 115881) ("NAGLinkSupportPackage" 0 115469) ("MyUnivariatePolynomial" 0 115452) ("MyExpression" 0 115422) ("MultivariateSquareFree" 0 115358) ("MultivariateLifting" 0 115270) ("MultivariateFactorize" 0 114937) ("Multiset" 0 114878) ("MultipleMap" 0 114803) ("MultiVariableCalculusFunctions" 0 114709) ("MultFiniteFactorize" 0 114635) ("MoreSystemCommands" 0 114556) ("MonomialExtensionTools" 0 114437) ("MonoidRing" 0 114412) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 114390) ("ModuleOperator" 0 114377) ("ModuleMonomial" 0 114349) ("Module&" 0 NIL) ("ModularRing" 0 114309) ("ModularHermitianRowReduction" 0 114104) ("ModularDistinctDegreeFactorizer" 0 114047) ("ModMonic" 0 113937) ("MeshCreationRoutinesForThreeDimensions" 0 113891) ("MergeThing" 0 113878) ("MatrixLinearAlgebraFunctions" 0 113851) ("MatrixCommonDenominator" 0 113741) ("MatrixCategoryFunctions2" 0 113360) ("MatrixCategory&" 0 NIL) ("Matrix" 0 108476) ("MappingPackageInternalHacks3" 0 108456) ("MappingPackageInternalHacks2" 0 108436) ("MappingPackageInternalHacks1" 0 108416) ("MappingPackage1" 0 108322) ("MakeUnaryCompiledFunction" 0 108262) ("MakeFunction" 0 108203) ("MakeFloatCompiledFunction" 0 108139) ("MakeBinaryCompiledFunction" 0 108091) ("Magma" 0 108060) ("MachineInteger" 0 108026) ("MachineFloat" 0 107957) ("MRationalFactorize" 0 107793) ("MPolyCatRationalFunctionFactorizer" 0 107683) ("MPolyCatPolyFactorizer" 0 107646) ("MPolyCatFunctions3" 0 107633) ("MPolyCatFunctions2" 0 107546) ("LyndonWord" 0 107459) ("Logic&" 0 NIL) ("Localize" 0 107442) ("LocalParametrizationOfSimplePointPackage" 0 107349) ("LocalAlgebra" 0 107336) ("ListToMap" 0 107285) ("ListMultiDictionary" 0 107253) ("ListMonoidOps" 0 107201) ("ListFunctions2" 0 106761) ("ListAggregate&" 0 NIL) ("List" 0 89063) ("LiouvillianFunction" 0 89022) ("LinesOpPack" 0 88957) ("LinearSystemPolynomialPackage" 0 88934) ("LinearSystemMatrixPackage" 0 88600) ("LinearSystemFromPowerSeriesPackage" 0 88572) ("LinearPolynomialEquationByFractions" 0 88451) ("LinearOrdinaryDifferentialOperatorsOps" 0 88412) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 88379) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 88346) ("LinearOrdinaryDifferentialOperator1" 0 88182) ("LinearOrdinaryDifferentialOperator" 0 88104) ("LinearDependence" 0 88076) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 88039) ("LiePolynomial" 0 88002) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 87970) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 87930) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 87859) ("Kovacic" 0 87826) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 87814) ("KernelFunctions2" 0 87799) ("Kernel" 0 85950) ("IrredPolyOverFiniteField" 0 85910) ("Interval" 0 85863) ("IntersectionDivisorPackage" 0 85819) ("InterpolateFormsPackage" 0 85775) ("InternalRationalUnivariateRepresentationPackage" 0 85701) ("InternalPrintPackage" 0 85593) ("InterfaceGroebnerPackage" 0 85546) ("IntegrationTools" 0 85237) ("IntegrationResultToFunction" 0 85142) ("IntegrationResultRFToFunction" 0 85102) ("IntegrationResultFunctions2" 0 84903) ("IntegrationResult" 0 84531) ("IntegrationFunctionsTable" 0 84476) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 84347) ("IntegralBasisPolynomialTools" 0 84307) ("IntegerSolveLinearPolynomialEquation" 0 84295) ("IntegerRoots" 0 84110) ("IntegerRetractions" 0 84078) ("IntegerPrimesPackage" 0 83646) ("IntegerNumberTheoryFunctions" 0 83545) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 83525) ("IntegerLinearDependence" 0 83486) ("IntegerFactorizationPackage" 0 83362) ("IntegerCombinatoricFunctions" 0 83146) ("IntegerBits" 0 83115) ("Integer" 0 67353) ("InputFormFunctions1" 0 67334) ("InputForm" 0 65073) ("InnerTrigonometricManipulations" 0 64945) ("InnerTaylorSeries" 0 64855) ("InnerTable" 0 64845) ("InnerSparseUnivariatePowerSeries" 0 64748) ("InnerPrimeField" 0 64714) ("InnerPolySum" 0 64690) ("InnerPolySign" 0 64607) ("InnerPAdicInteger" 0 64567) ("InnerNumericFloatSolvePackage" 0 64470) ("InnerNumericEigenPackage" 0 64413) ("InnerNormalBasisFieldFunctions" 0 64365) ("InnerMultFact" 0 64319) ("InnerMatrixQuotientFieldFunctions" 0 64286) ("InnerMatrixLinearAlgebraFunctions" 0 64217) ("InnerIndexedTwoDimensionalArray" 0 64139) ("InnerFreeAbelianMonoid" 0 64098) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 63852) ("InnerAlgebraicNumber" 0 63832) ("InnerAlgFactor" 0 63763) ("InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField" 0 63711) ("InfinitlyClosePoint" 0 63637) ("InfiniteTuple" 0 63583) ("InfClsPt" 0 63546) ("IndexedVector" 0 63519) ("IndexedString" 0 63508) ("IndexedOneDimensionalArray" 0 63439) ("IndexedList" 0 63430) ("IndexedFlexibleArray" 0 63343) ("IndexedExponents" 0 63042) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 63021) ("IndexedDirectProductOrderedAbelianMonoid" 0 62973) ("IndexedDirectProductObject" 0 62935) ("IndexedDirectProductAbelianMonoid" 0 62855) ("IndexedDirectProductAbelianGroup" 0 62840) ("IndexedBits" 0 62831) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 62808) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 62739) ("HomogeneousDirectProduct" 0 62658) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 62646) ("HashTable" 0 62590) ("HallBasis" 0 62569) ("GuessOptionFunctions0" 0 62559) ("GuessOption" 0 62525) ("GuessFiniteFunctions" 0 62509) ("Guess" 0 62409) ("Group&" 0 NIL) ("GroebnerPackage" 0 62180) ("GroebnerInternalPackage" 0 62053) ("GrayCode" 0 62039) ("GraphicsDefaults" 0 61939) ("GraphImage" 0 61851) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 61808) ("GenusZeroIntegration" 0 61779) ("GeneralizedMultivariateFactorize" 0 61707) ("GeneralTriangularSet" 0 61648) ("GeneralSparseTable" 0 61632) ("GeneralPolynomialSet" 0 61441) ("GeneralPolynomialGcdPackage" 0 61417) ("GeneralPackageForAlgebraicFunctionField" 0 61330) ("GeneralHenselPackage" 0 61244) ("GeneralDistributedMultivariatePolynomial" 0 61159) ("GenUFactorize" 0 61107) ("GenExEuclid" 0 60933) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 60895) ("GaloisGroupPolynomialUtilities" 0 60869) ("GaloisGroupFactorizer" 0 60821) ("GaloisGroupFactorizationUtilities" 0 60778) ("FunctionalSpecialFunction" 0 60763) ("FunctionSpaceUnivariatePolynomialFactor" 0 60664) ("FunctionSpaceToUnivariatePowerSeries" 0 60624) ("FunctionSpacePrimitiveElement" 0 60547) ("FunctionSpaceIntegration" 0 60309) ("FunctionSpaceFunctions2" 0 60225) ("FunctionSpaceComplexIntegration" 0 60196) ("FunctionSpaceAttachPredicates" 0 60149) ("FunctionSpaceAssertions" 0 60082) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 60054) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 60032) ("FreeModule1" 0 59956) ("FreeModule" 0 59851) ("FreeGroup" 0 59821) ("FreeAbelianGroup" 0 59802) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 59784) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 59756) ("FractionalIdeal" 0 59588) ("FractionFreeFastGaussianFractions" 0 59578) ("FractionFreeFastGaussian" 0 59532) ("Fraction" 0 51657) ("FourierComponent" 0 51639) ("FortranType" 0 51349) ("FortranScalarType" 0 51069) ("FortranPackage" 0 50859) ("FortranOutputStackPackage" 0 50614) ("FortranExpression" 0 50449) ("FortranCode" 0 50182) ("FloatingRealPackage" 0 50161) ("FloatingPointSystem&" 0 NIL) ("Float" 0 48307) ("FlexibleArray" 0 48282) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 48248) ("FiniteLinearAggregateFunctions2" 0 48069) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSquareFreeDecomposition" 0 47988) ("FiniteFieldSolveLinearPolynomialEquation" 0 47957) ("FiniteFieldPolynomialPackage" 0 47755) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 47694) ("FiniteFieldFunctions" 0 47541) ("FiniteFieldFactorizationWithSizeParseBySideEffect" 0 47479) ("FiniteFieldExtensionByPolynomial" 0 47394) ("FiniteFieldExtension" 0 47373) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 47312) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 47176) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRingFunctions2" 0 47138) ("FiniteAbelianMonoidRing&" 0 NIL) ("Finite&" 0 NIL) ("FileName" 0 46757) ("File" 0 46703) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactorisationOverPseudoAlgebraicClosureOfRationalNumber" 0 46594) ("FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber" 0 46543) ("FactoringUtilities" 0 46455) ("FactoredFunctions2" 0 46260) ("FactoredFunctions" 0 46191) ("FactoredFunctionUtilities" 0 46076) ("Factored" 0 41594) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 41565) ("ExpressionSpaceFunctions2" 0 41467) ("ExpressionSpace&" 0 NIL) ("ExpressionSolve" 0 41444) ("ExpressionFunctions2" 0 41067) ("Expression" 0 39231) ("ExponentialOfUnivariatePuiseuxSeries" 0 39116) ("ExponentialExpansion" 0 39076) ("ExpertSystemToolsPackage2" 0 39038) ("ExpertSystemToolsPackage1" 0 39017) ("ExpertSystemToolsPackage" 0 38526) ("ExpertSystemContinuityPackage" 0 38488) ("Exit" 0 38218) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 38198) ("EuclideanGroebnerBasisPackage" 0 38168) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 37960) ("Equation" 0 34561) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 34535) ("ElementaryRischDE" 0 34509) ("ElementaryIntegration" 0 34446) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 34406) ("ElementaryFunctionsUnivariateLaurentSeries" 0 34335) ("ElementaryFunctionStructurePackage" 0 34005) ("ElementaryFunctionSign" 0 33643) ("ElementaryFunctionODESolver" 0 33610) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 33595) ("EigenPackage" 0 33571) ("DrawOptionFunctions1" 0 33546) ("DrawOptionFunctions0" 0 33342) ("DrawOption" 0 33170) ("DoubleResultantPackage" 0 33147) ("DoubleFloatVector" 0 33125) ("DoubleFloatSpecialFunctions" 0 33109) ("DoubleFloat" 0 30977) ("Divisor" 0 30754) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 30349) ("DistinctDegreeFactorize" 0 30030) ("DisplayPackage" 0 30004) ("DiscreteLogarithmPackage" 0 29979) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 29417) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 29307) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DesingTreePackage" 0 29234) ("DesingTree" 0 29147) ("DegreeReductionPackage" 0 29123) ("DefiniteIntegrationTools" 0 29043) ("Database" 0 29023) ("DataList" 0 29010) ("CyclotomicPolynomialPackage" 0 28962) ("CyclicStreamTools" 0 28928) ("CoordinateSystems" 0 28886) ("ContinuedFraction" 0 28771) ("ConstantLODE" 0 28738) ("ComplexRootPackage" 0 28679) ("ComplexPatternMatch" 0 28658) ("ComplexPattern" 0 28637) ("ComplexIntegerSolveLinearPolynomialEquation" 0 28616) ("ComplexFunctions2" 0 28584) ("ComplexFactorization" 0 28516) ("ComplexDoubleFloatVector" 0 28487) ("ComplexCategory&" 0 NIL) ("Complex" 0 27901) ("CommuteUnivariatePolynomialCategory" 0 27754) ("Commutator" 0 27733) ("CommonOperators" 0 27580) ("CommonDenominator" 0 27446) ("CombinatorialFunction" 0 27431) ("Color" 0 27332) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 27268) ("ChineseRemainderToolsForIntegralBases" 0 27228) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 27206) ("CharacterClass" 0 27133) ("Character" 0 26811) ("ChangeOfVariable" 0 26711) ("CartesianTensor" 0 26681) ("CardinalNumber" 0 25964) ("BrillhartTests" 0 25938) ("BoundIntegerRoots" 0 25904) ("Boolean" 0 7575) ("BlowUpPackage" 0 7553) ("Bits" 0 7526) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 7465) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicStochasticDifferential" 0 7438) ("BasicOperatorFunctions1" 0 7245) ("BasicOperator" 0 5838) ("BasicFunctions" 0 5804) ("BalancedPAdicInteger" 0 5778) ("BalancedFactorisation" 0 5739) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5559) ("AttributeButtons" 0 5285) ("AssociationList" 0 5133) ("AssociatedLieAlgebra" 0 5113) ("Asp9" 0 5018) ("Asp80" 0 4974) ("Asp8" 0 4879) ("Asp78" 0 4835) ("Asp77" 0 4791) ("Asp74" 0 4731) ("Asp73" 0 4671) ("Asp7" 0 4559) ("Asp6" 0 4533) ("Asp55" 0 4489) ("Asp50" 0 4445) ("Asp49" 0 4384) ("Asp42" 0 4340) ("Asp41" 0 4296) ("Asp4" 0 4236) ("Asp35" 0 4210) ("Asp34" 0 4174) ("Asp33" 0 4130) ("Asp31" 0 4069) ("Asp30" 0 4033) ("Asp29" 0 4013) ("Asp28" 0 3959) ("Asp27" 0 3939) ("Asp24" 0 3895) ("Asp20" 0 3851) ("Asp19" 0 3807) ("Asp12" 0 3763) ("Asp10" 0 3719) ("Asp1" 0 3533) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3493) ("ApplyRules" 0 3437) ("AnyFunctions1" 0 2370) ("Any" 0 1020) ("AntiSymm" 0 1002) ("AnnaNumericalOptimizationPackage" 0 981) ("AnnaNumericalIntegrationPackage" 0 952) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 779) ("AlgebraicManipulations" 0 493) ("AlgebraicIntegration" 0 467) ("AlgebraicHermiteIntegration" 0 444) ("AlgebraicFunction" 0 429) ("AlgebraGivenByStructuralConstants" 0 396) ("Algebra&" 0 NIL) ("AlgFactor" 0 289) ("Aggregate&" 0 NIL) ("AffineSpace" 0 273) ("AffinePlane" 0 88) ("AffineAlgebraicSetComputeWithResultant" 0 54) ("AffineAlgebraicSetComputeWithGroebnerBasis" 0 20) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
+(("e04ucfAnnaType" 0 237588) ("e04nafAnnaType" 0 237551) ("e04mbfAnnaType" 0 237514) ("e04jafAnnaType" 0 237477) ("e04gcfAnnaType" 0 237440) ("e04fdfAnnaType" 0 237403) ("e04dgfAnnaType" 0 237366) ("e04AgentsPackage" 0 237227) ("d03eefAnnaType" 0 237184) ("d03AgentsPackage" 0 237165) ("d02ejfAnnaType" 0 237121) ("d02cjfAnnaType" 0 237077) ("d02bhfAnnaType" 0 237033) ("d02bbfAnnaType" 0 236989) ("d02AgentsPackage" 0 236919) ("d01gbfAnnaType" 0 236883) ("d01fcfAnnaType" 0 236847) ("d01asfAnnaType" 0 236811) ("d01aqfAnnaType" 0 236775) ("d01apfAnnaType" 0 236739) ("d01anfAnnaType" 0 236703) ("d01amfAnnaType" 0 236667) ("d01alfAnnaType" 0 236631) ("d01akfAnnaType" 0 236595) ("d01ajfAnnaType" 0 236559) ("d01WeightsPackage" 0 236506) ("d01TransformFunctionType" 0 236470) ("d01AgentsPackage" 0 236217) ("XRecursivePolynomial" 0 236168) ("XPolynomialRing" 0 236141) ("XPBWPolynomial" 0 236121) ("XDistributedPolynomial" 0 236031) ("WildFunctionFieldIntegralBasis" 0 235991) ("WeightedPolynomials" 0 235959) ("Void" 0 231563) ("ViewportPackage" 0 231475) ("ViewDefaultsPackage" 0 231263) ("VectorSpace&" 0 NIL) ("VectorFunctions2" 0 230954) ("VectorCategory&" 0 NIL) ("Vector" 0 225838) ("Variable" 0 225463) ("UserDefinedPartialOrdering" 0 225401) ("UniversalSegmentFunctions2" 0 225367) ("UniversalSegment" 0 224501) ("UnivariateTaylorSeriesFunctions2" 0 224463) ("UnivariateTaylorSeriesCategory&" 0 NIL) ("UnivariateTaylorSeriesCZero" 0 224334) ("UnivariateTaylorSeries" 0 224173) ("UnivariateSkewPolynomialCategoryOps" 0 224138) ("UnivariateSkewPolynomialCategory&" 0 NIL) ("UnivariatePuiseuxSeriesWithExponentialSingularity" 0 224075) ("UnivariatePuiseuxSeriesConstructorCategory&" 0 NIL) ("UnivariatePuiseuxSeriesConstructor" 0 224015) ("UnivariatePuiseuxSeries" 0 223794) ("UnivariatePowerSeriesCategory&" 0 NIL) ("UnivariatePolynomialSquareFree" 0 223675) ("UnivariatePolynomialDivisionPackage" 0 223630) ("UnivariatePolynomialDecompositionPackage" 0 223604) ("UnivariatePolynomialCommonDenominator" 0 223391) ("UnivariatePolynomialCategoryFunctions2" 0 222267) ("UnivariatePolynomialCategory&" 0 NIL) ("UnivariatePolynomial" 0 221958) ("UnivariateLaurentSeriesFunctions2" 0 221920) ("UnivariateLaurentSeriesConstructorCategory&" 0 NIL) ("UnivariateLaurentSeriesConstructor" 0 221892) ("UnivariateLaurentSeries" 0 221792) ("UnivariateFormalPowerSeriesFunctions" 0 221782) ("UnivariateFormalPowerSeries" 0 221694) ("UniqueFactorizationDomain&" 0 NIL) ("UnaryRecursiveAggregate&" 0 NIL) ("U8Vector" 0 221681) ("U32Vector" 0 221635) ("U16Vector" 0 221621) ("TwoFactorize" 0 221568) ("TwoDimensionalViewport" 0 221395) ("TwoDimensionalPlotClipping" 0 221349) ("TwoDimensionalArrayCategory&" 0 NIL) ("TwoDimensionalArray" 0 221333) ("TubePlotTools" 0 221292) ("TubePlot" 0 221207) ("TrigonometricManipulations" 0 221022) ("TrigonometricFunctionCategory&" 0 NIL) ("TriangularSetCategory&" 0 NIL) ("TriangularMatrixOperations" 0 220832) ("Tree" 0 220790) ("TranscendentalRischDESystem" 0 220762) ("TranscendentalRischDE" 0 220718) ("TranscendentalManipulations" 0 220602) ("TranscendentalIntegration" 0 220534) ("TranscendentalHermiteIntegration" 0 220504) ("TranscendentalFunctionCategory&" 0 NIL) ("TransSolvePackageService" 0 220482) ("TopLevelDrawFunctionsForCompiledFunctions" 0 220456) ("TopLevelDrawFunctions" 0 220444) ("ToolsForSign" 0 220337) ("ThreeSpace" 0 220085) ("ThreeDimensionalViewport" 0 219958) ("ThreeDimensionalMatrix" 0 219915) ("TheSymbolTable" 0 219865) ("TextFile" 0 219824) ("TexFormat" 0 219809) ("TemplateUtilities" 0 219789) ("TaylorSolve" 0 219769) ("TaylorSeries" 0 219742) ("TangentExpansions" 0 219703) ("TabulatedComputationPackage" 0 219567) ("Tableau" 0 219547) ("TableAggregate&" 0 NIL) ("Table" 0 218892) ("SystemSolvePackage" 0 218787) ("SystemODESolver" 0 218765) ("SymmetricPolynomial" 0 218719) ("SymmetricGroupCombinatoricFunctions" 0 218670) ("SymmetricFunctions" 0 218648) ("SymbolTable" 0 218369) ("Symbol" 0 210178) ("Switch" 0 210115) ("SupFractionFactorizer" 0 210100) ("SuchThat" 0 210020) ("SubSpaceComponentProperty" 0 209926) ("SubSpace" 0 209900) ("SubResultantPackage" 0 209795) ("StringAggregate&" 0 NIL) ("String" 0 198526) ("StreamTranscendentalFunctionsNonCommutative" 0 198490) ("StreamTranscendentalFunctions" 0 198277) ("StreamTaylorSeriesOperations" 0 197848) ("StreamInfiniteProduct" 0 197782) ("StreamFunctions3" 0 197589) ("StreamFunctions2" 0 197086) ("StreamFunctions1" 0 197048) ("StreamAggregate&" 0 NIL) ("Stream" 0 195185) ("StorageEfficientMatrixOperations" 0 195174) ("Stack" 0 195136) ("SquareMatrixCategory&" 0 NIL) ("SquareMatrix" 0 195003) ("SquareFreeRegularTriangularSetGcdPackage" 0 194876) ("SquareFreeRegularTriangularSet" 0 194779) ("SquareFreeRegularSetDecompositionPackage" 0 194744) ("SquareFreeQuasiComponentPackage" 0 194567) ("SplittingTree" 0 194540) ("SplittingNode" 0 194497) ("SparseUnivariateTaylorSeries" 0 194431) ("SparseUnivariateSkewPolynomial" 0 194365) ("SparseUnivariatePolynomialFunctions2" 0 193851) ("SparseUnivariatePolynomialExpressions" 0 193817) ("SparseUnivariatePolynomial" 0 187090) ("SparseUnivariateLaurentSeries" 0 187056) ("SparseMultivariateTaylorSeries" 0 187039) ("SparseMultivariatePolynomial" 0 185782) ("SortedCache" 0 185753) ("SmithNormalForm" 0 185721) ("SingletonAsOrderedSet" 0 185024) ("SingleInteger" 0 177301) ("SimpleCell" 0 177249) ("SimpleAlgebraicExtension" 0 177118) ("SetCategory&" 0 NIL) ("SetAggregate&" 0 NIL) ("Set" 0 176680) ("SequentialDifferentialVariable" 0 176643) ("SemiGroup&" 0 NIL) ("SegmentFunctions2" 0 176528) ("SegmentBindingFunctions2" 0 176486) ("SegmentBinding" 0 176119) ("Segment" 0 175034) ("ScriptFormulaFormat" 0 175009) ("SExpressionOf" 0 174993) ("SExpression" 0 174764) ("RoutinesTable" 0 174173) ("RootsFindingPackage" 0 174037) ("Ring&" 0 NIL) ("RightOpenIntervalRootCharacterization" 0 174021) ("RewriteRule" 0 173976) ("RetractableTo&" 0 NIL) ("RetractSolvePackage" 0 173950) ("Result" 0 172879) ("RepeatedSquaring" 0 172638) ("RepeatedDoubling" 0 172455) ("RegularTriangularSetGcdPackage" 0 172397) ("RegularTriangularSetCategory&" 0 NIL) ("RegularTriangularSet" 0 172380) ("RegularSetDecompositionPackage" 0 172355) ("RegularChain" 0 172300) ("Reference" 0 171917) ("ReductionOfOrder" 0 171884) ("ReduceLODE" 0 171862) ("RecursivePolynomialCategory&" 0 NIL) ("RecursiveAggregate&" 0 NIL) ("RecurrenceOperator" 0 171852) ("RectangularMatrixCategory&" 0 NIL) ("RealZeroPackage" 0 171772) ("RealSolvePackage" 0 171744) ("RealRootCharacterizationCategory&" 0 NIL) ("RealPolynomialUtilitiesPackage" 0 171689) ("RealNumberSystem&" 0 NIL) ("RealClosure" 0 171657) ("RealClosedField&" 0 NIL) ("RationalRicDE" 0 171567) ("RationalLODE" 0 171428) ("RationalIntegration" 0 171307) ("RationalFunctionSign" 0 171249) ("RationalFunctionIntegration" 0 171215) ("RationalFunctionFactor" 0 171182) ("RationalFunction" 0 171134) ("RationalFactorize" 0 170904) ("RandomNumberSource" 0 170824) ("RadixExpansion" 0 170762) ("RadicalSolvePackage" 0 170740) ("RadicalCategory&" 0 NIL) ("QuotientFieldCategoryFunctions2" 0 170717) ("QuotientFieldCategory&" 0 NIL) ("Queue" 0 170705) ("QueryEquation" 0 170692) ("QuaternionCategory&" 0 NIL) ("Quaternion" 0 170679) ("QuasiComponentPackage" 0 170565) ("QuasiAlgebraicSet" 0 170542) ("QuadraticForm" 0 170522) ("PushVariables" 0 170495) ("PureAlgebraicIntegration" 0 170418) ("PseudoRemainderSequence" 0 170333) ("PseudoLinearNormalForm" 0 170313) ("PseudoAlgebraicClosureOfRationalNumber" 0 170196) ("PseudoAlgebraicClosureOfFiniteField" 0 169925) ("ProjectiveSpace" 0 169905) ("ProjectivePlaneOverPseudoAlgebraicClosureOfFiniteField" 0 169792) ("ProjectivePlane" 0 169687) ("ProjectiveAlgebraicSetPackage" 0 169594) ("Product" 0 169553) ("PrintPackage" 0 169527) ("PrimitiveRatRicDE" 0 169509) ("PrimitiveRatDE" 0 169456) ("PrimitiveElement" 0 169422) ("PrimitiveArray" 0 168591) ("PrimeField" 0 168498) ("PrecomputedAssociatedEquations" 0 168474) ("PowerSeriesLimitPackage" 0 168382) ("PowerSeriesCategory&" 0 NIL) ("PositiveInteger" 0 158593) ("PolynomialSquareFree" 0 158569) ("PolynomialSolveByFormulas" 0 158545) ("PolynomialSetUtilitiesPackage" 0 158148) ("PolynomialSetCategory&" 0 NIL) ("PolynomialRoots" 0 158045) ("PolynomialRing" 0 157877) ("PolynomialPackageForCurve" 0 157780) ("PolynomialNumberTheoryFunctions" 0 157726) ("PolynomialInterpolationAlgorithms" 0 157698) ("PolynomialIdeals" 0 157647) ("PolynomialGcdPackage" 0 157571) ("PolynomialFunctions2" 0 157375) ("PolynomialFactorizationExplicit&" 0 NIL) ("PolynomialFactorizationByRecursionUnivariate" 0 157312) ("PolynomialFactorizationByRecursion" 0 157288) ("PolynomialDecomposition" 0 157258) ("PolynomialCategoryQuotientFunctions" 0 156859) ("PolynomialCategoryLifting" 0 156224) ("PolynomialCategory&" 0 NIL) ("Polynomial" 0 153811) ("PolyGroebner" 0 153765) ("PolToPol" 0 153728) ("PointsOfFiniteOrderTools" 0 153674) ("PointsOfFiniteOrder" 0 153651) ("PointPackage" 0 153510) ("Point" 0 153074) ("PoincareBirkhoffWittLyndonBasis" 0 153037) ("PlotTools" 0 153022) ("Plot3D" 0 152955) ("Plot" 0 152818) ("Plcs" 0 152759) ("PlaneAlgebraicCurvePlot" 0 152715) ("PlacesOverPseudoAlgebraicClosureOfFiniteField" 0 152663) ("Places" 0 152626) ("PiCoercions" 0 152604) ("Pi" 0 152568) ("PermutationGroup" 0 152539) ("Permutation" 0 152444) ("PatternMatchTools" 0 152381) ("PatternMatchSymbol" 0 152370) ("PatternMatchResultFunctions2" 0 152323) ("PatternMatchResult" 0 150905) ("PatternMatchQuotientFieldCategory" 0 150878) ("PatternMatchPushDown" 0 150757) ("PatternMatchPolynomialCategory" 0 150720) ("PatternMatchListResult" 0 150675) ("PatternMatchListAggregate" 0 150658) ("PatternMatchKernel" 0 150615) ("PatternMatchIntegration" 0 150496) ("PatternMatchIntegerNumberSystem" 0 150471) ("PatternMatchFunctionSpace" 0 150456) ("PatternFunctions1" 0 150386) ("Pattern" 0 148853) ("PartitionsAndPermutations" 0 148753) ("Partition" 0 148636) ("PartialDifferentialRing&" 0 NIL) ("ParametrizationPackage" 0 148517) ("ParametricSurface" 0 148417) ("ParametricSpaceCurve" 0 148314) ("ParametricPlaneCurve" 0 148211) ("ParadoxicalCombinatorsForStreams" 0 148010) ("Palette" 0 147808) ("PackageForPoly" 0 147501) ("PAdicRationalConstructor" 0 147459) ("PAdicInteger" 0 147441) ("OutputPackage" 0 147071) ("OutputForm" 0 137224) ("OrderlyDifferentialVariable" 0 137118) ("OrderlyDifferentialPolynomial" 0 137085) ("OrderedVariableList" 0 136532) ("OrderedSet&" 0 NIL) ("OrderedRing&" 0 NIL) ("OrderedFreeMonoid" 0 136380) ("OrderedCompletionFunctions2" 0 136309) ("OrderedCompletion" 0 135526) ("OrdSetInts" 0 135492) ("OpenMathPackage" 0 135466) ("OpenMathErrorKind" 0 135448) ("OpenMathEncoding" 0 135270) ("OpenMathDevice" 0 135088) ("OpenMathConnection" 0 135062) ("OnePointCompletionFunctions2" 0 135029) ("OnePointCompletion" 0 134216) ("OneDimensionalArrayAggregate&" 0 NIL) ("OneDimensionalArray" 0 134147) ("OctonionCategory&" 0 NIL) ("ODETools" 0 134099) ("ODEIntensityFunctionsTable" 0 134036) ("ODEIntegration" 0 133927) ("NumericalPDEProblem" 0 133884) ("NumericalOptimizationProblem" 0 133828) ("NumericalODEProblem" 0 133784) ("NumericalIntegrationProblem" 0 133721) ("NumericTubePlot" 0 133675) ("NumericRealEigenPackage" 0 133654) ("Numeric" 0 133615) ("NumberTheoreticPolynomialFunctions" 0 133585) ("NumberFormats" 0 133555) ("NormalizationPackage" 0 133382) ("NoneFunctions1" 0 133347) ("None" 0 133046) ("NonNegativeInteger" 0 117109) ("NonLinearSolvePackage" 0 117091) ("NonLinearFirstOrderODESolver" 0 117059) ("NonAssociativeRng&" 0 NIL) ("NonAssociativeRing&" 0 NIL) ("NonAssociativeAlgebra&" 0 NIL) ("NewtonPolygon" 0 117041) ("NewtonInterpolation" 0 117031) ("NewSparseUnivariatePolynomialFunctions2" 0 116995) ("NewSparseUnivariatePolynomial" 0 116917) ("NewSparseMultivariatePolynomial" 0 116805) ("NeitherSparseOrDensePowerSeries" 0 116718) ("NagPartialDifferentialEquationsPackage" 0 116699) ("NagOrdinaryDifferentialEquationsPackage" 0 116629) ("NagOptimisationPackage" 0 116473) ("NagIntegrationPackage" 0 116301) ("NagEigenPackage" 0 116280) ("NPCoef" 0 116256) ("NAGLinkSupportPackage" 0 115844) ("MyUnivariatePolynomial" 0 115827) ("MyExpression" 0 115797) ("MultivariateSquareFree" 0 115733) ("MultivariateLifting" 0 115645) ("MultivariateFactorize" 0 115312) ("Multiset" 0 115253) ("MultipleMap" 0 115178) ("MultiVariableCalculusFunctions" 0 115084) ("MultFiniteFactorize" 0 115010) ("MoreSystemCommands" 0 114931) ("MonomialExtensionTools" 0 114812) ("MonoidRing" 0 114787) ("Monoid&" 0 NIL) ("MonogenicAlgebra&" 0 NIL) ("MonadWithUnit&" 0 NIL) ("Monad&" 0 NIL) ("MoebiusTransform" 0 114765) ("ModuleOperator" 0 114752) ("ModuleMonomial" 0 114724) ("Module&" 0 NIL) ("ModularRing" 0 114684) ("ModularHermitianRowReduction" 0 114479) ("ModularDistinctDegreeFactorizer" 0 114422) ("ModMonic" 0 114312) ("MeshCreationRoutinesForThreeDimensions" 0 114266) ("MergeThing" 0 114253) ("MatrixLinearAlgebraFunctions" 0 114226) ("MatrixCommonDenominator" 0 114116) ("MatrixCategoryFunctions2" 0 113735) ("MatrixCategory&" 0 NIL) ("Matrix" 0 108851) ("MappingPackageInternalHacks3" 0 108831) ("MappingPackageInternalHacks2" 0 108811) ("MappingPackageInternalHacks1" 0 108791) ("MappingPackage1" 0 108697) ("MakeUnaryCompiledFunction" 0 108637) ("MakeFunction" 0 108578) ("MakeFloatCompiledFunction" 0 108514) ("MakeBinaryCompiledFunction" 0 108466) ("Magma" 0 108435) ("MachineInteger" 0 108401) ("MachineFloat" 0 108332) ("MRationalFactorize" 0 108168) ("MPolyCatRationalFunctionFactorizer" 0 108058) ("MPolyCatPolyFactorizer" 0 108021) ("MPolyCatFunctions3" 0 108008) ("MPolyCatFunctions2" 0 107921) ("LyndonWord" 0 107834) ("Logic&" 0 NIL) ("Localize" 0 107817) ("LocalParametrizationOfSimplePointPackage" 0 107724) ("LocalAlgebra" 0 107711) ("ListToMap" 0 107660) ("ListMultiDictionary" 0 107628) ("ListMonoidOps" 0 107576) ("ListFunctions2" 0 107136) ("ListAggregate&" 0 NIL) ("List" 0 89330) ("LiouvillianFunction" 0 89289) ("LinesOpPack" 0 89224) ("LinearSystemPolynomialPackage" 0 89201) ("LinearSystemMatrixPackage" 0 88867) ("LinearSystemFromPowerSeriesPackage" 0 88839) ("LinearPolynomialEquationByFractions" 0 88718) ("LinearOrdinaryDifferentialOperatorsOps" 0 88679) ("LinearOrdinaryDifferentialOperatorFactorizer" 0 88646) ("LinearOrdinaryDifferentialOperatorCategory&" 0 NIL) ("LinearOrdinaryDifferentialOperator2" 0 88613) ("LinearOrdinaryDifferentialOperator1" 0 88449) ("LinearOrdinaryDifferentialOperator" 0 88371) ("LinearDependence" 0 88343) ("LinearAggregate&" 0 NIL) ("LinGroebnerPackage" 0 88306) ("LiePolynomial" 0 88269) ("LieAlgebra&" 0 NIL) ("LexTriangularPackage" 0 88237) ("LeftAlgebra&" 0 NIL) ("LeadingCoefDetermination" 0 88197) ("LazyStreamAggregate&" 0 NIL) ("LaurentPolynomial" 0 88126) ("Kovacic" 0 88093) ("KeyedDictionary&" 0 NIL) ("KeyedAccessFile" 0 88081) ("KernelFunctions2" 0 88066) ("Kernel" 0 86217) ("IrredPolyOverFiniteField" 0 86177) ("Interval" 0 86130) ("IntersectionDivisorPackage" 0 86086) ("InterpolateFormsPackage" 0 86042) ("InternalRationalUnivariateRepresentationPackage" 0 85968) ("InternalPrintPackage" 0 85860) ("InterfaceGroebnerPackage" 0 85813) ("IntegrationTools" 0 85504) ("IntegrationResultToFunction" 0 85409) ("IntegrationResultRFToFunction" 0 85369) ("IntegrationResultFunctions2" 0 85170) ("IntegrationResult" 0 84798) ("IntegrationFunctionsTable" 0 84743) ("IntegralDomain&" 0 NIL) ("IntegralBasisTools" 0 84614) ("IntegralBasisPolynomialTools" 0 84574) ("IntegerSolveLinearPolynomialEquation" 0 84562) ("IntegerRoots" 0 84377) ("IntegerRetractions" 0 84345) ("IntegerPrimesPackage" 0 83913) ("IntegerNumberTheoryFunctions" 0 83812) ("IntegerNumberSystem&" 0 NIL) ("IntegerMod" 0 83792) ("IntegerLinearDependence" 0 83753) ("IntegerFactorizationPackage" 0 83629) ("IntegerCombinatoricFunctions" 0 83413) ("IntegerBits" 0 83382) ("Integer" 0 67607) ("InputFormFunctions1" 0 67588) ("InputForm" 0 65327) ("InnerTrigonometricManipulations" 0 65199) ("InnerTaylorSeries" 0 65109) ("InnerTable" 0 65099) ("InnerSparseUnivariatePowerSeries" 0 65002) ("InnerPrimeField" 0 64968) ("InnerPolySum" 0 64944) ("InnerPolySign" 0 64861) ("InnerPAdicInteger" 0 64821) ("InnerNumericFloatSolvePackage" 0 64724) ("InnerNumericEigenPackage" 0 64667) ("InnerNormalBasisFieldFunctions" 0 64619) ("InnerMultFact" 0 64573) ("InnerMatrixQuotientFieldFunctions" 0 64540) ("InnerMatrixLinearAlgebraFunctions" 0 64471) ("InnerIndexedTwoDimensionalArray" 0 64393) ("InnerFreeAbelianMonoid" 0 64352) ("InnerEvalable&" 0 NIL) ("InnerCommonDenominator" 0 64106) ("InnerAlgebraicNumber" 0 64086) ("InnerAlgFactor" 0 64017) ("InfinitlyClosePointOverPseudoAlgebraicClosureOfFiniteField" 0 63965) ("InfinitlyClosePoint" 0 63891) ("InfiniteTuple" 0 63837) ("InfClsPt" 0 63800) ("IndexedVector" 0 63773) ("IndexedString" 0 63762) ("IndexedOneDimensionalArray" 0 63693) ("IndexedList" 0 63684) ("IndexedFlexibleArray" 0 63597) ("IndexedExponents" 0 63296) ("IndexedDirectProductOrderedAbelianMonoidSup" 0 63275) ("IndexedDirectProductOrderedAbelianMonoid" 0 63227) ("IndexedDirectProductObject" 0 63189) ("IndexedDirectProductAbelianMonoid" 0 63109) ("IndexedDirectProductAbelianGroup" 0 63094) ("IndexedBits" 0 63085) ("IndexedAggregate&" 0 NIL) ("IdealDecompositionPackage" 0 63062) ("HyperbolicFunctionCategory&" 0 NIL) ("HomogeneousDistributedMultivariatePolynomial" 0 62993) ("HomogeneousDirectProduct" 0 62912) ("HomogeneousAggregate&" 0 NIL) ("HeuGcd" 0 62900) ("HashTable" 0 62844) ("HallBasis" 0 62823) ("GuessOptionFunctions0" 0 62813) ("GuessOption" 0 62779) ("GuessFiniteFunctions" 0 62763) ("Guess" 0 62663) ("Group&" 0 NIL) ("GroebnerPackage" 0 62434) ("GroebnerInternalPackage" 0 62307) ("GrayCode" 0 62293) ("GraphicsDefaults" 0 62193) ("GraphImage" 0 62105) ("GradedModule&" 0 NIL) ("GradedAlgebra&" 0 NIL) ("GosperSummationMethod" 0 62062) ("GenusZeroIntegration" 0 62033) ("GeneralizedMultivariateFactorize" 0 61961) ("GeneralTriangularSet" 0 61902) ("GeneralSparseTable" 0 61886) ("GeneralPolynomialSet" 0 61695) ("GeneralPolynomialGcdPackage" 0 61671) ("GeneralPackageForAlgebraicFunctionField" 0 61584) ("GeneralHenselPackage" 0 61498) ("GeneralDistributedMultivariatePolynomial" 0 61413) ("GenUFactorize" 0 61361) ("GenExEuclid" 0 61187) ("GcdDomain&" 0 NIL) ("GaloisGroupUtilities" 0 61149) ("GaloisGroupPolynomialUtilities" 0 61123) ("GaloisGroupFactorizer" 0 61075) ("GaloisGroupFactorizationUtilities" 0 61032) ("FunctionalSpecialFunction" 0 61017) ("FunctionSpaceUnivariatePolynomialFactor" 0 60918) ("FunctionSpaceToUnivariatePowerSeries" 0 60878) ("FunctionSpacePrimitiveElement" 0 60801) ("FunctionSpaceIntegration" 0 60563) ("FunctionSpaceFunctions2" 0 60479) ("FunctionSpaceComplexIntegration" 0 60450) ("FunctionSpaceAttachPredicates" 0 60403) ("FunctionSpaceAssertions" 0 60336) ("FunctionSpace&" 0 NIL) ("FunctionFieldCategoryFunctions2" 0 60308) ("FunctionFieldCategory&" 0 NIL) ("FullyRetractableTo&" 0 NIL) ("FullyLinearlyExplicitRingOver&" 0 NIL) ("FullyEvalableOver&" 0 NIL) ("FreeMonoid" 0 60286) ("FreeModule1" 0 60210) ("FreeModule" 0 60105) ("FreeGroup" 0 60075) ("FreeAbelianGroup" 0 60056) ("FramedNonAssociativeAlgebra&" 0 NIL) ("FramedModule" 0 60038) ("FramedAlgebra&" 0 NIL) ("FractionalIdealFunctions2" 0 60010) ("FractionalIdeal" 0 59842) ("FractionFreeFastGaussianFractions" 0 59832) ("FractionFreeFastGaussian" 0 59786) ("Fraction" 0 51868) ("FourierComponent" 0 51850) ("FortranType" 0 51560) ("FortranScalarType" 0 51280) ("FortranPackage" 0 51070) ("FortranOutputStackPackage" 0 50825) ("FortranExpression" 0 50660) ("FortranCode" 0 50393) ("FloatingRealPackage" 0 50372) ("FloatingPointSystem&" 0 NIL) ("Float" 0 48518) ("FlexibleArray" 0 48493) ("FiniteSetAggregate&" 0 NIL) ("FiniteRankNonAssociativeAlgebra&" 0 NIL) ("FiniteRankAlgebra&" 0 NIL) ("FiniteLinearAggregateSort" 0 48459) ("FiniteLinearAggregateFunctions2" 0 48280) ("FiniteLinearAggregate&" 0 NIL) ("FiniteFieldSquareFreeDecomposition" 0 48199) ("FiniteFieldSolveLinearPolynomialEquation" 0 48168) ("FiniteFieldPolynomialPackage" 0 47966) ("FiniteFieldNormalBasisExtensionByPolynomial" 0 47905) ("FiniteFieldFunctions" 0 47752) ("FiniteFieldFactorizationWithSizeParseBySideEffect" 0 47690) ("FiniteFieldExtensionByPolynomial" 0 47605) ("FiniteFieldExtension" 0 47584) ("FiniteFieldCyclicGroupExtensionByPolynomial" 0 47523) ("FiniteFieldCategory&" 0 NIL) ("FiniteDivisorCategory&" 0 NIL) ("FiniteDivisor" 0 47387) ("FiniteAlgebraicExtensionField&" 0 NIL) ("FiniteAbelianMonoidRingFunctions2" 0 47349) ("FiniteAbelianMonoidRing&" 0 NIL) ("Finite&" 0 NIL) ("FileName" 0 46968) ("File" 0 46914) ("FieldOfPrimeCharacteristic&" 0 NIL) ("Field&" 0 NIL) ("FactorisationOverPseudoAlgebraicClosureOfRationalNumber" 0 46805) ("FactorisationOverPseudoAlgebraicClosureOfAlgExtOfRationalNumber" 0 46754) ("FactoringUtilities" 0 46666) ("FactoredFunctions2" 0 46471) ("FactoredFunctions" 0 46402) ("FactoredFunctionUtilities" 0 46287) ("Factored" 0 41805) ("ExtensionField&" 0 NIL) ("ExtensibleLinearAggregate&" 0 NIL) ("ExtAlgBasis" 0 41776) ("ExpressionSpaceFunctions2" 0 41678) ("ExpressionSpace&" 0 NIL) ("ExpressionSolve" 0 41655) ("ExpressionFunctions2" 0 41278) ("Expression" 0 39442) ("ExponentialOfUnivariatePuiseuxSeries" 0 39327) ("ExponentialExpansion" 0 39287) ("ExpertSystemToolsPackage2" 0 39249) ("ExpertSystemToolsPackage1" 0 39228) ("ExpertSystemToolsPackage" 0 38737) ("ExpertSystemContinuityPackage" 0 38699) ("Exit" 0 38429) ("Evalable&" 0 NIL) ("EuclideanModularRing" 0 38409) ("EuclideanGroebnerBasisPackage" 0 38379) ("EuclideanDomain&" 0 NIL) ("ErrorFunctions" 0 38171) ("Equation" 0 34772) ("EltableAggregate&" 0 NIL) ("ElementaryRischDESystem" 0 34746) ("ElementaryRischDE" 0 34720) ("ElementaryIntegration" 0 34657) ("ElementaryFunctionsUnivariatePuiseuxSeries" 0 34617) ("ElementaryFunctionsUnivariateLaurentSeries" 0 34546) ("ElementaryFunctionStructurePackage" 0 34216) ("ElementaryFunctionSign" 0 33854) ("ElementaryFunctionODESolver" 0 33821) ("ElementaryFunctionCategory&" 0 NIL) ("ElementaryFunction" 0 33806) ("EigenPackage" 0 33782) ("DrawOptionFunctions1" 0 33757) ("DrawOptionFunctions0" 0 33553) ("DrawOption" 0 33381) ("DoubleResultantPackage" 0 33358) ("DoubleFloatVector" 0 33336) ("DoubleFloatSpecialFunctions" 0 33320) ("DoubleFloat" 0 31188) ("Divisor" 0 30965) ("DivisionRing&" 0 NIL) ("DistributedMultivariatePolynomial" 0 30560) ("DistinctDegreeFactorize" 0 30241) ("DisplayPackage" 0 30215) ("DiscreteLogarithmPackage" 0 30190) ("DirectProductCategory&" 0 NIL) ("DirectProduct" 0 29628) ("DifferentialVariableCategory&" 0 NIL) ("DifferentialSparseMultivariatePolynomial" 0 29518) ("DifferentialRing&" 0 NIL) ("DifferentialPolynomialCategory&" 0 NIL) ("DifferentialExtension&" 0 NIL) ("DictionaryOperations&" 0 NIL) ("Dictionary&" 0 NIL) ("DesingTreePackage" 0 29445) ("DesingTree" 0 29358) ("DegreeReductionPackage" 0 29334) ("DefiniteIntegrationTools" 0 29254) ("Database" 0 29234) ("DataList" 0 29221) ("CylindricalAlgebraicDecompositionUtilities" 0 29163) ("CyclotomicPolynomialPackage" 0 29115) ("CyclicStreamTools" 0 29081) ("CoordinateSystems" 0 29039) ("ContinuedFraction" 0 28924) ("ConstantLODE" 0 28891) ("ComplexRootPackage" 0 28832) ("ComplexPatternMatch" 0 28811) ("ComplexPattern" 0 28790) ("ComplexIntegerSolveLinearPolynomialEquation" 0 28769) ("ComplexFunctions2" 0 28737) ("ComplexFactorization" 0 28669) ("ComplexDoubleFloatVector" 0 28640) ("ComplexCategory&" 0 NIL) ("Complex" 0 28054) ("CommuteUnivariatePolynomialCategory" 0 27907) ("Commutator" 0 27886) ("CommonOperators" 0 27733) ("CommonDenominator" 0 27599) ("CombinatorialFunction" 0 27584) ("Color" 0 27485) ("Collection&" 0 NIL) ("CoerceVectorMatrixPackage" 0 27421) ("ChineseRemainderToolsForIntegralBases" 0 27381) ("CharacteristicPolynomialInMonogenicalAlgebra" 0 27359) ("CharacterClass" 0 27286) ("Character" 0 26964) ("ChangeOfVariable" 0 26864) ("Cell" 0 26819) ("CartesianTensor" 0 26789) ("CardinalNumber" 0 26072) ("BrillhartTests" 0 26046) ("BoundIntegerRoots" 0 26012) ("Boolean" 0 7575) ("BlowUpPackage" 0 7553) ("Bits" 0 7526) ("BitAggregate&" 0 NIL) ("BinaryTreeCategory&" 0 NIL) ("BinaryTree" 0 7465) ("BinaryRecursiveAggregate&" 0 NIL) ("BasicType&" 0 NIL) ("BasicStochasticDifferential" 0 7438) ("BasicOperatorFunctions1" 0 7245) ("BasicOperator" 0 5838) ("BasicFunctions" 0 5804) ("BalancedPAdicInteger" 0 5778) ("BalancedFactorisation" 0 5739) ("BagAggregate&" 0 NIL) ("Automorphism" 0 5559) ("AttributeButtons" 0 5285) ("AssociationList" 0 5133) ("AssociatedLieAlgebra" 0 5113) ("Asp9" 0 5018) ("Asp80" 0 4974) ("Asp8" 0 4879) ("Asp78" 0 4835) ("Asp77" 0 4791) ("Asp74" 0 4731) ("Asp73" 0 4671) ("Asp7" 0 4559) ("Asp6" 0 4533) ("Asp55" 0 4489) ("Asp50" 0 4445) ("Asp49" 0 4384) ("Asp42" 0 4340) ("Asp41" 0 4296) ("Asp4" 0 4236) ("Asp35" 0 4210) ("Asp34" 0 4174) ("Asp33" 0 4130) ("Asp31" 0 4069) ("Asp30" 0 4033) ("Asp29" 0 4013) ("Asp28" 0 3959) ("Asp27" 0 3939) ("Asp24" 0 3895) ("Asp20" 0 3851) ("Asp19" 0 3807) ("Asp12" 0 3763) ("Asp10" 0 3719) ("Asp1" 0 3533) ("ArcTrigonometricFunctionCategory&" 0 NIL) ("ApplyUnivariateSkewPolynomial" 0 3493) ("ApplyRules" 0 3437) ("AnyFunctions1" 0 2370) ("Any" 0 1020) ("AntiSymm" 0 1002) ("AnnaNumericalOptimizationPackage" 0 981) ("AnnaNumericalIntegrationPackage" 0 952) ("AlgebraicallyClosedFunctionSpace&" 0 NIL) ("AlgebraicallyClosedField&" 0 NIL) ("AlgebraicNumber" 0 779) ("AlgebraicManipulations" 0 493) ("AlgebraicIntegration" 0 467) ("AlgebraicHermiteIntegration" 0 444) ("AlgebraicFunction" 0 429) ("AlgebraGivenByStructuralConstants" 0 396) ("Algebra&" 0 NIL) ("AlgFactor" 0 289) ("Aggregate&" 0 NIL) ("AffineSpace" 0 273) ("AffinePlane" 0 88) ("AffineAlgebraicSetComputeWithResultant" 0 54) ("AffineAlgebraicSetComputeWithGroebnerBasis" 0 20) ("AbelianSemiGroup&" 0 NIL) ("AbelianMonoidRing&" 0 NIL) ("AbelianMonoid&" 0 NIL) ("AbelianGroup&" 0 NIL))
\ No newline at end of file
